(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   2652927,      60561]
NotebookOptionsPosition[   2642596,      60338]
NotebookOutlinePosition[   2643018,      60354]
CellTagsIndexPosition[   2642975,      60351]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LATTICEEASY NOTEBOOK: Spectra", "Title",
 CellChangeTimes->{
  3.7174401524416075`*^9},ExpressionUUID->"647ae26a-0dfd-4da5-9dec-\
e031ea6f6415"],

Cell["\<\
This notebook produces plots of spectra from the output of the latticeeasy \
program.
Last modified: 10/19/17\
\>", "Text",
 CellChangeTimes->{{3.7174401484273477`*^9, 3.717440162773382*^9}, {
  3.7174485351852736`*^9, 
  3.717448540200205*^9}},ExpressionUUID->"640a50f2-602b-4e60-918a-\
dc10b0712773"],

Cell["Clear all variables to avoid naming conflicts.", "Text",
 CellChangeTimes->{{3.7173593539180403`*^9, 
  3.717359364375927*^9}},ExpressionUUID->"92a70921-2b96-45c9-ab5e-\
c2fd9df0fb0e"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7173584246909575`*^9, 
  3.7173584246929617`*^9}},ExpressionUUID->"ff631b0f-5c88-4747-8849-\
2106354cba40"],

Cell[CellGroupData[{

Cell["\<\
PARAMETERS: Set parameters for where to read data and what to plot\
\>", "Section",
 CellChangeTimes->{
  3.717440194863881*^9},ExpressionUUID->"f6388f7c-32e9-4027-a88a-\
9cb9ca3112da"],

Cell[TextData[StyleBox["All binary parameters are set to 1 for yes and 0 for \
no.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.717440190392207*^9, 
  3.7174402035079317`*^9}},ExpressionUUID->"a11f6c1f-d9df-4210-8ae3-\
482ec5295260"],

Cell["\<\
The number of labels should be at least as large as the number of fields. \
Additional labels will be ignored.\
\>", "Text",ExpressionUUID->"4a2226d2-1f00-403c-b1f2-07a8632f8e50"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"label", "[", "0", "]"}], "=", "\"\<\[Phi]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "1", "]"}], "=", "\"\<\[Chi]\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.717448182775401*^9, 
  3.7174481882166743`*^9}},ExpressionUUID->"ce530a0c-cdd3-451e-9d9e-\
68661d11a4c3"],

Cell["\<\
The run variables are
  dir - The directory where the files are stored
  ext - The extension of the data files
  nflds - The number of fields in the simulations\
\>", "Text",
 CellChangeTimes->{{3.7174402201295547`*^9, 3.7174402214530697`*^9}, {
  3.717440261982934*^9, 
  3.7174402624820094`*^9}},ExpressionUUID->"9df98c66-da92-4bd4-a460-\
62d7067e867a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"run", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dir", "[", "run", "]"}], "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{
   RowBox[{"ext", "[", "run", "]"}], "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{
   RowBox[{"nflds", "[", "run", "]"}], "=", "2"}], ";", 
  RowBox[{"run", "++"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numruns", "=", "run"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"nfldsmax", "=", 
   RowBox[{"Max", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"nflds", "[", "run", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"run", ",", "0", ",", 
        RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.422107888545641*^9, 3.423922610698845*^9, {3.445191121169889*^9, 
   3.445191129007491*^9}, {3.7174402889097395`*^9, 
   3.7174402951317234`*^9}},ExpressionUUID->"455df81f-858a-46a4-970b-\
7d4dbc4742b3"],

Cell["\<\
The parameters cutir and cutuv determine how many frequencies to leave out of \
the spectrum plots from the IR and UV ends of the spectrum respectively. This \
feature can be useful because the extreme ends of the spectra are based on \
very few points and are thus less reliable than the points in the middle. For \
example setting cutir=1 avoids plotting the zeromode. These settings will not \
affect the calculation of n (=Integral(n_k)), which automatically uses all \
frequencies except the zeromode.\
\>", "Text",ExpressionUUID->"b97756e8-b54c-4a9c-82fc-958cb0382575"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cutir", "=", "2"}], ";", 
  RowBox[{"cutuv", "=", "1"}], ";"}]], "Input",ExpressionUUID->"11367dc8-0d41-\
4b1d-8d23-12e2c9d26249"],

Cell["\<\
The four parameters do<> control whether or not to calculate each kind of \
spectrum. The parameters plot<> controls whether to make separate plots of \
that spectrum at a range of times. If do<>=1 for a particular spectrum the \
plots at all times will be shown together on one plot (even if plot<>=0). The \
parameter plotsomething is set to 1 if any spectra are being plotted at \
individual times. See the DATA section below.
  power - Power spectrum k^(kexponent)|f_k|^2.
  fdpower - Power spectrum |f_k'|^2.
  number - Number density n_k.
  energy - Energy density rho_k.\
\>", "Text",ExpressionUUID->"d3f0a529-3981-4da3-8802-e2e886131cb8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dopower", "=", "1"}], ";", 
  RowBox[{"plotpower", "=", "1"}], ";", 
  RowBox[{"kexponent", "=", "2"}], ";", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"dopower", "\[Equal]", "0"}], ",", 
    RowBox[{"plotpower", "=", "0"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dofdpower", "=", "1"}], ";", 
  RowBox[{"plotfdpower", "=", "1"}], ";", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"dofdpower", "\[Equal]", "0"}], ",", 
    RowBox[{"plotfdpower", "=", "0"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"donumber", "=", "1"}], ";", 
  RowBox[{"plotnumber", "=", "1"}], ";", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"donumber", "\[Equal]", "0"}], ",", 
    RowBox[{"plotnumber", "=", "0"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"doenergy", "=", "1"}], ";", 
  RowBox[{"plotenergy", "=", "1"}], ";", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"doenergy", "\[Equal]", "0"}], ",", 
    RowBox[{"plotenergy", "=", "0"}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"plotpower", "\[Equal]", "0"}], " ", "&&", " ", 
     RowBox[{"plotfdpower", "\[Equal]", "0"}], " ", "&&", " ", 
     RowBox[{"plotnumber", "\[Equal]", "0"}], " ", "&&", " ", 
     RowBox[{"plotenergy", "\[Equal]", "0"}]}], ",", 
    RowBox[{"plotsomething", "=", "0"}], ",", 
    RowBox[{"plotsomething", "=", "1"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.423922617378018*^9, 3.423922624603045*^9}, {
  3.445191133746305*^9, 3.445191138434103*^9}, {3.717440345268284*^9, 
  3.7174403582092657`*^9}},ExpressionUUID->"703ff8f5-efb2-4dfa-9b2c-\
0fb9c7ff4a5d"]
}, Closed]],

Cell[CellGroupData[{

Cell["DATA: Read in data and make tables", "Section",
 CellChangeTimes->{
  3.7174403845099506`*^9},ExpressionUUID->"d1ffe392-1495-4f30-b8ea-\
d93a51dd6529"],

Cell["Read in times at which spectra were recorded.", "Text",ExpressionUUID->"c38a4233-03c0-4297-a19d-8d4e21baf914"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"timetable", "[", "run", "]"}], "=", 
      RowBox[{"ReadList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"dir", "[", "run", "]"}], "<>", "\"\<spectratimes\>\"", "<>", 
         RowBox[{"ext", "[", "run", "]"}]}], ",", "Real"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"numtimes", "[", "run", "]"}], "=", 
      RowBox[{"Count", "[", 
       RowBox[{
        RowBox[{"timetable", "[", "run", "]"}], ",", "_Real"}], "]"}]}], 
     ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"numtimesmax", "=", 
  RowBox[{"Max", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"numtimes", "[", "run", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"run", ",", "0", ",", 
       RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]}], "Input",Exp\
ressionUUID->"20954f38-80a4-406e-a851-1e63061d85d3"],

Cell[BoxData["21"], "Output",
 CellChangeTimes->{3.4221081870044966`*^9, 3.4221102105589733`*^9, 
  3.423922630326469*^9, 3.424185037342954*^9, 3.445191151299864*^9, 
  3.71744309015497*^9},ExpressionUUID->"cc223350-5cc4-402a-9490-30e6d172faa6"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"fld", "=", "0"}], ",", 
       RowBox[{"fld", "<", 
        RowBox[{"nflds", "[", "run", "]"}]}], ",", 
       RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", "]"}], "=", 
         RowBox[{"ReadList", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"dir", "[", "run", "]"}], "<>", "\"\<spectra\>\"", "<>", 
            RowBox[{"ToString", "[", "fld", "]"}], "<>", 
            RowBox[{"ext", "[", "run", "]"}]}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", "7", "}"}]}], "]"}]}], "]"}]}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",ExpressionUUID->"55dd7ff1-d5ce-47d8-bebb-0fe8084e65a7"],

Cell["\<\
Number of frequencies in each spectrum. (The number plotted may be smaller if \
cutir or cutuv > 0.)\
\>", "Text",ExpressionUUID->"242e76a5-d1f1-4660-8214-dd6a2188d0b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"numfreqs", "[", "run", "]"}], "=", 
      RowBox[{"IntegerPart", "[", 
       RowBox[{
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"intablespectra", "[", "run", "]"}], "[", "0", "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"_Real", ",", 
            RowBox[{"{", "7", "}"}]}], "]"}]}], "]"}], "/", 
        RowBox[{"numtimes", "[", "run", "]"}]}], "]"}]}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",ExpressionUUID->"4e83951c-\
fb68-44a2-888e-ab33bbdd6244"],

Cell["\<\
Verify that the number of data points in each spectrum file is correct.\
\>", "Text",ExpressionUUID->"b07fa990-61c0-4fa0-bd42-a65e7ef5f768"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"fld", "=", "0"}], ",", 
       RowBox[{"fld", "<", 
        RowBox[{"nflds", "[", "run", "]"}]}], ",", 
       RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"numtimes", "[", "run", "]"}], "*", 
            RowBox[{"numfreqs", "[", "run", "]"}]}], "\[NotEqual]", 
           RowBox[{"Count", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", "]"}], 
             ",", 
             RowBox[{"Table", "[", 
              RowBox[{"_Real", ",", 
               RowBox[{"{", "7", "}"}]}], "]"}]}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{
            "\"\<Run \>\"", ",", "run", ",", "\"\<: Mismatch in field \>\"", 
             ",", "fld"}], "]"}], ";", 
           RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",ExpressionUUID->"043a5482-e018-46ae-aa33-f0650c7f80bb"],

Cell["\<\
The minimum frequency kmin is used to set the origin of plots; The frequency \
kmax isn't used in this notebook as it stands but is sometimes handy to know. \
The number numfreqscut is the number of frequencies in each plot.\
\>", "Text",ExpressionUUID->"ef71382c-8d12-4330-92dc-079ec68a92a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"kmin", "[", "run", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"intablespectra", "[", "run", "]"}], "[", "0", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{"1", "+", "cutir"}], ",", "1"}], "]"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"kmax", "[", "run", "]"}], "=", 
      RowBox[{
       RowBox[{
        RowBox[{"intablespectra", "[", "run", "]"}], "[", "0", "]"}], "[", 
       RowBox[{"[", 
        RowBox[{
         RowBox[{
          RowBox[{"numfreqs", "[", "run", "]"}], "-", "cutuv"}], ",", "1"}], 
        "]"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"numfreqscut", "[", "run", "]"}], "=", 
      RowBox[{
       RowBox[{"numfreqs", "[", "run", "]"}], "-", "cutir", "-", "cutuv"}]}], 
     ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",ExpressionUUID->\
"5de2389b-5465-4b83-a9b2-12e1e8e210ed"],

Cell["Create tables of the spectra.", "Text",ExpressionUUID->"5a16e1d9-f2f9-497a-9b5c-6ea379ab8d92"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"time", "=", "1"}], ",", 
       RowBox[{"time", "\[LessEqual]", 
        RowBox[{"numtimes", "[", "run", "]"}]}], ",", 
       RowBox[{"time", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"startindex", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"time", "-", "1"}], ")"}], "*", 
           RowBox[{"numfreqs", "[", "run", "]"}]}], "+", "1", "+", 
          "cutir"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"finishindex", "=", 
         RowBox[{
          RowBox[{"time", "*", 
           RowBox[{"numfreqs", "[", "run", "]"}]}], "-", "cutuv"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"dopower", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"powertable", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "kexponent"}],
                     "*", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "4"}], "]"}], "]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "startindex", ",", "finishindex"}], 
                  "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"powermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Min", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"powertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"numfreqscut", "[", "run", "]"}]}], "}"}]}], 
                 "]"}], "]"}]}], ";"}]}], " ", "\[IndentingNewLine]", "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"dofdpower", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"fdpowertable", "[", "run", "]"}], "[", "fld", "]"}],
                 "[", "time", "]"}], "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "kexponent"}],
                     "*", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "5"}], "]"}], "]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "startindex", ",", "finishindex"}], 
                  "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"fdpowermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Min", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"fdpowertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"numfreqscut", "[", "run", "]"}]}], "}"}]}], 
                 "]"}], "]"}]}], ";"}]}], " ", "\[IndentingNewLine]", "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"donumber", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbertable", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "0"}], "*", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "6"}], "]"}], "]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "startindex", ",", "finishindex"}], 
                  "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Min", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"numbertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"numfreqscut", "[", "run", "]"}]}], "}"}]}], 
                 "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbermax", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Max", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"numbertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"numfreqscut", "[", "run", "]"}]}], "}"}]}], 
                 "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"number", "[", "run", "]"}], "[", "fld", "]"}], "[", 
                "time", "]"}], "=", 
               RowBox[{"Sum", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], "*", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "6"}], "]"}], "]"}]}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"time", "-", "1"}], ")"}], "*", 
                    RowBox[{"numfreqs", "[", "run", "]"}]}], "+", "2"}], ",", 
                   RowBox[{"time", "*", 
                    RowBox[{"numfreqs", "[", "run", "]"}]}]}], "}"}]}], 
                "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"doenergy", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"energytable", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "1"}], "]"}], "]"}], "^", "kexponent"}],
                     "*", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"intablespectra", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "7"}], "]"}], "]"}]}]}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "startindex", ",", "finishindex"}], 
                  "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"energymin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], "=", 
               RowBox[{"Min", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{"energytable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1", ",", 
                    RowBox[{"numfreqscut", "[", "run", "]"}]}], "}"}]}], 
                 "]"}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], 
           ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"dopower", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"powerminallflds", "[", "run", "]"}], "[", "time", "]"}], 
           "=", 
           RowBox[{"Min", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"powermin", "[", "run", "]"}], "[", "fld", "]"}], "[",
                "time", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"fld", ",", "0", ",", 
                RowBox[{
                 RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
             "]"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"dofdpower", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"fdpowerminallflds", "[", "run", "]"}], "[", "time", 
            "]"}], "=", 
           RowBox[{"Min", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"fdpowermin", "[", "run", "]"}], "[", "fld", "]"}], 
               "[", "time", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"fld", ",", "0", ",", 
                RowBox[{
                 RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
             "]"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"donumber", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"numberminallflds", "[", "run", "]"}], "[", "time", "]"}],
            "=", 
           RowBox[{"Min", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"numbermin", "[", "run", "]"}], "[", "fld", "]"}], 
               "[", "time", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"fld", ",", "0", ",", 
                RowBox[{
                 RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
             "]"}], "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"doenergy", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"energyminallflds", "[", "run", "]"}], "[", "time", "]"}],
            "=", 
           RowBox[{"Min", "[", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"energymin", "[", "run", "]"}], "[", "fld", "]"}], 
               "[", "time", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"fld", ",", "0", ",", 
                RowBox[{
                 RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
             "]"}], "]"}]}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
     ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",ExpressionUUID->\
"ba40603a-7f5c-4686-8ce6-78cafde98795"]
}, Closed]],

Cell[CellGroupData[{

Cell["NUMBER DENSITY: Make plots of total number density vs. time", "Section",
 CellChangeTimes->{
  3.717443146372367*^9},ExpressionUUID->"77e9d301-cd92-4d0a-8936-\
850c8d80f4d3"],

Cell["\<\
If number spectra are being calculated then make tables and plots of total \
number density vs. time.\
\>", "Text",ExpressionUUID->"22bbbac7-b571-4557-bcf3-8eb86678bbe1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"donumber", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"numbervstime", "[", "run", "]"}], "[", "fld", "]"}], 
            "=", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"timetable", "[", "run", "]"}], "[", 
                 RowBox[{"[", "time", "]"}], "]"}], ",", 
                RowBox[{
                 RowBox[{
                  RowBox[{"number", "[", "run", "]"}], "[", "fld", "]"}], "[",
                  "time", "]"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"time", ",", "1", ",", 
                RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}]}], 
           ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ntotaltable", "[", "run", "]"}], "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"numbervstime", "[", "run", "]"}], "[", "0", "]"}], 
              "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "1"}], "]"}], "]"}], ",", 
             RowBox[{"Sum", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbervstime", "[", "run", "]"}], "[", "fld", "]"}],
                 "[", 
                RowBox[{"[", 
                 RowBox[{"i", ",", "2"}], "]"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"fld", ",", "0", ",", 
                 RowBox[{
                  RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
              "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", 
             RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", "nfldsmax"}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"fld", "<", 
              RowBox[{"nflds", "[", "run", "]"}]}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"numbervstimeplot", "[", "run", "]"}], "[", "fld", 
                "]"}], "=", 
               RowBox[{"ListLogPlot", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"numbervstime", "[", "run", "]"}], "[", "fld", 
                  "]"}], ",", 
                 RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                 RowBox[{"PlotStyle", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"Hue", "[", 
                    RowBox[{"fld", "/", 
                    RowBox[{"nflds", "[", "run", "]"}]}], "]"}], "}"}]}], ",", 
                 RowBox[{"AxesLabel", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<t\>\"", ",", "\"\<n\>\""}], "}"}]}], ",", 
                 RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], 
                "]"}]}], ";"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"numbervstimeplot", "[", "run", "]"}], "[", "fld", 
                "]"}], "=", 
               RowBox[{"Graphics", "[", 
                RowBox[{"\"\<This run does not include this field\>\"", ",", 
                 RowBox[{"{", 
                  RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], ";"}]}], 
            "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", 
         "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"nvstallfldsplot", "[", "run", "]"}], "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"numbervstimeplot", "[", "run", "]"}], "[", "fld", 
              "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"fld", ",", "0", ",", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], ";",
         "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"nvstallfldslinearplot", "[", "run", "]"}], "=", 
         RowBox[{"ListPlot", "[", 
          RowBox[{
           RowBox[{"ntotaltable", "[", "run", "]"}], ",", 
           RowBox[{"Joined", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "Automatic"}], "}"}]}], ",", 
           RowBox[{"DisplayFunction", "\[Rule]", "Identity"}]}], "]"}]}], 
        ";"}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"fld", "=", "0"}], ",", 
       RowBox[{"fld", "<", "nfldsmax"}], ",", 
       RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         StyleBox["Print",
          Background->RGBColor[0, 1, 1]], 
         StyleBox["[",
          Background->RGBColor[0, 1, 1]], 
         RowBox[{
          StyleBox["Show",
           Background->RGBColor[0, 1, 1]], "[", 
          RowBox[{
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"numbervstimeplot", "[", "run", "]"}], "[", "fld", 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"run", ",", "0", ",", 
                 RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "}"}], 
            "]"}], ",", 
           RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
           RowBox[{"ImageSize", "\[Rule]", 
            RowBox[{"300", "*", "numruns"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"\"\<Number density for \>\"", "<>", 
             RowBox[{"label", "[", "fld", "]"}]}]}]}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{
      StyleBox["Print",
       Background->RGBColor[0, 1, 0]], "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"GraphicsGrid", "[", 
         RowBox[{"{", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"nvstallfldsplot", "[", "run", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"run", ",", "0", ",", 
              RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "}"}], "]"}], 
        ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"300", "*", "numruns"}]}], ",", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
         "\"\<Total number density for all fields\>\""}]}], "]"}], "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{
      StyleBox["Print",
       Background->RGBColor[0, 1, 0]], "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"GraphicsGrid", "[", 
         RowBox[{"{", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"nvstallfldslinearplot", "[", "run", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"run", ",", "0", ",", 
              RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "}"}], "]"}], 
        ",", 
        RowBox[{"DisplayFunction", "\[Rule]", "$DisplayFunction"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"300", "*", "numruns"}]}], ",", 
        RowBox[{
        "PlotLabel", "\[Rule]", 
         "\"\<Total number density for all fields\>\""}]}], "]"}], "]"}], 
     ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{
  3.422107924827588*^9, {3.422109223774402*^9, 3.4221092291182547`*^9}, {
   3.4221092807286205`*^9, 3.4221092837130527`*^9}, {3.4221093137605047`*^9, 
   3.4221093468548903`*^9}, {3.422109390543229*^9, 3.4221094005902967`*^9}, 
   3.422109479748067*^9, {3.4221095199050875`*^9, 3.4221095722029667`*^9}, {
   3.4221098595991096`*^9, 3.422109860380375*^9}, {3.4221098953497963`*^9, 
   3.422109988929718*^9}, {3.424185332105956*^9, 3.424185401194361*^9}, {
   3.424185452546208*^9, 3.424185494305075*^9}, {3.424185800162619*^9, 
   3.42418581037783*^9}, {3.424185852849386*^9, 3.424185885340259*^9}, {
   3.7174477951765127`*^9, 
   3.7174478664410143`*^9}},ExpressionUUID->"9e54e3bf-a0e4-4950-bbaf-\
3715e4184040"],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    GraphicsBox[{{}, {{}, {}, 
       {Hue[0, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAADbW9tGkGQeQByxFp8C
ACRA1d03q6QjH0CQwB9+/j80QItN0n3GsB9AodrgRPR/PkAT4sCHJSIgQIl+
bf30X0RAdy29j0JTIECRC87g739JQEVeJVJoiiBAmpguxOqfTkC61BP1Zrgg
QLX+lgD8z1FA/lLkaubeIEDxgR3/BVBUQK1eKs+6XCFAFsPVARDQVkAvlyB1
41olQFJGXAAaUFlA1jC/xqyPMECOyeL+I9BbQLM1gCLQRzlAswqbAS5QXkDZ
R/3bzb0/QPjGEAAcaGBAx5+8aEWfP0CWCFT/IKhhQFlg0GsL0j9AKCmwACbo
YkAV9G51KiVAQMZq8/8qKGRAcimb/KdAQEBkrDb/L2hlQHQ9Tm/sj0BA98yS
ADWoZkDzrZRYbKpAQJUO1v856GdAIxoDlqJsQEC8H7dfPgBpQC5L/ms7GkBA
zZeR/g==
         "]]}}, {}, {}, {{}, {}}, {{}, {}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{
       FormBox["\"t\"", TraditionalForm], 
       FormBox["\"n\"", TraditionalForm]},
     AxesOrigin->{0, 5.730472561590572},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 200.007614}, {6.168583020265154, 33.33143145808926}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}},
     Ticks->FrontEndValueCache[{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {13.815510557964274`, 
          FormBox[
           
           TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {18.420680743952367`, 
          FormBox[
           
           TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {23.025850929940457`, 
          FormBox[
           
           TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {27.631021115928547`, 
          FormBox[
           
           TemplateBox[{"10", "12"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {32.23619130191664, 
          FormBox[
           
           TemplateBox[{"10", "14"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.89015165207416, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.93667166770906, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.98112343027989, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}}}]], {189., -116.80842387373012}, 
    ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->300,
  PlotLabel->FormBox["\"Number density for \[Phi]\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{{3.424185316374938*^9, 3.424185338161826*^9}, 
   3.424185403502945*^9, 3.424185811775395*^9, 3.424185888774239*^9, 
   3.445191154530741*^9, 3.717447825555296*^9, 3.7174478703288774`*^9, 
   3.717448196642744*^9},ExpressionUUID->"efbc3cd5-2ff1-4f87-bceb-\
d5391efc5eda"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    GraphicsBox[{{}, {{}, {}, 
       {Hue[
         NCache[
          Rational[1, 2], 0.5], 1, 1], PointSize[0.012833333333333334`], 
        AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAAAGQ1vSf4IeQByxFp8C
ACRA5Lc4uSqfHkCQwB9+/j80QEJ7mqQO4R5AodrgRPR/PkBOMMuTsSofQIl+
bf30X0RA3FBkB9uuIUCRC87g739JQKsy7ECAyiZAmpguxOqfTkBPZxXXDA0t
QLX+lgD8z1FA3alo2BOKMUDxgR3/BVBUQLV8TjNNozRAFsPVARDQVkBiE78m
oMM2QFJGXAAaUFlAMyVonfjdOUCOyeL+I9BbQDK9mzW/Wj1AswqbAS5QXkB0
YS+sSGI+QPjGEAAcaGBAO+oHRCUKP0CWCFT/IKhhQPlWirVTnD5AKCmwACbo
YkAeuIn2yQ0/QMZq8/8qKGRA5Fifst9EP0BkrDb/L2hlQKx5c5iJpT9A98yS
ADWoZkDtXxdHLVk/QJUO1v856GdAbaeTEZhYP0C8H7dfPgBpQIjUb5yWUj9A
35KORQ==
         "]]}}, {}, {}, {{}, {}}, {{}, {}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{
       FormBox["\"t\"", TraditionalForm], 
       FormBox["\"n\"", TraditionalForm]},
     AxesOrigin->{0, 5.884112414954971},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 200.007614}, {6.293041278065109, 31.646630790893752`}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}},
     Ticks->FrontEndValueCache[{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{6.907755278982137, 
          FormBox["1000", TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {11.512925464970229`, 
          FormBox[
           
           TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {16.11809565095832, 
          FormBox[
           
           TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {20.72326583694641, 
          FormBox[
           
           TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {25.328436022934504`, 
          FormBox[
           
           TemplateBox[{"10", "11"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {29.933606208922594`, 
          FormBox[
           
           TemplateBox[{"10", "13"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {9.210340371976184, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {13.815510557964274`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {18.420680743952367`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {23.025850929940457`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {27.631021115928547`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {32.23619130191664, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {34.94424150301885, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {35.23192357547063, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}}}]], {189., -116.80842387373012}, 
    ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->300,
  PlotLabel->FormBox["\"Number density for \[Chi]\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{{3.424185316374938*^9, 3.424185338161826*^9}, 
   3.424185403502945*^9, 3.424185811775395*^9, 3.424185888774239*^9, 
   3.445191154530741*^9, 3.717447825555296*^9, 3.7174478703288774`*^9, 
   3.7174481967312956`*^9},ExpressionUUID->"3ff89116-6888-4b6e-ac8f-\
3690891e5236"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    GraphicsBox[{{{}, {{}, {}, 
        {Hue[0, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
         1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAADbW9tGkGQeQByxFp8C
ACRA1d03q6QjH0CQwB9+/j80QItN0n3GsB9AodrgRPR/PkAT4sCHJSIgQIl+
bf30X0RAdy29j0JTIECRC87g739JQEVeJVJoiiBAmpguxOqfTkC61BP1Zrgg
QLX+lgD8z1FA/lLkaubeIEDxgR3/BVBUQK1eKs+6XCFAFsPVARDQVkAvlyB1
41olQFJGXAAaUFlA1jC/xqyPMECOyeL+I9BbQLM1gCLQRzlAswqbAS5QXkDZ
R/3bzb0/QPjGEAAcaGBAx5+8aEWfP0CWCFT/IKhhQFlg0GsL0j9AKCmwACbo
YkAV9G51KiVAQMZq8/8qKGRAcimb/KdAQEBkrDb/L2hlQHQ9Tm/sj0BA98yS
ADWoZkDzrZRYbKpAQJUO1v856GdAIxoDlqJsQEC8H7dfPgBpQC5L/ms7GkBA
zZeR/g==
          "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
        {Hue[
          NCache[
           Rational[1, 2], 0.5], 1, 1], PointSize[0.012833333333333334`], 
         AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAAAGQ1vSf4IeQByxFp8C
ACRA5Lc4uSqfHkCQwB9+/j80QEJ7mqQO4R5AodrgRPR/PkBOMMuTsSofQIl+
bf30X0RA3FBkB9uuIUCRC87g739JQKsy7ECAyiZAmpguxOqfTkBPZxXXDA0t
QLX+lgD8z1FA3alo2BOKMUDxgR3/BVBUQLV8TjNNozRAFsPVARDQVkBiE78m
oMM2QFJGXAAaUFlAMyVonfjdOUCOyeL+I9BbQDK9mzW/Wj1AswqbAS5QXkB0
YS+sSGI+QPjGEAAcaGBAO+oHRCUKP0CWCFT/IKhhQPlWirVTnD5AKCmwACbo
YkAeuIn2yQ0/QMZq8/8qKGRA5Fifst9EP0BkrDb/L2hlQKx5c5iJpT9A98yS
ADWoZkDtXxdHLVk/QJUO1v856GdAbaeTEZhYP0C8H7dfPgBpQIjUb5yWUj9A
35KORQ==
          "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{
       FormBox["\"t\"", TraditionalForm], 
       FormBox["\"n\"", TraditionalForm]},
     AxesOrigin->{0, 5.730472561590572},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Exp[#]& )[
            Part[#, 2]]}& )}},
     PlotRange->All,
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.05]}},
     Ticks->FrontEndValueCache[{Automatic, 
        Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{9.210340371976184, 
          FormBox[
           
           TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {13.815510557964274`, 
          FormBox[
           
           TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {18.420680743952367`, 
          FormBox[
           
           TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {23.025850929940457`, 
          FormBox[
           
           TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {27.631021115928547`, 
          FormBox[
           
           TemplateBox[{"10", "12"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {32.23619130191664, 
          FormBox[
           TemplateBox[{"10", "14"}, "Superscript", SyntaxForm -> 
            SuperscriptBox], TraditionalForm], {0.01, 0.}, {
           AbsoluteThickness[0.1]}}, {4.605170185988092, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {6.907755278982137, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {11.512925464970229`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {16.11809565095832, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {20.72326583694641, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {25.328436022934504`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {29.933606208922594`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {34.538776394910684`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.841361487904734`, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.89015165207416, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.93667166770906, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}, {36.98112343027989, 
          FormBox[
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
          0.}, {
           AbsoluteThickness[0.1]}}}}]], {189., -116.80842387373012}, 
    ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->300,
  PlotLabel->FormBox[
   "\"Total number density for all fields\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{{3.424185316374938*^9, 3.424185338161826*^9}, 
   3.424185403502945*^9, 3.424185811775395*^9, 3.424185888774239*^9, 
   3.445191154530741*^9, 3.717447825555296*^9, 3.7174478703288774`*^9, 
   3.7174481967342978`*^9},ExpressionUUID->"e6ae89eb-23e6-4ee9-9679-\
2bcdf4c464ea"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    GraphicsBox[{{}, {{}, {}, 
       {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
        0.012833333333333334`], AbsoluteThickness[1.6], 
        LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAAC2Ud8qzqCvQByxFp8C
ACRAJ0ADoOajsUCQwB9+/j80QJL6/EF+k7NAodrgRPR/PkBOFecD9ea1QIl+
bf30X0RATB2JPGhbxECRC87g739JQBcAiVq8qfZAmpguxOqfTkBYidTzyxk/
QbX+lgD8z1FA4O9ioyzBg0HxgR3/BVBUQLMZYsYmXctBFsPVARDQVkDqBCb7
9Kz8QVJGXAAaUFlAdafuRZvzQ0KOyeL+I9BbQGVcCTbLu5RCswqbAS5QXkDJ
xTzIJ27RQvjGEAAcaGBADIDtkzEt00KWCFT/IKhhQIznUNiJetNCKCmwACbo
YkB45d9VMfneQsZq8/8qKGRAPJZNEN0y40JkrDb/L2hlQKRicV9B+PBC98yS
ADWoZkBkbKEhwFXzQpUO1v856GdAANmxEuak6UK8H7dfPgBpQPqvx9tJKN9C
Jg2erQ==
         "]]}}, {}, {}, {{}, {}}, {{}, {}}},
     AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
     Axes->{True, True},
     AxesLabel->{None, None},
     AxesOrigin->{0, 0},
     DisplayFunction->Identity,
     Frame->{{False, False}, {False, False}},
     FrameLabel->{{None, None}, {None, None}},
     FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
     GridLines->{None, None},
     GridLinesStyle->Directive[
       GrayLevel[0.5, 0.4]],
     ImagePadding->All,
     Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}},
     PlotRange->{{0, 200.007614}, {0, 3.4014426523821425`*^14}},
     PlotRangeClipping->True,
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 
        Scaled[0.05]}},
     Ticks->{Automatic, Automatic}], {189., -116.80842387373012}, 
    ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], {}},
  ContentSelectable->True,
  DisplayFunction->Identity,
  ImageSize->300,
  PlotLabel->FormBox[
   "\"Total number density for all fields\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{{3.424185316374938*^9, 3.424185338161826*^9}, 
   3.424185403502945*^9, 3.424185811775395*^9, 3.424185888774239*^9, 
   3.445191154530741*^9, 3.717447825555296*^9, 3.7174478703288774`*^9, 
   3.717448196771346*^9},ExpressionUUID->"504797a6-84a8-40ac-80e9-\
9455d0ee1c5b"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["SPECTRA: Make plots of various types of spectra", "Section",
 CellChangeTimes->{{3.717447977895607*^9, 
  3.71744798334861*^9}},ExpressionUUID->"0db4247c-1cc5-4632-b580-\
98086167c67e"],

Cell["\<\
For each spectrum for which plots are being shown at separate times, display \
these plots.\
\>", "Text",
 CellChangeTimes->{{3.4221097397843094`*^9, 3.4221097630347557`*^9}, {
   3.422110749678699*^9, 3.422110751288105*^9}, 
   3.7174479913353148`*^9},ExpressionUUID->"3a15c55b-8a0c-408e-87c1-\
4cba742064f7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"plotsomething", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"time", "=", "1"}], ",", 
       RowBox[{"time", "\[LessEqual]", "numtimesmax"}], ",", 
       RowBox[{"time", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", "time", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"run", "=", "0"}], ",", 
          RowBox[{"run", "<", "numruns"}], ",", 
          RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"plotarray", "=", 
            RowBox[{"{", "}"}]}], ";", 
           RowBox[{"numplots", "=", "0"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"plotpower", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"powerplot", "[", "run", "]"}], "[", "time", "]"}], 
               "=", 
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"ListLogLogPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"powertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{".7", " ", 
                    RowBox[{"fld", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}], ")"}]}]}],
                     "]"}], "}"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"fld", ",", "0", ",", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}],
                   "]"}], ",", 
                 RowBox[{"AxesOrigin", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{
                    RowBox[{"powerminallflds", "[", "run", "]"}], "[", "time",
                     "]"}]}], "]"}]}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                 RowBox[{"PlotLabel", "\[Rule]", "\"\<Power\>\""}]}], "]"}]}],
               ";", " ", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"plotarray", ",", 
                RowBox[{
                 RowBox[{"powerplot", "[", "run", "]"}], "[", "time", "]"}]}],
                "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"numplots", "++"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"plotfdpower", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"fdpowerplot", "[", "run", "]"}], "[", "time", "]"}], 
               "=", 
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"ListLogLogPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"fdpowertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{".7", " ", 
                    RowBox[{"fld", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}], ")"}]}]}],
                     "]"}], "}"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"fld", ",", "0", ",", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}],
                   "]"}], ",", 
                 RowBox[{"AxesOrigin", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{
                    RowBox[{"fdpowerminallflds", "[", "run", "]"}], "[", 
                    "time", "]"}]}], "]"}]}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                 RowBox[{"PlotLabel", "\[Rule]", "\"\<FDPower\>\""}]}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"plotarray", ",", 
                RowBox[{
                 RowBox[{"fdpowerplot", "[", "run", "]"}], "[", "time", 
                 "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"numplots", "++"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"plotnumber", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"numberplot", "[", "run", "]"}], "[", "time", "]"}], 
               "=", 
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"ListLogLogPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"numbertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{".7", " ", 
                    RowBox[{"fld", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}], ")"}]}]}],
                     "]"}], "}"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"fld", ",", "0", ",", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}],
                   "]"}], ",", 
                 RowBox[{"AxesOrigin", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                    RowBox[{"Log", "[", 
                    RowBox[{"10", ",", 
                    RowBox[{
                    RowBox[{"numberminallflds", "[", "run", "]"}], "[", 
                    "time", "]"}]}], "]"}]}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
                 RowBox[{"PlotLabel", "\[Rule]", "\"\<Number\>\""}]}], 
                "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"plotarray", ",", 
                RowBox[{
                 RowBox[{"numberplot", "[", "run", "]"}], "[", "time", 
                 "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"numplots", "++"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"plotenergy", "\[Equal]", "1"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"energyplot", "[", "run", "]"}], "[", "time", "]"}], 
               "=", 
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"Table", "[", 
                  RowBox[{
                   RowBox[{"ListLogLogPlot", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"energytable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                    RowBox[{"PlotStyle", "\[Rule]", 
                    RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{".7", " ", 
                    RowBox[{"fld", "/", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}], ")"}]}]}],
                     "]"}], "}"}]}]}], "]"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"fld", ",", "0", ",", 
                    RowBox[{
                    RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}],
                   "]"}], ",", 
                 RowBox[{"AxesOrigin", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "2"}], ",", 
                    RowBox[{"-", "12"}]}], "}"}]}], ",", 
                 RowBox[{"PlotRange", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"All", ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "12"}], ",", "6"}], "}"}]}], "}"}]}], ",", 
                 RowBox[{"AxesLabel", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<k\>\"", ",", 
                    "\"\<\!\(\*SuperscriptBox[\(k\), \
\(3\)]\)\!\(\*SubscriptBox[\(\[Rho]\), \(k\)]\)\>\""}], "}"}]}]}], "]"}]}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"AppendTo", "[", 
               RowBox[{"plotarray", ",", 
                RowBox[{
                 RowBox[{"energyplot", "[", "run", "]"}], "[", "time", 
                 "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{"numplots", "++"}], ";"}]}], "\[IndentingNewLine]", 
            "]"}], ";", "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"numplots", ">", "2"}], ",", 
             RowBox[{"plotwidth", "=", "700"}], ",", 
             RowBox[{"plotwidth", "=", 
              RowBox[{"288", "*", "numplots"}]}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Print", "@", 
            RowBox[{"Show", "[", 
             RowBox[{"GraphicsGrid", "[", 
              RowBox[{
               RowBox[{"{", "plotarray", "}"}], ",", 
               RowBox[{"ImageSize", "\[Rule]", 
                RowBox[{"{", 
                 RowBox[{"plotwidth", ",", 
                  RowBox[{"plotwidth", "/", "GoldenRatio"}]}], "}"}]}], ",", 
               RowBox[{"PlotLabel", "\[Rule]", 
                RowBox[{"\"\<Run \>\"", "<>", 
                 RowBox[{"ToString", "[", "run", "]"}], "<>", 
                 "\"\<: Spectra for all fields at t=\>\"", "<>", 
                 RowBox[{"ToString", "[", 
                  RowBox[{
                   RowBox[{"timetable", "[", "run", "]"}], "[", 
                   RowBox[{"[", "time", "]"}], "]"}], "]"}]}]}]}], "]"}], 
             "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4221097001429234`*^9, 3.4221097147213283`*^9}, {
   3.4221099989611607`*^9, 3.4221100958380203`*^9}, 3.4221102965293736`*^9, {
   3.4221104118440876`*^9, 3.4221104462509985`*^9}, {3.424187017787942*^9, 
   3.4241870418075*^9}, 3.424187122226433*^9, {3.424187178374255*^9, 
   3.424187201883821*^9}, {3.717448002615774*^9, 
   3.7174480843698206`*^9}},ExpressionUUID->"3af5fb35-91fb-49d1-9629-\
3f50ad376e83"],

Cell[CellGroupData[{

Cell[BoxData["1"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480874262457`*^9},ExpressionUUID->"d35c166d-08e6-47f8-a37b-\
0a842b4fa933"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IfhDYygUpwN64dwvy
SOQ/jBELKeV0KMDfVqmFon3tPwD/hZci7SXA/AmBZtBQ8j8K24b+1XckwIOR
BD6aO/U/P1oMWxmaI8CF+JAQAbP3P8gVvomXQiTAZ8hRwvLV+T+P4sEUqv8h
wFqa8FBjuPs/pD8twJ81I8CrG0W78Wf9P3gFerv9uyHAXkJExlXu/j8HXJOm
4GMhwErxjfBdKQBAWuQReTo7IcAwDFZVS80AQFDkbZoppSDAaPTEOBFlAUDa
IzZJk9QgwBxYWWJd8gFACR+XUcXQH8BfwE5WinYCQJGKYXkLVyDAYf4DKbPy
AkA/wy/5BwUgwLaVvjjCZwNAGFYo4PcgIMCvqhQXfdYDQPvJfNKazh3AURxh
nYk/BECOQqPYFbgewMj9nsV1owRA7OiKgn8hHsDOEUy2uwIFQDM1ceaI3x3A
vDSKScVdBUDM4xPtYEQdwGmz5tPutAVA9XBrD3kgHcAWQH4EiQgGQHXAfbRr
eRzAZgymBNxYBkBpanMdBDccwMht5d0mpgZAflKbb32+HMA6mcUHovAGQBJA
mTYzzhvAlSeDB4A4B0BDFHkRZGgbwE1Dkz7ufQdAUkxogdPuG8CQQGBSFcEH
QO7PuxESwxrAiC1M0xoCCEBkLaq3FowbwC5hhhMgQQhARds3tmKyGsBGqu6p
Q34IQPCpUmC35BnA3EI/hKG5CEChwzM9HToawHV70zNT8whAmIA/9PwDG8C+
4ugvcCsJQGayGy3ZKRnAKjnT1g1iCUDI+woHeGIawG//PYJAlwlA7CDdyxIV
GcDNqh9dGssJQHlgcT9L8RrA2pJMb6z9CUDkqIW8WaQZwEOMXYUGLwpADZZj
ODWoGcAFBF1ON18KQACzPm4wkRbASqAKdkyOCkC3A9THVvQUwAoRMTo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+EMw9H2QwtwN64dwvy
SOQ/BRKDOjSRKsDfVqmFon3tP/bCSRhtyyjA/AmBZtBQ8j/WoVV26eYowIOR
BD6aO/U/w2GzwJ2oJsCF+JAQAbP3PxSRDvPveibAZ8hRwvLV+T8bggiWDBol
wFqa8FBjuPs/lj6JNf32I8CrG0W78Wf9P+h+rJ13sCLAXkJExlXu/j+eKUm9
PsQjwErxjfBdKQBAA1vSQM01IsAwDFZVS80AQPrlOsfJiyLAaPTEOBFlAUAh
9EJ6yV8iwBxYWWJd8gFAL1zQy1qLIcBfwE5WinYCQEGfT0utiSHAYf4DKbPy
AkBg6ZFpJeMgwLaVvjjCZwNA7IBj1wzXIMCvqhQXfdYDQFXUJKqtLSDAURxh
nYk/BECv5ayK5yIgwMj9nsV1owRAykkTIQvFHsDOEUy2uwIFQGraC5W4SR/A
vDSKScVdBUAmNAAGQMIewGmz5tPutAVABf5wLd8SHsAWQH4EiQgGQCNJ/S1d
RB3AZgymBNxYBkCEBSdALQAewMht5d0mpgZAmHnsXDKPHMA6mcUHovAGQHTg
Dakz8xzAlSeDB4A4B0Cq7dTcuIUcwE1Dkz7ufQdALYzTs0sbHMCQQGBSFcEH
QGh3qF6bRhzAiC1M0xoCCEDTIkIg4LgbwC5hhhMgQQhAESNqZ1sQHMBGqu6p
Q34IQBRkFzwNVRrA3EI/hKG5CEAeEyvI7vAbwHV70zNT8whAaUiiWxR+G8C+
4ugvcCsJQFFeJ2vBChvAKjnT1g1iCUCu8EmhS4UawG//PYJAlwlAhW6s/oK2
GMDNqh9dGssJQDZCXA7BIhnA2pJMb6z9CUAPDT7Gkn0XwEOMXYUGLwpAcp8G
l2q5G8AFBF1ON18KQEceHnUkHRrASqAKdkyOCkBfWFYq+vAbwKE2LD8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.3081686928932905`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.01948336229021, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.73180128983843, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.326336181730264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.172185501903007`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.038654109278484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.9208710736221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Iuiw8FWknwN64dwvy
SOQ/05/wE9tXI8DfVqmFon3tPz2ZURVbSiLA/AmBZtBQ8j+qxPrdeYIfwIOR
BD6aO/U/tvHPWmnYHcCF+JAQAbP3Pzj6jsaJexnAZ8hRwvLV+T+gG4EpBnYY
wFqa8FBjuPs/OQfYEnbDFcCrG0W78Wf9Px1a+b9c2RbAXkJExlXu/j+DKzuv
y+UTwErxjfBdKQBAI9B0OtePEcAwDFZVS80AQEG12rDGWxDAaPTEOBFlAUA3
j+V6x68RwBxYWWJd8gFAcRHKd/TlD8BfwE5WinYCQNe4vy7DRw3AYf4DKbPy
AkDt5j6H2VQJwLaVvjjCZwNACqJmAK/SCMCvqhQXfdYDQI0Xr4ibvAbAURxh
nYk/BED4C4KVbsYDwMj9nsV1owRAOrq1buugBMDOEUy2uwIFQMbMNBwNoQDA
vDSKScVdBUCszhL9Sj0AwGmz5tPutAVA99V97aoA/r8WQH4EiQgGQBpQfhfK
vPq/ZgymBNxYBkBQ+gDWtxv4v8ht5d0mpgZAtlvqqYGp8786mcUHovAGQOJI
jDr5R/S/lSeDB4A4B0D3C6ryRp3vv01Dkz7ufQdASuxY6sqJ8L+QQGBSFcEH
QLKVnrKMMOa/iC1M0xoCCEC5J8lWRu3pvy5hhhMgQQhAggi2U0ds579Gqu6p
Q34IQKOJ2jn8l96/3EI/hKG5CEBKUUYhcffbv3V70zNT8whAtwiiFJuOlb++
4ugvcCsJQLYRWfcWfrC/KjnT1g1iCUCtlgr1pRTXv2//PYJAlwlAaOHx7aBD
3r/Nqh9dGssJQE4UT727G+w/2pJMb6z9CUDgSzcCqcHkP0OMXYUGLwpAm2zs
ljzAzj8FBF1ON18KQKrGtbh/6OU/SqAKdkyOCkCFhC4GnVMIwEZMSn0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/hZHq/xzwjwN64dwvy
SOQ/t7ifSGfiIMDfVqmFon3tP/Pg+SXDvR3A/AmBZtBQ8j9AJ8qHzAAawIOR
BD6aO/U/+WwxxUusGMCF+JAQAbP3Pw1dU+mVuxTAZ8hRwvLV+T8UusvmAJ0T
wFqa8FBjuPs/mTnGrWJfE8CrG0W78Wf9PxfxFwYcBhHAXkJExlXu/j8y5ZKq
B1cRwErxjfBdKQBA4Fs5AXp7D8AwDFZVS80AQOP/rvZ/iA7AaPTEOBFlAUB6
4O6zLAILwBxYWWJd8gFA0fXCLXBgB8BfwE5WinYCQD9b+ISk0gjAYf4DKbPy
AkCEl4mT2UEEwLaVvjjCZwNAemkEF8HbBMCvqhQXfdYDQOdFbd94ywDAURxh
nYk/BEAEf2JlXzAAwMj9nsV1owRAhhnxmzvz/b/OEUy2uwIFQLC3JN/zuf+/
vDSKScVdBUAcBKMJ0GL3v2mz5tPutAVAfbb00LnS9L8WQH4EiQgGQBYiGNoJ
h/O/ZgymBNxYBkDnV4Ry2wPzv8ht5d0mpgZAVXj1i5Zq7786mcUHovAGQC0n
ogmYeOm/lSeDB4A4B0C172yQNuvqv01Dkz7ufQdAWdY2DXU86L+QQGBSFcEH
QG0XeivjuuS/iC1M0xoCCEALpfcr7Efmvy5hhhMgQQhABb2/Lpag0r9Gqu6p
Q34IQC3XKBlscc6/3EI/hKG5CECpfR62TO+jP3V70zNT8whAjpufTZL4wj++
4ugvcCsJQGfQuGvrZMQ/KjnT1g1iCUCIQE76snLRP2//PYJAlwlAoze4S4eZ
6L/Nqh9dGssJQBNATRIjE5I/2pJMb6z9CUAAUg2Q52jfP0OMXYUGLwpAiLCT
3QVT2T8FBF1ON18KQFmOvCVnvcY/SqAKdkyOCkDoLRtEzHvSP7TXQtU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.083521200257323},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+BXFTIrrntv964dwvy
SOQ/GH8x/KtI77/fVqmFon3tP7XE3uHxCuu//AmBZtBQ8j+YNLPZW/bhv4OR
BD6aO/U/zyPivmEw5L+F+JAQAbP3PyeF4fShVOa/Z8hRwvLV+T/111TDweva
v1qa8FBjuPs/cNo8sYl457+rG0W78Wf9P02CqgpUaum/XkJExlXu/j/lByBQ
pWPlv0rxjfBdKQBASxSh3ffq4r8wDFZVS80AQIn3kmkqV+G/aPTEOBFlAUCh
1FZ400/uvxxYWWJd8gFA+Bn49uP/5b9fwE5WinYCQDqnfg5Mjuu/Yf4DKbPy
AkCiGvLGGj7nv7aVvjjCZwNAdWl/dxWG7L+vqhQXfdYDQMsbVXjj4+K/URxh
nYk/BECHV5NbAl7mv8j9nsV1owRA9YMjEDMf6r/OEUy2uwIFQMiycLhRqOW/
vDSKScVdBUDDAckcRbjmv2mz5tPutAVAXbdfxaS+578WQH4EiQgGQPmXeDZD
ueW/ZgymBNxYBkAdF0f7m9Tlv8ht5d0mpgZAk8EsWdfK5r86mcUHovAGQNGI
JXMXZue/lSeDB4A4B0B5FxoYDbjkv01Dkz7ufQdAu7byroe56r+QQGBSFcEH
QEq+GEGz0eO/iC1M0xoCCEC86EUQAOLrvy5hhhMgQQhA98scE24V6r9Gqu6p
Q34IQPI5ZGYluuW/3EI/hKG5CEB7i7Z+YDPpv3V70zNT8whA298EgE1s57++
4ugvcCsJQEmipN1bRuS/KjnT1g1iCUDxQ1wzXTDwv2//PYJAlwlAZ3R2VVAI
7r/Nqh9dGssJQA+xaC35n92/2pJMb6z9CUAZaIrFKWTjv0OMXYUGLwpAMeEJ
q+qH7b8FBF1ON18KQMe462g25de/SqAKdkyOCkDs8+p7ow3iv6F4WxM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9XbSBEZgbsv964dwvy
SOQ/YJgnBqm16b/fVqmFon3tP+DfohWwuOe//AmBZtBQ8j8o7EGcnYfuv4OR
BD6aO/U/vVVr0MX16L+F+JAQAbP3P/aqZd+7C+W/Z8hRwvLV+T9ENp16Le7j
v1qa8FBjuPs/mj9D/PCi5L+rG0W78Wf9P6RK9AuJl9W/XkJExlXu/j8N/Wqq
wkTuv0rxjfBdKQBAnk30oB3h4r8wDFZVS80AQCh5VBEwHey/aPTEOBFlAUDh
FzQBMODqvxxYWWJd8gFAbGcep8op479fwE5WinYCQKeDFkwJX+y/Yf4DKbPy
AkBVQmnIyZjjv7aVvjjCZwNAhOAoo0dX6r+vqhQXfdYDQNqQcAzJ1OG/URxh
nYk/BEBycOjlkD7lv8j9nsV1owRAxLQRNr144b/OEUy2uwIFQHEwOSgQy+m/
vDSKScVdBUDfMchwAWXjv2mz5tPutAVA2JFpSqYp4r8WQH4EiQgGQIiI0ozJ
xuG/ZgymBNxYBkDEG5NI/cznv8ht5d0mpgZA1vj9iIJ04r86mcUHovAGQM/P
v14PVeS/lSeDB4A4B0AOw9tEHtbmv01Dkz7ufQdAv93J51IQ57+QQGBSFcEH
QJ/c8gvIJem/iC1M0xoCCED2fYqjPJ/qvy5hhhMgQQhACYaO2dFY6L9Gqu6p
Q34IQBCRimj8pOO/3EI/hKG5CECYWDnmCZvnv3V70zNT8whA0/JUvwbX5r++
4ugvcCsJQHbFP8uo6ue/KjnT1g1iCUAlbX0Zp7Xmv2//PYJAlwlAWfxB12SP
7L/Nqh9dGssJQD57s72Cj+m/2pJMb6z9CUBhp6i5gsTbv0OMXYUGLwpAwUBI
VTUm8b8FBF1ON18KQLxxrwRKUPG/SqAKdkyOCkD4H+ersuv0vwTxXGM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5678589014015875},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-1.2039728043259361`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.3\"", 0.3, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.4\"", 0.4, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.6\"", 0.6, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.7\"", 0.7, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.5141277326297755`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.4271163556401458`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.3470736479666092`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2729656758128873`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.1394342831883648`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.0788096613719298`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.0216512475319814`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.9675840262617056, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.8675005677047231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.8209805520698302, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.7765287894989963, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.7339691750802004, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6539264674066639, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.616186139423817, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.579818495252942, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5447271754416722, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.4780358009429998, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.4462871026284195, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.4155154439616658, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.3856624808119846, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.3285040669720361, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.3011050927839216, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2744368457017603, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2484613592984996, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+6A/MhjH4vwN64dwvy
SOQ/y/evQDOVLcDfVqmFon3tP3Zyu4hV7CvA/AmBZtBQ8j/I6hwaTxAqwIOR
BD6aO/U/k8MHGVU2KcCF+JAQAbP3P78la6WHeijAZ8hRwvLV+T/VusEI3SAn
wFqa8FBjuPs/Ttk5bzYZJ8CrG0W78Wf9P/oUj0rNmybAXkJExlXu/j947rim
D80lwErxjfBdKQBA4DzuFrUmJcAwDFZVS80AQOjYdMgUkyTAaPTEOBFlAUBR
B2MzO/EkwBxYWWJd8gFA9J9MLCsFJMBfwE5WinYCQBcnG31M/SPAYf4DKbPy
AkCYyBfzxlsjwLaVvjjCZwNADdPiMS9ZI8CvqhQXfdYDQEW5ERB2bSLAURxh
nYk/BEAwfTCH/lUiwMj9nsV1owRAmYshbitHIsDOEUy2uwIFQLScDGm7uiHA
vDSKScVdBUBTnuGfroghwGmz5tPutAVATUes+dRXIcAWQH4EiQgGQE4r070t
+iDAZgymBNxYBkABwaPfHL8gwMht5d0mpgZAuvj1EXaVIMA6mcUHovAGQKPV
HNfYZyDAlSeDB4A4B0CU+53d5gcgwE1Dkz7ufQdAdHoQHyY0IMCQQGBSFcEH
QJjVLo2uJB/AiC1M0xoCCEAoAX58c8YfwC5hhhMgQQhA9R9ZdX8tH8BGqu6p
Q34IQFL2Ne+9Rh7A3EI/hKG5CECo6awkDV8ewHV70zNT8whAUaV1PT7RHcC+
4ugvcCsJQJb41VCSFx3AKjnT1g1iCUBeZrc4CUkewG//PYJAlwlAQuWSruus
HcDNqh9dGssJQJqHZY0OfBvA2pJMb6z9CUAr150Qc8IbwEOMXYUGLwpAjJc1
b+O7HMAFBF1ON18KQG7BpTAaQxrASqAKdkyOCkD+KaO2ULwawMLNNKo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8l9p2BGrcrwN64dwvy
SOQ/6F05+GfwKcDfVqmFon3tP/IrbpHwpSjA/AmBZtBQ8j/Gf4slECkowIOR
BD6aO/U/WLqWDWIQJ8CF+JAQAbP3P2mpdfZJLSbAZ8hRwvLV+T/ZgEkcH4sl
wFqa8FBjuPs/flxOjVYWJcCrG0W78Wf9P/zoWqWxBCTAXkJExlXu/j8dddNN
DtIkwErxjfBdKQBARrNG6gq6I8AwDFZVS80AQI45Kdfn8CPAaPTEOBFlAUDZ
uLruOIYjwBxYWWJd8gFAW45dI1m7IsBfwE5WinYCQBr+csBhASPAYf4DKbPy
AkDPlScOxCwiwLaVvjjCZwNAWvFBzQ1RIsCvqhQXfdYDQLBPK3gXhyHAURxh
nYk/BEBt+dTDmn0hwMj9nsV1owRAzNZbwFEEIcDOEUy2uwIFQL/z0fuLTSHA
vDSKScVdBUDKcmUJCK8gwGmz5tPutAVAvY7lKNdkIMAWQH4EiQgGQC0B9huA
KCDAZgymBNxYBkCqqSOxGFYgwMht5d0mpgZA4IgT1IGcH8A6mcUHovAGQI6p
rwpleB/AlSeDB4A4B0DR2y5vN2sfwE1Dkz7ufQdA9R4h47gWH8CQQGBSFcEH
QBYrt5K6/x7AiC1M0xoCCEAB9Skw7NgewC5hhhMgQQhAuLtPTxI7HsBGqu6p
Q34IQOwcWrugUB3A3EI/hKG5CECizOgz138dwHV70zNT8whA6ORcapMaHcC+
4ugvcCsJQOPsWYZa8BzAKjnT1g1iCUCpCPyVv34cwG//PYJAlwlAoG3nQ1Dy
HMDNqh9dGssJQHn0DVyuSxzA2pJMb6z9CUBL0ooMRJAawEOMXYUGLwpAhLsk
Lr/XHMAFBF1ON18KQGBoUTvcnBzASqAKdkyOCkBJIJJ3E0MdwBKbNzQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=0.\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480883696823`*^9},ExpressionUUID->"e701f3e7-32ba-42e7-a9c2-\
5bb2805a16db"],

Cell[BoxData["2"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448088371669*^9},ExpressionUUID->"dd4d8d79-a539-4a88-b625-\
fcd62e77ac1f"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT96t2pOYjAnwN64dwvy
SOQ/h/DlJReVJsDfVqmFon3tP32Gxk9vsSPA/AmBZtBQ8j9jr1WF8CYjwIOR
BD6aO/U/5Q8ik55PI8CF+JAQAbP3P+c/bmiugSLAZ8hRwvLV+T/H6FmImtkh
wFqa8FBjuPs/EXh2qi2XIsCrG0W78Wf9P4bPZV6JzyHAXkJExlXu/j8YRMLS
kFYhwErxjfBdKQBAC9q77WYyIMAwDFZVS80AQMYTIYxZcSDAaPTEOBFlAUCs
Et+Qs0wgwBxYWWJd8gFA+2QByRE4H8BfwE5WinYCQP9GTdlIjSDAYf4DKbPy
AkAk6DBmLMwewLaVvjjCZwNA2GztOAQlH8CvqhQXfdYDQIgPxkKyUB7AURxh
nYk/BEAvKZPyL0odwMj9nsV1owRAXuYaPag+HsDOEUy2uwIFQJJn3VH0LBzA
vDSKScVdBUBsdq10IaYcwGmz5tPutAVA89enJ0jmHMAWQH4EiQgGQPWReaYJ
/BvAZgymBNxYBkDrNt9oloMbwMht5d0mpgZAsG/C615sGsA6mcUHovAGQPDc
lTwpVBrAlSeDB4A4B0C8m0XuUAgawE1Dkz7ufQdAn+HjBMdHGsCQQGBSFcEH
QNW8dBFlKhnAiC1M0xoCCEDFAkn0wGIZwC5hhhMgQQhAACsgpFdbGcBGqu6p
Q34IQJglbiy7whjA3EI/hKG5CEAsOrwTDYYZwHV70zNT8whA5dNrFa1jGMC+
4ugvcCsJQPXprrTlkhbAKjnT1g1iCUC9wD33AJUYwG//PYJAlwlANu/Ml9jm
GMDNqh9dGssJQC2uAw4TBxfA2pJMb6z9CUCyp0E27LQWwEOMXYUGLwpAG6ZJ
jvHhFsAFBF1ON18KQKFdN5EiTxjASqAKdkyOCkB2efloQC4WwLf+Nbw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9buicWZPUswN64dwvy
SOQ/aTta9BiRK8DfVqmFon3tP7ctTl0FxCnA/AmBZtBQ8j8UU4r0eJ0nwIOR
BD6aO/U/KeVITvRlJcCF+JAQAbP3P6yQwUop0CTAZ8hRwvLV+T8Ztg3gQuUk
wFqa8FBjuPs/+XSMe2FjI8CrG0W78Wf9P0gnzIST3SLAXkJExlXu/j/fGFi3
5TAjwErxjfBdKQBAP1wU7dWSIsAwDFZVS80AQES8yBRVQyLAaPTEOBFlAUAB
VmVdULchwBxYWWJd8gFAKxYTGTf1IMBfwE5WinYCQB8AiAfUSSHAYf4DKbPy
AkBPTYx5/98gwLaVvjjCZwNANNoKGMuiIMCvqhQXfdYDQPL0ZNw0zB/AURxh
nYk/BEA0Sa4lRLkfwMj9nsV1owRAwW/XUw+KHsDOEUy2uwIFQGPrpGej8x3A
vDSKScVdBUAUM7nouMcewGmz5tPutAVAOlxImY33HMAWQH4EiQgGQOMrxcnU
KRzAZgymBNxYBkDYQTkTD7QcwMht5d0mpgZApUU8O/gSHMA6mcUHovAGQLcN
ICUj9BvAlSeDB4A4B0BLiHkQbq0bwE1Dkz7ufQdADBZOtjIpHMCQQGBSFcEH
QIM38kw9ARvAiC1M0xoCCECI37wLUysbwC5hhhMgQQhAX/FoP/8sG8BGqu6p
Q34IQMpZ5CD7jBnA3EI/hKG5CEBRp4NDECkawHV70zNT8whAkUhAlQRxGcC+
4ugvcCsJQFhdmqix+RnAKjnT1g1iCUBEpvIrwSMawG//PYJAlwlAKLnVFx2b
GcDNqh9dGssJQNMFpN7CmxjA2pJMb6z9CUBbjm2eKmkXwEOMXYUGLwpAIv5c
0mzLG8AFBF1ON18KQPig58/BKRjASqAKdkyOCkCKVRxkRe4ZwDuGMAE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.288271069236267},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.01948336229021, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.73180128983843, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.326336181730264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.172185501903007`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.038654109278484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.9208710736221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8h+igzsNMlwN64dwvy
SOQ/WTevzFwZIcDfVqmFon3tP3lU6C/iryDA/AmBZtBQ8j8+iQ2XwXEdwIOR
BD6aO/U/LFQTqFAiGsCF+JAQAbP3P1hH6UAI4RnAZ8hRwvLV+T/2EyLE3wIY
wFqa8FBjuPs/060BZES9FMCrG0W78Wf9P1IXETN1/BTAXkJExlXu/j8KE2FH
tLUSwErxjfBdKQBA9e6zClunEsAwDFZVS80AQA8h+l+GHg/AaPTEOBFlAUDt
iTD3jSMRwBxYWWJd8gFAFsXV1DNkDsBfwE5WinYCQASMoKdYVgvAYf4DKbPy
AkBETv6LpeYJwLaVvjjCZwNAWJfATYSXCMCvqhQXfdYDQHwLwA1+8gTAURxh
nYk/BEBKoE66vqkFwMj9nsV1owRAayMWOPKWAsDOEUy2uwIFQGWuandOIQLA
vDSKScVdBUCpE8JTVFkAwGmz5tPutAVAo/Bvmzl2/L8WQH4EiQgGQI48veBt
cPq/ZgymBNxYBkCw5D/cPir5v8ht5d0mpgZAZ+yKXVw29786mcUHovAGQKw3
ViWLpPa/lSeDB4A4B0CtowC+U/Dyv01Dkz7ufQdAu0DUS2228L+QQGBSFcEH
QHhUfy266em/iC1M0xoCCEDuvDZgEJTwvy5hhhMgQQhAb3VRB9DZ7L9Gqu6p
Q34IQApCGnTvmee/3EI/hKG5CEDpU+aeBWfcv3V70zNT8whAq/f/lqxV3L++
4ugvcCsJQM898HcFgeq/KjnT1g1iCUCws/BPR6Lkv2//PYJAlwlA0wpKpP3X
2b/Nqh9dGssJQDBSSHf5O+A/2pJMb6z9CUB9PegbmJ/WP0OMXYUGLwpA9oby
rn3Qxb8FBF1ON18KQN3NCRIEv/E/SqAKdkyOCkDvET2+Xv7jv2ONQvI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/CFMYsabsgwN64dwvy
SOQ/NY4uNG70H8DfVqmFon3tPzrCWuazLBbA/AmBZtBQ8j9eiSiCIE0bwIOR
BD6aO/U/k+6YPA7FG8CF+JAQAbP3Pwe6sO+WmRfAZ8hRwvLV+T/rx92XVjcU
wFqa8FBjuPs/Fzg7Yc2JFMCrG0W78Wf9P4p2Ty0laxDAXkJExlXu/j/J1DNE
f4ISwErxjfBdKQBAVDsBs5LYDcAwDFZVS80AQGpkNtNUhg/AaPTEOBFlAUA/
x/nZC7INwBxYWWJd8gFAtEhdpDStCcBfwE5WinYCQJRITm0R2QnAYf4DKbPy
AkCBDlmszrYEwLaVvjjCZwNAxEEX3fmjBcCvqhQXfdYDQEnWJNgIGgLAURxh
nYk/BEBQYvT5GlYBwMj9nsV1owRAu340tp3c/r/OEUy2uwIFQDRbcD2O/gLA
vDSKScVdBUBdxx3qADz4v2mz5tPutAVA99ohOPMs+b8WQH4EiQgGQEbng6hR
Lfi/ZgymBNxYBkAG7quHLlb4v8ht5d0mpgZAJ4c+4eb68b86mcUHovAGQPyJ
iKa6k/C/lSeDB4A4B0BXAwBj1hbxv01Dkz7ufQdAztQnTvET6b+QQGBSFcEH
QKYc4rNxbO6/iC1M0xoCCEBG+D37+MXpvy5hhhMgQQhAOG+fnVJO4L9Gqu6p
Q34IQHtdhUGX19u/3EI/hKG5CEBeu18JLVLWv3V70zNT8whArV6Uhj7R1L++
4ugvcCsJQFeShP05lbe/KjnT1g1iCUDktUOhLczDP2//PYJAlwlA0UPYTMjG
yr/Nqh9dGssJQE9VJMwRXLu/2pJMb6z9CUDvnO6MGGrfP0OMXYUGLwpADbSc
BJ5t1D8FBF1ON18KQJCC3TqHQ92/SqAKdkyOCkDQF2diWRPAvxYjQzg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.739652708745527},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT83KVDlqTGsv964dwvy
SOQ/qXIc4cVwwT/fVqmFon3tP9S7y91jsME//AmBZtBQ8j+ii/7L3ISiP4OR
BD6aO/U/1NOirzrbwL+F+JAQAbP3P3uh5d7thda/Z8hRwvLV+T8XYGwwQ2DV
v1qa8FBjuPs/RGFOhmaO3b+rG0W78Wf9PygzQaQ5CeS/XkJExlXu/j+FivfZ
HV7gv0rxjfBdKQBATwAidyWU2r8wDFZVS80AQPCcpUnaPtm/aPTEOBFlAUCg
xKdhEo/nvxxYWWJd8gFAOWbv5c3s4L9fwE5WinYCQJZKACY7a+m/Yf4DKbPy
AkAcO/s5Q9jiv7aVvjjCZwNAURsdl4BV57+vqhQXfdYDQNqJgLYVGOK/URxh
nYk/BECcNxtuaFzjv8j9nsV1owRA8n2VK6q/5r/OEUy2uwIFQHPDDwsq2eC/
vDSKScVdBUDkM7w7TDTkv2mz5tPutAVAM5S7kBdS5b8WQH4EiQgGQPb5P9hJ
OeO/ZgymBNxYBkAp0G6loa3jv8ht5d0mpgZAZF34UXpA4L86mcUHovAGQHCF
xWSgbeK/lSeDB4A4B0CF4B3IT0bhv01Dkz7ufQdAVM/3IaLH47+QQGBSFcEH
QLtdrMuz0Ny/iC1M0xoCCEAMVClXnM7kvy5hhhMgQQhAG0etwOjc5b9Gqu6p
Q34IQOksRMh0hOO/3EI/hKG5CEA2wvWZFjTmv3V70zNT8whAuaJwmUcx47++
4ugvcCsJQA3sR1JKv9u/KjnT1g1iCUC2ajyridbqv2//PYJAlwlAP/zkCf9N
7L/Nqh9dGssJQLWl213fp9O/2pJMb6z9CUAnQ76cw0bZv0OMXYUGLwpAeHBs
KiAH5b8FBF1ON18KQCFNmsWoQ9a/SqAKdkyOCkCBObE+1hrnvxwSVBc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+g4YPc34mqP964dwvy
SOQ/WlOGjeiU5b/fVqmFon3tP3RuYXsp9eQ//AmBZtBQ8j8bKzfKgdrpv4OR
BD6aO/U/bmvXPwLM57+F+JAQAbP3P68+QnWofuS/Z8hRwvLV+T/g1yc9i5nj
v1qa8FBjuPs/cpmte9ez5L+rG0W78Wf9P3pa2g+kpNO/XkJExlXu/j/7hnjx
7F/uv0rxjfBdKQBACjP9hVsW4r8wDFZVS80AQLDOCy+y4+u/aPTEOBFlAUD/
pwL2KCHrvxxYWWJd8gFA1ke8aUBC479fwE5WinYCQJWBK1A8aey/Yf4DKbPy
AkDCPrVjpJnjv7aVvjjCZwNAZ4XLG+ge6r+vqhQXfdYDQOrGeooDK+K/URxh
nYk/BEBMbPfm2Tnlv8j9nsV1owRAb2TvJV1m4b/OEUy2uwIFQM8Gu/treem/
vDSKScVdBUAF8ruqJcHjv2mz5tPutAVAirdozVkn4r8WQH4EiQgGQD8fRBTn
juG/ZgymBNxYBkCGH5k9p8Hnv8ht5d0mpgZAb/+QfMm44r86mcUHovAGQDVs
S4RAUOS/lSeDB4A4B0DJj4Q48Ojmv01Dkz7ufQdAgvJZ1xCr57+QQGBSFcEH
QKEcq1bQTei/iC1M0xoCCED+W952Ygbqvy5hhhMgQQhAGJcOCiyP6L9Gqu6p
Q34IQH2OLXR9MuO/3EI/hKG5CECl1AP1im3nv3V70zNT8whAuPZMb6dU5r++
4ugvcCsJQGPuPclRBui/KjnT1g1iCUAhFxuD/STnv2//PYJAlwlAL4SCWo/T
7L/Nqh9dGssJQO01uXpe8ui/2pJMb6z9CUCn7omj0I/bv0OMXYUGLwpAHW79
00PG8b8FBF1ON18KQOiLzfs27e+/SqAKdkyOCkBtY+vgbyb0v9eFWs8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5469435389473166},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            TagBox[
             InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            TagBox[
             InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.09531017980432493, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.1823215567939546, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.26236426446749106`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.3364722366212129, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.47000362924573563`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.5306282510621704, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.5877866649021191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6418538861723947, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.7419373447293773, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.7884573603642703, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.8329091229351039, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.8754687373538999, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.9162907318741551, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/arxLf8RcuwN64dwvy
SOQ/p8fBjzuTK8DfVqmFon3tPyVGmb+sGSrA/AmBZtBQ8j95QMpUhfcowIOR
BD6aO/U/1x56LapKKMCF+JAQAbP3PwSQfWmi2CfAZ8hRwvLV+T+SoSMfsgEn
wFqa8FBjuPs/Slmj9dGUJsCrG0W78Wf9P1nKCIXFTSbAXkJExlXu/j8a9nod
sIIlwErxjfBdKQBAvEhMh8bQJMAwDFZVS80AQA6r90ogSyTAaPTEOBFlAUCi
O+YXtookwBxYWWJd8gFA18OP94W3I8BfwE5WinYCQO7dmkhN3iPAYf4DKbPy
AkD+M2GhBRgjwLaVvjjCZwNAU7ydMY4II8CvqhQXfdYDQFVEnAJZYyLAURxh
nYk/BECV46sP8CciwMj9nsV1owRA65JF078SIsDOEUy2uwIFQFbrOYxVbyHA
vDSKScVdBUCY0yey82EhwGmz5tPutAVAIMjKs2EyIcAWQH4EiQgGQMVn2Vuc
0yDAZgymBNxYBkA+70Uo3J0gwMht5d0mpgZATzBJ1B8uIMA6mcUHovAGQLua
lIExGSDAlSeDB4A4B0C66YQWTKMfwE1Dkz7ufQdAia/RTCmMH8CQQGBSFcEH
QG4VNEVaeh7AiC1M0xoCCECz9FsOvuUewC5hhhMgQQhAgCoz/IioHsBGqu6p
Q34IQOkKvGFhAR7A3EI/hKG5CEA6SuKeiQAewHV70zNT8whAAfv0oOhLHcC+
4ugvcCsJQHt0m2TLSxzAKjnT1g1iCUA5AFMULpgdwG//PYJAlwlAqzRoBLB2
HcDNqh9dGssJQJ2tMY9O3RrA2pJMb6z9CUCGFN0KA+wawEOMXYUGLwpAyAOT
1HasG8AFBF1ON18KQGPoVkqfKRrASqAKdkyOCkApbgSuzV4bwD9cNHc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT92X1CpYpIqwN64dwvy
SOQ/ir1k4f1hKsDfVqmFon3tPxS80kUViibA/AmBZtBQ8j9SrQa/T4kowIOR
BD6aO/U/6uVm8nWjJ8CF+JAQAbP3Pyz+riExxCbAZ8hRwvLV+T+74KoGLB8m
wFqa8FBjuPs/Ds5/0sGqJcCrG0W78Wf9PxFtADA+giTAXkJExlXu/j9Ab6rq
t1olwErxjfBdKQBApxBDHHYuJMAwDFZVS80AQBj7iVt+ZyTAaPTEOBFlAUDQ
g7846/0jwBxYWWJd8gFA+vHVLZcrI8BfwE5WinYCQLxxQNLjaiPAYf4DKbPy
AkAmkUDaq5AiwLaVvjjCZwNAtARaw3irIsCvqhQXfdYDQNL2KSbh5SHAURxh
nYk/BECKqQCeD9IhwMj9nsV1owRAJPfrxcxTIcDOEUy2uwIFQM+MES+alCHA
vDSKScVdBUDHYbKhVf0gwGmz5tPutAVA8jL3WMapIMAWQH4EiQgGQLumZt1l
ZiDAZgymBNxYBkAKmu67zZMgwMht5d0mpgZAhtoBD8oNIMA6mcUHovAGQExv
il++6B/AlSeDB4A4B0DL3rAqeNkfwE1Dkz7ufQdAvyuWyvmQH8CQQGBSFcEH
QBJIS0uCRh/AiC1M0xoCCEDs7D1LRSMfwC5hhhMgQQhAk8LwYCGbHsBGqu6p
Q34IQJQ7K7hQlx3A3EI/hKG5CEB/VSHnissdwHV70zNT8whAthK6m2tYHcC+
4ugvcCsJQDymS3vfPh3AKjnT1g1iCUCUMNNKP9QcwG//PYJAlwlAblvnz7I/
HcDNqh9dGssJQPvvQ7F5ehzA2pJMb6z9CUCklsfhbswawEOMXYUGLwpA8aB6
d+k8HcAFBF1ON18KQEciMtSDgBzASqAKdkyOCkCATPy8MEodwOW/Pqk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=10.\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480894397955`*^9},ExpressionUUID->"cde033c3-587f-4ce5-a54f-\
be5e0e3b9fde"],

Cell[BoxData["3"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480894417973`*^9},ExpressionUUID->"af5d6983-63d3-406f-94bd-\
80eeff7a2746"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8KZXdd1EgkwN64dwvy
SOQ/jsj9Gu8nI8DfVqmFon3tP513ugsefyPA/AmBZtBQ8j/529nciiMjwIOR
BD6aO/U/hOjclTJMIsCF+JAQAbP3P4Pwu7NnFyLAZ8hRwvLV+T+MkzldQ7oh
wFqa8FBjuPs/QtUDpFNSIcCrG0W78Wf9P6m6smnEIyHAXkJExlXu/j96Mgkp
LRMhwErxjfBdKQBACB/woB2TIMAwDFZVS80AQH8CdgZ5GyDAaPTEOBFlAUCK
+XkxAaIgwBxYWWJd8gFAXIsXNctiH8BfwE5WinYCQIQ2JQGSQR/AYf4DKbPy
AkASyMVpvV0fwLaVvjjCZwNArzonrtm2HsCvqhQXfdYDQPrrPeQC1RzAURxh
nYk/BECwtTITJpMewMj9nsV1owRAengQkfmyHMDOEUy2uwIFQH1BFr9BbBzA
vDSKScVdBUBL3TIgXn0cwGmz5tPutAVAgDR5DQN5G8AWQH4EiQgGQP0mHzHL
3RvAZgymBNxYBkCv87b+QAAbwMht5d0mpgZARcfuUyfkGsA6mcUHovAGQICw
I1jvBhvAlSeDB4A4B0D2To9KnCoawE1Dkz7ufQdAPXj07OlfGcCQQGBSFcEH
QKCFP+he/RjAiC1M0xoCCEDPj6J+nYoZwC5hhhMgQQhAjF/TSIMkGsBGqu6p
Q34IQK1vBlHfRhnA3EI/hKG5CEB/aXnpZ9sYwHV70zNT8whACWAQOGAJGMC+
4ugvcCsJQNjlcOK8zhfAKjnT1g1iCUCmlzPfdgIZwG//PYJAlwlAUiBXN3oN
GMDNqh9dGssJQF1HTUsDaxXA2pJMb6z9CUBhPzN8zjEVwEOMXYUGLwpAKKdG
/EXaGMAFBF1ON18KQHQPMOs+vxXASqAKdkyOCkDaoqlx238XwFqLLxo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9WauzELwApwN64dwvy
SOQ/k5aCntdAJ8DfVqmFon3tP7LfFqIWFiLA/AmBZtBQ8j8ENyUz8ScnwIOR
BD6aO/U/BQixQIkhJcCF+JAQAbP3P/Mb/y1SUyTAZ8hRwvLV+T9qBf14uQUk
wFqa8FBjuPs/5azZxf5sIsCrG0W78Wf9P38vhHOaHyLAXkJExlXu/j80M+9n
rGwiwErxjfBdKQBARG19WrcaIcAwDFZVS80AQBNVVO0ThiHAaPTEOBFlAUCL
HePyHOAhwBxYWWJd8gFAiRSfzpLtIMBfwE5WinYCQJzrBCdPwSDAYf4DKbPy
AkD+Gdmth3IgwLaVvjjCZwNA4PZVt6xlH8CvqhQXfdYDQINrYO0+ZB7AURxh
nYk/BEBBerKNGzAewMj9nsV1owRAkGJuupqCHsDOEUy2uwIFQOzN9YTcRB3A
vDSKScVdBUBSU8U0p+0dwGmz5tPutAVA9M4VpaGjHMAWQH4EiQgGQAeWExP8
QhzAZgymBNxYBkB5ubbVUX4cwMht5d0mpgZARcHxZIa0GsA6mcUHovAGQNYd
UrAJlBvAlSeDB4A4B0BsBAM5etgawE1Dkz7ufQdA7rzc7ch2GsCQQGBSFcEH
QHSZi4+LAhvAiC1M0xoCCEBON44UG5MawC5hhhMgQQhAEZHWQy68GsBGqu6p
Q34IQDUrKcjk1BjA3EI/hKG5CECJS5NCZYkZwHV70zNT8whAF6ipid/KGMC+
4ugvcCsJQOJXiBI9cxnAKjnT1g1iCUCt1Uj1sdYZwG//PYJAlwlAuhU1Hr7b
GcDNqh9dGssJQGVQbD3tzRjA2pJMb6z9CUCRtXKV048XwEOMXYUGLwpA77nn
8PfjGMAFBF1ON18KQLYvWsRTURvASqAKdkyOCkDTTaW7zcwawEhTOfE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.428839302553781},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-12.206072645530174`, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "1.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "1.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.199705077879927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9SI/lWR9MlwN64dwvy
SOQ/Eb1q7G8kIsDfVqmFon3tPyzT/mBSmh7A/AmBZtBQ8j/WLrT9bEAawIOR
BD6aO/U/E3d4VlpPG8CF+JAQAbP3PwSuuu/olxjAZ8hRwvLV+T+FoLySRWMV
wFqa8FBjuPs/nGkhFGa8FMCrG0W78Wf9P3R8afDzwRTAXkJExlXu/j+/A9gI
ttERwErxjfBdKQBAuhbow9RzEMAwDFZVS80AQHcddLxbPw7AaPTEOBFlAUDz
qIZbN74OwBxYWWJd8gFAbwu/S5V5DMBfwE5WinYCQIGK1tWXng3AYf4DKbPy
AkDi3pmnjdoGwLaVvjjCZwNAiSysawbMBsCvqhQXfdYDQLEo78t0GAfAURxh
nYk/BEDn3MO8d6UBwMj9nsV1owRAXuTX9vhmBMDOEUy2uwIFQFh7On8lI/6/
vDSKScVdBUCYbJLkTuT+v2mz5tPutAVA7VB8WHOc/b8WQH4EiQgGQB5eUKuf
p/i/ZgymBNxYBkAUF1hygWv1v8ht5d0mpgZAxpXpCHTG8r86mcUHovAGQDti
/L9C/vC/lSeDB4A4B0DsUglxwTPvv01Dkz7ufQdAnVTbZmFu8r+QQGBSFcEH
QMWo9okJwuO/iC1M0xoCCECgLclnPQfsvy5hhhMgQQhAPncL3/704r9Gqu6p
Q34IQLTYN5a2fty/3EI/hKG5CEDTDpO0VSDfv3V70zNT8whAupddC3jB1L++
4ugvcCsJQHO1sfUsvrK/KjnT1g1iCUAFP2vQF8vXv2//PYJAlwlA1JtajoDt
4L/Nqh9dGssJQGeFQeOpFbg/2pJMb6z9CUC86Qn0jbTJP0OMXYUGLwpAEp8v
pc2Dxz8FBF1ON18KQKL7KTIoaOg/SqAKdkyOCkCNQzSZNMvRPxA4Sy4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Y0uUzhoIjwN64dwvy
SOQ/j/AuHGbvIcDfVqmFon3tPzhTTQvSWxrA/AmBZtBQ8j/AZlfCkOcZwIOR
BD6aO/U/ZXi4wEv2GsCF+JAQAbP3PyKH7/e7PhjAZ8hRwvLV+T+GLpZZvhIW
wFqa8FBjuPs/PVdM+j54FsCrG0W78Wf9P0TwnZny9hHAXkJExlXu/j+z0per
hgAUwErxjfBdKQBAkGiyC6avEcAwDFZVS80AQI5IgS20ShHAaPTEOBFlAUAz
oZGjSLwNwBxYWWJd8gFA0ldkGhs3CsBfwE5WinYCQLhHH9zR6QvAYf4DKbPy
AkDp9cY5u5UGwLaVvjjCZwNAikBzOiG1CcCvqhQXfdYDQEmrBKc/xATAURxh
nYk/BEC9WZedTmkEwMj9nsV1owRA45JgpvfN/7/OEUy2uwIFQB9GyVP2HwTA
vDSKScVdBUAW95YV4aD7v2mz5tPutAVAIdn8hLfK+r8WQH4EiQgGQEiCmDry
y/e/ZgymBNxYBkBAqhdpUN74v8ht5d0mpgZAwp9s2h9z9786mcUHovAGQGWc
4huR9/G/lSeDB4A4B0CNJJnODkj0v01Dkz7ufQdApfTyYfme8r+QQGBSFcEH
QNIqVqNude6/iC1M0xoCCEBO/Hgz0lXuvy5hhhMgQQhAyDqgQorR479Gqu6p
Q34IQMTajz3dR+S/3EI/hKG5CEDNU+YOjQDgv3V70zNT8whAQ9HYRdr33r++
4ugvcCsJQIIrHSdIgsu/KjnT1g1iCUAQ9ZzApxWwP2//PYJAlwlAggLSICiM
xL/Nqh9dGssJQNpMlT+CSKa/2pJMb6z9CUDvAfj7vRzgP0OMXYUGLwpAZf4q
iE96yr8FBF1ON18KQC41HLYg588/SqAKdkyOCkA7hA50uCJ4P81mSOs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.739305264860038},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Jd+6QujvuP964dwvy
SOQ/lvrxFBOR6T/fVqmFon3tP3AfCCvzkt8//AmBZtBQ8j9MGOdbUw7dP4OR
BD6aO/U/Ugfd6fexbj+F+JAQAbP3P9cjtuHdere/Z8hRwvLV+T8VkEe/0X6V
v1qa8FBjuPs/S8nmU7tixr+rG0W78Wf9PwrBlSHXtNq/XkJExlXu/j/Rw3Ci
i5rVv0rxjfBdKQBA6fGo2KKl0r8wDFZVS80AQHFR9ECZLdC/aPTEOBFlAUBj
5BZUq2vkvxxYWWJd8gFAYnko2VA73b9fwE5WinYCQI167aVAleW/Yf4DKbPy
AkD5WQ7DbKrev7aVvjjCZwNA+HW8szgw4r+vqhQXfdYDQIYtilk8Qd2/URxh
nYk/BEA4Cjak0RXhv8j9nsV1owRAhdUaQ73W4r/OEUy2uwIFQGkfzPAUjdm/
vDSKScVdBUD25EoBn9rhv2mz5tPutAVAqtf5q0bm378WQH4EiQgGQDyfmNAw
NOG/ZgymBNxYBkBkULG1kzfcv8ht5d0mpgZA5nYJ1m9m3b86mcUHovAGQMAl
LqJzBOG/lSeDB4A4B0B9cSr+7HLev01Dkz7ufQdA8kNgcjR74L+QQGBSFcEH
QIJ2VUElI9a/iC1M0xoCCEAoKI7xH9Pjvy5hhhMgQQhACXxbKba15b9Gqu6p
Q34IQNpDybKpg+K/3EI/hKG5CEAqu/WMxqTjv3V70zNT8whAkc5e7eX837++
4ugvcCsJQDFUi8Hvl9y/KjnT1g1iCUBnNCn+fDvqv2//PYJAlwlA1ArBg0r4
6L/Nqh9dGssJQKB6TrkHzMi/2pJMb6z9CUDodcVBUt/Hv0OMXYUGLwpAI7mF
+fcf678FBF1ON18KQP6/9lIZCMy/SqAKdkyOCkAhgUssacvnv0P5WCE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8zfnxxZmG2P964dwvy
SOQ/vniYigH8yb/fVqmFon3tPzfIs+rbwvY//AmBZtBQ8j+xcnp08xLMv4OR
BD6aO/U/AKc9uef65b+F+JAQAbP3P3k7UthGJ+O/Z8hRwvLV+T/wZbE7a//j
v1qa8FBjuPs/YSa9QQVf5L+rG0W78Wf9P0MzuaNpJdS/XkJExlXu/j8LeHHE
0Bnuv0rxjfBdKQBAkaLNB8Ue4r8wDFZVS80AQJVNgoJpC+y/aPTEOBFlAUBn
8JqjoznrvxxYWWJd8gFA6C/t4Nhs479fwE5WinYCQNnPho9GWOy/Yf4DKbPy
AkCsLd4amOzjv7aVvjjCZwNAVZ+vqQIq6r+vqhQXfdYDQOO8U47P9+G/URxh
nYk/BEAlyDQTni7lv8j9nsV1owRAbaPsQUrS4b/OEUy2uwIFQJysO53q1ui/
vDSKScVdBUAnLCZSgC/kv2mz5tPutAVA75/3nxpy4r8WQH4EiQgGQFqJQMir
++G/ZgymBNxYBkDgrh2vs57nv8ht5d0mpgZAznKNAxOK4b86mcUHovAGQOhd
omZsReS/lSeDB4A4B0BD0WOTCBzmv01Dkz7ufQdAil/4PKYG5r+QQGBSFcEH
QKhsieAPwOi/iC1M0xoCCEB+9VImDpjpvy5hhhMgQQhAGYbNVqt66L9Gqu6p
Q34IQONbK689heK/3EI/hKG5CEAgl62wnPjmv3V70zNT8whAnTEoVOeD5b++
4ugvcCsJQBOIkRI0xue/KjnT1g1iCUC3vVlboonnv2//PYJAlwlAFhhRG9SM
7b/Nqh9dGssJQCf3QrZ/d+m/2pJMb6z9CUBf+l7voALdv0OMXYUGLwpAp9Pw
Y6cm8L8FBF1ON18KQGtp3C5m4fK/SqAKdkyOCkA/HfSqXzH1vw/HVyI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5752465481370873},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8ZY//V03sswN64dwvy
SOQ/RqvatsKAKsDfVqmFon3tP1RVXBwkiynA/AmBZtBQ8j/EPnCWqT4owIOR
BD6aO/U/7zpcUuoTKMCF+JAQAbP3P9jyFI/kXifAZ8hRwvLV+T8CZ6Qf/msm
wFqa8FBjuPs/oSrzuZMKJsCrG0W78Wf9P3W6cDkw6CXAXkJExlXu/j/2hulc
My8lwErxjfBdKQBABL82GF+WJMAwDFZVS80AQI3Tiq4zByTAaPTEOBFlAUC9
aDQF8FskwBxYWWJd8gFAtqO/J4qUI8BfwE5WinYCQBp/P61koyPAYf4DKbPy
AkA7isc3V+IiwLaVvjjCZwNAekVs6/q3IsCvqhQXfdYDQGn4Q1c4LiLAURxh
nYk/BEBrpj06vAUiwMj9nsV1owRAPUKbVxLWIcDOEUy2uwIFQLK3U8mrLyHA
vDSKScVdBUC1uNpXZD0hwGmz5tPutAVAITp2X/7dIMAWQH4EiQgGQJpmEhLF
tCDAZgymBNxYBkBdCLKmEEYgwMht5d0mpgZAVE9MDRUWIMA6mcUHovAGQAnz
4RvRAyDAlSeDB4A4B0AQSAIauGMfwE1Dkz7ufQdAlxEDeBskH8CQQGBSFcEH
QB0IyA4jER7AiC1M0xoCCEDdvDCmLccewC5hhhMgQQhAZfWJP3ClHsBGqu6p
Q34IQOmMyuHX4h3A3EI/hKG5CEDhJa5Y3q8dwHV70zNT8whApuame7PmHMC+
4ugvcCsJQOqrLweHWhzAKjnT1g1iCUCW6PqN3IYdwG//PYJAlwlAhJv2d6YN
HcDNqh9dGssJQBK5E7BdahrA2pJMb6z9CUAg3v3tsxYawEOMXYUGLwpATxKl
undwHMAFBF1ON18KQFyabPwuphnASqAKdkyOCkDLHvl5mXUbwHvgM6Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9tiofuB98rwN64dwvy
SOQ/iMNg6xnCKsDfVqmFon3tPwsjW1GuOCbA/AmBZtBQ8j+S6TlUoYUowIOR
BD6aO/U/DCGfQViXKMCF+JAQAbP3P/g6uk10qSfAZ8hRwvLV+T+cdO6PzAon
wFqa8FBjuPs/bIvPdFt4JsCrG0W78Wf9P4xve4fKRyXAXkJExlXu/j/RFUs0
QwgmwErxjfBdKQBAInNG2u3SJMAwDFZVS80AQKAucvHa/iTAaPTEOBFlAUDV
DWgEZYckwBxYWWJd8gFAh2cu5vesI8BfwE5WinYCQDmDrFcn3iPAYf4DKbPy
AkA4InvbygEjwLaVvjjCZwNAk5p2OrMOI8CvqhQXfdYDQJLPoVB/PiLAURxh
nYk/BEBeA7JBbCYiwMj9nsV1owRA3s0uadypIcDOEUy2uwIFQJDxN8zo0yHA
vDSKScVdBUC++TvBPkkhwGmz5tPutAVAqZgdOhfvIMAWQH4EiQgGQEU4yedo
qSDAZgymBNxYBkD43ow3asogwMht5d0mpgZAMCa0Gx8wIMA6mcUHovAGQFdW
JiAdJiDAlSeDB4A4B0AkqyePQg8gwE1Dkz7ufQdAEpGPIOy1H8CQQGBSFcEH
QHlFQCcAqR/AiC1M0xoCCEAj5P8dj2UfwC5hhhMgQQhA+9ukYtbjHsBGqu6p
Q34IQNC76BrlyB3A3EI/hKG5CEBajua66QAewHV70zNT8whANG5N/iJ/HcC+
4ugvcCsJQPjmojb3dB3AKjnT1g1iCUASQDZZAxwdwG//PYJAlwlAYCCCtzyP
HcDNqh9dGssJQAcYP0C9wBzA2pJMb6z9CUBL/ZVJXxcbwEOMXYUGLwpAbk1f
HTQGHcAFBF1ON18KQAU8maOFax3ASqAKdkyOCkCHczI72rkdwMsqMG8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=20.25\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448090460642*^9},ExpressionUUID->"1467eded-c9bb-466c-82d4-\
00f0c859b32c"],

Cell[BoxData["4"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448090462645*^9},ExpressionUUID->"ca6c7c17-c460-4f2c-9a31-\
c4574a10613c"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/xJ+F1j10iwN64dwvy
SOQ/qMs/JRIhJMDfVqmFon3tP5hxIIwuEiPA/AmBZtBQ8j/dtVqtQFgiwIOR
BD6aO/U/sSgHLZrvIcCF+JAQAbP3P93Hy6fJ4iHAZ8hRwvLV+T8x7Gqilfog
wFqa8FBjuPs/R57fpX0CIcCrG0W78Wf9P3Egu0gKyCDAXkJExlXu/j9nqJ91
STEgwErxjfBdKQBA4BV4+EsyIMAwDFZVS80AQACJ9IAtth7AaPTEOBFlAUAP
M1W+TdIfwBxYWWJd8gFAzyLsrQBjHsBfwE5WinYCQO5v/v+3dB7AYf4DKbPy
AkAQ0nHRCP4ewLaVvjjCZwNAWHAbFiFWHcCvqhQXfdYDQKMMsnaA4h3AURxh
nYk/BEAB/XGu6iQcwMj9nsV1owRAluo7UOYOHcDOEUy2uwIFQF8qxfRKfhvA
vDSKScVdBUBv0/SyUZcbwGmz5tPutAVAOhgHVg2WG8AWQH4EiQgGQFP0Ceii
VxvAZgymBNxYBkBlOE9ID0cbwMht5d0mpgZAKTuS0r4AGsA6mcUHovAGQFcM
nS0ehRnAlSeDB4A4B0DYl/NRY3IZwE1Dkz7ufQdAIj/OiocTGcCQQGBSFcEH
QLS/NL/ichjAiC1M0xoCCEAcSByAq8wZwC5hhhMgQQhAO2v4ZJXiGMBGqu6p
Q34IQBoEEMFy2hjA3EI/hKG5CEDPVtV5tUwawHV70zNT8whAfrl5H7wEF8C+
4ugvcCsJQIdPNNLUXRfAKjnT1g1iCUD1+dQINB0ZwG//PYJAlwlAXAeg/doH
GMDNqh9dGssJQLJ7whtNWhXA2pJMb6z9CUAxEIv7LQYVwEOMXYUGLwpA3PZ1
EJI+GcAFBF1ON18KQMA/UdbSUBTASqAKdkyOCkCdyNfgs+kWwOODMts=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8nathMW8AowN64dwvy
SOQ/9LDshMsCJ8DfVqmFon3tPzjokNE7tSbA/AmBZtBQ8j+V09eH1L0hwIOR
BD6aO/U/ux8Q7og9I8CF+JAQAbP3P355/GJFHiPAZ8hRwvLV+T9PQehLejci
wFqa8FBjuPs/ZEERbKkiI8CrG0W78Wf9Pw/VOlEOQSHAXkJExlXu/j8NLkIS
TociwErxjfBdKQBA6kht5xA9IcAwDFZVS80AQPSJyrwVfyHAaPTEOBFlAUCJ
QeLTa5cgwBxYWWJd8gFAFUyGK1WFIMBfwE5WinYCQFokEn5uUyDAYf4DKbPy
AkD7T85avwEfwLaVvjjCZwNATP4/OcZbH8CvqhQXfdYDQM5EAfC/dx3AURxh
nYk/BECFYxZYjcodwMj9nsV1owRAL0a58UszHcDOEUy2uwIFQGOMCtWKsR3A
vDSKScVdBUAnIkrTUyYcwGmz5tPutAVApPcqO6fHG8AWQH4EiQgGQJsU2IaA
KBzAZgymBNxYBkA+IQ1iu4gbwMht5d0mpgZAN7Z4UgZxG8A6mcUHovAGQOCd
LV2CIhvAlSeDB4A4B0CidifTvucbwE1Dkz7ufQdA/e/iqThwGsCQQGBSFcEH
QM6qsNBLVRrAiC1M0xoCCEDMF3cNne0ZwC5hhhMgQQhAdOv8ObpfGsBGqu6p
Q34IQNNlUsLPNxjA3EI/hKG5CEDIPOA7/ugYwHV70zNT8whA/JuF0T3lGMC+
4ugvcCsJQJh2J3gUARnAKjnT1g1iCUB6grNrC9wYwG//PYJAlwlABv8PDQx4
GsDNqh9dGssJQH+2H+o0nBjA2pJMb6z9CUAYpvK/HNYVwEOMXYUGLwpAQA+y
PbMiGcAFBF1ON18KQB3N2yBeYRrASqAKdkyOCkDU1ajMYU8awPfyMmg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.374696727920156},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-12.206072645530174`, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "1.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "1.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            TemplateBox[{"\[Times]", "\"\[Times]\"", "5.`", 
              TemplateBox[{"10", 
                RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
               SuperscriptBox]}, "RowWithSeparators"], TraditionalForm], {
           0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.005\"", 0.005, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.199705077879927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8pYDtOAVYiwN64dwvy
SOQ/p2iOIptZH8DfVqmFon3tPwLRFKUuSh7A/AmBZtBQ8j/xg6oi7t8awIOR
BD6aO/U/i3rp/348GsCF+JAQAbP3P2haKIsWnRfAZ8hRwvLV+T9CtDu4WlMV
wFqa8FBjuPs/TRfSZGr4E8CrG0W78Wf9P0Dldx5zBRTAXkJExlXu/j/YTFI9
8hsSwErxjfBdKQBAgR3IZcU/EMAwDFZVS80AQOi7CogR8w/AaPTEOBFlAUAA
8z/tXUgPwBxYWWJd8gFALx/bZFfSDMBfwE5WinYCQJa+Q4bgYgzAYf4DKbPy
AkBLbh7jbwcGwLaVvjjCZwNAI+ZNKKq5BsCvqhQXfdYDQLpoLLciWgPAURxh
nYk/BEC7x4WvtDgFwMj9nsV1owRAmLJ7yAZmAcDOEUy2uwIFQID/MWwXswDA
vDSKScVdBUDNCu4kU8r/v2mz5tPutAVA3vqxHvsj+r8WQH4EiQgGQHBvFQ/A
3fm/ZgymBNxYBkAn2xuI2xbyv8ht5d0mpgZAbXEgqkbA8r86mcUHovAGQHSq
W90rSvK/lSeDB4A4B0BdtXnI5aPwv01Dkz7ufQdA2UrB3GhO8L+QQGBSFcEH
QO8j+47r1OO/iC1M0xoCCEAJkNvuTHTivy5hhhMgQQhAQ0HuW2bw6L9Gqu6p
Q34IQEH7xJ8redi/3EI/hKG5CEBjk2XKnLuuv3V70zNT8whAKHuC2MnH4r++
4ugvcCsJQC7ofpSzFKy/KjnT1g1iCUAKKO66UF/Cv2//PYJAlwlAZx8LlY6w
yb/Nqh9dGssJQI0WKKtKv7w/2pJMb6z9CUB96NIYzorUP0OMXYUGLwpAbNLp
NSwP0T8FBF1ON18KQK013DzTguU/SqAKdkyOCkCEzfeF+RTlP1R9QvQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8YotU+XMMmwN64dwvy
SOQ/z3wfjT6TI8DfVqmFon3tP7tD6mKp+hfA/AmBZtBQ8j+AV7P4nKIfwIOR
BD6aO/U/ByxsaAZ0H8CF+JAQAbP3P2floDdntxrAZ8hRwvLV+T+HJAjjvlcZ
wFqa8FBjuPs/iZwu/F91FcCrG0W78Wf9P71bQLvZqRPAXkJExlXu/j+NDr06
lfETwErxjfBdKQBAah+b149yEcAwDFZVS80AQBQPcZr6TBHAaPTEOBFlAUCt
hDizJjoRwBxYWWJd8gFALC2qQI+mC8BfwE5WinYCQAutttF4iw3AYf4DKbPy
AkA8rvAwUc0JwLaVvjjCZwNAr4U0G9GXCcCvqhQXfdYDQEew/OIbzwbAURxh
nYk/BED4fkLEQDQFwMj9nsV1owRAKsrgaMcPAsDOEUy2uwIFQJ/z+gKyygLA
vDSKScVdBUCdpbLONx4BwGmz5tPutAVAJz9MBicG/r8WQH4EiQgGQIa22z+2
Uvi/ZgymBNxYBkBZij2JXQP9v8ht5d0mpgZAyy1Clwr29L86mcUHovAGQLZJ
lzFs6vO/lSeDB4A4B0CnWxefdNDwv01Dkz7ufQdA21Y6Z0fS8r+QQGBSFcEH
QC0IAsLlwPG/iC1M0xoCCEAWFp/Y0d3xvy5hhhMgQQhA6oUSx+ki579Gqu6p
Q34IQLeFkW5dxuq/3EI/hKG5CECse+Vj/Ljlv3V70zNT8whAgbsdkCq/27++
4ugvcCsJQNxMQelo19S/KjnT1g1iCUAq9MK1Og7Av2//PYJAlwlA21QMfdCJ
s7/Nqh9dGssJQKFzv6//3Li/2pJMb6z9CUAHlJ6QLIWgP0OMXYUGLwpAhsMe
8ghpwr8FBF1ON18KQGblfYAbpb8/SqAKdkyOCkA3rurFvIa1v2OPRoE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.942950072308346},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/hnhPdK5MAQN64dwvy
SOQ/vhvq0pjM8T/fVqmFon3tPwYqWdQafeQ//AmBZtBQ8j/gAA3q4jbiP4OR
BD6aO/U/yZEn0sDbyj+F+JAQAbP3P+uEpfEYKLI/Z8hRwvLV+T8IA7Sy/abJ
P1qa8FBjuPs/Ar07NWk/gD+rG0W78Wf9P06groW05c6/XkJExlXu/j+fk0w/
FznBv0rxjfBdKQBAg4xYeDTYxr8wDFZVS80AQLQDSozlccC/aPTEOBFlAUDW
/ivotXvevxxYWWJd8gFA5hUHsOX41L9fwE5WinYCQBQDj/U/pt+/Yf4DKbPy
AkB2812PvlXYv7aVvjjCZwNAllpqLLXQ17+vqhQXfdYDQAEHis1ETdq/URxh
nYk/BECSWVtl16XZv8j9nsV1owRAc2ep1jwW37/OEUy2uwIFQKaRQSawmda/
vDSKScVdBUASzDVIlsPcv2mz5tPutAVA9sZrVjAL278WQH4EiQgGQO89CbtW
wd+/ZgymBNxYBkDVtjrgNibYv8ht5d0mpgZAbUjFtw161b86mcUHovAGQPfA
TIg6f9a/lSeDB4A4B0BStdNzCTvZv01Dkz7ufQdA64XgmKDf2r+QQGBSFcEH
QEubNVNDC9G/iC1M0xoCCEDZ0TbIIxDhvy5hhhMgQQhAh/0WNPAJ4r9Gqu6p
Q34IQC3czqSRcd+/3EI/hKG5CEALTv7x+Rzjv3V70zNT8whAUp6PPKnJ2b++
4ugvcCsJQAJmvaJP2Ne/KjnT1g1iCUD9OrT2wLvnv2//PYJAlwlA4N/t5cd9
5b/Nqh9dGssJQOZgSyRDnMa/2pJMb6z9CUDhd/5z9wbAv0OMXYUGLwpAhx4S
yo58678FBF1ON18KQMNM0v86zZS/SqAKdkyOCkDw7KVq4RXgv20YVVU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8RywBVijPlv964dwvy
SOQ/vNTLAwlf47/fVqmFon3tP13jPqvBJvc//AmBZtBQ8j+0mFHydI7XP4OR
BD6aO/U//kE6P0hU5b+F+JAQAbP3P9Nv6kRPkOO/Z8hRwvLV+T9yQuHb8sXi
v1qa8FBjuPs/gH1GHX7p5L+rG0W78Wf9P2VRmbMwxtS/XkJExlXu/j9WUAZE
BF7uv0rxjfBdKQBAYRy0zERy4r8wDFZVS80AQFpCKG9Q3eu/aPTEOBFlAUC/
pTHf/MjqvxxYWWJd8gFALDkFuyh0479fwE5WinYCQDm7KPyPAOy/Yf4DKbPy
AkCLIWCKbH/jv7aVvjjCZwNAydBhS7E06r+vqhQXfdYDQIdqOuS5gOG/URxh
nYk/BEBlrqJgZQ3lv8j9nsV1owRA6ao7H3cw4b/OEUy2uwIFQE/MUugcKum/
vDSKScVdBUBcNlC4yQXjv2mz5tPutAVAB41584+o4b8WQH4EiQgGQG4yCLdZ
KeK/ZgymBNxYBkDBGH9rytPmv8ht5d0mpgZADinGOqIb4786mcUHovAGQCha
nLNZL+S/lSeDB4A4B0A3cxaW467nv01Dkz7ufQdAe0cYhB1C5r+QQGBSFcEH
QLabN65c2+e/iC1M0xoCCEAIQvluxZjovy5hhhMgQQhA0hO1/+uL6L9Gqu6p
Q34IQNOMqLdOguG/3EI/hKG5CECx1dxGZibmv3V70zNT8whAZ6cVaRyt5b++
4ugvcCsJQMwZVJnKR+e/KjnT1g1iCUB23A/M/FXmv2//PYJAlwlAlEVwOv20
7r/Nqh9dGssJQM+VFaR4XOm/2pJMb6z9CUBye5jpK1vWv0OMXYUGLwpA8LfO
SCBw8L8FBF1ON18KQIegxCYsUfK/SqAKdkyOCkCRmMVYAOD0v/eyURY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5666187254797448},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.772588722239781, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.833213344056216, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Phk2gy2gqwN64dwvy
SOQ/vAjURjX2KcDfVqmFon3tP/6mMKQdTCnA/AmBZtBQ8j/N85AtsREowIOR
BD6aO/U/kWj5ZySwJ8CF+JAQAbP3P3hjx2gsECfAZ8hRwvLV+T9tPQ3PUPwl
wFqa8FBjuPs/YMDq9XywJcCrG0W78Wf9P19MV5KfjyXAXkJExlXu/j+tgOHG
S8gkwErxjfBdKQBA0H11fgZdJMAwDFZVS80AQEUsgq+XyCPAaPTEOBFlAUCq
8ME6dQkkwBxYWWJd8gFAsi12E3hTI8BfwE5WinYCQCdUtUjnRyPAYf4DKbPy
AkD9U/vzDbEiwLaVvjjCZwNAI5YPmDJUIsCvqhQXfdYDQOLFKrp9FiLAURxh
nYk/BED+EBU3XMIhwMj9nsV1owRA3273feehIcDOEUy2uwIFQCDa54dqGCHA
vDSKScVdBUDJxKgnUwYhwGmz5tPutAVA1lbwcje3IMAWQH4EiQgGQLn03Tkv
oCDAZgymBNxYBkBKNR+G3yUgwMht5d0mpgZA86Mux2muH8A6mcUHovAGQELM
2RUVTx/AlSeDB4A4B0CRDoj00hAfwE1Dkz7ufQdA3/9lhhLDHsCQQGBSFcEH
QGVyMd7Ivx3AiC1M0xoCCED3aW8Sam8ewC5hhhMgQQhAzAUxmCUwHsBGqu6p
Q34IQD6UuNWViR3A3EI/hKG5CECIb4aAbp8dwHV70zNT8whAMPkE5pKDHMC+
4ugvcCsJQAQyE/vnDhzAKjnT1g1iCUCSK03BajcdwG//PYJAlwlAQwpHHGOe
HMDNqh9dGssJQAUZBVLDWBrA2pJMb6z9CUABJuUNDdkZwEOMXYUGLwpAcqf+
dHR8HMAFBF1ON18KQP4xYpgo3BjASqAKdkyOCkBluXN6In8awLZPM+Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT97R5v0wdwvwN64dwvy
SOQ/NETPEtF4LcDfVqmFon3tP6nAFVqIjCfA/AmBZtBQ8j/QuV2BQ4IowIOR
BD6aO/U/ftJFh3Z0KcCF+JAQAbP3P4JnO4NYaijAZ8hRwvLV+T+limVcXZEn
wFqa8FBjuPs/3up4Ue0CJ8CrG0W78Wf9P8ZWqiSquyXAXkJExlXu/j/fMVHu
QWwmwErxjfBdKQBA9NAg0ucrJcAwDFZVS80AQLyLQsVGRCXAaPTEOBFlAUCB
5PVuQb8kwBxYWWJd8gFANG2gPlTmI8BfwE5WinYCQNnhbEswCyTAYf4DKbPy
AkDUBlP1vigjwLaVvjjCZwNAyxZHD843I8CvqhQXfdYDQItKgX0CXCLAURxh
nYk/BECtEn8w9EUiwMj9nsV1owRAKA+r93q+IcDOEUy2uwIFQGMk5MQk9SHA
vDSKScVdBUCcQDF4b1AhwGmz5tPutAVAxh07GXf6IMAWQH4EiQgGQHFV4iWC
wiDAZgymBNxYBkDonc3GSNIgwMht5d0mpgZAK9M+ixhcIMA6mcUHovAGQNYY
m/tVNiDAlSeDB4A4B0C5knH4QjkgwE1Dkz7ufQdAs04xZGvcH8CQQGBSFcEH
QHrf4GyFqh/AiC1M0xoCCECurqynmWEfwC5hhhMgQQhAnukHZiIAH8BGqu6p
Q34IQG6K3f5MwR3A3EI/hKG5CEBBjVp/wv0dwHV70zNT8whAGJg4abKaHcC+
4ugvcCsJQJzhih60eR3AKjnT1g1iCUCIAENjHwkdwG//PYJAlwlAnUepC2XH
HcDNqh9dGssJQDlQAdN/zxzA2pJMb6z9CUBghGTAur0awEOMXYUGLwpA6kaU
Aa4oHcAFBF1ON18KQJVvGVUSVh3ASqAKdkyOCkDIpGRQVrQdwFZQNgw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=30.4998\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480910516977`*^9},ExpressionUUID->"d0d518e5-1e76-4de9-b4b5-\
e3b8bb215fcd"],

Cell[BoxData["5"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448091550394*^9},ExpressionUUID->"3def9cd5-69ce-4305-9ed5-\
68b063db6f85"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/OPMesB3YiwN64dwvy
SOQ/agcH9AZWI8DfVqmFon3tP8jMElJXQCLA/AmBZtBQ8j9Yd+sU7VEiwIOR
BD6aO/U/CTjgSY3ZIcCF+JAQAbP3P4XuR9b/nCHAZ8hRwvLV+T+JOxm7rVwg
wFqa8FBjuPs/errqAgQ7IcCrG0W78Wf9P2ZyHOwC5yDAXkJExlXu/j/Nw8aW
gyQgwErxjfBdKQBA9d/OUdKeH8AwDFZVS80AQMYG3EbcKx/AaPTEOBFlAUBx
rzfwr9EewBxYWWJd8gFAS0t9v7AOH8BfwE5WinYCQPbrIjLSnh7AYf4DKbPy
AkDaJ5I1lZkdwLaVvjjCZwNA5gYLKYDQHcCvqhQXfdYDQH9QIdOsUx3AURxh
nYk/BEDLw26h6BUdwMj9nsV1owRA/l1BXkVHHMDOEUy2uwIFQJzXigGdCBzA
vDSKScVdBUD5z3LYIlobwGmz5tPutAVAYYYPfnvIGsAWQH4EiQgGQNNaYZgx
zxvAZgymBNxYBkBQwA+aUnsawMht5d0mpgZASBPM25MhGsA6mcUHovAGQO6t
8RS1ehnAlSeDB4A4B0A1ZniKM6oZwE1Dkz7ufQdA7/05KV10GcCQQGBSFcEH
QGY9ZXOC9RfAiC1M0xoCCEAXZVxrfZcZwC5hhhMgQQhAVl5nEuZXGcBGqu6p
Q34IQCs0MYV9NBjA3EI/hKG5CECJfM/79RQYwHV70zNT8whAxlBz7L8tF8C+
4ugvcCsJQFcdfubs5xfAKjnT1g1iCUB9XkCbGYEYwG//PYJAlwlA6XD/EdA4
GMDNqh9dGssJQOQos6nM6hXA2pJMb6z9CUBgmBcVtCMVwEOMXYUGLwpAmp/y
nZuhGMAFBF1ON18KQAk85/gq/BPASqAKdkyOCkBL4+oOPdoUwB8kN5A=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9OH2euxi8rwN64dwvy
SOQ/ThEYsbvZKMDfVqmFon3tP1yn2yeFESXA/AmBZtBQ8j8DUlj6ElgiwIOR
BD6aO/U/nE/cBu8IJ8CF+JAQAbP3P3ITv/+vLCTAZ8hRwvLV+T/VEmnJ60oj
wFqa8FBjuPs/oTcphOOkIsCrG0W78Wf9Pz5QzQlmbyHAXkJExlXu/j9FxEXK
wNQiwErxjfBdKQBARGDNkgdWIcAwDFZVS80AQEUkr7rThiHAaPTEOBFlAUDR
DckyXkYhwBxYWWJd8gFAO1tjz/93IMBfwE5WinYCQJ7+1L2kbCDAYf4DKbPy
AkCpjh07U58fwLaVvjjCZwNAVccu5w7sH8CvqhQXfdYDQOFzMCH5sx7AURxh
nYk/BEBeotHaehAewMj9nsV1owRAyq+LLCYYHsDOEUy2uwIFQKVk3vG90R7A
vDSKScVdBUDGRTy+7pgcwGmz5tPutAVAEV+PjytkHMAWQH4EiQgGQEnu3HnU
wBvAZgymBNxYBkC9+M1bcuocwMht5d0mpgZABSVo+LsMG8A6mcUHovAGQOzx
gfN6VRvAlSeDB4A4B0CzqgCSXLsawE1Dkz7ufQdAKxnglMDcGsCQQGBSFcEH
QPXz3XOHkBrAiC1M0xoCCEAyhUlb/qcawC5hhhMgQQhAxjEUoWWbGsBGqu6p
Q34IQP5yeN6l9BjA3EI/hKG5CEAwFAmogIEawHV70zNT8whA6cZ5B6jcGcC+
4ugvcCsJQEV2GfoGShnAKjnT1g1iCUCk/J9TErEYwG//PYJAlwlA7MK25HuR
GcDNqh9dGssJQO6z7LsWjhnA2pJMb6z9CUAJ8cP9xZ4WwEOMXYUGLwpAmEiI
AN6XGMAFBF1ON18KQB17Mo05KRjASqAKdkyOCkDTUuqb5+AZwL46PlU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.903500693236463},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/lHMyEo8IhwN64dwvy
SOQ/ho/nft30HsDfVqmFon3tP7QNrytnkxzA/AmBZtBQ8j9tb/BzIm0ZwIOR
BD6aO/U/uRAAlO5jGcCF+JAQAbP3P8sv8gG/exbAZ8hRwvLV+T9eF9df3jMU
wFqa8FBjuPs/N75uJ33XEsCrG0W78Wf9P0wUwgcM0hLAXkJExlXu/j+5Zx5y
n2cRwErxjfBdKQBAoMPi7T0OD8AwDFZVS80AQNu3JKcPiAzAaPTEOBFlAUBo
kq6gSYkOwBxYWWJd8gFAxYIW4lD0CcBfwE5WinYCQAZPJwgdLwrAYf4DKbPy
AkDgTA5kGbgGwLaVvjjCZwNA424VD0JiBMCvqhQXfdYDQM35SQS8sQPAURxh
nYk/BEALgmG+MBwBwMj9nsV1owRAM/Ar9WsMAsDOEUy2uwIFQE5Og/85Yfu/
vDSKScVdBUA0zJ5X3Lr9v2mz5tPutAVAgAMnmrAW+b8WQH4EiQgGQHSdccaM
Ofe/ZgymBNxYBkCF5/EAwP3zv8ht5d0mpgZAls2YDnE78L86mcUHovAGQDRv
YLF4VvC/lSeDB4A4B0AmkYvXd6Tqv01Dkz7ufQdACBhuxUKt57+QQGBSFcEH
QEmkJyhnM+W/iC1M0xoCCEDlv5PsgHvhvy5hhhMgQQhAfByrE+hC279Gqu6p
Q34IQNkeclZa99O/3EI/hKG5CEBsEKk/QKnVv3V70zNT8whA2uQrGzAT2L++
4ugvcCsJQFjpIRRFWMM/KjnT1g1iCUDlGr9+RHXTv2//PYJAlwlAiY3pT6e3
xj/Nqh9dGssJQIB020nJvtQ/2pJMb6z9CUA4M4wU6FLhP0OMXYUGLwpAa8h/
cvgN1z8FBF1ON18KQCMtpsjMe+U/SqAKdkyOCkBe3qCQ2brPvxo7Prw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9rcSKZ1O0jwN64dwvy
SOQ/N1XRe0QhIcDfVqmFon3tP7baFZ095xfA/AmBZtBQ8j9kXGg7LzEYwIOR
BD6aO/U/+Zd+bavkGMCF+JAQAbP3P+rZOSIkHhnAZ8hRwvLV+T/knwXXyxAX
wFqa8FBjuPs/2i54nujLFcCrG0W78Wf9P9MPLXsxaxPAXkJExlXu/j/Zu8Nn
AlETwErxjfBdKQBAuRgbr75OEcAwDFZVS80AQN1pYcVHIhHAaPTEOBFlAUBu
T1/UiVcPwBxYWWJd8gFAkBay3rWeC8BfwE5WinYCQCfzu007TA3AYf4DKbPy
AkDVrBjbtpIIwLaVvjjCZwNAVqwdTStPCMCvqhQXfdYDQPvZhith+wPAURxh
nYk/BEBoDRzXNZcEwMj9nsV1owRAic5A2ndtAMDOEUy2uwIFQF8wkmLBzADA
vDSKScVdBUC6aQLCoxwAwGmz5tPutAVArZkL9viz+78WQH4EiQgGQKOVq8Yn
0/m/ZgymBNxYBkARgumLkqz3v8ht5d0mpgZAnQkQbzGu9b86mcUHovAGQDKI
bt5A+/K/lSeDB4A4B0BIPvbzYJv0v01Dkz7ufQdAAJ26xghB8b+QQGBSFcEH
QM6QPE40IvC/iC1M0xoCCECGELmIIhfuvy5hhhMgQQhArtOXghZb5L9Gqu6p
Q34IQIdLf0lTIeO/3EI/hKG5CED/v3BhXxPTv3V70zNT8whA8YqKkBDoyr++
4ugvcCsJQMvv8lsAJM+/KjnT1g1iCUBf1q4IaP/Ev2//PYJAlwlAf0lYFN7j
y7/Nqh9dGssJQGUe/i9FMbs/2pJMb6z9CUCB6T3IkGDSP0OMXYUGLwpAteVl
RLH50r8FBF1ON18KQNio5dHCDNe/SqAKdkyOCkDHLdPuC+bCv6lORNg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.327532845897484},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+lUrlPIVABQN64dwvy
SOQ/zalS/zew9D/fVqmFon3tP4SA+AwAo/A//AmBZtBQ8j/K3nb3MOjoP4OR
BD6aO/U/Ur4QXj171D+F+JAQAbP3P4aPl0nwhtE/Z8hRwvLV+T+T8x+DXMbe
P1qa8FBjuPs/oIl8BEDxuT+rG0W78Wf9P0cj3Da2bsG/XkJExlXu/j9sXruX
R36nv0rxjfBdKQBAga5dYtqedD8wDFZVS80AQO5waD34SJK/aPTEOBFlAUBA
7Lg7AA/SvxxYWWJd8gFAz6xLkJoF0b9fwE5WinYCQBiqw+lEGNq/Yf4DKbPy
AkAKIRIHU6TPv7aVvjjCZwNA1LKiRS2807+vqhQXfdYDQFpuOUOEENe/URxh
nYk/BEBCRwT1HdHUv8j9nsV1owRAXKtsGNZy2r/OEUy2uwIFQAi7DdSk69C/
vDSKScVdBUDDRqXaP2vXv2mz5tPutAVAK4UfZIkY0r8WQH4EiQgGQHHODNWu
DN+/ZgymBNxYBkAJGsbnyR3Vv8ht5d0mpgZAXdiGdhVJ0r86mcUHovAGQH+l
+d4bENO/lSeDB4A4B0Blh4MHlQfWv01Dkz7ufQdAh2M+fUO517+QQGBSFcEH
QNmgiEqvH8q/iC1M0xoCCEAAsqvH3Hjfvy5hhhMgQQhA9K29XJ2H379Gqu6p
Q34IQDerSHdodte/3EI/hKG5CECcb+NpgOXbv3V70zNT8whADUkI1Z3w17++
4ugvcCsJQFj7uqNwade/KjnT1g1iCUCSQtjehNzmv2//PYJAlwlADSEh0PqU
4b/Nqh9dGssJQIUmzVUtGsu/2pJMb6z9CUAtppATex2zv0OMXYUGLwpAaHHt
3w+H578FBF1ON18KQKYQEtRGl6M/SqAKdkyOCkCC6AL1eo3YvxmWSaI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8ageyk/DPiv964dwvy
SOQ/cZglILZw27/fVqmFon3tP3lruM62du8//AmBZtBQ8j+MlOZzE93uP4OR
BD6aO/U/3qa1CUfA5L+F+JAQAbP3PxdXQV0uyuW/Z8hRwvLV+T9LHma7oFvj
v1qa8FBjuPs/3CXo/Nb647+rG0W78Wf9P26BIRtm19S/XkJExlXu/j9sqkIl
QEzuv0rxjfBdKQBASahfA72w4r8wDFZVS80AQGEV3R4ceuu/aPTEOBFlAUAa
vtNquPHqvxxYWWJd8gFAGbMq5300479fwE5WinYCQGKWEZ2t++u/Yf4DKbPy
AkAAlxbLYpzjv7aVvjjCZwNAZjUGUcYo6r+vqhQXfdYDQJ4376ZesOG/URxh
nYk/BEAd2cj9hNvkv8j9nsV1owRA3ectsr2g4b/OEUy2uwIFQEaqX0F+yem/
vDSKScVdBUBxqbguTEHjv2mz5tPutAVAnBF5lOc84r8WQH4EiQgGQAsOHHp0
l+G/ZgymBNxYBkD/EsSE4DDov8ht5d0mpgZAADsMTGzS4b86mcUHovAGQI8J
UsOuEOS/lSeDB4A4B0Bq3lWTTa/lv01Dkz7ufQdA/r5G1oXB5r+QQGBSFcEH
QBFXq4WJdue/iC1M0xoCCEB03pq0ltjpvy5hhhMgQQhAFoffBSVE6L9Gqu6p
Q34IQOSbXs3QteK/3EI/hKG5CEAhgObkkDTov3V70zNT8whA5gjQaCfM5r++
4ugvcCsJQDLUy8ozaOe/KjnT1g1iCUDzffSM3+Tlv2//PYJAlwlAZEZJOmgR
7b/Nqh9dGssJQDjXQOH7muq/2pJMb6z9CUCxbE8SVq7Zv0OMXYUGLwpAkQJb
D+Om778FBF1ON18KQPu/QHQVz++/SqAKdkyOCkD+q+MJPUv0v2h3V2o=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5508455525522915},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U6ZQUGwgqwN64dwvy
SOQ/vNkQ7i1+KcDfVqmFon3tPwQy9LhnayjA/AmBZtBQ8j+ntEO1KKEnwIOR
BD6aO/U/xtVFMqBvJ8CF+JAQAbP3P4jb9/E5oibAZ8hRwvLV+T+WIkQH/Wgl
wFqa8FBjuPs/mWvmY3B9JcCrG0W78Wf9P2crqL/3ViXAXkJExlXu/j9TQOTD
1ZkkwErxjfBdKQBAqz6CRBn9I8AwDFZVS80AQIq92vWWjiPAaPTEOBFlAUAS
SSTPhqQjwBxYWWJd8gFAiQJJFIMyI8BfwE5WinYCQLMaH252GiPAYf4DKbPy
AkBAcQU2x2siwLaVvjjCZwNA+1hzJwkzIsCvqhQXfdYDQNnzdD+f+yHAURxh
nYk/BEC0T/bRH5shwMj9nsV1owRAv0agqpF8IcDOEUy2uwIFQCxWRkur6iDA
vDSKScVdBUDEtATBP9sgwGmz5tPutAVAmxqYi5NvIMAWQH4EiQgGQFHvF9kJ
miDAZgymBNxYBkB6XIqhAA0gwMht5d0mpgZAPhId3mR6H8A6mcUHovAGQLU5
/+lVFx/AlSeDB4A4B0Dx4AJISd0ewE1Dkz7ufQdAKc8bOP2PHsCQQGBSFcEH
QJLd7JLPfx3AiC1M0xoCCEAczjTvwkQewC5hhhMgQQhAE8AKRnTmHcBGqu6p
Q34IQIMa0UV4CR3A3EI/hKG5CEBcNHyBSfkcwHV70zNT8whAu3fVreNlHMC+
4ugvcCsJQB3IpKfLBhzAKjnT1g1iCUAbKm6m9xkdwG//PYJAlwlA9tCM9iEh
HMDNqh9dGssJQAgePonXfBrA2pJMb6z9CUAPqKt+ZqMZwEOMXYUGLwpAZzHH
73X9G8AFBF1ON18KQDlugVtQnxjASqAKdkyOCkAn5ExS9QQawDi3NIM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/1pE31T/kswN64dwvy
SOQ/2Z3g8EQDK8DfVqmFon3tP0tgBmV77SbA/AmBZtBQ8j+R7MBaQgEmwIOR
BD6aO/U/JIicw6BfKMCF+JAQAbP3P5ncfiSisyfAZ8hRwvLV+T/BFAwYzOQm
wFqa8FBjuPs/dn55bydZJsCrG0W78Wf9P5l+jOknNyXAXkJExlXu/j+tYune
gvclwErxjfBdKQBAJfpOoDHKJMAwDFZVS80AQNKWYW0u5iTAaPTEOBFlAUBK
u5EU/XQkwBxYWWJd8gFABeJ9wpCcI8BfwE5WinYCQPP9ALfhzCPAYf4DKbPy
AkCV8qQ6TPIiwLaVvjjCZwNA7we6a0EFI8CvqhQXfdYDQHPfFCRKMSLAURxh
nYk/BEAxCBkdUBkiwMj9nsV1owRAS1f8E3WfIcDOEUy2uwIFQLOJ+gpr3CHA
vDSKScVdBUDNLt82KTQhwGmz5tPutAVA5Oy9GPjlIMAWQH4EiQgGQOYWhLnY
nSDAZgymBNxYBkDSoHvQhs4gwMht5d0mpgZAmk03VAIwIMA6mcUHovAGQJd9
RhsPHiDAlSeDB4A4B0DPmp6sKgQgwE1Dkz7ufQdAX5oBpSXFH8CQQGBSFcEH
QLHWMqkIeR/AiC1M0xoCCEC3m52KumYfwC5hhhMgQQhA/pkcYhXXHsBGqu6p
Q34IQHHLlnXryB3A3EI/hKG5CEAEsUqfBiMewHV70zNT8whArBl3ls+iHcC+
4ugvcCsJQC4m2rTRYx3AKjnT1g1iCUAo4bxH+eEcwG//PYJAlwlAQIz5ZiV7
HcDNqh9dGssJQHI+TOgw4RzA2pJMb6z9CUAqTwWeKd4awEOMXYUGLwpAtN4H
8TftHMAFBF1ON18KQG+OXsDGpxzASqAKdkyOCkDdy0pdknwdwJStOhM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=40.7497\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448091883445*^9},ExpressionUUID->"fe48b464-f719-4098-bd5e-\
dc1f79a02ba3"],

Cell[BoxData["6"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448092429459*^9},ExpressionUUID->"79a9ff64-34fb-41bb-be65-\
d5ec2eaecbdf"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9TI4E8igQjwN64dwvy
SOQ/8NcekTHsIcDfVqmFon3tPyiqiM14uiHA/AmBZtBQ8j/RBaMNBGMiwIOR
BD6aO/U/zlNO7jkCIsCF+JAQAbP3P5kUzyGf3SHAZ8hRwvLV+T8zXRldSjkg
wFqa8FBjuPs/bZOrbLJkIMCrG0W78Wf9PwJe9KXkVyDAXkJExlXu/j874zO7
fKcgwErxjfBdKQBAGLn2Gs1xH8AwDFZVS80AQCDtHAb04B/AaPTEOBFlAUAo
53aXpuEewBxYWWJd8gFAI+hDSwJZHsBfwE5WinYCQMyUseWbuR7AYf4DKbPy
AkAX+wCGfzQdwLaVvjjCZwNAI3EtHnlkHMCvqhQXfdYDQHm9nWPvyRzAURxh
nYk/BEAu8P9Fnz0cwMj9nsV1owRA5hZCHz2gG8DOEUy2uwIFQLDKXPNlPhvA
vDSKScVdBUBX0KD8fh8bwGmz5tPutAVA6WUH2OsmGsAWQH4EiQgGQH+rYjxX
kBrAZgymBNxYBkD0doKNxjsawMht5d0mpgZA2t3JepyVGcA6mcUHovAGQH7z
dlQkGhnAlSeDB4A4B0DCnQmIohMZwE1Dkz7ufQdAcCay7FFRGcCQQGBSFcEH
QImvkWIkPBjAiC1M0xoCCEBLp7uZljQZwC5hhhMgQQhAmdOrjbaQGMBGqu6p
Q34IQCAdYoQLoRfA3EI/hKG5CED2BcjlmJIXwHV70zNT8whAyqQJjaLvF8C+
4ugvcCsJQPnTYLCT4RbAKjnT1g1iCUCMgOtIRvMZwG//PYJAlwlAk8TgosoR
F8DNqh9dGssJQAUYN//apRTA2pJMb6z9CUAOrb7IIlQVwEOMXYUGLwpAByRV
3seMGMAFBF1ON18KQAqh5t8RIBTASqAKdkyOCkAeEjmm5akfwNv0Np8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/XRMdIkFQtwN64dwvy
SOQ/2sJQB52zKsDfVqmFon3tP7htiD94VCbA/AmBZtBQ8j/SUcc0UnggwIOR
BD6aO/U/0scvfhBFJsCF+JAQAbP3P1kxdf1UziTAZ8hRwvLV+T/6xac9ZAsk
wFqa8FBjuPs/RJ6vFI+dI8CrG0W78Wf9P2Sx7IIWbCLAXkJExlXu/j/pZ8Dz
ahgjwErxjfBdKQBAjyUPFa/+IcAwDFZVS80AQF+rwRqiKyLAaPTEOBFlAUDj
4aLqzxEiwBxYWWJd8gFAHJstOuz/IMBfwE5WinYCQDLrHFiELSHAYf4DKbPy
AkBwIfQfo18hwLaVvjjCZwNAaGswHZZ4IMCvqhQXfdYDQHaU0lT6hB7AURxh
nYk/BEAxR9s6OmMfwMj9nsV1owRA871sZWYuH8DOEUy2uwIFQBv+qsdn8B7A
vDSKScVdBUBLVOnLvVUdwGmz5tPutAVAbHtN0mjbHMAWQH4EiQgGQI0sB+6g
zhzAZgymBNxYBkDpnMLMZ4gdwMht5d0mpgZAS3DrPRiSG8A6mcUHovAGQN9q
Uh+ucBvAlSeDB4A4B0CUS739QQIcwE1Dkz7ufQdAjA07vSIYG8CQQGBSFcEH
QKJttGhtpxrAiC1M0xoCCEBLy6wBqJMbwC5hhhMgQQhA1g79b5TfGsBGqu6p
Q34IQGHS9D3+0xnA3EI/hKG5CEBX2f+M0GEbwHV70zNT8whAPJo2qyh7GsC+
4ugvcCsJQFSBDOlr8hnAKjnT1g1iCUBGtqBSiuMawG//PYJAlwlAHMTo9yzL
GsDNqh9dGssJQHu1tS1eQhnA2pJMb6z9CUAG0tGrPYgXwEOMXYUGLwpAZAsL
CINeG8AFBF1ON18KQMtv7c+NxRnASqAKdkyOCkCBxBc0R/AYwNuxOXg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.368999498172113},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.01948336229021, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.73180128983843, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.326336181730264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.172185501903007`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.038654109278484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.9208710736221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8uyHERSLogwN64dwvy
SOQ/6rCaRKYjIMDfVqmFon3tP+3nWBycxxvA/AmBZtBQ8j/uqHvkPzIZwIOR
BD6aO/U/0h9NKZsCGMCF+JAQAbP3PwU6HYnC0xXAZ8hRwvLV+T8YYXKKqugT
wFqa8FBjuPs/S6X0soT4E8CrG0W78Wf9P9XDhWwGPBLAXkJExlXu/j/DH/+K
o1gQwErxjfBdKQBAc12eqNQQDcAwDFZVS80AQLebti6ofgrAaPTEOBFlAUDn
+xtCVOkKwBxYWWJd8gFAHrbG1PCPCsBfwE5WinYCQJ6Z3SWhiAjAYf4DKbPy
AkBglIzh+VQFwLaVvjjCZwNAe+KhlkF6BcCvqhQXfdYDQCajdR7aOgTAURxh
nYk/BECGaMS0VDgBwMj9nsV1owRA5vWqsl+qAsDOEUy2uwIFQLU2C3nNG/y/
vDSKScVdBUB5IljMYzj9v2mz5tPutAVAUHXafeJp978WQH4EiQgGQHjYUyUT
Evu/ZgymBNxYBkAMpQoHcnLzv8ht5d0mpgZA+P3FxA0e7786mcUHovAGQAk1
XHrT/O+/lSeDB4A4B0BO4UiSDFLqv01Dkz7ufQdAlTGB/Aso5L+QQGBSFcEH
QIpXzxTypd+/iC1M0xoCCECEcGYPpQrevy5hhhMgQQhA/vbldC5c4L9Gqu6p
Q34IQId8ce7hQNK/3EI/hKG5CECTibwBYKXXv3V70zNT8whAkhgSiL5ss7++
4ugvcCsJQEad8Phxjrg/KjnT1g1iCUBkBb7/etT8vm//PYJAlwlAgNKqrp87
tD/Nqh9dGssJQPCXqKhA+og/2pJMb6z9CUDmxD82g0blP0OMXYUGLwpAFEvE
a8/uyD8FBF1ON18KQAMSmbRTy+g/SqAKdkyOCkAJxU6I0fTpPxc4RyI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9rrTA1BbgiwN64dwvy
SOQ/7U3kNckdIMDfVqmFon3tP7XPBEffbhrA/AmBZtBQ8j+n4TOSIMAVwIOR
BD6aO/U/J95PzzX1GMCF+JAQAbP3P6oadtA73xfAZ8hRwvLV+T8wTBv7u7YV
wFqa8FBjuPs/WEBMOWvIE8CrG0W78Wf9P6WnV3E0WRHAXkJExlXu/j9afKsP
+sISwErxjfBdKQBAQBBwHeKcD8AwDFZVS80AQLTG5DUL0A/AaPTEOBFlAUBx
6C2AzU8MwBxYWWJd8gFA9gEO82OKCcBfwE5WinYCQMszREwpEArAYf4DKbPy
AkCHziugoooDwLaVvjjCZwNASod0OFJeBsCvqhQXfdYDQEaiMkt2IQXAURxh
nYk/BECq0R8v1vYBwMj9nsV1owRAviyQlbbe/L/OEUy2uwIFQJu0BtyAWwDA
vDSKScVdBUC7gWFBHyb9v2mz5tPutAVAD8cIvsTD+b8WQH4EiQgGQC+a1tx1
WvW/ZgymBNxYBkBFh6bntfH0v8ht5d0mpgZA++qtaycX9L86mcUHovAGQPof
R910ofK/lSeDB4A4B0BSKVvW6RTvv01Dkz7ufQdAQDbcus2t77+QQGBSFcEH
QJ9NtdRr3PC/iC1M0xoCCEBGerUC4Trnvy5hhhMgQQhAB+rpbSBN4r9Gqu6p
Q34IQIFzMe87gta/3EI/hKG5CEAcH/0gryW7v3V70zNT8whAz3rgAorEtL++
4ugvcCsJQDEcEQs/2ri/KjnT1g1iCUDktSnr2YTRP2//PYJAlwlAq6Dw5e9X
pz/Nqh9dGssJQG1NTEo2Q7I/2pJMb6z9CUDmVlxdoKngP0OMXYUGLwpAMfOq
Bee/0T8FBF1ON18KQDde2rDdq7Y/SqAKdkyOCkCiHtnWGZTdv4kQQ8Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.064742172022192},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9h+mhvRCsCQN64dwvy
SOQ/yaiIeTQ4+T/fVqmFon3tP4Jn8umon/Q//AmBZtBQ8j9ozAVjQ+noP4OR
BD6aO/U/LaxCRpOn3D+F+JAQAbP3P9XlK0+3z9Q/Z8hRwvLV+T+dBf0U3wXi
P1qa8FBjuPs/lVKYjF7nxj+rG0W78Wf9Pw6CPuUWerQ/XkJExlXu/j/w/qng
8XGlv0rxjfBdKQBASx+pWXblwz8wDFZVS80AQGbewP2xO6U/aPTEOBFlAUBf
uALQou25vxxYWWJd8gFAKKdo200ayr9fwE5WinYCQLHToTAFO9W/Yf4DKbPy
AkDgALs1UBO9v7aVvjjCZwNArXicaBR7xb+vqhQXfdYDQLFeBwVJBNS/URxh
nYk/BEDs3/KumlHMv8j9nsV1owRAMjfDwCGS1b/OEUy2uwIFQN9zjV8CJMe/
vDSKScVdBUDubIXmolTUv2mz5tPutAVA3SOaqaudwr8WQH4EiQgGQMQLTXCF
/dm/ZgymBNxYBkAbn2eOu/LRv8ht5d0mpgZA0AQ0hWwwyL86mcUHovAGQDXH
uA51oc2/lSeDB4A4B0CciFqa/z/Qv01Dkz7ufQdA0kJE0Vtr07+QQGBSFcEH
QMAfoBCwlse/iC1M0xoCCEBP4aCRl+TZvy5hhhMgQQhAyXbfyeqc2r9Gqu6p
Q34IQD2wQALIDNG/3EI/hKG5CEBnvYM0zVTXv3V70zNT8whAEQZFaYje2L++
4ugvcCsJQGXBz/GEps6/KjnT1g1iCUA0ADSuYfLov2//PYJAlwlADRLRyirP
2r/Nqh9dGssJQJrtxn4C8bC/2pJMb6z9CUD1NP00KdSwv0OMXYUGLwpAORg7
dq+g6b8FBF1ON18KQHW6d7Hjb6g/SqAKdkyOCkAxwSGBpinxv/GVT1g=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IssRrMaXov964dwvy
SOQ/gTFtjaul47/fVqmFon3tPwpKDTFmf9E//AmBZtBQ8j8ZfmNH7PwAQIOR
BD6aO/U/Lzhr/jwV57+F+JAQAbP3P/CeMDh2ReW/Z8hRwvLV+T/4zNYkW6Pj
v1qa8FBjuPs/h6pdcpzk47+rG0W78Wf9P44V2I6FHNW/XkJExlXu/j9mANCP
XmTuv0rxjfBdKQBA+dmX5OoO4r8wDFZVS80AQN/0L9XHweu/aPTEOBFlAUAT
Wpf9ENvqvxxYWWJd8gFA6Zvm9llg479fwE5WinYCQP5oiKs6Auy/Yf4DKbPy
AkBKQgJ+iWjjv7aVvjjCZwNAJNodHLpk6r+vqhQXfdYDQMgkW1VoHOK/URxh
nYk/BEBmNDysNVblv8j9nsV1owRAWRmnmv+C4b/OEUy2uwIFQIOUtef8bOm/
vDSKScVdBUBE2/zSI2fjv2mz5tPutAVAbw2E+PEh4r8WQH4EiQgGQG5wSFuE
w+G/ZgymBNxYBkATh1tWPNznv8ht5d0mpgZATyQCy8hZ4r86mcUHovAGQPen
e9722uO/lSeDB4A4B0DPGRWlZ9/mv01Dkz7ufQdAyOEyIGIz5r+QQGBSFcEH
QL2V1eGRyOe/iC1M0xoCCEAEoOHCa6Dqvy5hhhMgQQhAGyem9e1D6L9Gqu6p
Q34IQNk5eEn+UOO/3EI/hKG5CEArvFEIaiTov3V70zNT8whAOp0TH7Uo57++
4ugvcCsJQCx8RfG4/ee/KjnT1g1iCUAygSMW943nv2//PYJAlwlArlZxXNIH
7r/Nqh9dGssJQNy5Xx1qtOm/2pJMb6z9CUD0P6eTOvPbv0OMXYUGLwpA44AT
ATWQ8b8FBF1ON18KQMRQHSOzTfG/SqAKdkyOCkCV426ygDvzvzRjVVU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5220337070539389},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Zv5lV6nYpwN64dwvy
SOQ/Oc58U1C5KMDfVqmFon3tP9yv1RMGyCfA/AmBZtBQ8j9W360HrocnwIOR
BD6aO/U//XT2UYAcJ8CF+JAQAbP3P7f2QtaSeybAZ8hRwvLV+T9I4XcDJzUl
wFqa8FBjuPs//m8k1PtNJcCrG0W78Wf9P/lYhCJr4iTAXkJExlXu/j80BSuG
HZIkwErxjfBdKQBAjKMO1ueqI8AwDFZVS80AQKZuPTV/ayPAaPTEOBFlAUD1
HQl3T0UjwBxYWWJd8gFAmWqzc2wQI8BfwE5WinYCQBTNtuTv8CLAYf4DKbPy
AkD8vAUNaiUiwLaVvjjCZwNALfwmoDfpIcCvqhQXfdYDQKjyS49E4SHAURxh
nYk/BEBVbKT+KmQhwMj9nsV1owRAGY7Jcz5UIcDOEUy2uwIFQDbRxpB4viDA
vDSKScVdBUAM+YViw8AgwGmz5tPutAVALx4usxIoIMAWQH4EiQgGQKc/BTeI
cCDAZgymBNxYBkB7x0cCAuUfwMht5d0mpgZA8c4Wq3cUH8A6mcUHovAGQPkm
3YnE0R7AlSeDB4A4B0BvQOc6V38ewE1Dkz7ufQdAK9FfZgRJHsCQQGBSFcEH
QFb0o2ETah3AiC1M0xoCCEDTzyIZNOodwC5hhhMgQQhA8wvPfjWWHcBGqu6p
Q34IQOVior67oRzA3EI/hKG5CEDZStzkBq8cwHV70zNT8whAAUiG+yZzHMC+
4ugvcCsJQJ7l+mCBhBvAKjnT1g1iCUBhaAZBY1sdwG//PYJAlwlAllZLjNSa
G8DNqh9dGssJQF5HETdZ5hnA2pJMb6z9CUAxAoLYCJsZwEOMXYUGLwpAoTgR
Qto/HMAFBF1ON18KQAm3AB0FkxjASqAKdkyOCkDgNrsvy8UcwLFhMzk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT90VWbVgCUswN64dwvy
SOQ/Jh+IcMkxKsDfVqmFon3tP41uI0zkPCfA/AmBZtBQ8j/xMJ104J4iwIOR
BD6aO/U//kkYfpiIJ8CF+JAQAbP3P+iUKTjqwSbAZ8hRwvLV+T8M8wmI/xEm
wFqa8FBjuPs/bedwWISQJcCrG0W78Wf9Py0lWYNkgSTAXkJExlXu/j/QBFN5
LE8lwErxjfBdKQBA+ddTpbciJMAwDFZVS80AQHELIKzhWiTAaPTEOBFlAUBQ
87KTw+8jwBxYWWJd8gFA4d2AMhskI8BfwE5WinYCQLW/yQu5WyPAYf4DKbPy
AkALog8KaIUiwLaVvjjCZwNAmed3DCmoIsCvqhQXfdYDQDoGV6y63SHAURxh
nYk/BEDOQSrVC80hwMj9nsV1owRAMvwf9yhPIcDOEUy2uwIFQIHlSknEjSHA
vDSKScVdBUBqmMFkEPIgwGmz5tPutAVATff/3QqkIMAWQH4EiQgGQHUByUGe
ZCDAZgymBNxYBkAg9cOHq5AgwMht5d0mpgZAgRZ+9lQDIMA6mcUHovAGQCop
xGKm0R/AlSeDB4A4B0C4Gzh4F9AfwE1Dkz7ufQdA0CMfNQxaH8CQQGBSFcEH
QIsWoUieLh/AiC1M0xoCCEBpN7C7ui8fwC5hhhMgQQhA0+kVMCiLHsBGqu6p
Q34IQPAvODrHlB3A3EI/hKG5CEANMrw7btwdwHV70zNT8whAa1GRzBttHcC+
4ugvcCsJQGu7amdZOB3AKjnT1g1iCUAbGEbRXtwcwG//PYJAlwlAt0l6OpZh
HcDNqh9dGssJQP/yHAu2jRzA2pJMb6z9CUDE3rccbs4awEOMXYUGLwpAawIJ
PP0qHcAFBF1ON18KQIKaeJqh0hzASqAKdkyOCkAX5nP6YgsdwMOGMKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=50.9995\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480927495136`*^9},ExpressionUUID->"d582313f-e8e0-4654-8d0d-\
3dd8cde8c259"],

Cell[BoxData["7"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480931888766`*^9},ExpressionUUID->"2462c9e3-85db-4b76-be3c-\
b276b99a7d86"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/VzI4VWrAjwN64dwvy
SOQ/uyXpiHNwI8DfVqmFon3tP/eO7M/LxSLA/AmBZtBQ8j8GrHPzbMIhwIOR
BD6aO/U/PvaBt4/NIcCF+JAQAbP3P2Cu/D6NeiHAZ8hRwvLV+T8tNdz9ffQf
wFqa8FBjuPs/b6smKfTTIMCrG0W78Wf9PzmfeNPybh/AXkJExlXu/j9u5ww4
AUMgwErxjfBdKQBAZ9IZxYL8HsAwDFZVS80AQCIBIz5FSR7AaPTEOBFlAUDK
q5w0ZVkewBxYWWJd8gFA+sBTsdROHsBfwE5WinYCQMP2duebYR3AYf4DKbPy
AkDi8R5cKMUcwLaVvjjCZwNAV4yPXmzvHMCvqhQXfdYDQAdpLAxD6BzAURxh
nYk/BEARYI0x4HkbwMj9nsV1owRAqosj6RLmG8DOEUy2uwIFQCepNTXhwhrA
vDSKScVdBUDdwsujDFEbwGmz5tPutAVAerIDpI1oGsAWQH4EiQgGQKxs75Fk
jRrAZgymBNxYBkBNGsReYb0awMht5d0mpgZALxSXJYVrGMA6mcUHovAGQFM2
ThHDIhnAlSeDB4A4B0BHIsTFLxIZwE1Dkz7ufQdAThPQn0iJGMCQQGBSFcEH
QLbC7b/pzxfAiC1M0xoCCEDwVGv1gWgYwC5hhhMgQQhAZFHO8GUUGcBGqu6p
Q34IQFB5Xd4SphfA3EI/hKG5CECcf1e/29gXwHV70zNT8whAVdeG/KdtF8C+
4ugvcCsJQA0iQmHFuBbAKjnT1g1iCUBVliMphZ4YwG//PYJAlwlA4sUhneQi
GMDNqh9dGssJQMOhB3PBERfA2pJMb6z9CUCY1LEVVVsUwEOMXYUGLwpAfCT5
F4uMFsAFBF1ON18KQM9UQMBEkhXASqAKdkyOCkCIPO8MVpcVwBp7OM8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Mm/o99uIswN64dwvy
SOQ/0zZ6xTKpK8DfVqmFon3tP68ihkLclyXA/AmBZtBQ8j+FZH3DXygdwIOR
BD6aO/U/6LylklMpJsCF+JAQAbP3P4XA5eOhDCbAZ8hRwvLV+T+1ABU7YcQk
wFqa8FBjuPs/dXlTcsm2I8CrG0W78Wf9P2VSstAi1yLAXkJExlXu/j9SYGFz
gXgjwErxjfBdKQBAI3FrHzPdIsAwDFZVS80AQM7nG3BvpCLAaPTEOBFlAUC9
ghrZw7oiwBxYWWJd8gFAmQBqdprfIcBfwE5WinYCQNDFioximyHAYf4DKbPy
AkDQTaUu3aYgwLaVvjjCZwNA2f134mtOIMCvqhQXfdYDQNn0CLzMAiDAURxh
nYk/BECN7vXY2NsfwMj9nsV1owRA5pnNBl4nH8DOEUy2uwIFQOl93z/xzx/A
vDSKScVdBUCWVoQXBgQewGmz5tPutAVAc/rBE4pmHcAWQH4EiQgGQArmTf1l
OB3AZgymBNxYBkCgCaHqpToewMht5d0mpgZAeYWRzLBvHcA6mcUHovAGQPi0
wE0fWhzAlSeDB4A4B0C7i/nYJQYcwE1Dkz7ufQdAG8WL/0o6HMCQQGBSFcEH
QCOnTQV6rxvAiC1M0xoCCECYkS2ohRAcwC5hhhMgQQhAfD1fS0j3G8BGqu6p
Q34IQBCtq+Fr/xnA3EI/hKG5CEDE0387J9QawHV70zNT8whAwV+Vz+PuGcC+
4ugvcCsJQLnecRhgPhvAKjnT1g1iCUDSryN++jAZwG//PYJAlwlAa2pci6HB
GsDNqh9dGssJQCTI2tZ+GRnA2pJMb6z9CUDTJvTs06MZwEOMXYUGLwpA8kBj
Ok1UGsAFBF1ON18KQCVEwaBsXxnASqAKdkyOCkCWy3Gz2sQawNRWQAk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.272638944860985},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.01948336229021, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.73180128983843, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.326336181730264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.172185501903007`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.038654109278484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.9208710736221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/djG5cY7ggwN64dwvy
SOQ//GfDwzcQG8DfVqmFon3tP0/AdULlwhjA/AmBZtBQ8j9vCIUvtFsZwIOR
BD6aO/U/OKLqsTvJFsCF+JAQAbP3P1Go+XBnUxXAZ8hRwvLV+T96v05eyjYT
wFqa8FBjuPs/einyUa5wEsCrG0W78Wf9P5P48qx3DhLAXkJExlXu/j9j2YQA
qBUQwErxjfBdKQBArd3Ok1w6DsAwDFZVS80AQKS7yj1KzgvAaPTEOBFlAUBq
8HckXAcKwBxYWWJd8gFAv4jRuoHkB8BfwE5WinYCQIBsfroBeAjAYf4DKbPy
AkBqvcLF3ycFwLaVvjjCZwNAMLYdMEMVA8CvqhQXfdYDQFjw16T+wgLAURxh
nYk/BEAzqKyQjNYAwMj9nsV1owRA0xP+JxohAMDOEUy2uwIFQH8SP1bUZ/y/
vDSKScVdBUAezC+0LHf5v2mz5tPutAVArphba4L3878WQH4EiQgGQMdSGsnz
2fa/ZgymBNxYBkCqCWxmvrzwv8ht5d0mpgZA9o0PKJLE8r86mcUHovAGQE4Q
DK4SJ+2/lSeDB4A4B0CQ2/dfTInnv01Dkz7ufQdAFRG7aKt55b+QQGBSFcEH
QM+m50V/heC/iC1M0xoCCEDn8UyRAzrjvy5hhhMgQQhAOemTyfnR179Gqu6p
Q34IQJvBjbjxfsG/3EI/hKG5CEBbLBv62e3Jv3V70zNT8whAan66Qt+wsr++
4ugvcCsJQCMaNh92jMQ/KjnT1g1iCUDUsbQc8x6+v2//PYJAlwlAaQtcTo3L
4T/Nqh9dGssJQIALVwMGOOU/2pJMb6z9CUBWsCPKhN7bP0OMXYUGLwpA9NJs
M6ShpT8FBF1ON18KQE4ea6tn7PM/SqAKdkyOCkDgdbryD9fRv7cqRxc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9myZxovyEhwN64dwvy
SOQ/o6F6q12uHMDfVqmFon3tP7rnRxp4thPA/AmBZtBQ8j/8p47VCHUWwIOR
BD6aO/U/H0nh9RRxGcCF+JAQAbP3PyxA+t9pWxXAZ8hRwvLV+T/wIxpza14U
wFqa8FBjuPs/+bowzDBGFMCrG0W78Wf9P3JJUz8lhxDAXkJExlXu/j/YvEN1
0xoSwErxjfBdKQBAZ5dIx89fDMAwDFZVS80AQL/HOi4d+A3AaPTEOBFlAUCU
rAUqbOIJwBxYWWJd8gFA7SDzWodTBsBfwE5WinYCQB4Un0QfcQjAYf4DKbPy
AkCGuzEw3jAFwLaVvjjCZwNAEG9q4iogCMCvqhQXfdYDQDIyr0XUnwHAURxh
nYk/BECZHMBWkg0BwMj9nsV1owRAQ1GKOFha/L/OEUy2uwIFQChDQJcJIP2/
vDSKScVdBUA52Dq9xL/6v2mz5tPutAVAA7tyKjDt978WQH4EiQgGQIJiFTAa
vfO/ZgymBNxYBkACdiwzbDDyv8ht5d0mpgZA3Rj+Swnt6b86mcUHovAGQOHI
tRaVuO2/lSeDB4A4B0A+oL2sijTvv01Dkz7ufQdAp3zX2upU57+QQGBSFcEH
QElxm0+dWei/iC1M0xoCCED1yeXgzMXivy5hhhMgQQhA+Zcc5tRt1L9Gqu6p
Q34IQMusZTuzZNW/3EI/hKG5CEB/GeUY/C3Iv3V70zNT8whAARvzwGCHyL++
4ugvcCsJQH5UsdGaWcg/KjnT1g1iCUDVvUbXCCuxv2//PYJAlwlAHjBHUhZ+
sz/Nqh9dGssJQNGPIhvg5HE/2pJMb6z9CUBd6GiFMnntP0OMXYUGLwpARheU
pq6ywz8FBF1ON18KQFp6tkKow6C/SqAKdkyOCkDjLSDKzKy0P1KCP30=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -3.7201289468573497`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/SPqfu5oMAQN64dwvy
SOQ/6CaTGq6p/T/fVqmFon3tP+2c2h0d7fc//AmBZtBQ8j9U17e36ersP4OR
BD6aO/U/lBbAUE4Q5T+F+JAQAbP3P+MeJiG6k94/Z8hRwvLV+T8+Sywj97Dm
P1qa8FBjuPs/vAMS38+izz+rG0W78Wf9P0U5ZSrpg9E/XkJExlXu/j+Ke21o
BYm2P0rxjfBdKQBAqm6Akyttwj8wDFZVS80AQDM9uLrcLcM/aPTEOBFlAUA7
31kdOjWaPxxYWWJd8gFAo4iz7s/Epr9fwE5WinYCQNoCOS7UDcG/Yf4DKbPy
AkCdKjwr5Dmlv7aVvjjCZwNAgWt5ftDPvb+vqhQXfdYDQH+mTG/QKtC/URxh
nYk/BEBRWmdHqlC3v8j9nsV1owRACkFbdbFJ0L/OEUy2uwIFQJ4bmAO0+r2/
vDSKScVdBUBgBO8X2hbPv2mz5tPutAVAUN47a9UMtr8WQH4EiQgGQKYVgBQp
Z9O/ZgymBNxYBkBRdfb8bT/Rv8ht5d0mpgZA71CZEO7qtL86mcUHovAGQAeQ
jQP+nMm/lSeDB4A4B0DHZM1yi8PLv01Dkz7ufQdAFRNaQRN+yr+QQGBSFcEH
QNLtHKQgMMC/iC1M0xoCCEAPgwyfsbnVvy5hhhMgQQhAyQf7bmux279Gqu6p
Q34IQAntBrkKSMu/3EI/hKG5CEBfrwTC6EvWv3V70zNT8whAo/FrbSzm07++
4ugvcCsJQPtwT3xVLsi/KjnT1g1iCUBklO64PCvlv2//PYJAlwlAPLs7JkRy
1r/Nqh9dGssJQKDwEeimyc6/2pJMb6z9CUB9c+2ePdefP0OMXYUGLwpA4c72
v+Qy4b8FBF1ON18KQLOS9xvzt5M/SqAKdkyOCkDMPAhbhlfhvyMESJI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ni9hpFfDQv964dwvy
SOQ/2OpJ5JWlzL/fVqmFon3tP4D1CQWk6PQ//AmBZtBQ8j+Hx7/M/PMJQIOR
BD6aO/U/vj+YWSC65r+F+JAQAbP3P3nO0BIYTOW/Z8hRwvLV+T+28a6s5Hbk
v1qa8FBjuPs/QiGrahQm5b+rG0W78Wf9P0RrN59+/NS/XkJExlXu/j9cQD91
nqHuv0rxjfBdKQBANGLS5Z714b8wDFZVS80AQO/AKmTc0eu/aPTEOBFlAUBN
thkZVnbqvxxYWWJd8gFA2tSKGwHW4r9fwE5WinYCQC0rPfeJKey/Yf4DKbPy
AkAsfGhe6rbjv7aVvjjCZwNAeHB3mTD26r+vqhQXfdYDQCpfT3GaNOK/URxh
nYk/BEBThlibQlvlv8j9nsV1owRAIFKInaVd4b/OEUy2uwIFQMdGdRuWRem/
vDSKScVdBUB3a/5vsNnjv2mz5tPutAVAhqB3iE6S4r8WQH4EiQgGQP9Ej6rT
1OG/ZgymBNxYBkAzVYksIaDnv8ht5d0mpgZANfF+0hCz4r86mcUHovAGQGtg
wVWnL+S/lSeDB4A4B0C3EOVWQcXmv01Dkz7ufQdA+I9vaugY57+QQGBSFcEH
QH96gq0fgei/iC1M0xoCCECGnnjgdGLqvy5hhhMgQQhA83et50956L9Gqu6p
Q34IQO1hPCumjuO/3EI/hKG5CEDGbBVlJ7Xnv3V70zNT8whA3t6yigKI5r++
4ugvcCsJQIE1BcUA+Oe/KjnT1g1iCUDXHyfDwVnmv2//PYJAlwlA8EGgrihj
7b/Nqh9dGssJQCWxMNSJjum/2pJMb6z9CUCd11fhq/Ldv0OMXYUGLwpAAAnc
aubM8L8FBF1ON18KQGp5LS+z/PC/SqAKdkyOCkDBJDCiToL0v8zgWZ4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5566844308791865},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8WBHphzogpwN64dwvy
SOQ/B+yOOyP3J8DfVqmFon3tP+T7b74cOSfA/AmBZtBQ8j8vkx5vFisnwIOR
BD6aO/U/LoZR2VSfJsCF+JAQAbP3P2OPG56nICbAZ8hRwvLV+T9L5SgCet8k
wFqa8FBjuPs/5xMy/68hJcCrG0W78Wf9P+M1hHpCdiTAXkJExlXu/j/ykXpX
qkgkwErxjfBdKQBApaeKaOuqI8AwDFZVS80AQOPJutHoMCPAaPTEOBFlAUBQ
O2QiLgAjwBxYWWJd8gFAo/3KDgm7IsBfwE5WinYCQASkX8rliCLAYf4DKbPy
AkB0A4jut/0hwLaVvjjCZwNA9eElGaDMIcCvqhQXfdYDQM0gKt3zvyHAURxh
nYk/BEB58N3qzh8hwMj9nsV1owRAlP6g2mkoIcDOEUy2uwIFQFX42C02nCDA
vDSKScVdBUAJKTFZz5ggwGmz5tPutAVA44rHmkQIIMAWQH4EiQgGQKVKmsty
OiDAZgymBNxYBkDSt0vt5NYfwMht5d0mpgZAsePRyHSlHsA6mcUHovAGQA8Y
Qsm+rx7AlSeDB4A4B0BSVz02H1cewE1Dkz7ufQdAOs/fIkvkHcCQQGBSFcEH
QOqX3cG6LB3AiC1M0xoCCEA60ZFSJKUdwC5hhhMgQQhAx1A3Y9ulHcBGqu6p
Q34IQK5/cSTzaRzA3EI/hKG5CEDHbQk9nJ0cwHV70zNT8whAzhyi5JkiHMC+
4ugvcCsJQCNTS/BmTxvAKjnT1g1iCUAkkrno1OEcwG//PYJAlwlASgbfXKxT
G8DNqh9dGssJQPCfH5BLmBrA2pJMb6z9CUDdspN67zUZwEOMXYUGLwpAvdWD
njQxG8AFBF1ON18KQClbXSyisBjASqAKdkyOCkD1jmzKfKUawN5rO6I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8w37Y/oIsqwN64dwvy
SOQ/F07UsArVKMDfVqmFon3tP+Qd5W+0mSTA/AmBZtBQ8j9GR8lZu6QfwIOR
BD6aO/U/O6ggBjD5JsCF+JAQAbP3P72Mx3V/PSbAZ8hRwvLV+T8myuRZaZ8l
wFqa8FBjuPs/BVK0WeopJcCrG0W78Wf9Pykxzgf2CiTAXkJExlXu/j9KXPXh
kOIkwErxjfBdKQBApg4Dv6C1I8AwDFZVS80AQK9HX+gW9iPAaPTEOBFlAUAp
CAuQFokjwBxYWWJd8gFA5HyDDjS/IsBfwE5WinYCQA6NHrbDBiPAYf4DKbPy
AkBCev72+jYiwLaVvjjCZwNAczwR3PZiIsCvqhQXfdYDQJiUORe6lCHAURxh
nYk/BEDwOrq/uYYhwMj9nsV1owRAhLTY86kJIcDOEUy2uwIFQJgfwkHUSyHA
vDSKScVdBUAKh/yqr7wgwGmz5tPutAVA1fJLdnhxIMAWQH4EiQgGQIwVREYv
LyDAZgymBNxYBkCeYcIN51ggwMht5d0mpgZAOYSUv/SuH8A6mcUHovAGQGTh
w+L1fR/AlSeDB4A4B0Au33Zs1XIfwE1Dkz7ufQdA/o9XKC4hH8CQQGBSFcEH
QJeSXs5U9B7AiC1M0xoCCEBFR2a77dkewC5hhhMgQQhAZv5kV1lHHsBGqu6p
Q34IQHuDoHe3VR3A3EI/hKG5CEDUCZq5rIodwHV70zNT8whAkr7AvwMYHcC+
4ugvcCsJQHv8QNYD+RzAKjnT1g1iCUDwG5Xb+nkcwG//PYJAlwlAJCrhpSoT
HcDNqh9dGssJQPaXuCW4URzA2pJMb6z9CUCb0ZhyH7kawEOMXYUGLwpAJvpI
6y/HHMAFBF1ON18KQF0O/m1xjRzASqAKdkyOCkCvoKVEFS4dwKKdOpc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=61.2494\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448093495129*^9},ExpressionUUID->"87c85fa6-25c1-4ed9-978f-\
2bad0254ba9f"],

Cell[BoxData["8"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480940956397`*^9},ExpressionUUID->"53a172ee-57d2-4aef-9b10-\
0f39792636f6"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Pf2hfzPgjwN64dwvy
SOQ/zpoHojhPIsDfVqmFon3tP60+qtJI9yHA/AmBZtBQ8j92s/Vsc3AhwIOR
BD6aO/U/kLGyHEjRIMCF+JAQAbP3P6mmA0OCCSHAZ8hRwvLV+T9B5xsiCXAf
wFqa8FBjuPs/KAm52p+JIMCrG0W78Wf9P7slW20MXSDAXkJExlXu/j/RzK2+
dEUgwErxjfBdKQBACDhZJWxuH8AwDFZVS80AQEQnnJXTAB/AaPTEOBFlAUD+
6EBfBbQdwBxYWWJd8gFAGr9UdyxEHsBfwE5WinYCQBVEGXhIzh3AYf4DKbPy
AkByNwtD75McwLaVvjjCZwNAJiJKQ3BGHMCvqhQXfdYDQDhsACbnuBzAURxh
nYk/BEDAdj+ljfwbwMj9nsV1owRA53RR9DuHG8DOEUy2uwIFQDwoae+UGxvA
vDSKScVdBUA8S501DX8bwGmz5tPutAVA5eW1YeLDGcAWQH4EiQgGQISy+hwJ
nBrAZgymBNxYBkAe4RWxkVEawMht5d0mpgZA8M3xTc2sGMA6mcUHovAGQCCt
WrL3QBnAlSeDB4A4B0BSc61HSX8YwE1Dkz7ufQdA82OD9cCJGMCQQGBSFcEH
QKKwmQ5yNRjAiC1M0xoCCEBo5AKccRAYwC5hhhMgQQhAhAf6w24CGMBGqu6p
Q34IQEQ6SHhZ1BbA3EI/hKG5CEDguywWMf8WwHV70zNT8whA7Agko+YqF8C+
4ugvcCsJQHX96SmLkRbAKjnT1g1iCUC4cyXK6rgYwG//PYJAlwlAE4PeKN8f
FsDNqh9dGssJQIvAa1Am0hjA2pJMb6z9CUDzOImR5CgUwEOMXYUGLwpATSK3
DlWcGMAFBF1ON18KQGX6DWifGBXASqAKdkyOCkAke238bskWwE2+MCs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8+gSDUTOgrwN64dwvy
SOQ/IFj87WgxK8DfVqmFon3tP54vr4s+BSTA/AmBZtBQ8j92DB34z08kwIOR
BD6aO/U/O/E0WopJJsCF+JAQAbP3PxwVQ5/f3yXAZ8hRwvLV+T9cZxrEQdwk
wFqa8FBjuPs/2mB4IymqI8CrG0W78Wf9PxWJ3Ty1uiLAXkJExlXu/j/PN2/A
QrIjwErxjfBdKQBALblhufXEIsAwDFZVS80AQP+NPx8UpCLAaPTEOBFlAUCJ
WKPx3UwiwBxYWWJd8gFA7e1bkJhEIcBfwE5WinYCQKea+efBpyHAYf4DKbPy
AkBmjOLU/9UgwLaVvjjCZwNALtoj3S66IMCvqhQXfdYDQDPHLeVxRyDAURxh
nYk/BEDB17S1N7kfwMj9nsV1owRA2unxZg+/HsDOEUy2uwIFQFRAOJ+EbR/A
vDSKScVdBUBZWD2kNL8ewGmz5tPutAVAQRKOF1ggHsAWQH4EiQgGQC79rj0x
Zh3AZgymBNxYBkA1ZM6X1pwdwMht5d0mpgZA51c2ZhwQHcA6mcUHovAGQAjP
5JfeahzAlSeDB4A4B0DHLdprLLkcwE1Dkz7ufQdALOdeqsxWHMCQQGBSFcEH
QG6MAcJvPRzAiC1M0xoCCECjM8GdDNMbwC5hhhMgQQhAM9mcesRTG8BGqu6p
Q34IQKXGaWbyLhvA3EI/hKG5CEC+QIB84CsbwHV70zNT8whAB5CAaeKcGsC+
4ugvcCsJQPF4jUSkzhrAKjnT1g1iCUATI3Z1bvwZwG//PYJAlwlAamRmG9wm
GsDNqh9dGssJQMp6gMZ6hRrA2pJMb6z9CUAgWZCetd4XwEOMXYUGLwpAmXhP
9BS0GcAFBF1ON18KQJqEU9N3UxnASqAKdkyOCkDR8WLuQZ8bwATjOlo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.060019757062184},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-15.01948336229021, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.73180128983843, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.326336181730264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.172185501903007`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-14.038654109278484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.9208710736221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/zmU870XIdwN64dwvy
SOQ/ZLuDi2ATG8DfVqmFon3tP+8k1xpDeRnA/AmBZtBQ8j8DUUvJz88YwIOR
BD6aO/U/592boXqNF8CF+JAQAbP3P0S7DS/ipxXAZ8hRwvLV+T8ZLcH3ZGwT
wFqa8FBjuPs/bfa7ngSREcCrG0W78Wf9P/zOCNYO9w/AXkJExlXu/j+aKMea
xmUPwErxjfBdKQBAA+HEuEUkDMAwDFZVS80AQBHXIZ1lxgnAaPTEOBFlAUA0
kN+kGzkLwBxYWWJd8gFAwfJQF0jrB8BfwE5WinYCQK7w5mZCUgfAYf4DKbPy
AkAu/MVfPlcDwLaVvjjCZwNArLFLsaeyA8CvqhQXfdYDQEA2TwenegLAURxh
nYk/BED2n2XSPSX+v8j9nsV1owRAwGCu7iJa/7/OEUy2uwIFQMBt4V7pLfm/
vDSKScVdBUApdYBqyR34v2mz5tPutAVAbo2eQtAj9b8WQH4EiQgGQHC1u1u7
9vW/ZgymBNxYBkDZIMoilyfxv8ht5d0mpgZAOYgDMQ4G7786mcUHovAGQMi6
lBHlb+i/lSeDB4A4B0Cg7eG95KHov01Dkz7ufQdA5cl6CWLx4L+QQGBSFcEH
QGhbVnVgFdm/iC1M0xoCCEAsya4ZSzrhvy5hhhMgQQhAWVzzC5UM4L9Gqu6p
Q34IQPxvKuhwHtW/3EI/hKG5CEAey65ocaHXv3V70zNT8whAeNIDyuvQqj++
4ugvcCsJQEYhz7ctkso/KjnT1g1iCUB5kZNYg2qCv2//PYJAlwlAcKoDKj+U
1D/Nqh9dGssJQJBQ/hBBYes/2pJMb6z9CUB0w/a4yDDhP0OMXYUGLwpA+zWM
BMxM3D8FBF1ON18KQGLaXRfb3/I/SqAKdkyOCkAmXi+l4TXlP47MRPM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Xm+Xg9KEgwN64dwvy
SOQ/YrD983F0IMDfVqmFon3tP5Km1bw9rhbA/AmBZtBQ8j+9irMIMBbkv4OR
BD6aO/U/d2J/XckKGcCF+JAQAbP3P+GWpLhHmxXAZ8hRwvLV+T8KDRD3SBoU
wFqa8FBjuPs/gzxa+7dgFMCrG0W78Wf9P+cXhbQD3BDAXkJExlXu/j+LxRCO
334RwErxjfBdKQBA4ac3NcCzDMAwDFZVS80AQPAdewri+g3AaPTEOBFlAUBM
xPSZq0ULwBxYWWJd8gFAHZII9dyECMBfwE5WinYCQGoXZibhPAjAYf4DKbPy
AkB9R3jyWXEEwLaVvjjCZwNA1vEFQmJOBcCvqhQXfdYDQJdEKlSJhQDAURxh
nYk/BECU4BAhh14BwMj9nsV1owRA9PmnOyIp/r/OEUy2uwIFQNnWRfWr3v6/
vDSKScVdBUConjYhfLT3v2mz5tPutAVAsxnE74V99L8WQH4EiQgGQDy3Ta3r
CfO/ZgymBNxYBkCfoxA4CXv0v8ht5d0mpgZA37GK4l8n7L86mcUHovAGQBdp
5uwGyu2/lSeDB4A4B0A4W06llqLpv01Dkz7ufQdAOUMGulyX5r+QQGBSFcEH
QPXdgW6IWuS/iC1M0xoCCEDcp2jd1iHlvy5hhhMgQQhA+PfuhmO33b9Gqu6p
Q34IQGLv57bXaaq/3EI/hKG5CEAnFHEMRDK7v3V70zNT8whAqsvS2L1fgb++
4ugvcCsJQJDUAuGnZ7s/KjnT1g1iCUCJspK/KOLDP2//PYJAlwlAUJNBvlnB
sr/Nqh9dGssJQPjYCBAwFNY/2pJMb6z9CUDOUTFQskjjP0OMXYUGLwpAEiLy
pkcsgr8FBF1ON18KQN2v5I5zEqi/SqAKdkyOCkBy63bnkArOP68dSa8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -3.6117324936304076`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/m6e6ZXZQFQN64dwvy
SOQ/ZRlVZ607AEDfVqmFon3tP8eT8mbHcvg//AmBZtBQ8j+HtnWwSOfwP4OR
BD6aO/U/wtLM0vlt6j+F+JAQAbP3P357jy+Ub+E/Z8hRwvLV+T9tp5YDqyfo
P1qa8FBjuPs/2QJLvELU2z+rG0W78Wf9P+dwgjZLt9c/XkJExlXu/j/uSUER
MVLBP0rxjfBdKQBADnHxxgYHzD8wDFZVS80AQHCT9ZsacMg/aPTEOBFlAUCq
pNCFGVCrPxxYWWJd8gFAcUTF4WySo79fwE5WinYCQMJi6GN8ycC/Yf4DKbPy
AkBHfr+tj4m2P7aVvjjCZwNAub5hYnfxrb+vqhQXfdYDQF7mG2Az5Mq/URxh
nYk/BED8Bi7hoauuv8j9nsV1owRA63ZonPbIxr/OEUy2uwIFQMvfU8A1/LO/
vDSKScVdBUDBMnOZyDbNv2mz5tPutAVA51sgpKn4nb8WQH4EiQgGQBRhTkK+
WNK/ZgymBNxYBkB8Mxj/LzjNv8ht5d0mpgZArFkMuNKtqr86mcUHovAGQFBG
lRDR7cO/lSeDB4A4B0CUe5/QenPCv01Dkz7ufQdA/MFQAhhDw7+QQGBSFcEH
QAb5rzuBrcG/iC1M0xoCCEDt8ga7bcjQvy5hhhMgQQhA4+/y/k7h1L9Gqu6p
Q34IQMnuwVxdFMO/3EI/hKG5CEALQWZEywXRv3V70zNT8whA/MJ7IgM2zL++
4ugvcCsJQGMXciqMu8K/KjnT1g1iCUAgk80eayPkv2//PYJAlwlAgzjdJGn/
xr/Nqh9dGssJQL+HSaaykNS/2pJMb6z9CUDuzCihHBW4P0OMXYUGLwpAlruw
H10j5r8FBF1ON18KQMmja+pbjao/SqAKdkyOCkBKf665zePev/QNUCQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8gqo5e7E+2P964dwvy
SOQ/5OX/zsXg67/fVqmFon3tPxsXymNoOvY//AmBZtBQ8j+CAaPpq3ISQIOR
BD6aO/U/273vZhHn5r+F+JAQAbP3PwNR4EgNKOW/Z8hRwvLV+T+R9QYFqhzk
v1qa8FBjuPs/3e+fk0wG5b+rG0W78Wf9P7G8sqGshdW/XkJExlXu/j/6r28j
IEfuv0rxjfBdKQBAQbkI6qMS4r8wDFZVS80AQPwpSTlH0Ou/aPTEOBFlAUBH
dNo5puTqvxxYWWJd8gFAM8bVEp9l479fwE5WinYCQNtitm4tI+y/Yf4DKbPy
AkDO7K1Frpzjv7aVvjjCZwNA1EKH8ART6r+vqhQXfdYDQGmerisp5+G/URxh
nYk/BEBk/3avxm3lv8j9nsV1owRALFjOEpCB4b/OEUy2uwIFQJqqAk5lkOm/
vDSKScVdBUBmEVj1Rafjv2mz5tPutAVAwciHl0L54b8WQH4EiQgGQJD1Czq5
yOG/ZgymBNxYBkCZdPL2Ib7nv8ht5d0mpgZAgiXpny2r4r86mcUHovAGQM4Z
QH5LgOS/lSeDB4A4B0AYNPKH//Lmv01Dkz7ufQdAfrjZDRoi57+QQGBSFcEH
QDxEMuPR2Oi/iC1M0xoCCEBjoseY0ojqvy5hhhMgQQhA2xvyeWRs6L9Gqu6p
Q34IQGu6VDyO8uO/3EI/hKG5CED/Y/V0nLHnv3V70zNT8whA5MopRNGO5r++
4ugvcCsJQLunKd6s+Oe/KjnT1g1iCUClIy5Qdafmv2//PYJAlwlAxwPnUStF
7b/Nqh9dGssJQHRXQjFxVeq/2pJMb6z9CUC4EW8h3zDcv0OMXYUGLwpAR6ZU
tGyS8L8FBF1ON18KQCDEqiV8+PC/SqAKdkyOCkAoAwnNDd70v/P9WLc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5664122400079933},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox["50", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9MiTjbEFcowN64dwvy
SOQ/Z5aLrOCdJ8DfVqmFon3tP5I4+8AhLCfA/AmBZtBQ8j/z9Gf6Gt0mwIOR
BD6aO/U/r/lmhZFLJsCF+JAQAbP3PwJ7uI9a/yXAZ8hRwvLV+T/DStp0K8ck
wFqa8FBjuPs/mgmE8TTCJMCrG0W78Wf9P7fzlKqFRSTAXkJExlXu/j8z1y53
9jAkwErxjfBdKQBAa4rTftSEI8AwDFZVS80AQJ57QoJYHCPAaPTEOBFlAUDM
+IWsKfIiwBxYWWJd8gFA+oA46SO4IsBfwE5WinYCQKWPx5hphyLAYf4DKbPy
AkB/zma2qLshwLaVvjjCZwNAYnKkIx2vIcCvqhQXfdYDQFovR5ocqiHAURxh
nYk/BECg5HYEsw8hwMj9nsV1owRAZLwqqjUBIcDOEUy2uwIFQB3epRSDiCDA
vDSKScVdBUB5fgjtcJEgwGmz5tPutAVAX7on0tzWH8AWQH4EiQgGQCe3dkQG
MiDAZgymBNxYBkAxEacCgqwfwMht5d0mpgZASROYZDmHHsA6mcUHovAGQIhP
H7P0gR7AlSeDB4A4B0BRAHcp0AwewE1Dkz7ufQdAfBkoGR+rHcCQQGBSFcEH
QI+dZ8jYOB3AiC1M0xoCCEDjz2PlXFYdwC5hhhMgQQhA0jOeh0g5HcBGqu6p
Q34IQGOUui9aKBzA3EI/hKG5CEA7ooZi40gcwHV70zNT8whAEfQFPWPFG8C+
4ugvcCsJQIPY9ImkIxvAKjnT1g1iCUD60NcPDMEcwG//PYJAlwlAu72bxmCk
GsDNqh9dGssJQJdVr0Yy6xrA2pJMb6z9CUCXLmVt0vUYwEOMXYUGLwpAxJL9
AmXPG8AFBF1ON18KQNSmr6rljRjASqAKdkyOCkAUAG+m1GgawNQTOE4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Dq9O0590pwN64dwvy
SOQ/nAv3tKomKsDfVqmFon3tP+H+m2KmdSTA/AmBZtBQ8j84wDGyXzgawIOR
BD6aO/U/FdfXQugBJ8CF+JAQAbP3P1gD/P0CQSbAZ8hRwvLV+T/vLuQ4YJ8l
wFqa8FBjuPs/lj23y1gtJcCrG0W78Wf9PxWHid1zFCTAXkJExlXu/j+mbI9I
/OEkwErxjfBdKQBAFBiQ6Em8I8AwDFZVS80AQIt46der+iPAaPTEOBFlAUAG
BkkRW5QjwBxYWWJd8gFABIymDXTMIsBfwE5WinYCQHjF8ypwCiPAYf4DKbPy
AkCn5SRfRzkiwLaVvjjCZwNAPKOfGHtcIsCvqhQXfdYDQIHcBv5ykyHAURxh
nYk/BEAV35frS4shwMj9nsV1owRAKgndPjYPIcDOEUy2uwIFQGzi7z+jUyHA
vDSKScVdBUDGF+efhrwgwGmz5tPutAVAFG9Jr79qIMAWQH4EiQgGQBa/8W8n
MSDAZgymBNxYBkC4MI5GZF0gwMht5d0mpgZAIQ+LsQmzH8A6mcUHovAGQB03
SH/LjB/AlSeDB4A4B0AJQpAgGX0fwE1Dkz7ufQdAqWg0WZ8mH8CQQGBSFcEH
QKFYgzlbAx/AiC1M0xoCCEBgWOZpreIewC5hhhMgQQhAAZS6RpxJHsBGqu6p
Q34IQEBPPH/bZR3A3EI/hKG5CEAfbTJkxo0dwHV70zNT8whAvZp8Xz4cHcC+
4ugvcCsJQEYfDaBa/BzAKjnT1g1iCUAeae9AyoYcwG//PYJAlwlAvTGNao4S
HcDNqh9dGssJQKHiiFt+bRzA2pJMb6z9CUDW3vvguZ8awEOMXYUGLwpAyqa0
IkG7HMAFBF1ON18KQABe4JoDjxzASqAKdkyOCkCn988Zf0cdwG2WMWw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=71.2498\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480943753834`*^9},ExpressionUUID->"c3be1222-db0d-4471-b3d9-\
41c9ddee4996"],

Cell[BoxData["9"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448094983588*^9},ExpressionUUID->"05aa7e69-417e-468d-9092-\
04d272a2dd0a"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8fXGLzxYgewN64dwvy
SOQ/29MoaWQuIcDfVqmFon3tP7Yx2ib0iiHA/AmBZtBQ8j9fDYraibMgwIOR
BD6aO/U/MqnLH0+GIMCF+JAQAbP3P4LGzbo/hiDAZ8hRwvLV+T9Qj7HoRH8f
wFqa8FBjuPs/o0o+vdg4IMCrG0W78Wf9P6O/yYShOB/AXkJExlXu/j9golkP
JxQgwErxjfBdKQBA0CANpPRqHsAwDFZVS80AQIGwdd+nhh3AaPTEOBFlAUAm
YFD2CUkdwBxYWWJd8gFAynVZ61UEHsBfwE5WinYCQJXqyVh32R3AYf4DKbPy
AkCXtgZKsOEbwLaVvjjCZwNA2btBn99sHMCvqhQXfdYDQNDfCRVueRzAURxh
nYk/BEAKO9B7u6kawMj9nsV1owRAkVTIXw1eG8DOEUy2uwIFQFk1xlwN2xrA
vDSKScVdBUDl2F/dpgcbwGmz5tPutAVADWGiY475GcAWQH4EiQgGQMT+1sXI
2RrAZgymBNxYBkChUvTcQaIZwMht5d0mpgZAHaHUr+7NGMA6mcUHovAGQIgO
kGJ7bxjAlSeDB4A4B0Aai4ZlhpoYwE1Dkz7ufQdA7+HLYGXCF8CQQGBSFcEH
QBsThMAQbBfAiC1M0xoCCEChIzwpAp4XwC5hhhMgQQhAUYU0xBsEGcBGqu6p
Q34IQA/sy5UGLBfA3EI/hKG5CEDWsogxDpEXwHV70zNT8whAVCztjT6zFsC+
4ugvcCsJQBibJEtrIhbAKjnT1g1iCUBbav4xJ/MXwG//PYJAlwlAMWKZJ06p
FsDNqh9dGssJQMp89HcihRbA2pJMb6z9CUAwOSsEzw0TwEOMXYUGLwpAgc3+
kbGAFsAFBF1ON18KQE4IRNwDVxLASqAKdkyOCkAy1zYzlAgXwOTiMwY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+ZOuPEMlorwN64dwvy
SOQ/vW/o/8JlKcDfVqmFon3tP9UOwbVnCyfA/AmBZtBQ8j8glfywVAcRwIOR
BD6aO/U//dwKDwcYJsCF+JAQAbP3P4iK0p3YiiTAZ8hRwvLV+T/HrGyHwcUj
wFqa8FBjuPs/2zpTv/FSJMCrG0W78Wf9PwcRj7kRRSLAXkJExlXu/j/VhACg
JeoiwErxjfBdKQBA1/Xj4JIJIsAwDFZVS80AQPccG/KDtyHAaPTEOBFlAUCf
TAb1GoEhwBxYWWJd8gFAkmfkAu+wIMBfwE5WinYCQN+oEBnnRyHAYf4DKbPy
AkBWxN7faIwgwLaVvjjCZwNAomtKX75YIMCvqhQXfdYDQHxDke07AR/AURxh
nYk/BEDvkVwYt60ewMj9nsV1owRACtnJ/s8ZHsDOEUy2uwIFQBXEteNrdB7A
vDSKScVdBUBeHnrlJrccwGmz5tPutAVAqVmQjXIBHcAWQH4EiQgGQAmghaeJ
RRzAZgymBNxYBkCBYy5qYh4dwMht5d0mpgZAyooGt7pAHMA6mcUHovAGQHHE
hTZ9NRvAlSeDB4A4B0Ce8Zpv1cwbwE1Dkz7ufQdA5C8zeWBYG8CQQGBSFcEH
QDF+5rgIJhrAiC1M0xoCCEAm2Q5K8SEawC5hhhMgQQhAgRWfsSppGsBGqu6p
Q34IQBL1bSQoQBnA3EI/hKG5CEDhTjf6SUQZwHV70zNT8whAtXd2YhXvGcC+
4ugvcCsJQOT2HpGilBrAKjnT1g1iCUCqtuDLVr8ZwG//PYJAlwlA/lU3BhKu
GsDNqh9dGssJQDd/pahcwxfA2pJMb6z9CUB9oOfXPYMXwEOMXYUGLwpAPQ5C
PqxpGcAFBF1ON18KQLVUgz2UVRrASqAKdkyOCkD/uhKgxLEYwBgrN5k=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.93948455110147},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-13.815510557964274`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.8971199848858813`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+sek0W42EawN64dwvy
SOQ/b6WtfmEzG8DfVqmFon3tP1gInRObYRnA/AmBZtBQ8j+Oje64k3wZwIOR
BD6aO/U/G5QnK1IsF8CF+JAQAbP3P7W5nlu7ARbAZ8hRwvLV+T9PYJ6UtaER
wFqa8FBjuPs/WZ/hnw4yEsCrG0W78Wf9P52Vq0TFwRDAXkJExlXu/j+1O4Uy
BOkNwErxjfBdKQBAVy/PtTtxDMAwDFZVS80AQEXiKmG54gnAaPTEOBFlAUAZ
dAmOJXwLwBxYWWJd8gFAKNTrNUB6B8BfwE5WinYCQKjFTlJBjQbAYf4DKbPy
AkBCidHXXdQDwLaVvjjCZwNAeTeuZ+QoAsCvqhQXfdYDQKGqqAlLkgHAURxh
nYk/BECYrX+jVMMAwMj9nsV1owRAJ4mBGDum/b/OEUy2uwIFQNWhXcMlXve/
vDSKScVdBUASGV2oKJ/4v2mz5tPutAVAYvaG082t8b8WQH4EiQgGQAnB6wUG
x/S/ZgymBNxYBkCte9uSk7Lxv8ht5d0mpgZAvpS1qGWi6L86mcUHovAGQEaF
tUe1mey/lSeDB4A4B0DABDOwscDkv01Dkz7ufQdAUdxVC0HC4b+QQGBSFcEH
QOX9jnDJjN2/iC1M0xoCCEC6wCcVKKTivy5hhhMgQQhAxGGaPUjYyL9Gqu6p
Q34IQBkN52AUV8e/3EI/hKG5CEAVvcnjNXvAv3V70zNT8whAAnlABf4CkL++
4ugvcCsJQJvJ9aApB9M/KjnT1g1iCUCMZ1jP0he7v2//PYJAlwlAedeQlzwL
4j/Nqh9dGssJQHXroJvmFOg/2pJMb6z9CUDMRgF7/kDXP0OMXYUGLwpA6Edn
UtwJrT8FBF1ON18KQNcJzDFhecg/SqAKdkyOCkDR7X2MoNb0P0ckQZc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+hjmCCjwkiwN64dwvy
SOQ/y0Tymff/H8DfVqmFon3tP8INxo5hYhjA/AmBZtBQ8j+KkwebUXYEwIOR
BD6aO/U/9/gwLQ6QGcCF+JAQAbP3PzmLW9SAVRjAZ8hRwvLV+T+f8ApxiXIW
wFqa8FBjuPs/ptNdAEkbE8CrG0W78Wf9P7sSuQ+/pBHAXkJExlXu/j8geBxx
cxQTwErxjfBdKQBA2cylct+1D8AwDFZVS80AQPpEeNbg2hDAaPTEOBFlAUAG
Lzf/emwOwBxYWWJd8gFAk2UyXUnBCsBfwE5WinYCQCvZgs6a/AnAYf4DKbPy
AkCHWaX37voFwLaVvjjCZwNAgpNQPTHHBsCvqhQXfdYDQFEASyhVdwPAURxh
nYk/BECRh/69zFkDwMj9nsV1owRAT3k9ucBFAMDOEUy2uwIFQHMbfNY4PgHA
vDSKScVdBUDCXuXBqQQAwGmz5tPutAVAe72gVcoc+b8WQH4EiQgGQILY9dhV
gfe/ZgymBNxYBkChA3YHJ2T2v8ht5d0mpgZAQ10Q9GjK8b86mcUHovAGQG7m
oSNQrfO/lSeDB4A4B0CuGgzHS93wv01Dkz7ufQdA8noznqPg7r+QQGBSFcEH
QOmBPFwSvfK/iC1M0xoCCEB+ctpMYpfxvy5hhhMgQQhATXteiSz85b9Gqu6p
Q34IQLkSgquKu+C/3EI/hKG5CEAy5k1ndu3iv3V70zNT8whAap8yjFQIyr++
4ugvcCsJQPu6roouXoW/KjnT1g1iCUBsykcaEOWxP2//PYJAlwlAaJkfW+uM
bb/Nqh9dGssJQGt+EAYXRNm/2pJMb6z9CUCjYCjV9zjgP0OMXYUGLwpATsMm
RSS+sr8FBF1ON18KQE6A6k1x7MQ/SqAKdkyOCkB7dyIiWDXgv0nIQJM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -3.9167599240528617`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9wrm/8gbMQQN64dwvy
SOQ/5TL7PoweAkDfVqmFon3tP6AignWWUPo//AmBZtBQ8j/HZGaB05jyP4OR
BD6aO/U/DqgceRdG7j+F+JAQAbP3Py9zI/fzpOQ/Z8hRwvLV+T9ZOEaYL2Du
P1qa8FBjuPs/rNrpgoQf2z+rG0W78Wf9PwUDtYfQcdw/XkJExlXu/j+AjdWd
TyLSP0rxjfBdKQBAAWrDMIFs1D8wDFZVS80AQKVknIzOINc/aPTEOBFlAUAG
XLcRyW+5PxxYWWJd8gFAK3X3m88Skz9fwE5WinYCQOstXTrRwLe/Yf4DKbPy
AkCCTummIG/DP7aVvjjCZwNAIok9pDuagT+vqhQXfdYDQHmaT+LKy7+/URxh
nYk/BEC8a5RQpPyhP8j9nsV1owRActkVifiuu7/OEUy2uwIFQI0zZiN17IQ/
vDSKScVdBUDBKPIXyYLHv2mz5tPutAVA87HSK1Q/pD8WQH4EiQgGQEOOXAMZ
VNK/ZgymBNxYBkDEFhBT5fjCv8ht5d0mpgZAJQPyKZKrfT86mcUHovAGQCZy
XCa+Gra/lSeDB4A4B0Dz1IeGMN28v01Dkz7ufQdAdXGCW/JSpr+QQGBSFcEH
QASNm/iMdKe/iC1M0xoCCEDGWIre41/Kvy5hhhMgQQhAJXhbkz/T1b9Gqu6p
Q34IQFicntjfBMS/3EI/hKG5CEAvRpMEErvRv3V70zNT8whAseIlSDc6xr++
4ugvcCsJQKiz/7bw5ae/KjnT1g1iCUALJSwgdrThv2//PYJAlwlA3WpA9djA
xL/Nqh9dGssJQHezpx83JsC/2pJMb6z9CUAmFM+kuL/QP0OMXYUGLwpAPEVV
CZzS4L8FBF1ON18KQKMT2xqsXdE/SqAKdkyOCkCNEiHMqNDHv0MkQxs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+GCm3q9K65v964dwvy
SOQ/s6RxamAJ0L/fVqmFon3tP2gzoBw/KOE//AmBZtBQ8j95WJ1+RhUXQIOR
BD6aO/U/OL0tK9mB57+F+JAQAbP3P0KUDWFvg+W/Z8hRwvLV+T8PwCQwJdTk
v1qa8FBjuPs/x/tk/XGv47+rG0W78Wf9P95uxaF9/dS/XkJExlXu/j9Uh0W8
jm7uv0rxjfBdKQBAaLVTOXYo4r8wDFZVS80AQJxGVdA30eu/aPTEOBFlAUBD
c0r2rt3qvxxYWWJd8gFAvCJAaaZI479fwE5WinYCQHlliyXkOuy/Yf4DKbPy
AkBNNCz7Vefjv7aVvjjCZwNAHadb3fI56r+vqhQXfdYDQPizeDHC5+G/URxh
nYk/BEDlfOolJi7lv8j9nsV1owRAW7VuhBxU4b/OEUy2uwIFQKToGNGgROm/
vDSKScVdBUDB33+ozU7jv2mz5tPutAVA7RE3UKhi4r8WQH4EiQgGQGtZ5dx2
s+G/ZgymBNxYBkD+OVPxaLnnv8ht5d0mpgZATcOvOJhD4786mcUHovAGQPZz
0HlM/uO/lSeDB4A4B0CEZe3T20nnv01Dkz7ufQdAdcfP5s4957+QQGBSFcEH
QMv3i1Bl+ua/iC1M0xoCCEABz46+Ktbovy5hhhMgQQhAriH4cT79579Gqu6p
Q34IQLiJCskrHOO/3EI/hKG5CEC4lTE4yIPmv3V70zNT8whAfxuF9XcA57++
4ugvcCsJQLqBaqIs8ui/KjnT1g1iCUC584aW2hvnv2//PYJAlwlAX/LLzRla
7r/Nqh9dGssJQGfbd4/7kOe/2pJMb6z9CUB0GNgkc2/cv0OMXYUGLwpA9pB5
XhWI8L8FBF1ON18KQDGX1aqf6vG/SqAKdkyOCkCVxbeQXOryv6SXXLw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5134303991631901},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox["50", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.313220387090301, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+1T3bdowImwN64dwvy
SOQ/pZDG4YlzJ8DfVqmFon3tPwUrc0ZJKyfA/AmBZtBQ8j8DWTBHW8smwIOR
BD6aO/U/elmNc2IqJsCF+JAQAbP3Pw8IMCUS4iXAZ8hRwvLV+T8vyHk5FHUk
wFqa8FBjuPs/fUqUfYzVJMCrG0W78Wf9P5vFLVJgKyTAXkJExlXu/j+MCXWP
b+8jwErxjfBdKQBAfwza3sJZI8AwDFZVS80AQNx2pxOGyyLAaPTEOBFlAUB5
tdd9qOAiwBxYWWJd8gFAXMSms6WgIsBfwE5WinYCQMwbFzxFeCLAYf4DKbPy
AkAhAAQngJ8hwLaVvjjCZwNAcBgOHa2QIcCvqhQXfdYDQLGSdE0jgSHAURxh
nYk/BEDMK3a3EuIgwMj9nsV1owRAwLb0PsTfIMDOEUy2uwIFQM2GbkioXSDA
vDSKScVdBUDj3wb6An0gwGmz5tPutAVA+wSX0C+UH8AWQH4EiQgGQNxjFXzo
MyDAZgymBNxYBkDxwg2olV0fwMht5d0mpgZASl6KGiJOHsA6mcUHovAGQBhR
8tUaPh7AlSeDB4A4B0AMJ4bC9e8dwE1Dkz7ufQdA8iuPjus/HcCQQGBSFcEH
QC7zirrA3BzAiC1M0xoCCEBdCO2WcR8dwC5hhhMgQQhAt8dnG2ZKHcBGqu6p
Q34IQHWUSoEFMhzA3EI/hKG5CEBbMguML1YcwHV70zNT8whAl8e5i6uXG8C+
4ugvcCsJQLDxXBVMwBrAKjnT1g1iCUDdiqvkuHMcwG//PYJAlwlA9C51HmiT
GsDNqh9dGssJQBGCOkxiJBrA2pJMb6z9CUBjx5HcuksYwEOMXYUGLwpA70ry
/H8mG8AFBF1ON18KQPlDiKQDrxfASqAKdkyOCkCNz2TqYjoZwOUfMeg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/f2y38nW8rwN64dwvy
SOQ/6sp0kOYUKsDfVqmFon3tPwZvyb1lTCfA/AmBZtBQ8j/UEhZUQcsXwIOR
BD6aO/U/JaeaAwMYKMCF+JAQAbP3P76U9b6IRifAZ8hRwvLV+T96lD+OEZ0m
wFqa8FBjuPs/yP7hBDX+JcCrG0W78Wf9P7ErOG0E6iTAXkJExlXu/j/6sgex
c7IlwErxjfBdKQBAm8TqH7mAJMAwDFZVS80AQM93WhgdsSTAaPTEOBFlAUDr
QWVF3z4kwBxYWWJd8gFAUDCTRvxsI8BfwE5WinYCQPHZH7JKpCPAYf4DKbPy
AkA1MLe/680iwLaVvjjCZwNAH2gzCRnhIsCvqhQXfdYDQGMWoIRTEiLAURxh
nYk/BECXS/JGtv4hwMj9nsV1owRAkZMnIC99IcDOEUy2uwIFQEnCLKXduCHA
vDSKScVdBUA0eU+HehshwGmz5tPutAVA+GG4iLbQIMAWQH4EiQgGQJRacbaV
iSDAZgymBNxYBkCBgVflarIgwMht5d0mpgZAepJHsZgzIMA6mcUHovAGQLyu
W5fmCiDAlSeDB4A4B0BDCrAi0AwgwE1Dkz7ufQdAjjVfrp+0H8CQQGBSFcEH
QLc5l29eSx/AiC1M0xoCCEAZREPGzCkfwC5hhhMgQQhA71PakOGyHsBGqu6p
Q34IQN49FCdgvB3A3EI/hKG5CED/QcLdItQdwHV70zNT8whAfS6Phl6SHcC+
4ugvcCsJQNL7QmvYfh3AKjnT1g1iCUDig2EecfQcwG//PYJAlwlAnly7L3WQ
HcDNqh9dGssJQNPKKDmmbBzA2pJMb6z9CUCMY3dT9/cawEOMXYUGLwpAsDB4
XPAIHcAFBF1ON18KQEkbaPltGB3ASqAKdkyOCkAd9MGFfxQdwHhoN+Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=81.2504\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480952628574`*^9},ExpressionUUID->"3439620c-efd0-42e1-b857-\
81d206c8cd74"],

Cell[BoxData["10"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480960958233`*^9},ExpressionUUID->"5328a584-daea-489a-b47c-\
2fb22aa265f4"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+W2aTQFjYdwN64dwvy
SOQ/9l/wPWblIMDfVqmFon3tP5Nakz3a7CDA/AmBZtBQ8j8H4qm3EdEgwIOR
BD6aO/U/cVSFnVRiIMCF+JAQAbP3P9WVGu5dOyDAZ8hRwvLV+T/ybO93CBke
wFqa8FBjuPs/zSQpHjC4H8CrG0W78Wf9Pw8LWQs18R7AXkJExlXu/j9LrHmJ
Z1YfwErxjfBdKQBAZzuD8rwZHsAwDFZVS80AQOca/b+0jx3AaPTEOBFlAUCJ
x+e8uOodwBxYWWJd8gFAKXM0cwXuHcBfwE5WinYCQC6+zeEoihzAYf4DKbPy
AkBfxDCvdaUbwLaVvjjCZwNAmRwHU/xxHMCvqhQXfdYDQMJGJ/zXqxvAURxh
nYk/BEDtv8krLQAbwMj9nsV1owRATUwaMbrIGsDOEUy2uwIFQFhKAPQbuBnA
vDSKScVdBUANp88ZppQawGmz5tPutAVAuLaD7gRtGcAWQH4EiQgGQJlYqcfx
+hnAZgymBNxYBkCenMUwRWYZwMht5d0mpgZA2Q+8hgniF8A6mcUHovAGQClQ
kOxtoBjAlSeDB4A4B0DA8up64xQYwE1Dkz7ufQdAhwbChUSzF8CQQGBSFcEH
QKzuyb8w3hfAiC1M0xoCCEC5elxtI1MYwC5hhhMgQQhAJNO3JKuXF8BGqu6p
Q34IQG9c4BKNVBfA3EI/hKG5CECcY/jxaucXwHV70zNT8whAJalDeDp8FsC+
4ugvcCsJQBTWRqMfARbAKjnT1g1iCUBWFZS5iBUXwG//PYJAlwlA8IWRdOSB
FcDNqh9dGssJQEVwso7+FBfA2pJMb6z9CUDgCt4+8msTwEOMXYUGLwpAcCPN
DtQ7FsAFBF1ON18KQL2/ryO7VxLASqAKdkyOCkD5yCV7bzscwI+kOKU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9F+LIEaPwnwN64dwvy
SOQ/TO/hQyDDI8DfVqmFon3tP+0srE4IiSPA/AmBZtBQ8j/aZ7T00jYEwIOR
BD6aO/U/Q5sO7vj7I8CF+JAQAbP3P8x6MyHzaSPAZ8hRwvLV+T8Lcb00cvMi
wFqa8FBjuPs/UWs1b883IsCrG0W78Wf9P/5QWfzBKyHAXkJExlXu/j8NZ2k9
dfshwErxjfBdKQBAqriqSjocIsAwDFZVS80AQFP/AwMlKSHAaPTEOBFlAUCa
Ct47pncgwBxYWWJd8gFAEm/g66/GH8BfwE5WinYCQBQeKRxQKSDAYf4DKbPy
AkC7xeSasyMewLaVvjjCZwNATwUL7x6pH8CvqhQXfdYDQPvYgo+WMh7AURxh
nYk/BED6C/a7Ck8ewMj9nsV1owRAS3Nl4uEbHcDOEUy2uwIFQPeK8wN7bh3A
vDSKScVdBUDDreou/JgdwGmz5tPutAVABp+U+5CqHMAWQH4EiQgGQLNhTpCC
tBvAZgymBNxYBkCr1/i/IcwbwMht5d0mpgZAt3PfnKPBGsA6mcUHovAGQPlf
/UNhhxrAlSeDB4A4B0AQkiqrlpEbwE1Dkz7ufQdA/9mcjr0PGsCQQGBSFcEH
QBeLaysOkxrAiC1M0xoCCEApIl2ebUwawC5hhhMgQQhAb7HzgUo1GsBGqu6p
Q34IQMpQTQslchjA3EI/hKG5CECHkhXt5DAZwHV70zNT8whAVwuPxt5eGMC+
4ugvcCsJQDggEtEaDxnAKjnT1g1iCUAATdeQJMkYwG//PYJAlwlA79TD+ZFn
GMDNqh9dGssJQMc/uISAfRjA2pJMb6z9CUCYxCEBL7sWwEOMXYUGLwpAYf7Y
QDY2GsAFBF1ON18KQDVRxNr8PBrASqAKdkyOCkCgUw87wm8awBRtNsk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.208485512029839},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.716898269296165`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.429216196844383`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-12.02375108873622, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.86960040890896, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.736069016284437`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.618285980628055`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+w9YkV+wwFwN64dwvy
SOQ/DPidQ5Y6HMDfVqmFon3tP6GRz5hj2RnA/AmBZtBQ8j8/NHPi5ckXwIOR
BD6aO/U/BuPJnyxUFsCF+JAQAbP3P+cctTU/gRbAZ8hRwvLV+T8/1wJU+B4S
wFqa8FBjuPs/cDpSDeDmEcCrG0W78Wf9PzurhAP1fxDAXkJExlXu/j/3wBK1
NZcOwErxjfBdKQBA9NOHIZTMC8AwDFZVS80AQKxuyCv8aQjAaPTEOBFlAUBR
JJSbrg4IwBxYWWJd8gFAQMTwi1pdBsBfwE5WinYCQIWNRCEKJgnAYf4DKbPy
AkBt3wj/oAkDwLaVvjjCZwNA/zKhCS2mAMCvqhQXfdYDQIHOogNfxwHAURxh
nYk/BEAlsbOCpVv8v8j9nsV1owRAk2SqVyFs/7/OEUy2uwIFQEoZxORllPu/
vDSKScVdBUDeAHzMHFb4v2mz5tPutAVA86LRQ6LJ8r8WQH4EiQgGQBSbRFc8
gPW/ZgymBNxYBkAhxX9TOq/wv8ht5d0mpgZAP9x/kapk7b86mcUHovAGQCX4
fldWbua/lSeDB4A4B0Dw1H8be0rkv01Dkz7ufQdAgbEdx0JB27+QQGBSFcEH
QLMQmhhM09a/iC1M0xoCCEBC8pExIN/Svy5hhhMgQQhALcae+A5m279Gqu6p
Q34IQMX+PuJDi72/3EI/hKG5CEAmBpBexcmnv3V70zNT8whAPcBLUIiHib++
4ugvcCsJQExWX/E5QdE/KjnT1g1iCUDTpWWCwNDKv2//PYJAlwlAntmA/SH+
2j/Nqh9dGssJQEEiurhtIO8/2pJMb6z9CUBS9BMwXEnjP0OMXYUGLwpABpuY
wA4IvT8FBF1ON18KQOfsXMhE0eI/SqAKdkyOCkD057IFuov5P7NDQ7I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+uv/7vp1YkwN64dwvy
SOQ/rsWESZ3DIMDfVqmFon3tP82KUTkOAh/A/AmBZtBQ8j/KGZmC+zjov4OR
BD6aO/U/UNcPEzdoHcCF+JAQAbP3P6uBGilEzBrAZ8hRwvLV+T87hyEezNEX
wFqa8FBjuPs/OYGu88SvFsCrG0W78Wf9P6fstElOxBPAXkJExlXu/j+GQz1m
suIUwErxjfBdKQBAWW3xUluAEMAwDFZVS80AQP+XfyoW9hHAaPTEOBFlAUCx
2aIqiZYRwBxYWWJd8gFAJi/J8nceDsBfwE5WinYCQNWckOIwSg7AYf4DKbPy
AkD8gX8sPD8MwLaVvjjCZwNArQCHxZDtCMCvqhQXfdYDQOZRHqNdNgXAURxh
nYk/BEBkmEbwARsEwMj9nsV1owRAEjgCDelOAsDOEUy2uwIFQJ5cstfwfAPA
vDSKScVdBUB02NCjlOH8v2mz5tPutAVAzlDlJTDR+r8WQH4EiQgGQJhQLygN
B/q/ZgymBNxYBkD2fRxX8tz7v8ht5d0mpgZAx57x57pc9786mcUHovAGQHCm
fteGAfa/lSeDB4A4B0AB5AVgubzxv01Dkz7ufQdAiIe7glhG9L+QQGBSFcEH
QNxytkMDyPC/iC1M0xoCCEC57PmuSULwvy5hhhMgQQhAoL6rryR06L9Gqu6p
Q34IQBN6fnoTSOe/3EI/hKG5CEAQtbSUjgHjv3V70zNT8whAHjxdyvo/47++
4ugvcCsJQIefUa4hCdS/KjnT1g1iCUD8Jr8zfSPCv2//PYJAlwlA0O8t41oh
4b/Nqh9dGssJQKZavWgD176/2pJMb6z9CUDYqfR9a6PUP0OMXYUGLwpA8SBf
A+GkpT8FBF1ON18KQIJGnbqo+bo/SqAKdkyOCkA5cF45dDCxv7uiRnQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.416449165001488},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/59EtF/xIfQN64dwvy
SOQ/NH03F8jcAUDfVqmFon3tPwo7wPa4hfs//AmBZtBQ8j/7cnwvyCz1P4OR
BD6aO/U/MaJUacs58T+F+JAQAbP3P+6KZrx7y+U/Z8hRwvLV+T+ZgO6im1Dx
P1qa8FBjuPs/ffvEBo954T+rG0W78Wf9PyMANeOageA/XkJExlXu/j/2bKZ/
dgzVP0rxjfBdKQBADshq7Yqv2T8wDFZVS80AQLa2BRJLYNw/aPTEOBFlAUCO
VssnkQ3KPxxYWWJd8gFAYRoFyA88uj9fwE5WinYCQOIRJ8i8xaG/Yf4DKbPy
AkAkeKmuQmrNP7aVvjjCZwNALbgpxsSQuT+vqhQXfdYDQNXOuKq0uZq/URxh
nYk/BEAuKi3L3OK+P8j9nsV1owRABZCKq9v3sb/OEUy2uwIFQCZ9fWYa7a8/
vDSKScVdBUDCltUH6ky8v2mz5tPutAVApgdS9uXJtD8WQH4EiQgGQP++C4T8
ece/ZgymBNxYBkBWeHV6aui2v8ht5d0mpgZAFRNKL6FGtz86mcUHovAGQIMm
DFpobaS/lSeDB4A4B0ASnr/0jGKev01Dkz7ufQdAzv7/qUpXkD+QQGBSFcEH
QNmxd7f62rK/iC1M0xoCCEBWelGs4B/Kvy5hhhMgQQhAh3oyDn7lzb9Gqu6p
Q34IQF0LulFiBsS/3EI/hKG5CEAccHBb08fSv3V70zNT8whAwggSmeO9wb++
4ugvcCsJQKoB1Zx/8qK/KjnT1g1iCUDUJbZD4bLcv2//PYJAlwlAHVxYmnsx
p7/Nqh9dGssJQHRBjbZ8GrS/2pJMb6z9CUApPbHoQpvPP0OMXYUGLwpAkkji
zWeL3b8FBF1ON18KQOBCI4rGftU/SqAKdkyOCkCuTd9KnsrRv7FhSBY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT98C04nvsXOP964dwvy
SOQ/8QQqiX9w7j/fVqmFon3tPxqpYneLUdc//AmBZtBQ8j+9JYvg2s0bQIOR
BD6aO/U/DARg6QPc5r+F+JAQAbP3P02VOSkCJ+a/Z8hRwvLV+T/YZDQxvtTj
v1qa8FBjuPs/vWHljehG5L+rG0W78Wf9P3fDsNR7itS/XkJExlXu/j8s2ExV
/yLuv0rxjfBdKQBA/gGhkI3j4r8wDFZVS80AQBHn2yVSp+u/aPTEOBFlAUBz
jOPuMbPqvxxYWWJd8gFAoi5j2/MW479fwE5WinYCQNHjXp7Izeu/Yf4DKbPy
AkAM3hf79vfiv7aVvjjCZwNAmFcLAVxE6r+vqhQXfdYDQLn42QV5BuK/URxh
nYk/BEBgdYRey0vlv8j9nsV1owRAQASLG8U14b/OEUy2uwIFQEtpsSFbIum/
vDSKScVdBUDLnj0zmkTkv2mz5tPutAVApAk8DPO14r8WQH4EiQgGQNJt30pv
xOG/ZgymBNxYBkDvFbbeD0Lnv8ht5d0mpgZARY84/sMC4r86mcUHovAGQKaK
w61nBeO/lSeDB4A4B0DB3lB3sjnnv01Dkz7ufQdAhVh8az1s5b+QQGBSFcEH
QOi3a9AvOOi/iC1M0xoCCEAiKqC4oE3pvy5hhhMgQQhAxuHHpNZl6L9Gqu6p
Q34IQGkz9zs3uuG/3EI/hKG5CEATRiJOCaPmv3V70zNT8whAbOXR4EHQ5L++
4ugvcCsJQMOqETJFTee/KjnT1g1iCUDvUCvf8DTmv2//PYJAlwlAJfzABSH9
6r/Nqh9dGssJQMbhFlnRFum/2pJMb6z9CUC03Pfdu0bav0OMXYUGLwpAu13J
0bx38b8FBF1ON18KQHSvSFPFNfK/SqAKdkyOCkCW+OoXUwX1vwMfVbQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5705760673912321},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9aomkeU4wewN64dwvy
SOQ/ss9y/wmuJ8DfVqmFon3tP9RiZwlzICfA/AmBZtBQ8j88LJeDPYwmwIOR
BD6aO/U/qDvIUg30JcCF+JAQAbP3P7cLXHUv2iXAZ8hRwvLV+T94+G8XhDck
wFqa8FBjuPs/asaKut2cJMCrG0W78Wf9P2OfPyMzDCTAXkJExlXu/j8qHRAO
vNwjwErxjfBdKQBA0Ysa+vEyI8AwDFZVS80AQL9yjBBqpCLAaPTEOBFlAUDu
03qv6K0iwBxYWWJd8gFAL6x5/Tp4IsBfwE5WinYCQDnEpmNHXCLAYf4DKbPy
AkCIDEG5wXghwLaVvjjCZwNA3w85ZGdjIcCvqhQXfdYDQBnTgvelUCHAURxh
nYk/BEB7LsKLiLcgwMj9nsV1owRAm4reYtTNIMDOEUy2uwIFQLWNPFUhRCDA
vDSKScVdBUC4R4Z9glggwGmz5tPutAVA+BnVNg5sH8AWQH4EiQgGQKNNm+/I
/x/AZgymBNxYBkC/KQ5YgCMfwMht5d0mpgZAyW7bdC/5HcA6mcUHovAGQJcA
hg/1Dx7AlSeDB4A4B0AV1gk4/5sdwE1Dkz7ufQdAsFht/DQEHcCQQGBSFcEH
QLVc6auW+hzAiC1M0xoCCEBL23LGyB0dwC5hhhMgQQhAr93ynm3dHMBGqu6p
Q34IQMJqO+HlMhzA3EI/hKG5CEC/zgKWrmccwHV70zNT8whAhwGMWXN0G8C+
4ugvcCsJQK6n5VZCtxrAKjnT1g1iCUCNwxszFgkcwG//PYJAlwlAmvfWl0gc
GsDNqh9dGssJQJkdJYkK9BnA2pJMb6z9CUCM/lGFElsYwEOMXYUGLwpAbYXt
SXXlGsAFBF1ON18KQGoClFEEbRfASqAKdkyOCkD8ibAgEJkZwH7+NSg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8S+MVuRw4uwN64dwvy
SOQ/V+VyzfRuKsDfVqmFon3tP/fz94NuuinA/AmBZtBQ8j9ul1g+18wWwIOR
BD6aO/U/VL0BkguNKcCF+JAQAbP3Pwd0U0D8lSjAZ8hRwvLV+T8rcZqBV6In
wFqa8FBjuPs/8WqTOPX4JsCrG0W78Wf9P+qFA37uuSXAXkJExlXu/j8DlS1P
kGgmwErxjfBdKQBASHv+6usyJcAwDFZVS80AQPNsN57RQCXAaPTEOBFlAUAo
sf5J8L0kwBxYWWJd8gFAUHxs333gI8BfwE5WinYCQDkP8AoJCCTAYf4DKbPy
AkC4RKjmVyAjwLaVvjjCZwNAJstpwro4I8CvqhQXfdYDQFbp4gotZCLAURxh
nYk/BEBUwUd+4kkiwMj9nsV1owRADwKkqLa+IcDOEUy2uwIFQOpL1n6t9CHA
vDSKScVdBUCW3wHEi2QhwGmz5tPutAVAjqR7tZALIcAWQH4EiQgGQMq8u0AN
vCDAZgymBNxYBkCysdHhStkgwMht5d0mpgZAd7s9l55KIMA6mcUHovAGQCek
wX+lIyDAlSeDB4A4B0DmbEDUvTEgwE1Dkz7ufQdA2A1DfC3CH8CQQGBSFcEH
QMGwGklntR/AiC1M0xoCCEAy+pOxxHcfwC5hhhMgQQhAaDTzvJH7HsBGqu6p
Q34IQCxXGHEZyB3A3EI/hKG5CEB0KWeMdA0ewHV70zNT8whA8XI4RAh/HcC+
4ugvcCsJQA1hLy2veR3AKjnT1g1iCUDNRnMm2gQdwG//PYJAlwlAALK4HBhQ
HcDNqh9dGssJQCAUJCv/xhzA2pJMb6z9CUAiF4UfwPwawEOMXYUGLwpAD04q
ka5qHcAFBF1ON18KQIDIuAGlTx3ASqAKdkyOCkCNyt2Eq70dwHG3N2I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=91.251\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448096381792*^9},ExpressionUUID->"a6c57d61-8648-4723-9b5f-\
74d9b51e2e4f"],

Cell[BoxData["11"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448096897859*^9},ExpressionUUID->"8233fbbf-0ad2-430a-93a2-\
62eb3dda633b"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/gnmsJKbr1v964dwvy
SOQ/B//KQq82IMDfVqmFon3tPzPB+Yxgjx/A/AmBZtBQ8j/WATEUKU4gwIOR
BD6aO/U/+YueOqAOIMCF+JAQAbP3P9UNimJAbCDAZ8hRwvLV+T9POV5Ekz8f
wFqa8FBjuPs/JVU/3D6+H8CrG0W78Wf9P/XpxQZACR/AXkJExlXu/j9L79wl
QiofwErxjfBdKQBAxl9/+bTzHcAwDFZVS80AQHcouwMwshzAaPTEOBFlAUCw
BVdlJUUdwBxYWWJd8gFAx6cWhgJeHMBfwE5WinYCQBhq9LyuGh3AYf4DKbPy
AkCB21i7PjccwLaVvjjCZwNAZ+1v0EVhG8CvqhQXfdYDQPb+jFQvWBzAURxh
nYk/BEDO7NoWZSwawMj9nsV1owRApMTdOpABG8DOEUy2uwIFQPplBCDb8RnA
vDSKScVdBUAee8JAyWMawGmz5tPutAVArrYWJ3pDGcAWQH4EiQgGQIHfr4dk
PBrAZgymBNxYBkDrXkdduioZwMht5d0mpgZAco/iOpV3GMA6mcUHovAGQBbj
B1FLKxjAlSeDB4A4B0ATXBSoyUMYwE1Dkz7ufQdAot2MdxtVF8CQQGBSFcEH
QHTEDTGb4xbAiC1M0xoCCEBpInEHTXcXwC5hhhMgQQhA8Ns1pF0DGMBGqu6p
Q34IQG2ODfUo/BbA3EI/hKG5CEBdU4x/DbUYwHV70zNT8whAkRxHPK12FsC+
4ugvcCsJQM8OKGJPJxbAKjnT1g1iCUAzNZMK+0YXwG//PYJAlwlAElPNR+27
FMDNqh9dGssJQOYEDoa4VhTA2pJMb6z9CUBC9DEEYHcVwEOMXYUGLwpAEB4P
5lkbGMAFBF1ON18KQI7/Wz+e1RTASqAKdkyOCkD0uhWsxCwawIu7K0U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+D7oG9RkUUwN64dwvy
SOQ/fGKcXWC7B8DfVqmFon3tPzxGlYORISTA/AmBZtBQ8j9r9tzO8RgUwIOR
BD6aO/U/pEV5Pg7PJcCF+JAQAbP3PzigVqwj0CTAZ8hRwvLV+T+PHvz1wDwk
wFqa8FBjuPs/HegVebjbIsCrG0W78Wf9P+tLs3LJLCLAXkJExlXu/j8BSfXb
w+QiwErxjfBdKQBAH9h3iYo1IsAwDFZVS80AQAShoj6cniHAaPTEOBFlAUDP
RqC9HawhwBxYWWJd8gFAuC3KmJ+IIMBfwE5WinYCQCuS8onMTyHAYf4DKbPy
AkA2w0XM9wogwLaVvjjCZwNAyXJBbfVhIMCvqhQXfdYDQJo1Fg7MiB7AURxh
nYk/BEAABkNrYGwewMj9nsV1owRAT/iwTjisHcDOEUy2uwIFQMkYjG4T9h7A
vDSKScVdBUB9raOHqMsdwGmz5tPutAVAWW79wzGzHMAWQH4EiQgGQCtwhxcU
ThzAZgymBNxYBkCWJ4PAt2AcwMht5d0mpgZASJHyRPtFG8A6mcUHovAGQJdG
gMxqPBvAlSeDB4A4B0DdHon0rxAbwE1Dkz7ufQdA9v2VXx3TGsCQQGBSFcEH
QEhnMtTAIxvAiC1M0xoCCEDdfp0XK9EawC5hhhMgQQhAIySPNY2uGcBGqu6p
Q34IQOw9/jveURnA3EI/hKG5CECno0u5OOgZwHV70zNT8whA2pXSXYYPGcC+
4ugvcCsJQJ1tBhpIgRnAKjnT1g1iCUC9mpt/zvYYwG//PYJAlwlABwmnPdRW
GcDNqh9dGssJQI7V+CiFbhjA2pJMb6z9CUCK8ieW5P4WwEOMXYUGLwpAwYJ/
4NTAG8AFBF1ON18KQGS6QCDZsBjASqAKdkyOCkAgImn3vvYZwKFbOrI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.735723158098959},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.41431317630212, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-10.126631103850338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.721165995742174, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.567015315914915, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.433483923290392, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.315700887634009, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/M6AR4i6wLQN64dwvy
SOQ/Krjtn3INHMDfVqmFon3tP08AVN37SRfA/AmBZtBQ8j+9gFH/VW8WwIOR
BD6aO/U/5li5al+GFcCF+JAQAbP3PxtLKDC/+hTAZ8hRwvLV+T+TXA+/1vwQ
wFqa8FBjuPs/FdfZgxMWEsCrG0W78Wf9P8/646gyAxDAXkJExlXu/j8vv2eD
ZNANwErxjfBdKQBA1xT8OAWqC8AwDFZVS80AQE8bTOqqtwrAaPTEOBFlAUBf
dMJ7sBwIwBxYWWJd8gFAHp2gnycHB8BfwE5WinYCQCgiG07c2AbAYf4DKbPy
AkCbXSj5GDEBwLaVvjjCZwNA2oyqbPQnAsCvqhQXfdYDQAPJmMYHnf+/URxh
nYk/BECb4ydVqJT8v8j9nsV1owRA4pwnAQqs/L/OEUy2uwIFQFQuHVawT/i/
vDSKScVdBUAQskygCqD2v2mz5tPutAVAhYqpH/m+8r8WQH4EiQgGQAoMtDy2
//G/ZgymBNxYBkAPbg4tH0Puv8ht5d0mpgZAAMsEidtz5L86mcUHovAGQIfk
1u+y8Oa/lSeDB4A4B0CQSyrMaDXbv01Dkz7ufQdACwRbxYOj3L+QQGBSFcEH
QM4dwtv5N9+/iC1M0xoCCEAbtfVyDajavy5hhhMgQQhAPFNJ+E0axr9Gqu6p
Q34IQEyK0teYRLy/3EI/hKG5CEAOmQkVHzvCP3V70zNT8whAAHnHlc2Twj++
4ugvcCsJQA3dCtvyids/KjnT1g1iCUBlbJrlu6t/v2//PYJAlwlAVpGcgdJl
0z/Nqh9dGssJQLyzYLsh8d8/2pJMb6z9CUDG/f4bfcDyP0OMXYUGLwpAnD7u
hlZD2T8FBF1ON18KQEzIkbpQHPU/SqAKdkyOCkDmGQU0rSn5PyLLQCg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9LQi+snCrDP964dwvy
SOQ/+MXd6UfXAUDfVqmFon3tP45N/Y9ZERbA/AmBZtBQ8j9hCloyq4kCQIOR
BD6aO/U/eB/trOY1GcCF+JAQAbP3P2q50sjg3BfAZ8hRwvLV+T8nCJlHSC4V
wFqa8FBjuPs/d+vrj27AFcCrG0W78Wf9P/4bQRjArhHAXkJExlXu/j+4nf9s
HhMTwErxjfBdKQBA1/l2QCIcD8AwDFZVS80AQCacy8AdQxHAaPTEOBFlAUAz
ckI62dkNwBxYWWJd8gFAzOSBDsmRC8BfwE5WinYCQKHUpsX2xgnAYf4DKbPy
AkBIesU+H58HwLaVvjjCZwNAcrVd2pCuBsCvqhQXfdYDQBjfei18lwTAURxh
nYk/BEC5YCb7bhEEwMj9nsV1owRA5ICQsgorAcDOEUy2uwIFQE3vyhWtcgDA
vDSKScVdBUDZ+0ElQEP7v2mz5tPutAVAS/rWB8ly+r8WQH4EiQgGQEB3Qa6V
VPe/ZgymBNxYBkBfgS55mfj5v8ht5d0mpgZAIYlgm8Ed9b86mcUHovAGQM2K
bx0XcvO/lSeDB4A4B0D7LrTQNUHzv01Dkz7ufQdAyI6J7yWp8L+QQGBSFcEH
QEdbQaLGeOy/iC1M0xoCCEC1y7WOyhvtvy5hhhMgQQhAexOm3XOc7r9Gqu6p
Q34IQIJJrSBk8N+/3EI/hKG5CEBNHaVh+BTbv3V70zNT8whA6Cm9HO1a27++
4ugvcCsJQDO0Nw4Lpse/KjnT1g1iCUDsqDHTlK+6v2//PYJAlwlAFD7eRRSk
0b/Nqh9dGssJQHsGFCw1YsO/2pJMb6z9CUD7I7BeBWrYP0OMXYUGLwpA78zS
KLgL0j8FBF1ON18KQBiAAukrVMi/SqAKdkyOCkCUJR01VLm7v2f2QZc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -3.045764776489038},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.010\"", 0.01, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-8.111728083308073, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.824046010856292, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.418580902748128, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.264430222920869, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.1308988302963465`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-7.013115794639964, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.809142990314028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.521460917862246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-5.115995809754082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.961845129926823, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.710530701645918, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.506557897319982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.659260036932778, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ystapNUIrQN64dwvy
SOQ/roSPRfi+A0DfVqmFon3tP56CZLwMqAJA/AmBZtBQ8j9TxkTi17r5P4OR
BD6aO/U/HZ/RPQAB9D+F+JAQAbP3PxfIqsOVCOk/Z8hRwvLV+T+yfV19RAbx
P1qa8FBjuPs/B5eza4/A4D+rG0W78Wf9P4uYw5EF1OE/XkJExlXu/j+hp/6i
rqPZP0rxjfBdKQBAqs/FO1yA2z8wDFZVS80AQK4PGxgTmNs/aPTEOBFlAUA2
orjZYPHRPxxYWWJd8gFAbg9/SpsV0T9fwE5WinYCQGC2G0PUqYu/Yf4DKbPy
AkD0jQ05ly7RP7aVvjjCZwNAzn1+yRJrwz+vqhQXfdYDQBMkeMvl4WM/URxh
nYk/BECehBy0s7DNP8j9nsV1owRAmf+qJ9dyoL/OEUy2uwIFQDfyESfWibs/
vDSKScVdBUABl6EKp/uiv2mz5tPutAVA9PK8VJz6uj8WQH4EiQgGQNw4IWIm
jL+/ZgymBNxYBkA3rLyQNW6Ov8ht5d0mpgZAsHYK+FAIvT86mcUHovAGQMaH
h1yJOpY/lSeDB4A4B0AN7vluk8ygP01Dkz7ufQdAV5ZnwFansD+QQGBSFcEH
QDNdYzrHnqA/iC1M0xoCCEAIe5CbZdK/vy5hhhMgQQhAuKyY+wkhyb9Gqu6p
Q34IQG+Q4NZM87m/3EI/hKG5CEBCCSGc6abTv3V70zNT8whA6ZG36ioOtL++
4ugvcCsJQEplI87A8Ws/KjnT1g1iCUB6C+CVonzav2//PYJAlwlAKqneHwcC
qj/Nqh9dGssJQB39Qr3ER70/2pJMb6z9CUCWO23htlLCP0OMXYUGLwpAhafC
gh7L5L8FBF1ON18KQNenxe9Fh8M/SqAKdkyOCkCsFuLg2ivMv04LRMg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U8QE8X7shQN64dwvy
SOQ/G6Xpd6KuI0DfVqmFon3tPwCrIDLIm/U//AmBZtBQ8j8E1uothyggQIOR
BD6aO/U/KkzTa3w95L+F+JAQAbP3P2u9Qft/4OW/Z8hRwvLV+T9/cbbalfPi
v1qa8FBjuPs/1o1T4ABW5L+rG0W78Wf9P+fLo+9z4NO/XkJExlXu/j9uG5OF
+Bnuv0rxjfBdKQBAcYm2GLsY4r8wDFZVS80AQGSJbkdxIOy/aPTEOBFlAUDj
nHvWuBDrvxxYWWJd8gFAn7Jjm/Jf479fwE5WinYCQA1n8lDjHuy/Yf4DKbPy
AkCRC6W0DK3jv7aVvjjCZwNAPc8IFQdJ6r+vqhQXfdYDQN2kRCfK3OG/URxh
nYk/BEAIUj1p7zblv8j9nsV1owRA2JWQDg434b/OEUy2uwIFQNR/cIgit+m/
vDSKScVdBUD3zye6CpHjv2mz5tPutAVAf0UEW9BI4r8WQH4EiQgGQEoxMi/E
ouG/ZgymBNxYBkBIginB9dLnv8ht5d0mpgZAhs1dRu4h4r86mcUHovAGQJ6U
nSDL1eO/lSeDB4A4B0CUUxU1fAPmv01Dkz7ufQdA0r85ZiLi5b+QQGBSFcEH
QAv6b3jvS+i/iC1M0xoCCEATF8NE9vnpvy5hhhMgQQhATjrKCGV1579Gqu6p
Q34IQKA+IJVcF+O/3EI/hKG5CEBMkSo6pH3nv3V70zNT8whAXk8hGXfr5b++
4ugvcCsJQOtD1RFNaOe/KjnT1g1iCUA2ha2pbj7mv2//PYJAlwlAlK9xWqKb
7L/Nqh9dGssJQMNxMesUt+i/2pJMb6z9CUBcTMo+hcjav0OMXYUGLwpAAaNf
47sA8r8FBF1ON18KQBAmSUkCcvC/SqAKdkyOCkCleV0fbS30v0IWS4Y=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5476845999336935},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.523560759066484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT96AnrpGKj4v964dwvy
SOQ/jODTNcQDJ8DfVqmFon3tP6hEhqeMySXA/AmBZtBQ8j8i2pGs6+UlwIOR
BD6aO/U/441DkBeMJcCF+JAQAbP3P/iewECRmiXAZ8hRwvLV+T8+BnmajTkk
wFqa8FBjuPs/9OkYA+ugJMCrG0W78Wf9P6KRsoV48SPAXkJExlXu/j8+sqjR
ALMjwErxjfBdKQBAM/CuVX8gI8AwDFZVS80AQMu5z+0LpyLAaPTEOBFlAUBL
3msYsIMiwBxYWWJd8gFAW57atvAgIsBfwE5WinYCQA11U2tpTyLAYf4DKbPy
AkCclk4enGIhwLaVvjjCZwNAgJdpsyVHIcCvqhQXfdYDQNrTIAmSQCHAURxh
nYk/BEDFxSHpBn0gwMj9nsV1owRAU3HmQrO4IMDOEUy2uwIFQIKiaGP1KyDA
vDSKScVdBUByR6Fo8zEgwGmz5tPutAVA5SeoN5BRH8AWQH4EiQgGQOUEJ5sr
wB/AZgymBNxYBkD3M3xxItUewMht5d0mpgZAWWLKY7vfHcA6mcUHovAGQLUc
zzSIzx3AlSeDB4A4B0BGBb/rR1odwE1Dkz7ufQdAhyVMnbHQHMCQQGBSFcEH
QOgYS6DJjBzAiC1M0xoCCECTNNtVbcscwC5hhhMgQQhAcWfEOAu2HMBGqu6p
Q34IQEKytPUM+RvA3EI/hKG5CEAZbWA0l3QcwHV70zNT8whAP+pHVc41G8C+
4ugvcCsJQOH6Far/jBrAKjnT1g1iCUAhPf/3FeUbwG//PYJAlwlA52nES/i4
GcDNqh9dGssJQHMhnPdyLRnA2pJMb6z9CUB4u4rrL8QYwEOMXYUGLwpAJVIN
g5mlG8AFBF1ON18KQDmLgS2DKBjASqAKdkyOCkAF3leSJV0ZwInfOh0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9gMCRZ5rUSwN64dwvy
SOQ/DTFCtZYJB8DfVqmFon3tP+EH/DjHhyXA/AmBZtBQ8j/hqNi1MZkMwIOR
BD6aO/U/1zE43Z/EJ8CF+JAQAbP3PxVSzOnPLyfAZ8hRwvLV+T9925eN0mQm
wFqa8FBjuPs/BcXcVN/vJcCrG0W78Wf9P2X+MthhyiTAXkJExlXu/j+1LHhz
J5glwErxjfBdKQBAeUjSfTlsJMAwDFZVS80AQEsyTjw/pCTAaPTEOBFlAUD4
uae1szEkwBxYWWJd8gFA0yW/gzRfI8BfwE5WinYCQK+KAVZ5lCPAYf4DKbPy
AkAQ6Q0aPL0iwLaVvjjCZwNA51nNHg/WIsCvqhQXfdYDQGmiR0KBBiLAURxh
nYk/BECUCT0A4vQhwMj9nsV1owRAiX+ilbVxIcDOEUy2uwIFQIdJ3T8ztyHA
vDSKScVdBUDGOhYCRxchwGmz5tPutAVAdd7ieCzHIMAWQH4EiQgGQLNHG50p
gSDAZgymBNxYBkBi4baz+qwgwMht5d0mpgZAHYuJ9R4bIMA6mcUHovAGQPnh
ihw9AiDAlSeDB4A4B0B8szs2SeUfwE1Dkz7ufQdA5oUEhlN+H8CQQGBSFcEH
QCMxNxrLah/AiC1M0xoCCEB11iC3aUQfwC5hhhMgQQhAeVdCCMCYHsBGqu6p
Q34IQN7d5G8Esx3A3EI/hKG5CEBkbExwYusdwHV70zNT8whAQOz2pZRnHcC+
4ugvcCsJQK97qaP9RR3AKjnT1g1iCUDmByrrK9EcwG//PYJAlwlA7ve+z8NR
HcDNqh9dGssJQNEgOJdkihzA2pJMb6z9CUDClvLK6dYawEOMXYUGLwpAe/av
4y9hHcAFBF1ON18KQOKX5ANvtBzASqAKdkyOCkCvBWlExl8dwJKpONc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=101.252\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480972356715`*^9},ExpressionUUID->"ce06005d-8378-4709-a6fc-\
66eea090639a"],

Cell[BoxData["12"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448097793232*^9},ExpressionUUID->"e025549d-ab49-4e83-b0b4-\
f7719577fc53"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9am0sEQUMlQN64dwvy
SOQ/JZrxKekZ9D/fVqmFon3tP6hmdkyIdeu//AmBZtBQ8j+J6u2WHm8RwIOR
BD6aO/U/zfyM4QtmC8CF+JAQAbP3P42lTFLChCDAZ8hRwvLV+T9YUgEFq6ce
wFqa8FBjuPs/5ksenre6H8CrG0W78Wf9P8E36IVdwR7AXkJExlXu/j9yE020
6/wewErxjfBdKQBAnP+1qm2tHcAwDFZVS80AQPrgXkHquR3AaPTEOBFlAUCE
UYeRVnscwBxYWWJd8gFA5Qq79uiCHMBfwE5WinYCQL6ZylZB6hzAYf4DKbPy
AkA6ICfTm/oawLaVvjjCZwNAkCoLy4oxG8CvqhQXfdYDQDniuyP3zhvAURxh
nYk/BEB1NI2CZJcawMj9nsV1owRADk87vGbQGsDOEUy2uwIFQDh8B7rQzBnA
vDSKScVdBUBwGgFBBhUawGmz5tPutAVA73wsXlhXGcAWQH4EiQgGQLfNZr27
4xjAZgymBNxYBkBM2OHHc0UZwMht5d0mpgZAM02PH1ViGMA6mcUHovAGQNDe
lRvtiBjAlSeDB4A4B0CJLrgEtbMXwE1Dkz7ufQdAX+bCybRMF8CQQGBSFcEH
QBO4myXedRfAiC1M0xoCCEAcTNwq6oIXwC5hhhMgQQhAjRiDozmHF8BGqu6p
Q34IQOQhxfzS8BbA3EI/hKG5CECGEKyKTxoYwHV70zNT8whA+zSCMQniFsC+
4ugvcCsJQFqQFvUiohTAKjnT1g1iCUBbQUHoUDcXwG//PYJAlwlAxflRZshS
FcDNqh9dGssJQGOG56Wz4xTA2pJMb6z9CUAr+enRsmcTwEOMXYUGLwpAUqCp
K7FdF8AFBF1ON18KQCDMZ0EkHBTASqAKdkyOCkAxCBpZim4WwCutOEE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Uc+cU8EcXQN64dwvy
SOQ/Fq+BAwIkH0DfVqmFon3tP/lOkva5YeA//AmBZtBQ8j9f59D7kSPUP4OR
BD6aO/U/4TGIOx2hGsCF+JAQAbP3P8yH1iG0wiDAZ8hRwvLV+T9t2ZKhxq8j
wFqa8FBjuPs/lk0qAhMNJMCrG0W78Wf9P93Hcw4jlCPAXkJExlXu/j9XTqWB
ReUjwErxjfBdKQBAja1DtlxEI8AwDFZVS80AQAq2fN3OuCLAaPTEOBFlAUCD
qBIxkxUiwBxYWWJd8gFALAVQDuJeIcBfwE5WinYCQLYNpwuN7SHAYf4DKbPy
AkCBJhP2IdYgwLaVvjjCZwNAswyEjYTyIMCvqhQXfdYDQOAD6E7ITSDAURxh
nYk/BEA78E+CRmsgwMj9nsV1owRAU1267M4GIMDOEUy2uwIFQKWCpEnm/R7A
vDSKScVdBUC9HRUukeUewGmz5tPutAVAe4gmqh8WHsAWQH4EiQgGQAUcqAFp
dR3AZgymBNxYBkCzm9vzCxsewMht5d0mpgZAf062eQkzHMA6mcUHovAGQFn3
YOIrPhzAlSeDB4A4B0C7lB3qswQdwE1Dkz7ufQdAJvCfoxFiHMCQQGBSFcEH
QNA36VvpwBvAiC1M0xoCCEDKp6a3hvYbwC5hhhMgQQhAhL6UQdnoGsBGqu6p
Q34IQIDtN0pARRvA3EI/hKG5CED3qN5OIGEawHV70zNT8whAdBF7IX4JGsC+
4ugvcCsJQGQC0Q/LvxrAKjnT1g1iCUBS1vNYPCQZwG//PYJAlwlABUVlS3eu
HcDNqh9dGssJQP8RyyloWRrA2pJMb6z9CUBMoiCDa70XwEOMXYUGLwpAGkZe
Mq6MG8AFBF1ON18KQE/zdQNCwxnASqAKdkyOCkABXH5ajn4awB7dL5U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -4.3540348100618},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox["0.1`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8waGxcu68mQN64dwvy
SOQ/p82pXXD1EEDfVqmFon3tP/CWiH1qHhHA/AmBZtBQ8j+R38Za8aYCwIOR
BD6aO/U/+0Ul0djvCsCF+JAQAbP3P39k92Qz1BPAZ8hRwvLV+T/sDyTk0fsQ
wFqa8FBjuPs/YX9NmcL9EcCrG0W78Wf9P4s7bAOkGg/AXkJExlXu/j8TQypb
IHMOwErxjfBdKQBAlhCc451lC8AwDFZVS80AQDQ9VSrK9wfAaPTEOBFlAUAy
UiGFnhIKwBxYWWJd8gFA0mVz1LdyBsBfwE5WinYCQA/l31JFfQXAYf4DKbPy
AkBetum81fsCwLaVvjjCZwNA6IYLr3nZAMCvqhQXfdYDQImKrT5vsv+/URxh
nYk/BEAYNuo1gqX5v8j9nsV1owRAtll+YYeu+r/OEUy2uwIFQLa+sS1Bdfe/
vDSKScVdBUD5L67kc3L2v2mz5tPutAVAdHznYWqC8b8WQH4EiQgGQChFfakI
z/S/ZgymBNxYBkAT6B8rx1ftv8ht5d0mpgZA9hLW1nDd4786mcUHovAGQFTu
LMBTTOC/lSeDB4A4B0CGf1hk5OLdv01Dkz7ufQdAYFWZ4lAF2b+QQGBSFcEH
QIL/XxLnStS/iC1M0xoCCEDEUon96+vUvy5hhhMgQQhA8b4bXX8gyr9Gqu6p
Q34IQH3R3LI0R6q/3EI/hKG5CED1GgJeseO7P3V70zNT8whAwK2E/Bie1z++
4ugvcCsJQIfOdKdi7LY/KjnT1g1iCUARkFASJCPGP2//PYJAlwlAXmhGYIsy
4D/Nqh9dGssJQLjIxp3F9+o/2pJMb6z9CUBNyXemRdjtP0OMXYUGLwpABG7W
guxH2D8FBF1ON18KQCCa74yRDvM/SqAKdkyOCkB4G2KMjj31P5boSKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/wGOi/EYYiQN64dwvy
SOQ/7Vm1cdd6JUDfVqmFon3tP0S+SImdRBxA/AmBZtBQ8j+MUWkby44bQIOR
BD6aO/U/Y0v8bVB++j+F+JAQAbP3P7wMiPi50+I/Z8hRwvLV+T9tdXzBr7UR
wFqa8FBjuPs/nU3Q/vr8EcCrG0W78Wf9Py059tOo2w3AXkJExlXu/j8tYCG+
qvkQwErxjfBdKQBAkh73XZ8jC8AwDFZVS80AQHslTtGtPQ3AaPTEOBFlAUCA
cDfP62IMwBxYWWJd8gFAJMfEsiUXCMBfwE5WinYCQEQwouUzTAfAYf4DKbPy
AkBQOqaNzaQEwLaVvjjCZwNAraOyWlJjBMCvqhQXfdYDQNkBQLYjIgDAURxh
nYk/BEDHOLBYXMD+v8j9nsV1owRAIIpiuOM5+b/OEUy2uwIFQPfPpGpZaQDA
vDSKScVdBUBEa9d2GRv3v2mz5tPutAVAs69rW4PT9L8WQH4EiQgGQNw96D0I
y/K/ZgymBNxYBkBRx4u+79nyv8ht5d0mpgZAa0EIi5VL8b86mcUHovAGQLj4
t25lKe6/lSeDB4A4B0Ag5cnmj07nv01Dkz7ufQdAJ4sGIzqh5r+QQGBSFcEH
QDwSoUzyCOi/iC1M0xoCCEBpGxY9zqTjvy5hhhMgQQhANAcWMsev479Gqu6p
Q34IQEPanzXz9Xm/3EI/hKG5CEDN1yOVfu7Qv3V70zNT8whAQAYZGDk4y7++
4ugvcCsJQPtat4nKr7E/KjnT1g1iCUCODQcenpxLP2//PYJAlwlA1YzYTMUS
2D/Nqh9dGssJQM8+BvuoP9E/2pJMb6z9CUBNFailI4riP0OMXYUGLwpAa5Ky
HGTF2z8FBF1ON18KQD0Nb05Hz66/SqAKdkyOCkCtyKH0w+m4P/peQmE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -2.1528964637006913`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.9108207377686, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.997832114758229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.077874822431765`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.151982794585487`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.22097566607244, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.28551418721001, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.346138809026444`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.403297222866392`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ailg5OF42QN64dwvy
SOQ/nzqHiULZKUDfVqmFon3tP/WyJMQUkyFA/AmBZtBQ8j9PW/yoStAUQIOR
BD6aO/U/MHdeqjN8FUCF+JAQAbP3P6XNAhEIF+0/Z8hRwvLV+T8VbrboXFHy
P1qa8FBjuPs/w0KGpbVO4T+rG0W78Wf9P0Zu1Jix6eQ/XkJExlXu/j/jmHd0
DaLYP0rxjfBdKQBAWdr/1ksF3z8wDFZVS80AQMxisVNW69w/aPTEOBFlAUA6
7YZXGdfSPxxYWWJd8gFAPya+5PLD0T9fwE5WinYCQAE7wSr3ybg/Yf4DKbPy
AkDw01jaDETVP7aVvjjCZwNATO/HhV7jzz+vqhQXfdYDQLNfgtrNYLA/URxh
nYk/BEDABiliIkzQP8j9nsV1owRAt+QD1Zxvqj/OEUy2uwIFQM17PbkngMM/
vDSKScVdBUA2AFs+KceHP2mz5tPutAVA79ufYaupwD8WQH4EiQgGQPtCll7z
yGo/ZgymBNxYBkCcwUDPm5KOv8ht5d0mpgZA4O7yEMP8wD86mcUHovAGQIDb
cJfIHq0/lSeDB4A4B0B6fJujv464P01Dkz7ufQdAM2hqrMZStz+QQGBSFcEH
QH2KTwFAiWs/iC1M0xoCCEApfhtkreC4vy5hhhMgQQhAn0XCsSClwb9Gqu6p
Q34IQOPYnUHCALK/3EI/hKG5CEAmfZ/ozvPPv3V70zNT8whACh3btVh1p7++
4ugvcCsJQNbJlXZ1qsI/KjnT1g1iCUD8s/+tBXHVv2//PYJAlwlALIABvmJ1
jT/Nqh9dGssJQNBof1vGM8I/2pJMb6z9CUC9hkUEvSHWP0OMXYUGLwpAKfEN
l4Ot4b8FBF1ON18KQAmjqhD43sg/SqAKdkyOCkA1TXdERdm7v35LQlY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/lHIM2rhkzQN64dwvy
SOQ/AYrqkR3oM0DfVqmFon3tP/Ks1HHaXCpA/AmBZtBQ8j/3nO2C/7UoQIOR
BD6aO/U/mLXCkLhlGUCF+JAQAbP3P5Srx1b+NhNAZ8hRwvLV+T8jpgVxegCT
v1qa8FBjuPs/QEPMcOoK4L+rG0W78Wf9P1bdAXtBJNG/XkJExlXu/j8ryw5M
uKrtv0rxjfBdKQBADWVor1kk4b8wDFZVS80AQIgQ1mDf6uq/aPTEOBFlAUAG
XOcBRVbrvxxYWWJd8gFAijC9J3tS479fwE5WinYCQNsu+EE59uu/Yf4DKbPy
AkCohq4NiQzkv7aVvjjCZwNA+nUPSXwd6r+vqhQXfdYDQDqbM0QbNeG/URxh
nYk/BEAxeg7xGkPlv8j9nsV1owRAhC2UaArM4L/OEUy2uwIFQDWrMEMgh+m/
vDSKScVdBUBzbYTuQ4rjv2mz5tPutAVAwOUhK9cw4r8WQH4EiQgGQAI6b868
uuG/ZgymBNxYBkC7qTDT7u7nv8ht5d0mpgZAsvAHOT924r86mcUHovAGQNyv
o3JJ8OO/lSeDB4A4B0B1kqqhkrXmv01Dkz7ufQdANJOXQ+hf57+QQGBSFcEH
QNtwLWz5oui/iC1M0xoCCEAxY+T1Nm/qvy5hhhMgQQhA+0m4KE696L9Gqu6p
Q34IQKlx2qkncOO/3EI/hKG5CEAIb2OxnPDmv3V70zNT8whACWSMu+JF57++
4ugvcCsJQC8tQcFRc+i/KjnT1g1iCUDbehNmzzrlv2//PYJAlwlAHIILod6o
77/Nqh9dGssJQKJS0ENADeu/2pJMb6z9CUA38wEo5b3bv0OMXYUGLwpAA6hT
Pld78L8FBF1ON18KQIhT3LRMIvK/SqAKdkyOCkCrwmhq88zzv+CYTCk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.5374554150157191},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.423746202738826`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.51075757972846, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.590800287401994`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.664908259555716`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.733901131042668`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.79843965218024, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.859064273996673`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.916222687836623`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/qT/8RoeUdQN64dwvy
SOQ/TNM8S6cz7r/fVqmFon3tPy9yJ+taaxHA/AmBZtBQ8j90M9Xq5SUdwIOR
BD6aO/U/7qPyieaXGsCF+JAQAbP3PzAYbskfRSXAZ8hRwvLV+T+AMb5anwAk
wFqa8FBjuPs/2nlukT6KJMCrG0W78Wf9P6zsMUM9tSPAXkJExlXu/j/uaRLV
RbIjwErxjfBdKQBAJoT0/gv9IsAwDFZVS80AQKSpZfvPlSLAaPTEOBFlAUCb
ykOTi3YiwBxYWWJd8gFAX4T9T8MWIsBfwE5WinYCQC6vOaVCEiLAYf4DKbPy
AkAzn1U/UD4hwLaVvjjCZwNAfo/WYl8SIcCvqhQXfdYDQN8Dove4HSHAURxh
nYk/BEAoqiDYgG4gwMj9nsV1owRAuGpzEbaLIMDOEUy2uwIFQHjiDQJhEiDA
vDSKScVdBUBxHKqO4RYgwGmz5tPutAVANifbFCU0H8AWQH4EiQgGQH7vlSeJ
Ox/AZgymBNxYBkAdGgEKXNEewMht5d0mpgZAaQBH8NPIHcA6mcUHovAGQKk5
JkGrqB3AlSeDB4A4B0BCJ2lbBhcdwE1Dkz7ufQdA+hO5x86zHMCQQGBSFcEH
QFj+DJ+dpxzAiC1M0xoCCECOPV8z/qwcwC5hhhMgQQhAf44EUxZ4HMBGqu6p
Q34IQNCxmTsw1xvA3EI/hKG5CEDjz7mrEjgcwHV70zNT8whAg8odPDcSG8C+
4ugvcCsJQKh84Ngx+RnAKjnT1g1iCUDYZK8Sf5MbwG//PYJAlwlAEvWcIUjd
GcDNqh9dGssJQPb1E6uqDxnA2pJMb6z9CUBxKmfE5/IXwEOMXYUGLwpAXGAc
7IRAG8AFBF1ON18KQLGYz9wF/RfASqAKdkyOCkAhYKhX8+kYwLjhM/0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT++OUKxMFoYQN64dwvy
SOQ/S/uLFZPWHkDfVqmFon3tP8FQRI9sFfk//AmBZtBQ8j/xe/Y8mCPzP4OR
BD6aO/U/qQ8+foK7EcCF+JAQAbP3P4kEEXgIoxbAZ8hRwvLV+T8Ct2f9jGQk
wFqa8FBjuPs/DSYysEvaJMCrG0W78Wf9P632uzkD7iPAXkJExlXu/j9xk9DU
q9QkwErxjfBdKQBANGG81CeqI8AwDFZVS80AQIewruEa6SPAaPTEOBFlAUDx
YKg7oJgjwBxYWWJd8gFAJiiSbV7IIsBfwE5WinYCQLxP5O7UBCPAYf4DKbPy
AkAcnxXmpz0iwLaVvjjCZwNA/lFB8MRWIsCvqhQXfdYDQE8T/xTrhSHAURxh
nYk/BEDzamSGU4YhwMj9nsV1owRAb0xWYZYBIcDOEUy2uwIFQOvshsH3UCHA
vDSKScVdBUBNCHnTsrggwGmz5tPutAVAxVFHBk1sIMAWQH4EiQgGQAt3BR1+
LiDAZgymBNxYBkArM1nQsF4gwMht5d0mpgZAnBJLxRSpH8A6mcUHovAGQN3W
FdGMdx/AlSeDB4A4B0DiMNDojnIfwE1Dkz7ufQdA+iR1rYErH8CQQGBSFcEH
QHS/+4/C+R7AiC1M0xoCCEC7yLgz39wewC5hhhMgQQhAoaw7KBJRHsBGqu6p
Q34IQNM/PXsaUx3A3EI/hKG5CEAJfMclf3MdwHV70zNT8whAiCjnrdswHcC+
4ugvcCsJQMqCr311CR3AKjnT1g1iCUAsjGFYN1ccwG//PYJAlwlAFFB7Qxhd
HcDNqh9dGssJQDmYimBighzA2pJMb6z9CUDMK5K/tJYawEOMXYUGLwpAreTr
jLOzHMAFBF1ON18KQOfjEbXT1xzASqAKdkyOCkDCM2/CkAEdwDv4Nns=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=111.252\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480980964193`*^9},ExpressionUUID->"31263d13-3b44-40db-8e66-\
2204e75f05e8"],

Cell[BoxData["13"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480987201204`*^9},ExpressionUUID->"52b99aa8-8a6e-4f10-9f22-\
069ad2ed92ed"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+U4p4o0GcwQN64dwvy
SOQ/Uvm7IUtBL0DfVqmFon3tP9QCMHxIiypA/AmBZtBQ8j9Zb+hHACUrQIOR
BD6aO/U/6ElnnqShKUCF+JAQAbP3P80DsNotxSlAZ8hRwvLV+T8f6cSIrLMo
QFqa8FBjuPs/Nm9w7NUvJ0CrG0W78Wf9P5PWwpdI1yVAXkJExlXu/j/Ihfkb
GoAkQErxjfBdKQBA0da9sWytJUAwDFZVS80AQHJY6owQHCVAaPTEOBFlAUAs
LpQT5h0lQBxYWWJd8gFA9uEFjTbSJEBfwE5WinYCQKr5pSwQ5yNAYf4DKbPy
AkAOSw4DbZgjQLaVvjjCZwNABUNtzs2lI0CvqhQXfdYDQAvCODkRWyNAURxh
nYk/BEDRF8HoXtsiQMj9nsV1owRAI8LgV3/wIUDOEUy2uwIFQEH+2Dvi0SBA
vDSKScVdBUA/p9c4ZlogQGmz5tPutAVApOTmDfnNHEAWQH4EiQgGQHwuZW44
dRpAZgymBNxYBkC3beWNwHUZQMht5d0mpgZATmquR9njFkA6mcUHovAGQKvT
bbJs/RNAlSeDB4A4B0B1sxeEJc8RQE1Dkz7ufQdAZHlwxH6/EkCQQGBSFcEH
QM8PCS0Qvg9AiC1M0xoCCECfiqv1skwNQC5hhhMgQQhA+pac4i1rC0BGqu6p
Q34IQHGK05fdUwlA3EI/hKG5CECSNsg8zZ8BQHV70zNT8whAGzbqbvu//z++
4ugvcCsJQEb98NJmd/M/KjnT1g1iCUB1oAcMvZPwP2//PYJAlwlACEIDwSho
2j/Nqh9dGssJQNQ+PlY6rNO/2pJMb6z9CUA9NVZyi9EEwEOMXYUGLwpAsRiT
qTf5AMAFBF1ON18KQFTatqo/Evu/SqAKdkyOCkAle9RxAGIBwAIQKug=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/L+roB6mAoQN64dwvy
SOQ/jdigSkwbK0DfVqmFon3tP4euT0eU6ypA/AmBZtBQ8j/1rrSJ9hIrQIOR
BD6aO/U/o3DhZ9uWK0CF+JAQAbP3P5CcxHZMcytAZ8hRwvLV+T9orzTwTK4q
QFqa8FBjuPs/YRRQWiHoKUCrG0W78Wf9P5hkzAe10CdAXkJExlXu/j9ihExg
v8UkQErxjfBdKQBAJjf0UIwNJEAwDFZVS80AQEOK06hcGiRAaPTEOBFlAUAV
dDIo8UgkQBxYWWJd8gFA3JbqzHD4IkBfwE5WinYCQOPg2hrOpSJAYf4DKbPy
AkD5HM5rKIEhQLaVvjjCZwNAfru6eF21IECvqhQXfdYDQC/1X/sU+x5AURxh
nYk/BEDmLbcEYJMbQMj9nsV1owRA/aov/paQGkDOEUy2uwIFQGsa+3jujhlA
vDSKScVdBUAec3LYnXMWQGmz5tPutAVAavablSyeE0AWQH4EiQgGQB58ruLP
oBJAZgymBNxYBkB0/Uz3bkYRQMht5d0mpgZApm/ovzQiDUA6mcUHovAGQDxA
DHuvIQpAlSeDB4A4B0AdsskJ7l8JQE1Dkz7ufQdAaCgfVbOsBkCQQGBSFcEH
QBsDFAJEMQRAiC1M0xoCCECuVrat+gMDQC5hhhMgQQhAVPTFlr/h/D9Gqu6p
Q34IQDdyayNE0+8/3EI/hKG5CEC8Z16TobjlP3V70zNT8whAE0YaBeWnwj++
4ugvcCsJQDWhAeMNasq/KjnT1g1iCUDRqJQ5Jnr/v2//PYJAlwlALYx+uYgd
97/Nqh9dGssJQMu7LErI6QPA2pJMb6z9CUAUMZfWK1z3v0OMXYUGLwpApZmP
XHMjCMAFBF1ON18KQC3IKkNZz+q/SqAKdkyOCkClruNkiQL5v3HILj4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -1.3104010304140823`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8x+m//GE4uQN64dwvy
SOQ/uzDvl4RkK0DfVqmFon3tP0FNiFHx0jBA/AmBZtBQ8j8yg441aDkvQIOR
BD6aO/U/yHSJ9WRoL0CF+JAQAbP3P5r5xWzsVC9AZ8hRwvLV+T8ALISgt68u
QFqa8FBjuPs/BS8LzzGwLECrG0W78Wf9P4D9O31s5S1AXkJExlXu/j8rpkcr
Sj0vQErxjfBdKQBAg9iUebS8LUAwDFZVS80AQJc/7ebcWy1AaPTEOBFlAUC9
GRRLgaktQBxYWWJd8gFAfHfKYXEDLUBfwE5WinYCQIiypnEslC1AYf4DKbPy
AkAinQfUEdstQLaVvjjCZwNAeFrWeq6KLUCvqhQXfdYDQEDSGRPDNC1AURxh
nYk/BEBbaqO4OncsQMj9nsV1owRAdoBT3bubK0DOEUy2uwIFQMF+vSllMitA
vDSKScVdBUCVpbjPaK0pQGmz5tPutAVASGsAm/FuKUAWQH4EiQgGQJ8UxXQx
ayhAZgymBNxYBkCf1SfMarsmQMht5d0mpgZA+dy/cB5UJUA6mcUHovAGQC3d
W56VVCVAlSeDB4A4B0A0gCbkf5MkQE1Dkz7ufQdAw0rqMjcUI0CQQGBSFcEH
QBaLn2D8liJAiC1M0xoCCEAYMWRhu6YiQC5hhhMgQQhAO9tdQNpDIkBGqu6p
Q34IQNh8L69CuSBA3EI/hKG5CECm9q7qsbwgQHV70zNT8whApIgJt4twIEC+
4ugvcCsJQH7UJAdq+R5AKjnT1g1iCUCUNCJjFYUYQG//PYJAlwlAe2tBl8IN
F0DNqh9dGssJQLxLIIU55xRA2pJMb6z9CUB85rNfuEYLQEOMXYUGLwpAeZq9
0f8zB0AFBF1ON18KQKX2giDtCw5ASqAKdkyOCkCG9vY0M/wRQMCuI68=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/i/svPrkYwQN64dwvy
SOQ/3Jq4xIFkMUDfVqmFon3tP3uT69z9DzJA/AmBZtBQ8j8GDg4WA0ExQIOR
BD6aO/U/zuAqvypNL0CF+JAQAbP3P6xt5am0vTBAZ8hRwvLV+T+CayeKrFox
QFqa8FBjuPs/HYCXVGloMUCrG0W78Wf9P33yIzBo1TBAXkJExlXu/j+4DWnF
pO8vQErxjfBdKQBApbLQt4GQLUAwDFZVS80AQMWTu96wHC5AaPTEOBFlAUC3
ApLU9U4tQBxYWWJd8gFAYtGEHKUXLUBfwE5WinYCQHP8wBiC8itAYf4DKbPy
AkDCcuxhwaArQLaVvjjCZwNAqD6cXcHUKkCvqhQXfdYDQBZ5N7g8JCpAURxh
nYk/BEB+z1WRPdwpQMj9nsV1owRAl7MTAgGJKEDOEUy2uwIFQK0YkINjMCdA
vDSKScVdBUCpmAQpzbwmQGmz5tPutAVArDCNOhbFJUAWQH4EiQgGQF6X0VX6
jSRAZgymBNxYBkCMqlURH6AjQMht5d0mpgZA7GxE+SRWI0A6mcUHovAGQCOy
0YuBtSJAlSeDB4A4B0AYqn74RZohQE1Dkz7ufQdAA/MAwrrWIUCQQGBSFcEH
QP0wOyTn8SBAiC1M0xoCCEA6MlXHDKsgQC5hhhMgQQhAYVYpPsbsHkBGqu6p
Q34IQD8lSt4cfx5A3EI/hKG5CEBzrEZTtIgaQHV70zNT8whAuIesFzP0GkC+
4ugvcCsJQIPZ1zTXdxdAKjnT1g1iCUBdddgX/WoVQG//PYJAlwlAYi/CV+sd
DkDNqh9dGssJQKxVgzO8bRRA2pJMb6z9CUByrRyyTXAUQEOMXYUGLwpATH0m
zr8/EkAFBF1ON18KQL0htTloCw1ASqAKdkyOCkBOs+ZPvGkVQH+4I6g=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.2596234941178772`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.818576016750736`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.905587393740365`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.985630101413904`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.059738073567623`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.128730945054574`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.193269466192145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.253894088008582`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.31105250184853, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9DJOsEZ747QN64dwvy
SOQ/5roWdmHsOUDfVqmFon3tP1DBHwKJdzhA/AmBZtBQ8j8iWDxsMh43QIOR
BD6aO/U/WrFx8XM7NkCF+JAQAbP3P1e9zVox0TVAZ8hRwvLV+T+en9z5KPc0
QFqa8FBjuPs/xvWXmQDRM0CrG0W78Wf9PzQZiWEeYTNAXkJExlXu/j+8YahW
CVEzQErxjfBdKQBAB4rWmKvDMkAwDFZVS80AQG+D90w+SjJAaPTEOBFlAUDv
NrZfyCQyQBxYWWJd8gFARzB64DO5MUBfwE5WinYCQNh+KPgKbDFAYf4DKbPy
AkBvuzifyD4xQLaVvjjCZwNAJbm1hmf/MECvqhQXfdYDQL3DcTGBrTBAURxh
nYk/BEBK1Uby9zkwQMj9nsV1owRAbFiXyyZGL0DOEUy2uwIFQKFH51iBNC5A
vDSKScVdBUDWORpg2hEtQGmz5tPutAVAJKapiuGWK0AWQH4EiQgGQMj9stNd
QypAZgymBNxYBkA3HQ1kPwYpQMht5d0mpgZAehveoB5/J0A6mcUHovAGQD/7
n0N1ayZAlSeDB4A4B0AkOX0ZdkolQE1Dkz7ufQdA1C9oANLVJECQQGBSFcEH
QFN9FcZPgSNAiC1M0xoCCEDAtSr5EfsiQC5hhhMgQQhAqZtAE81eIkBGqu6p
Q34IQDh9UXq3VyFA3EI/hKG5CEBxC5LB5v0fQHV70zNT8whA99GeZm7qHkC+
4ugvcCsJQOglkbjRGxxAKjnT1g1iCUClqjvwafMYQG//PYJAlwlAJ1Mogv90
FkDNqh9dGssJQNucnCrOgBNA2pJMb6z9CUAWQwybI14FQEOMXYUGLwpANAWz
nxeeBkAFBF1ON18KQLuSYPlHSwpASqAKdkyOCkATiRiVPXkJQCW3Hu4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/HzWVmJpE5QN64dwvy
SOQ/OhmRNou0OUDfVqmFon3tP15/4cwv9jhA/AmBZtBQ8j/tmi3BMBs4QIOR
BD6aO/U//HCCjs6rN0CF+JAQAbP3P7jmhRpGPDdAZ8hRwvLV+T8V+gpn1qE2
QFqa8FBjuPs/29Vb6/IGNkCrG0W78Wf9P7qOccfp2DRAXkJExlXu/j8RLiF+
hl0zQErxjfBdKQBAHTr4//NaMkAwDFZVS80AQJTPTpiJPTJAaPTEOBFlAUCV
46iZQfMxQBxYWWJd8gFAFUSovPxHMUBfwE5WinYCQPjbhI1QyzBAYf4DKbPy
AkC9QCwWly8wQLaVvjjCZwNAVHOLS7w+L0CvqhQXfdYDQIdGTOsS6y1AURxh
nYk/BEDbEJVlnZwsQMj9nsV1owRAiPzx9FJkK0DOEUy2uwIFQDsrdq1WRypA
vDSKScVdBUCN4BeDfOsoQGmz5tPutAVAOcWs+NN4J0AWQH4EiQgGQKZ13fCd
ZyZAZgymBNxYBkBN5dOwUmclQMht5d0mpgZAPNMgtkFIJEA6mcUHovAGQOoM
PHSvYSNAlSeDB4A4B0B2V7eYopkiQE1Dkz7ufQdAKZAhGdoaIkCQQGBSFcEH
QCkhlQ9GLCFAiC1M0xoCCED01p1wCLUgQC5hhhMgQQhA2N7Br2m2HkBGqu6p
Q34IQKBjIL1jbRxA3EI/hKG5CEBIzpeIBJkZQHV70zNT8whA4+3PTuhHGEC+
4ugvcCsJQLNOEn25mhVAKjnT1g1iCUCxnuWgY+MQQG//PYJAlwlAZ7Lj+K0+
DkDNqh9dGssJQBX8dPJCzA1A2pJMb6z9CUCf1N3ZtUAQQEOMXYUGLwpAn4HM
bQ8lCEAFBF1ON18KQE+2vq1TOBBASqAKdkyOCkAn784qvlgPQCQoK0I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.1599859471104117`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            
            TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            
            TemplateBox[{"10", "11"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.032218497590705`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.319900570042485`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.543044121356694`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/6PR2IWq0pQN64dwvy
SOQ/bSpR12INKEDfVqmFon3tP6YUFhogpSZA/AmBZtBQ8j/rclweKDwlQIOR
BD6aO/U/hSP2Uyp3JECF+JAQAbP3PyX9L3iBgiRAZ8hRwvLV+T8wIuKEeJkj
QFqa8FBjuPs/8VR2fx37IUCrG0W78Wf9PzcWhu8LuCFAXkJExlXu/j+nuNCh
vykiQErxjfBdKQBA8OEVBYmQIUAwDFZVS80AQPF8IWwRFCFAaPTEOBFlAUBh
K8+Z1zkhQBxYWWJd8gFAszWLaQTNIEBfwE5WinYCQP7mj6QWkiBAYf4DKbPy
AkDpJYJ5IJMgQLaVvjjCZwNAmXos0+FrIECvqhQXfdYDQBE4+yRLGiBAURxh
nYk/BEAEvDo03wIfQMj9nsV1owRAgVIjpmU8HUDOEUy2uwIFQCYy2vPNpRtA
vDSKScVdBUDKpHffUegZQGmz5tPutAVA47cjX0tzF0AWQH4EiQgGQFulGV+K
SBVAZgymBNxYBkAoxOiz+0gTQMht5d0mpgZArow1F8GtEEA6mcUHovAGQFND
OL1K5A1AlSeDB4A4B0C2FFTJtTMKQE1Dkz7ufQdAMdhcMXQ0CUCQQGBSFcEH
QIS3FhltrQRAiC1M0xoCCEDOpgLASVIDQC5hhhMgQQhAAQ+ZeoqgAUBGqu6p
Q34IQDNBAexAfvw/3EI/hKG5CECqJ3lCIg7zP3V70zNT8whA2ALhGcoS8D++
4ugvcCsJQAWBGwFM7Ng/KjnT1g1iCUCdcKCjw6rUv2//PYJAlwlAy+jroVv1
67/Nqh9dGssJQKUg8+Pkhfi/2pJMb6z9CUAws/Wz8UoNwEOMXYUGLwpA0wsl
NpF4C8AFBF1ON18KQOqaJu5HPgfASqAKdkyOCkA4Ta1+X3wHwEqqIcg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8W/cVi6N8oQN64dwvy
SOQ/fGL5PRvJKkDfVqmFon3tPwAXopxyeCpA/AmBZtBQ8j+XslHcya0pQIOR
BD6aO/U/lHIPZM2PKUCF+JAQAbP3PzXP+SGqVilAZ8hRwvLV+T/39A8Ee7Mo
QFqa8FBjuPs/yTgd8Q0AKECrG0W78Wf9P1Yx6RZjGiZAXkJExlXu/j9lWdhN
yJAjQErxjfBdKQBAxmUK0J/xIUAwDFZVS80AQBegSfwSFSJAaPTEOBFlAUAq
g+pGx9ghQBxYWWJd8gFAI6pXsarVIEBfwE5WinYCQKNdpel8KyBAYf4DKbPy
AkBTZYzprn0eQLaVvjjCZwNA0j0CHMnNHECvqhQXfdYDQK9YWoc6sBpAURxh
nYk/BEAOME1LgJYYQMj9nsV1owRAGGy/F4OkFkDOEUy2uwIFQGVENtx65BRA
vDSKScVdBUDQOnXe1Z8SQGmz5tPutAVAQ4NQ2FUqEEAWQH4EiQgGQG+obfaa
7gxAZgymBNxYBkBkm3ac7cIJQMht5d0mpgZAo0YX7FIRBkA6mcUHovAGQJdw
7pSZOgNAlSeDB4A4B0CS1nKd7toAQE1Dkz7ufQdAzrnfxVc9/z+QQGBSFcEH
QA4jp+tqNfk/iC1M0xoCCECclLwEo9r2Py5hhhMgQQhAen9KPEvV6j9Gqu6p
Q34IQBeD353yc9Y/3EI/hKG5CECV9h8uf9/Rv3V70zNT8whA42LB90f+4L++
4ugvcCsJQAiVTX8O8vG/KjnT1g1iCUDzyu9E584BwG//PYJAlwlAMvsmH4TB
BMDNqh9dGssJQKhgMKyZqQTA2pJMb6z9CUC5IUQZPV8BwEOMXYUGLwpAcv8X
1M4yCcAFBF1ON18KQLGTWiJyaADASqAKdkyOCkDjxxmlke4AwOT/MIM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=121.253\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480990098476`*^9},ExpressionUUID->"40fd334f-4d9a-43a0-9257-\
a41ed98cbdb6"],

Cell[BoxData["14"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174480996611714`*^9},ExpressionUUID->"1fa36350-7ca8-41d2-8099-\
0060fc1e578c"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8IHFi4hIIuQN64dwvy
SOQ/RlfhRMMqLUDfVqmFon3tPwIuA47F9DBA/AmBZtBQ8j9YvOTlrgEtQIOR
BD6aO/U/Bdx3myI+KUCF+JAQAbP3PwdwKKXUsypAZ8hRwvLV+T9Ew6hS3VYo
QFqa8FBjuPs/mgWP2GsXKkCrG0W78Wf9P9zJHkvKYihAXkJExlXu/j/mKsTw
dBYpQErxjfBdKQBA83eR9jv0JkAwDFZVS80AQEMTD0YaFCdAaPTEOBFlAUAI
3IfX0mQoQBxYWWJd8gFAxZGidUGTJ0BfwE5WinYCQKhMAUr//iVAYf4DKbPy
AkBBpYM1xf8mQLaVvjjCZwNAKmWjW0dXJUCvqhQXfdYDQD2DE/j47iNAURxh
nYk/BEC9Vx88li8kQMj9nsV1owRAAee5KoLvIkDOEUy2uwIFQHwuwcI83SNA
vDSKScVdBUCkhk1+WrgiQGmz5tPutAVAW8/Oe6TFIUAWQH4EiQgGQBumsWId
uB9AZgymBNxYBkBXvS9TisIdQMht5d0mpgZAUrjvN5ftG0A6mcUHovAGQFf1
0I3dDhpAlSeDB4A4B0By3trMpe0XQE1Dkz7ufQdA93OpKXQBGUCQQGBSFcEH
QFxunku/2xdAiC1M0xoCCEAEmcvrOI4VQC5hhhMgQQhAf1cJBW1gFUBGqu6p
Q34IQApK7u87YRNA3EI/hKG5CED0fn8QFnoSQHV70zNT8whAit4KWIUFEkC+
4ugvcCsJQM/QTWYSzg5AKjnT1g1iCUCiZctucJYIQG//PYJAlwlAbRBcoFcT
BUDNqh9dGssJQIhBIm8SDPY/2pJMb6z9CUDSRx2Uff/iP0OMXYUGLwpAxJdP
wEvp2D8FBF1ON18KQFDs9+6jxOS/SqAKdkyOCkC/4bzz7QD1v6vHJ1M=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8WHR0jMiQsQN64dwvy
SOQ/WQN+XA7dKUDfVqmFon3tP27EQuM+FCxA/AmBZtBQ8j9d9hQIWSkrQIOR
BD6aO/U/O73YtAzaKUCF+JAQAbP3P5wXnoFkWytAZ8hRwvLV+T86J7PWTYUr
QFqa8FBjuPs/KD4K1JV4LUCrG0W78Wf9P4C1GrRHOSxAXkJExlXu/j9FZKoQ
AH8rQErxjfBdKQBAvISeGOOoKkAwDFZVS80AQBiPOjNmECpAaPTEOBFlAUB4
lfUoz7AoQBxYWWJd8gFApp1QMlzlJkBfwE5WinYCQDVcGRQWliZAYf4DKbPy
AkBjl54o7YUlQLaVvjjCZwNAgoLcattUJECvqhQXfdYDQEYvU0FqqCNAURxh
nYk/BECy/d0HWIYiQMj9nsV1owRAl7D7191+IUDOEUy2uwIFQOzBGAZ6MB9A
vDSKScVdBUBqtEJLtXMgQGmz5tPutAVAlzOkxO5FHUAWQH4EiQgGQP1ucFvI
4htAZgymBNxYBkBxcp5uIU8ZQMht5d0mpgZAc3gCg3abF0A6mcUHovAGQGTO
VIF7CxdAlSeDB4A4B0DW+7N30w0WQE1Dkz7ufQdATOP70B7UE0CQQGBSFcEH
QJB73Pzy/RBAiC1M0xoCCEAeUU+wVuQNQC5hhhMgQQhAghjL8IYaBkBGqu6p
Q34IQEHyNu4kjwJA3EI/hKG5CECSE8LyVicGQHV70zNT8whAEp5GhMzCA0C+
4ugvcCsJQCwH9nIfeQdAKjnT1g1iCUDCrBVa+gIBQG//PYJAlwlAtm6kjuk5
AEDNqh9dGssJQGh1w+6vcPs/2pJMb6z9CUBob0OEBlbiv0OMXYUGLwpAHaQa
gEjG/b8FBF1ON18KQPzHyACqUfG/SqAKdkyOCkAeyJDIBpHCPxUHIL4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -0.8081825037379542},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/w3hB+wW0wQN64dwvy
SOQ/nsuMIoIUMUDfVqmFon3tP8yTOzm8OTFA/AmBZtBQ8j+e1By2d2AxQIOR
BD6aO/U/fgAGapjlMECF+JAQAbP3P0yMImEU5C9AZ8hRwvLV+T+vooZ3gkUw
QFqa8FBjuPs/EZUOclhoMECrG0W78Wf9P99hW6T2CS9AXkJExlXu/j8WrYpT
ww0wQErxjfBdKQBAujeCFEccMEAwDFZVS80AQBZZxVSXqy9AaPTEOBFlAUBH
dRvQY30wQBxYWWJd8gFAOOz8PcPGLkBfwE5WinYCQCwjo8USaS9AYf4DKbPy
AkBjBaawAiAwQLaVvjjCZwNAXOhbx2fUL0CvqhQXfdYDQJX+odUlmy5AURxh
nYk/BEBPLd41FSsuQMj9nsV1owRAEeLycWpxLUDOEUy2uwIFQGGGn0XTgS1A
vDSKScVdBUAOcVsAx2ktQGmz5tPutAVAhB6vxanZK0AWQH4EiQgGQEbEfsiP
iClAZgymBNxYBkAWUZ0Fn6cqQMht5d0mpgZAjTVZCx7PKUA6mcUHovAGQN8v
0mI/rClAlSeDB4A4B0Ar+xVPgY0oQE1Dkz7ufQdAVjIxsSnSJ0CQQGBSFcEH
QNyd92BzxyZAiC1M0xoCCED1ojSOimknQC5hhhMgQQhAQXx2q6o5JkBGqu6p
Q34IQJ+hOS3y4CRA3EI/hKG5CEC/S2LxQs8kQHV70zNT8whANxE7r/yGJEC+
4ugvcCsJQJu1CoT1aiRAKjnT1g1iCUApxWfWVUUiQG//PYJAlwlAHFr/9xw9
HEDNqh9dGssJQGMLgew2kxtA2pJMb6z9CUDlwLLTS1MZQEOMXYUGLwpAqahK
EKRTFkAFBF1ON18KQCU4tzIY1BRASqAKdkyOCkCKp27y7QATQACOHZQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Xxa7ZBOcxQN64dwvy
SOQ/Yph24BKGMUDfVqmFon3tPy7Srdq8AzJA/AmBZtBQ8j9E29c+q40wQIOR
BD6aO/U/s9jU0Q5QL0CF+JAQAbP3P/SDLH2GIjFAZ8hRwvLV+T9T6cooAakx
QFqa8FBjuPs/CxROBPkxMkCrG0W78Wf9P8XvWFMKzTFAXkJExlXu/j8wS1iB
ZhcxQErxjfBdKQBAlmn4ZxcAMUAwDFZVS80AQIkzaJGnvDBAaPTEOBFlAUCD
tSzDA3gwQBxYWWJd8gFA8lLJNr8TMEBfwE5WinYCQEK3wfMROjBAYf4DKbPy
AkDEV5vvPhkwQLaVvjjCZwNAKzBVj+csL0CvqhQXfdYDQEh8j9OHKi9AURxh
nYk/BEAvRSmMJ0IvQMj9nsV1owRApfWCl+VWLkDOEUy2uwIFQHYLR/PHmC1A
vDSKScVdBUCLNeDLiSYsQGmz5tPutAVAEj5a3fXhKkAWQH4EiQgGQM73zk89
CilAZgymBNxYBkCZ39HJRpEnQMht5d0mpgZAKKnreh7mJ0A6mcUHovAGQO4O
Ecy+zydAlSeDB4A4B0CnnyPROBQnQE1Dkz7ufQdABSCOqSYNJkCQQGBSFcEH
QG4fXDWAmSRAiC1M0xoCCEBeWlWcX4YiQC5hhhMgQQhA5tf/ynmmIkBGqu6p
Q34IQEI1uO8KASNA3EI/hKG5CECHsmqcbLQhQHV70zNT8whAiPc7uouoIEC+
4ugvcCsJQHoghn4MaSJAKjnT1g1iCUCV0ZbqQJ4hQG//PYJAlwlA3yh+lH2i
HkDNqh9dGssJQJNLRW0n1x5A2pJMb6z9CUAq3QnUaJocQEOMXYUGLwpA1Kao
VkX5FkAFBF1ON18KQF1RtUbYBxxASqAKdkyOCkCdUev2+/UWQDbKI1g=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.063292996306297},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.818576016750736`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.905587393740365`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.985630101413904`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.059738073567623`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.128730945054574`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.193269466192145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.253894088008582`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.31105250184853, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9+Fgl+oxI7QN64dwvy
SOQ/YlTJAC/oOUDfVqmFon3tP00nymmrpDpA/AmBZtBQ8j/y806sV384QIOR
BD6aO/U/wL5Htev0NkCF+JAQAbP3P41BFsu4MTZAZ8hRwvLV+T/EDk4EJmY1
QFqa8FBjuPs/SesV5Xx+NUCrG0W78Wf9P+9O/bKCUjRAXkJExlXu/j/unvZD
fX00QErxjfBdKQBAs+e94326M0AwDFZVS80AQC4qztnWWjNAaPTEOBFlAUBU
Z9U/3MozQBxYWWJd8gFAlfyqoevtMkBfwE5WinYCQO/JIOf/YzJAYf4DKbPy
AkA+2hDZVrAyQLaVvjjCZwNAMZgZZOsCMkCvqhQXfdYDQM1vM9aWLTFAURxh
nYk/BEAtMn/LifgwQMj9nsV1owRAEkFunmpUMEDOEUy2uwIFQENCgYq1dzBA
vDSKScVdBUCh+G3JLv4vQGmz5tPutAVAiwrVrxOLLkAWQH4EiQgGQNh57QGN
QCxAZgymBNxYBkBke0yFS/grQMht5d0mpgZAPv3s1NXcKkA6mcUHovAGQECE
GaJ6LSpAlSeDB4A4B0BpwbwyK9woQE1Dkz7ufQdAMay/5+SEKECQQGBSFcEH
QBAzLohWkidAiC1M0xoCCEBXGxFgqxAnQC5hhhMgQQhAMkRhOqBAJkBGqu6p
Q34IQDTRYVBS9CRA3EI/hKG5CEC7nv9WZ3skQHV70zNT8whAQnW4GVwUJEC+
4ugvcCsJQKLu3mpkJiNAKjnT1g1iCUBNQn0p/ykhQG//PYJAlwlAXgVXoEGo
HkDNqh9dGssJQNl8wdd3PBpA2pJMb6z9CUBnGwtycRsXQEOMXYUGLwpA5dff
JNp5FUAFBF1ON18KQC94wBxVxRFASqAKdkyOCkCeWrXcBkoOQIYjJK8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Nmkt6cCo7QN64dwvy
SOQ/RMou5eNROUDfVqmFon3tP4GgRZH4NjlA/AmBZtBQ8j8X5H6XJbM3QIOR
BD6aO/U/4HtjUpBzNkCF+JAQAbP3P6O9y6S99zZAZ8hRwvLV+T+jp0xfFtQ2
QFqa8FBjuPs/TgRzxqhMN0CrG0W78Wf9P8PJPmMVdzZAXkJExlXu/j+rOPDV
Cr41QErxjfBdKQBANsn6PwQsNUAwDFZVS80AQOi4z1BhqjRAaPTEOBFlAUA7
WWeIvugzQBxYWWJd8gFA+e5sZckDM0BfwE5WinYCQEE9Oz7BzzJAYf4DKbPy
AkC/4QRjOlEyQLaVvjjCZwNAkHJdyXOXMUCvqhQXfdYDQHZQKUbqSDFAURxh
nYk/BEASROtdm/kwQMj9nsV1owRAj1bN5DNVMEDOEUy2uwIFQPMcHEjBWi9A
vDSKScVdBUB27NyB5kUuQGmz5tPutAVAcnrrjwKELEAWQH4EiQgGQKGGv4Ms
7ypAZgymBNxYBkBSW6fvW1YpQMht5d0mpgZAi8lm1GXYKEA6mcUHovAGQFzA
ivLwcyhAlSeDB4A4B0A3o788RpwnQE1Dkz7ufQdALBXtLxRWJkCQQGBSFcEH
QEcmpICYsyRAiC1M0xoCCECEg1k8mQojQC5hhhMgQQhADVeJ2JHkIUBGqu6p
Q34IQOFpxoNBoSFA3EI/hKG5CEDeMXH/AA0hQHV70zNT8whA/1plEkobIEC+
4ugvcCsJQPvldoHKOSFAKjnT1g1iCUBeQfJvV8MfQG//PYJAlwlAqh0vCq5F
HUDNqh9dGssJQELfqRXLPBxA2pJMb6z9CUC4M3aeicAWQEOMXYUGLwpAUzYP
kmviEEAFBF1ON18KQPAYqCJlMRVASqAKdkyOCkDZwjedH3QUQPMAI1s=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.6443022724838834`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            
            TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            
            TemplateBox[{"10", "11"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.339071317030758`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.84989694079675, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IwTwHDvAnQN64dwvy
SOQ/UeRWUW/ZJ0DfVqmFon3tP2R4pu4+yypA/AmBZtBQ8j/LYdPqgdYnQIOR
BD6aO/U/GTxyWfDaJUCF+JAQAbP3P4HXshnXMiVAZ8hRwvLV+T+a4C4qyWsk
QFqa8FBjuPs/+dvH+0ZNJUCrG0W78Wf9P4Q9HGP4kiNAXkJExlXu/j84n7nG
U3YkQErxjfBdKQBAQOQS2Gt5I0AwDFZVS80AQLJaj4GVMSNAaPTEOBFlAUDL
ZiLJRYEkQBxYWWJd8gFAEo09uXQvI0BfwE5WinYCQAy9uu7GgCJAYf4DKbPy
AkAuCw5X1nAjQLaVvjjCZwNAWP41r+JtIkCvqhQXfdYDQE2bb5Z/GiFAURxh
nYk/BEDLm2wpYP0gQMj9nsV1owRAgeQlrbr9H0DOEUy2uwIFQEX+k67biyBA
vDSKScVdBUACwu2Vob0fQGmz5tPutAVAKoq9crpVHUAWQH4EiQgGQMKLa59c
QBlAZgymBNxYBkBr1V7YlSkZQMht5d0mpgZAX9duOtRoF0A6mcUHovAGQAzc
kyCHdRZAlSeDB4A4B0B1ngsdRT0UQE1Dkz7ufQdAvRHhVBz1E0CQQGBSFcEH
QKmqe3MudRJAiC1M0xoCCECB+lHT7NQRQC5hhhMgQQhAVMGunMaQEEBGqu6p
Q34IQEw/T/svqQxA3EI/hKG5CEBju4bpqHsLQHV70zNT8whAxC+JNkiECkC+
4ugvcCsJQLQ1f34heAdAKjnT1g1iCUAD4JVh4yYAQG//PYJAlwlApUFunsnp
8j/Nqh9dGssJQGjomM12msI/2pJMb6z9CUAExg/kp+vhv0OMXYUGLwpAAKFq
9fGR7L8FBF1ON18KQIOstxEK+/u/SqAKdkyOCkDbnGUEd60CwB2LLTk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8XhKWZMMEqQN64dwvy
SOQ/GU/D+168KEDfVqmFon3tP/7ERNATvSlA/AmBZtBQ8j8JDZ9MlawnQIOR
BD6aO/U/XQjd1/8AJkCF+JAQAbP3P2ZPH4rBvydAZ8hRwvLV+T9usEITYhwo
QFqa8FBjuPs/3bxlKNyiKUCrG0W78Wf9P/VfXjMSfChAXkJExlXu/j+0nM++
kYQnQErxjfBdKQBAgxZI17jUJkAwDFZVS80AQB8EGj8vOyZAaPTEOBFlAUBF
Nm9U0RolQBxYWWJd8gFAZLgUFpOwI0BfwE5WinYCQKpSTWdyoSNAYf4DKbPy
AkCEB064L/ciQLaVvjjCZwNA9fxYM3/UIUCvqhQXfdYDQGVLPpm5hSFAURxh
nYk/BECVN/MJ6S4hQMj9nsV1owRANrYu5BotIEDOEUy2uwIFQLKNbEopQR5A
vDSKScVdBUBWm3sdYpgcQGmz5tPutAVAOWNTgE+QGUAWQH4EiQgGQOwAHTWP
3xZAZgymBNxYBkCCCtLn6iAUQMht5d0mpgZAV4uq3UuUE0A6mcUHovAGQOTt
GRJHNxNAlSeDB4A4B0AwfYLiF+8RQE1Dkz7ufQdAWNbeXkyKD0CQQGBSFcEH
QI1CsqAuxglAiC1M0xoCCEA57A4sROADQC5hhhMgQQhAWdRg6JIGAEBGqu6p
Q34IQJI4bmdhW/8/3EI/hKG5CEBR20bEQA38P3V70zNT8whANtlKo53d9T++
4ugvcCsJQPUKU5G4CABAKjnT1g1iCUCH0QPZH5P2P2//PYJAlwlALNBQDPWc
6z/Nqh9dGssJQGJQ1ld+s+U/2pJMb6z9CUCdvSwMhPHjv0OMXYUGLwpAGDST
D24fAMAFBF1ON18KQErhLCfH8eu/SqAKdkyOCkDdtw1+tn/vv/zrIos=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=131.253\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448100050102*^9},ExpressionUUID->"d5bdd27d-4273-47bc-af2d-\
18d0074f4f16"],

Cell[BoxData["15"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481007701607`*^9},ExpressionUUID->"f83c42a6-9a71-4c21-a957-\
ae42387db3f6"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+ObobJGOMtQN64dwvy
SOQ/QjKDX7WFLEDfVqmFon3tP1QNCPgGgC5A/AmBZtBQ8j9J4iGXmeArQIOR
BD6aO/U/713qcDKPLECF+JAQAbP3P7cIwJUCpCtAZ8hRwvLV+T8acC2KVe4r
QFqa8FBjuPs/OViDPg8GK0CrG0W78Wf9PxXrF8Ow8ylAXkJExlXu/j9YuIVo
xa4pQErxjfBdKQBAeSxS/K6fKUAwDFZVS80AQP6t0SVtrClAaPTEOBFlAUDh
hYuWl4goQBxYWWJd8gFAWtesflg3KEBfwE5WinYCQPbFLhsGuCdAYf4DKbPy
AkA9D1AJjocoQLaVvjjCZwNAFgSVUstXJ0CvqhQXfdYDQM871RleJyZAURxh
nYk/BECKwmLkkl4lQMj9nsV1owRA7eJkXztzJUDOEUy2uwIFQNVjEOF7ECRA
vDSKScVdBUAEkRuxdHojQGmz5tPutAVAn4uO7EP+IUAWQH4EiQgGQKaNs+M5
EyJAZgymBNxYBkASdx/N380gQMht5d0mpgZA4HeJrcwtIEA6mcUHovAGQAI1
irOXZx9AlSeDB4A4B0BhSOzn82UeQE1Dkz7ufQdAZ5tuaWdVHUCQQGBSFcEH
QMcOSQ0zgxtAiC1M0xoCCECa6ttHm6QbQC5hhhMgQQhAGT2+PZqyF0BGqu6p
Q34IQLahC7FglBVA3EI/hKG5CEAO5unuAloVQHV70zNT8whAtdqfqvcGFEC+
4ugvcCsJQJ/uSpcbiBNAKjnT1g1iCUDrfh7hvDUOQG//PYJAlwlAgvaJaIh7
DkDNqh9dGssJQG5ErbyHNA9A2pJMb6z9CUDNAa3GNiQFQEOMXYUGLwpA/BQ4
fqpsCkAFBF1ON18KQCqBWIdfBwVASqAKdkyOCkBd8AelGqsJQNjVHx8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8F65NFi4srQN64dwvy
SOQ/WUxVU/4iL0DfVqmFon3tPyrXAVrp5C5A/AmBZtBQ8j+nHMHQD/0tQIOR
BD6aO/U/zir/50NRLUCF+JAQAbP3P895jYD02yxAZ8hRwvLV+T8Kfw17mGEt
QFqa8FBjuPs/N/6ifGNQLkCrG0W78Wf9P17sfH+kXS1AXkJExlXu/j/1Mu5K
37EqQErxjfBdKQBACTRwKT8rK0AwDFZVS80AQMtaDiLESytAaPTEOBFlAUDd
u31/8ncqQBxYWWJd8gFAJgqvwxdTKEBfwE5WinYCQGctEwCO3CdAYf4DKbPy
AkBs5BvNdpMmQLaVvjjCZwNAYkSBorBsJ0CvqhQXfdYDQG5tfRWdISZAURxh
nYk/BEDRi3zWzaElQMj9nsV1owRAX+hEaKlEJEDOEUy2uwIFQEmBqggp2yRA
vDSKScVdBUDCfltGAkoiQGmz5tPutAVAK4wvNTqsIkAWQH4EiQgGQM5l2qeF
0yFAZgymBNxYBkBdiT51OpshQMht5d0mpgZABM4ypoLBIEA6mcUHovAGQNtj
KqYTlh5AlSeDB4A4B0Ag0gM5DEwdQE1Dkz7ufQdAJhJF9cbiG0CQQGBSFcEH
QMHvPAtM1BlAiC1M0xoCCEDpLF3zbBsaQC5hhhMgQQhAwdQrAD77F0BGqu6p
Q34IQFfhLxS+nRZA3EI/hKG5CECx4mvIH4MVQHV70zNT8whAxU3H7RZbEkC+
4ugvcCsJQIv5s46ppRBAKjnT1g1iCUDhVw1klVQQQG//PYJAlwlAiNMws3Dx
C0DNqh9dGssJQCMdAzpEEg1A2pJMb6z9CUCJrKQWaNYEQEOMXYUGLwpAa87A
NkTz7T8FBF1ON18KQPmD52pCufo/SqAKdkyOCkAnkx5/hf4BQOXqH6M=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 0.406476015022289},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.51599092375669, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.60300230074632, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.683045008419857`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.75715298057358, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+hqba6Cm0xQN64dwvy
SOQ/3eW2dT6WMEDfVqmFon3tP5xalhfQ+DFA/AmBZtBQ8j/miGTD4gUyQIOR
BD6aO/U/qx8g7lu9MECF+JAQAbP3P2kCs3jBGTFAZ8hRwvLV+T8EYQiboEgx
QFqa8FBjuPs/ELjnZ0vnMECrG0W78Wf9PxlwOdaptTBAXkJExlXu/j/LmcQN
2uUwQErxjfBdKQBA/B1sBUpPMEAwDFZVS80AQEHN+UUfljBAaPTEOBFlAUAj
+9hzT8cwQBxYWWJd8gFA6FxxGxKMMEBfwE5WinYCQGMLV+QMuDBAYf4DKbPy
AkAa0ukHu94wQLaVvjjCZwNAF5WWgo5pMECvqhQXfdYDQAR8SXOq8S5AURxh
nYk/BECky53XnX4vQMj9nsV1owRA4VihBRJVLkDOEUy2uwIFQGEvK/fF5S5A
vDSKScVdBUB+d+aoWK4tQGmz5tPutAVASGVgmKssLUAWQH4EiQgGQA+ywSmI
vyxAZgymBNxYBkB8q+i4k/UqQMht5d0mpgZAKPDHbiMRK0A6mcUHovAGQMvu
PicYICpAlSeDB4A4B0C2wRxhjxEqQE1Dkz7ufQdAEmeTWHKHKUCQQGBSFcEH
QEkAV71HuSlAiC1M0xoCCEDlOK7UbnUoQC5hhhMgQQhAP84sPlgBKEBGqu6p
Q34IQH6Bin+QqSZA3EI/hKG5CEBRrAfmcRcmQHV70zNT8whAfMNv4a18JUC+
4ugvcCsJQIQ2Mpq2MSVAKjnT1g1iCUBbegF2Z/gkQG//PYJAlwlAeJqzKpnR
IkDNqh9dGssJQO6IOhHNPiJA2pJMb6z9CUCL1uJAWRMiQEOMXYUGLwpAuIEN
V6DpI0AFBF1ON18KQGEvN8S84yJASqAKdkyOCkCO+zjGHysdQDPmIeM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/OQam6UaIuQN64dwvy
SOQ/EGWRzE3XMEDfVqmFon3tP3tdWORymjBA/AmBZtBQ8j9mllC9L0UxQIOR
BD6aO/U/DSDPOzDGMkCF+JAQAbP3P8GiMdUs2TFAZ8hRwvLV+T+Se7UMDL0x
QFqa8FBjuPs/9nSY0mQzMUCrG0W78Wf9P+0Fu1M8BzJAXkJExlXu/j8Dg/ao
ub4xQErxjfBdKQBAc3tPJrinMUAwDFZVS80AQKNTd+/CujBAaPTEOBFlAUCQ
/mYBe2UxQBxYWWJd8gFAuur0oy06MUBfwE5WinYCQKfJgDj6JzFAYf4DKbPy
AkCB+2vg97cwQLaVvjjCZwNA/TBb8yelMECvqhQXfdYDQFye2LNbri9AURxh
nYk/BECcGNnA25AvQMj9nsV1owRA7IKHYcS8LkDOEUy2uwIFQMG3f0Hy5C1A
vDSKScVdBUBmeEs9tjwuQGmz5tPutAVAFdpx96GGLEAWQH4EiQgGQE6hKRY4
rSxAZgymBNxYBkDclhIYZ74rQMht5d0mpgZAzBtErC9TKkA6mcUHovAGQPoe
TmSKmipAlSeDB4A4B0AE2/2wHuopQE1Dkz7ufQdACS3vp4reKECQQGBSFcEH
QLpMlYbHXyhAiC1M0xoCCECfQ9Y7s7cnQC5hhhMgQQhARGPwQI1rJkBGqu6p
Q34IQNK7z81QKCdA3EI/hKG5CECqIki1QEsnQHV70zNT8whAljqK/uDVI0C+
4ugvcCsJQCW7d57xjSJAKjnT1g1iCUCnwgodILkiQG//PYJAlwlAG6aXR6Te
IUDNqh9dGssJQEuMfRJpnSJA2pJMb6z9CUDX6B0TBTUiQEOMXYUGLwpAyQwd
BD6EHUAFBF1ON18KQESPr4KFTBdASqAKdkyOCkDLSNKBhvYXQAblJ7I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.5296472516167987`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ix1N8Ias7QN64dwvy
SOQ/JsQd+y2DOUDfVqmFon3tP6ocuFIe5TlA/AmBZtBQ8j8v7jz4xNA4QIOR
BD6aO/U/5DHiMgmAN0CF+JAQAbP3P8TV/1Tb+zZAZ8hRwvLV+T+abzOyy7w2
QFqa8FBjuPs/xACK6o34NUCrG0W78Wf9P2ZUXURySTVAXkJExlXu/j9VCWR/
Fgk1QErxjfBdKQBAhFUXsxeDNEAwDFZVS80AQKjStvgiajRAaPTEOBFlAUA/
4yx9fvgzQBxYWWJd8gFAXkYpm8qQM0BfwE5WinYCQMpsxo1/WTNAYf4DKbPy
AkDdXWS9DHEzQLaVvjjCZwNAsB251sq9MkCvqhQXfdYDQH7OFOju2TFAURxh
nYk/BECXAd5K2pcxQMj9nsV1owRA10TPWZZAMUDOEUy2uwIFQONq7e1y1zBA
vDSKScVdBUBabkQtLUMwQGmz5tPutAVAcJoBMtZDL0AWQH4EiQgGQLbGxxa5
3S5AZgymBNxYBkDoDelM+CctQMht5d0mpgZAz+AVraGbLEA6mcUHovAGQLmb
WVTnvStAlSeDB4A4B0AahCteHDcrQE1Dkz7ufQdA1p7y1od/KkCQQGBSFcEH
QJOv7gKJ4ylAiC1M0xoCCEDGdKbKFDkpQC5hhhMgQQhAmWYinEmzJ0BGqu6p
Q34IQIAX66VnUSZA3EI/hKG5CECSP+5YTdwlQHV70zNT8whAqSI7BRETJUC+
4ugvcCsJQAZ2kpp1qCRAKjnT1g1iCUDNPeJKDDUjQG//PYJAlwlATFQoDGQo
IkDNqh9dGssJQBlrXb/HAiJA2pJMb6z9CUDKqmvtcyYgQEOMXYUGLwpAND8G
rtKWIUAFBF1ON18KQAMhRiDHQyBASqAKdkyOCkA4LFhxGMYfQLfsInI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+1K4RzZrM5QN64dwvy
SOQ/7B/smg8/OkDfVqmFon3tP3UWINmvUTlA/AmBZtBQ8j9jWB0qgKg4QIOR
BD6aO/U//0mAxRPkOECF+JAQAbP3P7s1hUNdrDdAZ8hRwvLV+T+B42OD9FY3
QFqa8FBjuPs/szLpg+E1N0CrG0W78Wf9P/m431Va1jZAXkJExlXu/j8UgAQR
D7w1QErxjfBdKQBAtYoSd8WGNUAwDFZVS80AQAH5WA/zBTVAaPTEOBFlAUCQ
eW0Db8U0QBxYWWJd8gFAC+Xlxrr3M0BfwE5WinYCQIOjyq/0oTNAYf4DKbPy
AkB0dvYmje4yQLaVvjjCZwNAcvP9z3fgMkCvqhQXfdYDQBrzhuiq/jFAURxh
nYk/BECE2YfvMK4xQMj9nsV1owRAEMxvD439MEDOEUy2uwIFQKhbPfc/3DBA
vDSKScVdBUD9UN0RCCQwQGmz5tPutAVA1zpkGUZZL0AWQH4EiQgGQFmPHgeq
sS5AZgymBNxYBkCYddne8PItQMht5d0mpgZA4sNWO1K2LEA6mcUHovAGQN6n
dCzytitAlSeDB4A4B0B2K3NdfdgqQE1Dkz7ufQdAWFASKVLNKUCQQGBSFcEH
QDehDvRyzShAiC1M0xoCCECYRk7JbnUoQC5hhhMgQQhA/Oen/TkpJ0BGqu6p
Q34IQFWsXLw41SZA3EI/hKG5CEDGi6BCZ3AmQHV70zNT8whANK4Cg874I0C+
4ugvcCsJQPaG+AK83SJAKjnT1g1iCUDELcr0aKgiQG//PYJAlwlASTJqj+Bs
IUDNqh9dGssJQIOntfZTuSFA2pJMb6z9CUBwafJT/i4gQEOMXYUGLwpAH1X8
Yc5KGUAFBF1ON18KQFws7Ean1xlASqAKdkyOCkB06SCGGNsbQO3HLK0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.7460669887839795`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            
            TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            
            TemplateBox[{"10", "11"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.032218497590705`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+qDT2ZjxspQN64dwvy
SOQ/9N1i6tIGJ0DfVqmFon3tPxXZBwTrUylA/AmBZtBQ8j9VqPcirnsoQIOR
BD6aO/U/BlEbzhrpJkCF+JAQAbP3P9SEPAUryCZAZ8hRwvLV+T+Nqbh2Vxcn
QFqa8FBjuPs/K15xSjFDJkCrG0W78Wf9P4CLRqLpfyVAXkJExlXu/j+blfnY
nI8lQErxjfBdKQBANlA+BrQIJUAwDFZVS80AQA8uYehGTiVAaPTEOBFlAUDa
5kHfJN0kQBxYWWJd8gFAJHSte0t3JEBfwE5WinYCQCJPykYWaiRAYf4DKbPy
AkArkXC4tfMkQLaVvjjCZwNAdx7qscnlI0CvqhQXfdYDQFk1G/PHciJAURxh
nYk/BEDWGkahijwiQMj9nsV1owRAROo0CIbWIUDOEUy2uwIFQDv1CfGcSSFA
vDSKScVdBUBrm7eJ8WYgQGmz5tPutAVAEF+FyHHJHkAWQH4EiQgGQJ9/5EM3
dx5AZgymBNxYBkBRr1gNvIgbQMht5d0mpgZAVuDDX4jlGkA6mcUHovAGQGF4
XWxrlhlAlSeDB4A4B0Abl3KQEfQYQE1Dkz7ufQdAAb7MY6ToF0CQQGBSFcEH
QJ1kYmTdFhdAiC1M0xoCCEB6hbc1BSUWQC5hhhMgQQhA4usOwxZ2E0BGqu6p
Q34IQHK655M7FRFA3EI/hKG5CEAiSoVSpn8QQHV70zNT8whATwSqIul8DkC+
4ugvcCsJQJZ9NOrCgg1AKjnT1g1iCUBPJlYpJFwIQG//PYJAlwlA4ZQ0cdW+
BEDNqh9dGssJQNHALkfUwwRA2pJMb6z9CUBUcGKOqNb7P0OMXYUGLwpACiUP
r/BCBEAFBF1ON18KQPLmGuooCf8/SqAKdkyOCkDtF8Btiyn9P/JDHmI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/L5U4u7G8lQN64dwvy
SOQ/OvYlCFOaKEDfVqmFon3tP9qORpFEUyhA/AmBZtBQ8j+i1UxxikIoQIOR
BD6aO/U/6VkOPEi6KUCF+JAQAbP3P8iBRDNpLShAZ8hRwvLV+T/Q9gfmnFgo
QFqa8FBjuPs/O66p+oC8KECrG0W78Wf9PylLTRg8nChAXkJExlXu/j8n5WEq
tfgmQErxjfBdKQBAsl09MzgPJ0AwDFZVS80AQPtlzG9wiCZAaPTEOBFlAUD9
Sqc31ncmQBxYWWJd8gFAegSRvEFHJUBfwE5WinYCQC45UEv++iRAYf4DKbPy
AkDUanQDJ+8jQLaVvjjCZwNAFeJGGpkqJECvqhQXfdYDQLmYVR/4uCJAURxh
nYk/BEDrKUIogGciQMj9nsV1owRAaIFnw9xQIUDOEUy2uwIFQN6oiF/3VSFA
vDSKScVdBUDLL0fUJyggQGmz5tPutAVAi1Tc8mHyHkAWQH4EiQgGQBkiBkxk
IB5AZgymBNxYBkDLtA8ZYRkdQMht5d0mpgZAzYQmxBMUG0A6mcUHovAGQBwx
GJO8gxlAlSeDB4A4B0DWSgpovzMYQE1Dkz7ufQdA3bva6FOCFkCQQGBSFcEH
QHfeUtsy6hRAiC1M0xoCCEBf+j/RLZ4UQC5hhhMgQQhAfp7+yOljEkBGqu6p
Q34IQPkBcWGwGRJA3EI/hKG5CED9nV36cqgRQHV70zNT8whAwC5Gm48XCkC+
4ugvcCsJQLLamt1wWwZAKjnT1g1iCUBoToF8uiYGQG//PYJAlwlA8voZTRnZ
AUDNqh9dGssJQEG7QV9JnANA2pJMb6z9CUBGIAdMnB38P0OMXYUGLwpA7PMa
X7Odrz8FBF1ON18KQM2iBVD9LdE/SqAKdkyOCkDz931IZf7qP+gWIWo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=141.254\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481010563765`*^9},ExpressionUUID->"a1382b4d-1202-4e63-abca-\
166d4d5aa8eb"],

Cell[BoxData["16"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448101494751*^9},ExpressionUUID->"3027954f-3d3e-4224-b418-\
1edcd9687c60"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/CZzhd5lcuQN64dwvy
SOQ/fP7n3dQCL0DfVqmFon3tP90lQFI/rS9A/AmBZtBQ8j9o2rBFPawuQIOR
BD6aO/U/ntg1xqQQLUCF+JAQAbP3P80yvVtavi1AZ8hRwvLV+T+lrl0OAaws
QFqa8FBjuPs/CQjNSgq7LECrG0W78Wf9Pw4JV3agXitAXkJExlXu/j8RDJGJ
Y7wpQErxjfBdKQBA7MTn717/KUAwDFZVS80AQLcpeZtecSpAaPTEOBFlAUA9
jITjWlgqQBxYWWJd8gFAEeCAqbe3KUBfwE5WinYCQPs7quBz8SdAYf4DKbPy
AkB9QXQwBxgpQLaVvjjCZwNAaHnb5YLSJ0CvqhQXfdYDQOBfZQJS4SZAURxh
nYk/BEDpE9Kglm8mQMj9nsV1owRAz8ZdVSeCJkDOEUy2uwIFQADIMkxJUiVA
vDSKScVdBUClTG7FGJgkQGmz5tPutAVApA8DkVe8IkAWQH4EiQgGQDvfQJLv
GiNAZgymBNxYBkA0KK4RwAkiQMht5d0mpgZAC+BKt/SzIUA6mcUHovAGQEw1
On58SSBAlSeDB4A4B0DRgfUhaHsgQE1Dkz7ufQdAbiiIoBNHIECQQGBSFcEH
QAr5Sithch5AiC1M0xoCCEAtF2cV9VUdQC5hhhMgQQhAzx6eaAvgG0BGqu6p
Q34IQFfKqk18gRlA3EI/hKG5CED+5zRYvjQZQHV70zNT8whAd1yQ30IJGEC+
4ugvcCsJQN05F/WlQhZAKjnT1g1iCUBQ51XgxigWQG//PYJAlwlAonVRZJ+o
FUDNqh9dGssJQMEO3r/YahRA2pJMb6z9CUDma6SdgX0UQEOMXYUGLwpAtuhu
MuQrE0AFBF1ON18KQOlO4nE9Cg9ASqAKdkyOCkCdN1AXLT8TQMYpHXA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/BvIvHOtopQN64dwvy
SOQ/S5+DnfnNK0DfVqmFon3tP6PImRZ0PjBA/AmBZtBQ8j9xaYDZfdgrQIOR
BD6aO/U/bkzEwpZNLkCF+JAQAbP3P5mDoEyu7ixAZ8hRwvLV+T8f5H/wkjot
QFqa8FBjuPs/mRMeonxJLUCrG0W78Wf9P0w8UL5zmy1AXkJExlXu/j95QPVp
/VMsQErxjfBdKQBAf+QZGcBMK0AwDFZVS80AQCwfijedEStAaPTEOBFlAUCb
APgs1OEpQBxYWWJd8gFAyc3Ogft/KUBfwE5WinYCQEVLOwxBNylAYf4DKbPy
AkBeEiS/zlMpQLaVvjjCZwNAQrX02c5qKECvqhQXfdYDQDq53oDQUSlAURxh
nYk/BECpHmefAusmQMj9nsV1owRAf+DmFfdxJkDOEUy2uwIFQJh+5msgDydA
vDSKScVdBUD9gi7szRQnQGmz5tPutAVAhsBGosIfJUAWQH4EiQgGQE0p2iOF
RSRAZgymBNxYBkCyGf6kdOckQMht5d0mpgZA0fj8Iw11I0A6mcUHovAGQDIU
ht4h5CNAlSeDB4A4B0D8JsLdTZQiQE1Dkz7ufQdARlhsfL0SJECQQGBSFcEH
QOzj7TQrlyJAiC1M0xoCCEDJ6/HYAG0hQC5hhhMgQQhAvACo1C4LIkBGqu6p
Q34IQGcRMaK4kh9A3EI/hKG5CEDtBLguKxocQHV70zNT8whA8iPixFTsFUC+
4ugvcCsJQEE8cCT5/BdAKjnT1g1iCUDxAMaMtwsaQG//PYJAlwlAJwonuhgC
E0DNqh9dGssJQIxb5dMRhxhA2pJMb6z9CUBqtYkccikYQEOMXYUGLwpAFm+l
aOY6EkAFBF1ON18KQGwz5q28wxZASqAKdkyOCkAHRSkoMWUUQGeBIh4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.6850625938099386`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.82614585206053, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Piv1eOE0xQN64dwvy
SOQ/BVMZhflJMEDfVqmFon3tPwifd427RjBA/AmBZtBQ8j9i/YR9WZwxQIOR
BD6aO/U/KLBnkElEMUCF+JAQAbP3PxG4sjGryzBAZ8hRwvLV+T/5Pez65TMx
QFqa8FBjuPs/4KWhvyrXMUCrG0W78Wf9PwG6NjWZyDBAXkJExlXu/j9JQ1I5
qrUxQErxjfBdKQBA0StRKS+iMUAwDFZVS80AQLx8gC+7/zBAaPTEOBFlAUAl
hSDcoB8xQBxYWWJd8gFAqEdsWPamMEBfwE5WinYCQNrW+nbD4zBAYf4DKbPy
AkAAvesoDRUxQLaVvjjCZwNAW0yTh0zIMECvqhQXfdYDQE+fFmj5fDBAURxh
nYk/BEB2c7u5YEgwQMj9nsV1owRAp6eT9wtuL0DOEUy2uwIFQL8jvsd9ATBA
vDSKScVdBUDivbgwCJYuQGmz5tPutAVAksVYWE/pLUAWQH4EiQgGQKFi4cay
CS1AZgymBNxYBkDWeRTmb2wsQMht5d0mpgZAmsP3qMRwK0A6mcUHovAGQBv6
yy1nuitAlSeDB4A4B0BlneNkmbMqQE1Dkz7ufQdAxCLJOYzbKkCQQGBSFcEH
QC38wVSo1CpAiC1M0xoCCEDRCHVQV0EqQC5hhhMgQQhAUU70Lc+tKUBGqu6p
Q34IQFD/ucaSQihA3EI/hKG5CECgC1k6GGQnQHV70zNT8whA+dzlMsWlJ0C+
4ugvcCsJQACcDpUQryhAKjnT1g1iCUAxLCM74TgnQG//PYJAlwlAwAJvmcmZ
JUDNqh9dGssJQAUnWpFxqCNA2pJMb6z9CUD85iM/2d0kQEOMXYUGLwpAibtq
ORj4JEAFBF1ON18KQN3LABbFRyVASqAKdkyOCkDvTEuCcYAjQKSeJdc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8owIh3jPguQN64dwvy
SOQ/M8A7Vg9iLUDfVqmFon3tPyklVvvjEjJA/AmBZtBQ8j+F46W8ts0xQIOR
BD6aO/U/S/GZW8xEMkCF+JAQAbP3P0FJFJLvODJAZ8hRwvLV+T9FaE5rAbUx
QFqa8FBjuPs/K2jAzILXMkCrG0W78Wf9P9gry9WMqzJAXkJExlXu/j/+H9lx
bOIyQErxjfBdKQBAhcUxSf9HMkAwDFZVS80AQGHOCicb2TFAaPTEOBFlAUCh
ZeluaOAxQBxYWWJd8gFAtgoGYnX2MUBfwE5WinYCQKjc+zxZrjFAYf4DKbPy
AkCxMPKjdo8xQLaVvjjCZwNAXz1RTe43MUCvqhQXfdYDQEMvwOfOhzFAURxh
nYk/BEDoqAb9UX0xQMj9nsV1owRAK6t+1atYMUDOEUy2uwIFQHYPVBXloDBA
vDSKScVdBUDH8z6GqDgwQGmz5tPutAVAJWOWLEjEMEAWQH4EiQgGQIKuDWpY
Ei9AZgymBNxYBkC4opQJ+HwvQMht5d0mpgZAZtAMRL81MEA6mcUHovAGQEu/
zWkyTy5AlSeDB4A4B0BGA5vj4lctQE1Dkz7ufQdA+y9jWQi2LUCQQGBSFcEH
QG1mz8viIS1AiC1M0xoCCEApjCQRx+wsQC5hhhMgQQhAXJm/9m6PK0BGqu6p
Q34IQBbDlMNMhSpA3EI/hKG5CEBb7LgeYNkpQHV70zNT8whA8yZPJ497KUC+
4ugvcCsJQCtzGIMGGSlAKjnT1g1iCUAXSDPGye8nQG//PYJAlwlAu7gBfIrf
KEDNqh9dGssJQDSBoOfrmChA2pJMb6z9CUBvu7bpTtMnQEOMXYUGLwpAaWvL
r9UnKEAFBF1ON18KQCz57tRVXihASqAKdkyOCkCqgYKXzfopQAFHJww=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.234747299597536},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+iNkxZFqY7QN64dwvy
SOQ/F5PzkSIMOkDfVqmFon3tPx2wDfaNjDlA/AmBZtBQ8j8yhdPOTv84QIOR
BD6aO/U/bmxZi8LdN0CF+JAQAbP3PxSuVPKmhDdAZ8hRwvLV+T/e+Nkn3uU2
QFqa8FBjuPs/s2+/8JrcNkCrG0W78Wf9P7cVy+JWujVAXkJExlXu/j8iALcQ
bYs1QErxjfBdKQBAdAU8dh9BNUAwDFZVS80AQDtIg6JP0DRAaPTEOBFlAUBl
kRCVkp00QBxYWWJd8gFAJEhMV+0RNEBfwE5WinYCQP3dLXjLejNAYf4DKbPy
AkCy06LG/rEzQLaVvjjCZwNAp/OyGMMLM0CvqhQXfdYDQPAfLR9RfTJAURxh
nYk/BEBzijDF5yEyQMj9nsV1owRA2DOW4sHJMUDOEUy2uwIFQCrQ1dipbjFA
vDSKScVdBUCUaR67pscwQGmz5tPutAVACEILb24AMEAWQH4EiQgGQDfxmdM6
ly9AZgymBNxYBkCOVt2j5HguQMht5d0mpgZAQw5Xz761LUA6mcUHovAGQP3T
5QXdwixAlSeDB4A4B0DBskolpkMsQE1Dkz7ufQdA4bcqEOYALECQQGBSFcEH
QKAi8hKlLCtAiC1M0xoCCEAcNWWCWW0qQC5hhhMgQQhADRubevWWKUBGqu6p
Q34IQD2jOCS8IihA3EI/hKG5CEBluhf0/5MnQHV70zNT8whAXLXGhFEfJ0C+
4ugvcCsJQPcYXdJoCidAKjnT1g1iCUDsOpaWZBomQG//PYJAlwlATTbMXIs+
JUDNqh9dGssJQNdDE0ubPCRA2pJMb6z9CUCCLUkBBV8kQEOMXYUGLwpAeyCO
J5PKI0AFBF1ON18KQCQ1zuivuCJASqAKdkyOCkAw8VmocUYjQJDeIik=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U982Vf3s5QN64dwvy
SOQ/9VCLhPHpOEDfVqmFon3tP1lRKHzonDpA/AmBZtBQ8j/E8enzQWg4QIOR
BD6aO/U/CIKXcOexOECF+JAQAbP3P8b5gLZ42jdAZ8hRwvLV+T98NBaAk1g3
QFqa8FBjuPs/LAczKYCEN0CrG0W78Wf9P8wYzHMZMjdAXkJExlXu/j806aBZ
ULc2QErxjfBdKQBAL6ldwvXjNUAwDFZVS80AQJJuq+/qXTVAaPTEOBFlAUA4
utYQBt00QBxYWWJd8gFAb63J4jygNEBfwE5WinYCQM9zaX6UMzRAYf4DKbPy
AkDv2QGQv/szQLaVvjjCZwNAZGrQr4ZpM0CvqhQXfdYDQDe78JaLozNAURxh
nYk/BEAsAHiSd/AyQMj9nsV1owRAnbz/PzKcMkDOEUy2uwIFQJdA+Y92LzJA
vDSKScVdBUCIAEoC7esxQGmz5tPutAVAhx0hDf2QMUAWQH4EiQgGQBiuhVhd
jjBAZgymBNxYBkBzqPsVZbYwQMht5d0mpgZAffCDRT2GMEA6mcUHovAGQB7J
EMqJ8y9AlSeDB4A4B0DcDGSsvpMuQE1Dkz7ufQdAeHhqtJ6LL0CQQGBSFcEH
QENi/r0sJS5AiC1M0xoCCEDydtoDuSotQC5hhhMgQQhAfM9QnJ4DLUBGqu6p
Q34IQD9JlXDL6CpA3EI/hKG5CEBmbWpH9mQpQHV70zNT8whAjfQGq6OzJ0C+
4ugvcCsJQNlnTGUvpCdAKjnT1g1iCUDaNgaQRp4nQG//PYJAlwlASslVi15P
JkDNqh9dGssJQHl2/K74FCdA2pJMb6z9CUD9io22/IgmQEOMXYUGLwpAUh0m
6FYrJUAFBF1ON18KQKsuZnDyDyZASqAKdkyOCkCaUnuYVXkmQAxWKWA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.065307775451532},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            
            TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.032218497590705`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8NoAfwTx8pQN64dwvy
SOQ/2rmumXQUKEDfVqmFon3tP/V1QA0yrihA/AmBZtBQ8j9PfCkYW+AoQIOR
BD6aO/U/RHRIRxirJ0CF+JAQAbP3P3zkKuxD3SdAZ8hRwvLV+T/jR5sH8m0n
QFqa8FBjuPs/lXkmyXoJKECrG0W78Wf9P553SCMPZSZAXkJExlXu/j9txepP
t5gmQErxjfBdKQBA2tyASTmFJkAwDFZVS80AQC2DVI2iGCZAaPTEOBFlAUA3
ph9dhSkmQBxYWWJd8gFAIyQys1Z4JUBfwE5WinYCQC3B5TFkryRAYf4DKbPy
AkD88b9tU3UlQLaVvjjCZwNAXvbPLJeDJECvqhQXfdYDQIVC5Y4WuyNAURxh
nYk/BEAD49/TvFEjQMj9nsV1owRARPe9YAnpIkDOEUy2uwIFQIrtW02XeiJA
vDSKScVdBUAxYKm6bnAhQGmz5tPutAVAJLejXQgjIEAWQH4EiQgGQCyI7E8y
6h9AZgymBNxYBkC77b7nkCoeQMht5d0mpgZA4p5Tq3AUHUA6mcUHovAGQNlN
AfXEoRtAlSeDB4A4B0Ak5MAhPgwbQE1Dkz7ufQdA+GoPG4jqGkCQQGBSFcEH
QCz+e7yHqhlAiC1M0xoCCECsn5TnCo0YQC5hhhMgQQhAuC86al8/F0BGqu6p
Q34IQN1/DQartBRA3EI/hKG5CEDczkrrBO0TQHV70zNT8whAkdYARWNdE0C+
4ugvcCsJQFvLqlz/hhNAKjnT1g1iCUBxC67w2PMRQG//PYJAlwlAbi9ALEaN
EEDNqh9dGssJQNcL0HYZqA1A2pJMb6z9CUBIQLFvWc8OQEOMXYUGLwpAJogz
L30SDUAFBF1ON18KQEhmh/m3VwlASqAKdkyOCkDRx6Y4rSIMQIUzHgw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9PSxUcPtcmQN64dwvy
SOQ/cW1EOwhtJ0DfVqmFon3tP1TxhurYECxA/AmBZtBQ8j9Vi7xE/qwoQIOR
BD6aO/U/6zR0Jf8iKkCF+JAQAbP3P1yezojTMClAZ8hRwvLV+T/aw76yedko
QFqa8FBjuPs/xrGSimbKKUCrG0W78Wf9P61rNrdLtSlAXkJExlXu/j86Tzsp
fEEpQErxjfBdKQBAWK8IQb4PKEAwDFZVS80AQPbc2y64dSdAaPTEOBFlAUBn
IBN01t4mQBxYWWJd8gFA7+sN5APGJkBfwE5WinYCQICeyGmxSSZAYf4DKbPy
AkBc9DiVvjAmQLaVvjjCZwNAmQlPZmxhJUCvqhQXfdYDQJBMVP0nIyZAURxh
nYk/BEC64wjyvQglQMj9nsV1owRAXd2tcM+mJEDOEUy2uwIFQNhDG6ErEyRA
vDSKScVdBUArBU9kLM0jQGmz5tPutAVAemnOJUlVI0AWQH4EiQgGQID2qqDh
jyFAZgymBNxYBkDfRKl+4hoiQMht5d0mpgZALC6nID/xIUA6mcUHovAGQAom
8QUlDyFAlSeDB4A4B0Du7YJ5NcgfQE1Dkz7ufQdAutjQjMMMIUCQQGBSFcEH
QOyk/Q5qsh9AiC1M0xoCCEAkaBwZHR4eQC5hhhMgQQhARnpeZoUzHkBGqu6p
Q34IQBkc//3TUxpA3EI/hKG5CEAvmVfPqaYXQHV70zNT8whAPUNY3qmTFEC+
4ugvcCsJQM90VZV7yRRAKjnT1g1iCUDnagpClREVQG//PYJAlwlA5VA/eEXC
EkDNqh9dGssJQJIBc+PdlRRA2pJMb6z9CUDtDrGqAMkTQEOMXYUGLwpAjwLI
v/BYEUAFBF1ON18KQDi/AJI/aRNASqAKdkyOCkAO405AEoQUQKsSHeE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=151.255\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481018459177`*^9},ExpressionUUID->"58acf29a-10ab-4f5c-a62e-\
819791800261"],

Cell[BoxData["17"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448102354306*^9},ExpressionUUID->"28b69bc9-99aa-405b-a081-\
c34c026f5d37"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+rWBNIPgcwQN64dwvy
SOQ/toMXsDK+L0DfVqmFon3tP4p0/8sHMy5A/AmBZtBQ8j9LNKyu9dctQIOR
BD6aO/U/VI1VsOgKL0CF+JAQAbP3PxdrtB31Ay5AZ8hRwvLV+T84DewcIw0r
QFqa8FBjuPs/vfCkbg05LUCrG0W78Wf9P9m3yLpR5StAXkJExlXu/j/SDH7h
dxQrQErxjfBdKQBAFw4gwIIAK0AwDFZVS80AQJjXw/OAxypAaPTEOBFlAUB1
IUgMD+QqQBxYWWJd8gFA8hAieyLYKUBfwE5WinYCQGa2RYf3tSlAYf4DKbPy
AkCuXr2u5AwqQLaVvjjCZwNA2qfMcDCJJ0CvqhQXfdYDQG8HR2RxxCdAURxh
nYk/BECofS+Y+UUnQMj9nsV1owRAU56i4wdvJ0DOEUy2uwIFQHIe+lTYxSVA
vDSKScVdBUCPgRw0cGYlQGmz5tPutAVArWoROctqJEAWQH4EiQgGQCYcF3X2
riNAZgymBNxYBkAu+XVn5cMjQMht5d0mpgZA0xUhyVMBI0A6mcUHovAGQJyu
K1WYmyJAlSeDB4A4B0Cu6DqI0Y0iQE1Dkz7ufQdAiQGh8U2SIUCQQGBSFcEH
QPHHzejA0SBAiC1M0xoCCEDsB1tZyzAhQC5hhhMgQQhAlezvgneuHEBGqu6p
Q34IQNe3Dxi11RxA3EI/hKG5CEBlZgpSWbAZQHV70zNT8whAH+1GhvntGUC+
4ugvcCsJQJ9aeQuQQRlAKjnT1g1iCUBr5Erj6l4WQG//PYJAlwlAfzrdIsbT
F0DNqh9dGssJQOeAgwAg4xJA2pJMb6z9CUBxGRF64sYUQEOMXYUGLwpA0AVs
8t8eEkAFBF1ON18KQKgNzhxcqRRASqAKdkyOCkAUGzadyXkPQG8fIQY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/zBx5AACoqQN64dwvy
SOQ/9xqWmAnoLEDfVqmFon3tPzWepMA1FSxA/AmBZtBQ8j9MqWLBB6AtQIOR
BD6aO/U/j+l5gEjOLECF+JAQAbP3P3ESLEq2Fi1AZ8hRwvLV+T81uYAUYFou
QFqa8FBjuPs/Ehm5uFI2LUCrG0W78Wf9P3XnLwPQTyxAXkJExlXu/j9o11F+
YBgtQErxjfBdKQBAYf4gDpofLEAwDFZVS80AQK+/9eDTGCtAaPTEOBFlAUBZ
xR5h6j8rQBxYWWJd8gFAPZsDdl/pKkBfwE5WinYCQBz2RmouCCpAYf4DKbPy
AkDGyy/J9JgpQLaVvjjCZwNA/PuUzeDzKUCvqhQXfdYDQBb2u5h+eSlAURxh
nYk/BECMoKWA0pEpQMj9nsV1owRA2vruFNy4KEDOEUy2uwIFQBY9EuD5TyhA
vDSKScVdBUB82vghtXwoQGmz5tPutAVAWrrCSSuCJ0AWQH4EiQgGQDdyHeFy
xSVAZgymBNxYBkB7dsuUnDQlQMht5d0mpgZA8WHY31n9JEA6mcUHovAGQHiz
JtMyVyRAlSeDB4A4B0CVJ/iyR28lQE1Dkz7ufQdALrVsX2xOJECQQGBSFcEH
QEijAbQ2TCNAiC1M0xoCCECOkEbYkNAiQC5hhhMgQQhA86//DbgcIUBGqu6p
Q34IQEQ5+2Bk6SBA3EI/hKG5CEAiH+rHbKQZQHV70zNT8whA3ezivRuIGkC+
4ugvcCsJQGX1dOi+7xlAKjnT1g1iCUC86n9qyQYbQG//PYJAlwlAvbLXLJuw
GUDNqh9dGssJQO5U3C+4HBlA2pJMb6z9CUAhD3FfDLoWQEOMXYUGLwpAqs7x
5kfqGEAFBF1ON18KQLBlSGf0yRhASqAKdkyOCkAhrGbVzq0NQHFDKAA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.6111748361951976`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.82614585206053, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+B6QAogrgwQN64dwvy
SOQ/TYDoaCneMEDfVqmFon3tPzKqCe4bNzJA/AmBZtBQ8j9zFjZPe1sxQIOR
BD6aO/U/5lDYK02nMUCF+JAQAbP3PyAWphNxcTFAZ8hRwvLV+T9yWGHEVnUx
QFqa8FBjuPs/6V9Bqa2IMUCrG0W78Wf9PycRpeTqsTFAXkJExlXu/j9Rq8nN
6IsxQErxjfBdKQBAWsbeA4e3MUAwDFZVS80AQIMwI5RcbzFAaPTEOBFlAUCx
uMzCPOExQBxYWWJd8gFA9wpKTKUXMUBfwE5WinYCQC4yQSIOQzFAYf4DKbPy
AkBexiudI6UxQLaVvjjCZwNADLIviaymMUCvqhQXfdYDQO0p2+RlsjBAURxh
nYk/BEDwKbMid0AxQMj9nsV1owRA3yIg2FJyMEDOEUy2uwIFQIR7T9dQhy9A
vDSKScVdBUAZNqCAS6YvQGmz5tPutAVAfYnSJ62cLkAWQH4EiQgGQJZqaY/o
aS5AZgymBNxYBkA90Dpwna0tQMht5d0mpgZAaeo4l4xBLUA6mcUHovAGQLZs
5A4J1yxAlSeDB4A4B0A6joxsDhYtQE1Dkz7ufQdAKRqI6iV/LECQQGBSFcEH
QOk8ec456CtAiC1M0xoCCEAHVQzhEM8rQC5hhhMgQQhAEBODFjgnK0BGqu6p
Q34IQJWlBfPl5yhA3EI/hKG5CEBwHD0vVx8pQHV70zNT8whA3m3eOaCzKEC+
4ugvcCsJQBgj94YKOSlAKjnT1g1iCUBrmIU3yXAoQG//PYJAlwlAe2yYOhhQ
JkDNqh9dGssJQPUm1tLavyVA2pJMb6z9CUCRTQLPVwwmQEOMXYUGLwpAxoaT
PRnWJUAFBF1ON18KQONvq5osXiVASqAKdkyOCkCY4j+dEK0cQI6OGyo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/kXpv1rBcxQN64dwvy
SOQ/JgO4mczIMUDfVqmFon3tPxGRcMpYQzJA/AmBZtBQ8j+qw1TEOX0xQIOR
BD6aO/U/1CbXL0ZeMkCF+JAQAbP3P2g+GoPktjJAZ8hRwvLV+T+lW3zErXYy
QFqa8FBjuPs/rb247hu+MkCrG0W78Wf9P7lZjTJBczJAXkJExlXu/j+vmCsh
MocyQErxjfBdKQBAQFUBCeR3MkAwDFZVS80AQIlvEEZNHjJAaPTEOBFlAUC8
Iy2TT2gyQBxYWWJd8gFAFZ94VXliMkBfwE5WinYCQBNgTmxtQjJAYf4DKbPy
AkAPRlUedaExQLaVvjjCZwNAnHGxWJEFMkCvqhQXfdYDQBFcU1zrMDFAURxh
nYk/BEBkRjL/7PoxQMj9nsV1owRA0aCeyfN9MUDOEUy2uwIFQLPzu9N2izFA
vDSKScVdBUBwfuhMtlsxQGmz5tPutAVAT5NrkHetMEAWQH4EiQgGQDgFUaRu
bjBAZgymBNxYBkCDX8XQ+UkwQMht5d0mpgZAp6kWnVUlMEA6mcUHovAGQBcT
0xu6LjBAlSeDB4A4B0BWFPaU60gwQE1Dkz7ufQdAJBxrakxgMECQQGBSFcEH
QCvrVkmqFi5AiC1M0xoCCEDEZr2QAcQuQC5hhhMgQQhAwuY+1bwrLEBGqu6p
Q34IQCrLOr+eDypA3EI/hKG5CEBpSJfwn/sqQHV70zNT8whA/M6dKgDKKUC+
4ugvcCsJQCHmQsPLESpAKjnT1g1iCUDXDilCL1cpQG//PYJAlwlAE1wfAApP
KEDNqh9dGssJQLkQlJMq2SdA2pJMb6z9CUAqbpQH5OklQEOMXYUGLwpAopIR
9DS/J0AFBF1ON18KQB+yMfdbPylASqAKdkyOCkAAejMn2GQqQMlDGpo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 3.1134609151557204`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8NdiQG+pY7QN64dwvy
SOQ/zhNe4Ld3OkDfVqmFon3tP7E2pQjKAjpA/AmBZtBQ8j9DgFVxuaU4QIOR
BD6aO/U/4ZlfWWSgOECF+JAQAbP3P3bJ2WQ9yjdAZ8hRwvLV+T9psS1CFaU2
QFqa8FBjuPs/DZNWqS7kNkCrG0W78Wf9PxrYhBIzRTZAXkJExlXu/j99WWPX
w7Q1QErxjfBdKQBAY1HtmaaDNUAwDFZVS80AQM5RNiGaFzVAaPTEOBFlAUB9
FokH/Ro1QBxYWWJd8gFAn/n52FBENEBfwE5WinYCQIWE6wclHDRAYf4DKbPy
AkAdLFbRqDU0QLaVvjjCZwNALZKZzK6FM0CvqhQXfdYDQMHGpDIT1DJAURxh
nYk/BEAqTSKxj9syQMj9nsV1owRAfZohv/dYMkDOEUy2uwIFQFOBKWXqcTFA
vDSKScVdBUAp/PWwKD0xQGmz5tPutAVAnrUWMPOcMEAWQH4EiQgGQCH/gkOU
PzBAZgymBNxYBkB0SdEbOAMwQMht5d0mpgZASELm3/8uL0A6mcUHovAGQIEZ
LeGMlS5AlSeDB4A4B0C9VGfdJHMuQE1Dkz7ufQdAIty5KWtuLUCQQGBSFcEH
QLEJzZLCjSxAiC1M0xoCCEBFcemBqJQsQC5hhhMgQQhAG5gDv/WIKkBGqu6p
Q34IQOLnt1VYcylA3EI/hKG5CEAVVOMeJGgoQHV70zNT8whAsuZJLCweKEC+
4ugvcCsJQBet8jENAShAKjnT1g1iCUBB5+CglMMmQG//PYJAlwlAydzBRkw9
JkDNqh9dGssJQA/en6SQPiRA2pJMb6z9CUDl70NdSM4kQEOMXYUGLwpAHo0j
l9jII0AFBF1ON18KQJnmokylUiRASqAKdkyOCkBP6KQKyUEhQFXQINA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8OSfuhK1M6QN64dwvy
SOQ/2fTlHXwjOkDfVqmFon3tP3wxOGxEWjlA/AmBZtBQ8j/+oBOgkNU4QIOR
BD6aO/U/jErk40RaOECF+JAQAbP3P2yjXr6MIzhAZ8hRwvLV+T+7vexaHgc4
QFqa8FBjuPs/JczNc8ZwN0CrG0W78Wf9P5BcVNEyvzZAXkJExlXu/j/opwuA
ALw2QErxjfBdKQBAjvNoFpQuNkAwDFZVS80AQE1n3dvTgDVAaPTEOBFlAUAi
PGWZJHc1QBxYWWJd8gFAKIBCah0oNUBfwE5WinYCQPqaz/OesTRAYf4DKbPy
AkA7hZN2wRY0QLaVvjjCZwNAkcwPZocyNECvqhQXfdYDQBVJ7OUQkTNAURxh
nYk/BECNQ7eJv8QzQMj9nsV1owRA84uD6x4sM0DOEUy2uwIFQMedVAm28zJA
vDSKScVdBUAB+EegNsoyQGmz5tPutAVAUvud7igdMkAWQH4EiQgGQLux80/1
YDFAZgymBNxYBkAkisbd4AwxQMht5d0mpgZADa9U4SLQMEA6mcUHovAGQM5t
PoYmkDBAlSeDB4A4B0Abu2IaNswwQE1Dkz7ufQdA4vp9bZxzMECQQGBSFcEH
QP9SJgGE8y5AiC1M0xoCCEDgsw8jvsIuQC5hhhMgQQhAExbXKd2DLEBGqu6p
Q34IQMK+m+k1sStA3EI/hKG5CECOAjQXP3opQHV70zNT8whA9iEWaK7HKEC+
4ugvcCsJQI0ZYvu8myhAKjnT1g1iCUCpPjunQGwoQG//PYJAlwlAIR+IY2x8
J0DNqh9dGssJQMM7+3z0BCdA2pJMb6z9CUD8NZvuNYElQEOMXYUGLwpA38Ti
y5WoJkAFBF1ON18KQJNXFuz5BSdASqAKdkyOCkD/LbUSR3YmQEP6JZ8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 3.7473042697858165`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            
            TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.032218497590705`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/j15UizRYpQN64dwvy
SOQ/dziGL735KEDfVqmFon3tP7vc/2JWlilA/AmBZtBQ8j/arLDAKTQoQIOR
BD6aO/U/GLH/DQopKUCF+JAQAbP3P0c22xdJbChAZ8hRwvLV+T8vwL9U7Okm
QFqa8FBjuPs/dgcZOkYXKECrG0W78Wf9Py8QNZ1ieidAXkJExlXu/j9w5bHA
lOkmQErxjfBdKQBAEaVIcpYKJ0AwDFZVS80AQOZTUoUMqCZAaPTEOBFlAUC/
ra14fSMnQBxYWWJd8gFA2vHVxjndJUBfwE5WinYCQNMtIPq88CVAYf4DKbPy
AkDWTI2zeX4mQLaVvjjCZwNAu/Rd3L52JUCvqhQXfdYDQPMeQV5AZyRAURxh
nYk/BEAVGfZhbsMkQMj9nsV1owRA+jIbwDcIJEDOEUy2uwIFQApTrQD+gSJA
vDSKScVdBUCwnNPULFkiQGmz5tPutAVA337dJJJaIUAWQH4EiQgGQGwLirLO
3CBAZgymBNxYBkCn0bxXVqEgQMht5d0mpgZAhAFSa6kDIEA6mcUHovAGQNaU
t6jQQx9AlSeDB4A4B0Bk1XAivGgfQE1Dkz7ufQdAOPb7QUDGHUCQQGBSFcEH
QK3x2vidbBxAiC1M0xoCCEDRLZGmktwcQC5hhhMgQQhAbgmD0xolGUBGqu6p
Q34IQCwmfJHXUhdA3EI/hKG5CEBe705Zw5UVQHV70zNT8whAnlIFhaFYFUC+
4ugvcCsJQCSqpIiDdBVAKjnT1g1iCUDJzxuxV0UTQG//PYJAlwlAKBOVzD2K
EkDNqh9dGssJQG2X2XPIsg1A2pJMb6z9CUBt/q0qgUQQQEOMXYUGLwpA+k1S
3cgKDUAFBF1ON18KQHYbjDhExA9ASqAKdkyOCkBWQuYXHxAEQDp3Ijw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9BQvX3fREpQN64dwvy
SOQ/sz4wcjZgKkDfVqmFon3tP497kwpYBCpA/AmBZtBQ8j9GYVJJlfQpQIOR
BD6aO/U/hnNYpL3PKUCF+JAQAbP3P8WdU3njGCpAZ8hRwvLV+T+bIrrNfYEq
QFqa8FBjuPs/rKuTMGrnKUCrG0W78Wf9P9qsAxNxDSlAXkJExlXu/j8gZwLY
Gn8pQErxjfBdKQBAfkEeQoPWKEAwDFZVS80AQOCPJwMp5ydAaPTEOBFlAUDe
TOqGljcoQBxYWWJd8gFAxfnPW9j7J0BfwE5WinYCQGhFR6c0ZidAYf4DKbPy
AkDrzm42UoQmQLaVvjjCZwNAXuv8GWYOJ0CvqhQXfdYDQOJrFbEzGSZAURxh
nYk/BEDZGBNTfscmQMj9nsV1owRAM/SPWaDcJUDOEUy2uwIFQGLa5ECariVA
vDSKScVdBUBrRMPu7ZolQGmz5tPutAVAO3unuB9+JEAWQH4EiQgGQAdKCSCK
QiNAZgymBNxYBkBS1I4XQdMiQMht5d0mpgZAVJGDSBiSIkA6mcUHovAGQChL
frFdRyJAlSeDB4A4B0BuncUskPEiQE1Dkz7ufQdA4SciG5tyIkCQQGBSFcEH
QNzTnIAOsSBAiC1M0xoCCEBHIvwgT68gQC5hhhMgQQhAauIsxOVDHUBGqu6p
Q34IQCQZJmCz+BtA3EI/hKG5CEBjqFgWsN4XQHV70zNT8whAcaLqI4fNFkC+
4ugvcCsJQGhcRZNjyBZAKjnT1g1iCUC3/4Zcl7oWQG//PYJAlwlABKBZbZEo
FUDNqh9dGssJQIwNEWfQghRA2pJMb6z9CUC9Fnx5DMkRQEOMXYUGLwpAk5zr
YGlfFEAFBF1ON18KQOnUotHRXhVASqAKdkyOCkDeNcifeYgUQIBaHtA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=161.255\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481026696167`*^9},ExpressionUUID->"736cfa48-a404-452f-ae84-\
f00f03dfb081"],

Cell[BoxData["18"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481031618032`*^9},ExpressionUUID->"65a25a64-22e8-4040-ad00-\
fd38e96d1f3b"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+L6GTt3EkvQN64dwvy
SOQ/K2sWeSc6L0DfVqmFon3tP6n6YDVVMzBA/AmBZtBQ8j9T99F7UsMtQIOR
BD6aO/U/TSE/E+iQLUCF+JAQAbP3Pwg08Qt7gy1AZ8hRwvLV+T90hzPce4Us
QFqa8FBjuPs/iTgtkIfTLECrG0W78Wf9PzD1/d9xLS1AXkJExlXu/j/pRmVJ
gHkrQErxjfBdKQBAJ2hBJeWRK0AwDFZVS80AQBYqc24caCtAaPTEOBFlAUAu
rYi13zwrQBxYWWJd8gFAXNHjuUp5KkBfwE5WinYCQEjJtkzH/SlAYf4DKbPy
AkAIoOOw0RoqQLaVvjjCZwNAr1aqpdMDKkCvqhQXfdYDQBEQfNooyihAURxh
nYk/BEAKyvZgNa8oQMj9nsV1owRAHcX/F94LJ0DOEUy2uwIFQGEW8UIwEyZA
vDSKScVdBUAmDr/TBdsmQGmz5tPutAVAW/6lJDZDJUAWQH4EiQgGQFSm1GYM
xCRAZgymBNxYBkALOIXFgbojQMht5d0mpgZA5dqWK/5nJEA6mcUHovAGQGPQ
PTUQOyNAlSeDB4A4B0AiQib5GUQjQE1Dkz7ufQdAggUahnE9I0CQQGBSFcEH
QKC81PUu7yFAiC1M0xoCCEBAdgwnJbshQC5hhhMgQQhAjsXTfLJeIEBGqu6p
Q34IQKXAq6wnsRxA3EI/hKG5CEAFCTqXoCQdQHV70zNT8whAT4LuQnCNGkC+
4ugvcCsJQJMILIy9yhhAKjnT1g1iCUB8HFGbug8aQG//PYJAlwlA2GPEKIue
F0DNqh9dGssJQKuFVSWa6RRA2pJMb6z9CUB5tiVPx9IVQEOMXYUGLwpABihQ
3iA7FkAFBF1ON18KQAc5l3nJ5hRASqAKdkyOCkCNyFeoVqoQQEfuGwM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT93txYkmzsuQN64dwvy
SOQ/6iQIWMZKLUDfVqmFon3tP6tTAzWsLy5A/AmBZtBQ8j/tXQYok8MtQIOR
BD6aO/U/LcDjCNyaLUCF+JAQAbP3P50HjrM1uy1AZ8hRwvLV+T/VzKlN3Ewu
QFqa8FBjuPs/m87HIiUrLUCrG0W78Wf9P+kk6jdTLy1AXkJExlXu/j+EVEP6
zPwsQErxjfBdKQBASrImMPgVLEAwDFZVS80AQJyHnFXD3StAaPTEOBFlAUCi
hPsGBsArQBxYWWJd8gFA2VV2beqoK0BfwE5WinYCQEvusm7TFytAYf4DKbPy
AkCmYcR1Ur4qQLaVvjjCZwNApI1MXWkNKkCvqhQXfdYDQOQT4ks+zilAURxh
nYk/BEB/RR30kZUpQMj9nsV1owRAJ39PqOrUKEDOEUy2uwIFQDuMavGp5ShA
vDSKScVdBUAudKrQ0O4nQGmz5tPutAVAEEZDY+EzKEAWQH4EiQgGQD1Pm/kO
nSdAZgymBNxYBkDpF9DelK4mQMht5d0mpgZAyiPULD60JkA6mcUHovAGQCCw
lFFmgSVAlSeDB4A4B0BFvThYUPMkQE1Dkz7ufQdATvOZagN6JUCQQGBSFcEH
QDX/P7TF/SRAiC1M0xoCCECKnAwOFKEjQC5hhhMgQQhAyhkjf5FlIUBGqu6p
Q34IQAbWwdyNmSBA3EI/hKG5CEC3wlft4g8gQHV70zNT8whANWPeQ6KgHkC+
4ugvcCsJQMGgLQNfXB5AKjnT1g1iCUAhxg5g1E8bQG//PYJAlwlA4202Dnhq
G0DNqh9dGssJQOlzBsiK6xpA2pJMb6z9CUCy4eQINKYXQEOMXYUGLwpAZv3F
hj8SF0AFBF1ON18KQI51MJpsHRpASqAKdkyOCkBmmT5pN9AZQBMlIfY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 1.809421163259639},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.82614585206053, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/6pNV6ioUwQN64dwvy
SOQ/Ydp9StTJMEDfVqmFon3tP8EXUQH7BTFA/AmBZtBQ8j+khfScpyAyQIOR
BD6aO/U/pmsUrwbyMUCF+JAQAbP3P1ZItewyVzFAZ8hRwvLV+T8kTgDjabMx
QFqa8FBjuPs/fXUmFWT2MUCrG0W78Wf9PzK8zs4vvDFAXkJExlXu/j/BGCue
WN8xQErxjfBdKQBAGAX6ZrwkMkAwDFZVS80AQJmiJyrDCDJAaPTEOBFlAUDW
g9jD1vUxQBxYWWJd8gFAodbYPsaUMUBfwE5WinYCQIfKEqUxbjFAYf4DKbPy
AkBNaT6SozIyQLaVvjjCZwNAqQf7HNtYMUCvqhQXfdYDQHnaEhleHDFAURxh
nYk/BECYzrXqeQMxQMj9nsV1owRAasD+Pv67MEDOEUy2uwIFQM/a/A85jjBA
vDSKScVdBUCeSTZKrkswQGmz5tPutAVAJKH64yn3L0AWQH4EiQgGQM3T81Ib
Gi9AZgymBNxYBkDgLz+BQLAuQMht5d0mpgZA0i29no5HLkA6mcUHovAGQPoj
EARhky5AlSeDB4A4B0DZJBs2t7ItQE1Dkz7ufQdAY7ff5oanLUCQQGBSFcEH
QKUxHr+hjixAiC1M0xoCCED9ETX7oPssQC5hhhMgQQhAR7d8svqLK0BGqu6p
Q34IQE/Urkq6SCtA3EI/hKG5CECUwjFAiAQqQHV70zNT8whAc7SjMkbVKUC+
4ugvcCsJQIdnGZilHSpAKjnT1g1iCUAKZJN//VEoQG//PYJAlwlAdiJMjAMz
KEDNqh9dGssJQNMdwgZn6yZA2pJMb6z9CUAhFIfxl9gmQEOMXYUGLwpAuIO8
j1AZJkAFBF1ON18KQEUMUb4ZRSdASqAKdkyOCkBmzfob3dokQG8WJI8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+YpZqwA2gwQN64dwvy
SOQ/yho/mHBuMUDfVqmFon3tP2H2TCWAzDFA/AmBZtBQ8j8bEgqk7TcyQIOR
BD6aO/U/alvyyDtSMkCF+JAQAbP3PxVj0XjjOTJAZ8hRwvLV+T/dzl4s30ky
QFqa8FBjuPs/T7u9/vTCMkCrG0W78Wf9P8bsOpTlwDJAXkJExlXu/j+nGJAf
1aoyQErxjfBdKQBAl4VvJfP9MkAwDFZVS80AQOXaR17mwDJAaPTEOBFlAUCv
W3Q0tkAyQBxYWWJd8gFAi6MpIzCUMkBfwE5WinYCQKBlOR7jbTJAYf4DKbPy
AkB801/rjGsyQLaVvjjCZwNAE8FwKHM2MkCvqhQXfdYDQIpX8zeOBDJAURxh
nYk/BEDyGZvoDf0xQMj9nsV1owRA4Cii/lLlMUDOEUy2uwIFQMtAI1FOzzFA
vDSKScVdBUBA416fn28xQGmz5tPutAVAYcJe1mZkMUAWQH4EiQgGQOCBV4cw
HDFAZgymBNxYBkBbC92jl+cwQMht5d0mpgZAYkFiBF+GMEA6mcUHovAGQI0o
XV65aTBAlSeDB4A4B0DKwJDSMFQwQE1Dkz7ufQdAUVdtQHw5MECQQGBSFcEH
QJZAaAuktS9AiC1M0xoCCEBg85pHPhEvQC5hhhMgQQhAZ1h1YpLiLUBGqu6p
Q34IQOM07PXrCS1A3EI/hKG5CECqHyT3qAosQHV70zNT8whATmf61OoDK0C+
4ugvcCsJQGrCGREYsypAKjnT1g1iCUC+8yBdwzQqQG//PYJAlwlA60dyQpqK
KUDNqh9dGssJQOPLnTcKFyhA2pJMb6z9CUCz0BFJq1UoQEOMXYUGLwpABP82
IHGHKEAFBF1ON18KQPlBOzfrciZASqAKdkyOCkAdZF3d5fEkQJWtI6Y=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.528591890818043},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9IdNCUdEs7QN64dwvy
SOQ/ap+5emw+OkDfVqmFon3tP2muhEj3ATpA/AmBZtBQ8j+mYohH7BA5QIOR
BD6aO/U/SKfnXlBeOECF+JAQAbP3PxfJiEUpljdAZ8hRwvLV+T90bqGXfxg3
QFqa8FBjuPs/P7qECb7zNkCrG0W78Wf9P3Q1c7oCpzZAXkJExlXu/j9rqKY1
Gfk1QErxjfBdKQBAfMdyMRXhNUAwDFZVS80AQHYmvJ95iTVAaPTEOBFlAUBE
IwaBMzw1QBxYWWJd8gFA2WZLatymNEBfwE5WinYCQCNpSy0bRTRAYf4DKbPy
AkDoIw47FoI0QLaVvjjCZwNAXshul9/pM0CvqhQXfdYDQJ3i2YufTDNAURxh
nYk/BEB2aMFlEhUzQMj9nsV1owRAmEEiNghdMkDOEUy2uwIFQIa3UBw65jFA
vDSKScVdBUBLc2TEK9wxQGmz5tPutAVAG2dMeoslMUAWQH4EiQgGQHvFy6/K
szBAZgymBNxYBkBOB6bPZzQwQMht5d0mpgZAMaEjSpk6MEA6mcUHovAGQAGA
Llgiqi9AlSeDB4A4B0DXiI5JwB8vQE1Dkz7ufQdAQeaw6T/pLkCQQGBSFcEH
QF+JoxUagC1AiC1M0xoCCEBrRaNaZlstQC5hhhMgQQhAPr5J1GvJK0BGqu6p
Q34IQK9h1hT9bipA3EI/hKG5CEBvNmVxacUpQHV70zNT8whAoaOCJNfNKEC+
4ugvcCsJQEVab66RaChAKjnT1g1iCUAXwNplD7wnQG//PYJAlwlAgfYn87bK
JkDNqh9dGssJQKAwMj8AVCVA2pJMb6z9CUDMBctjuG4lQEOMXYUGLwpAmJZv
kWo2JUAFBF1ON18KQN6tRh2HDyVASqAKdkyOCkCyqKJn+K0iQJPqG9U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT99g9G70ZQ7QN64dwvy
SOQ/F5M1lOMqOkDfVqmFon3tPzwyAAJWxDlA/AmBZtBQ8j9hJFwOlB05QIOR
BD6aO/U/Hc7RkiuOOECF+JAQAbP3P+ZXyzM4IDhAZ8hRwvLV+T/VsyCpyvc3
QFqa8FBjuPs/fQv/AoxuN0CrG0W78Wf9PzdGfKX4HzdAXkJExlXu/j93kQbK
ksI2QErxjfBdKQBAIhzthMNuNkAwDFZVS80AQLBVtl2yAzZAaPTEOBFlAUBD
aDoSOoc1QBxYWWJd8gFAMU5RoUhyNUBfwE5WinYCQDDqmsIhCjVAYf4DKbPy
AkBMDX4rUsQ0QLaVvjjCZwNAsIHOraZRNECvqhQXfdYDQJE1uZiY/zNAURxh
nYk/BEBEZfTh7MUzQMj9nsV1owRA+uXMrndkM0DOEUy2uwIFQOslREjCOjNA
vDSKScVdBUAXoLARfasyQGmz5tPutAVAT/sx/LmZMkAWQH4EiQgGQDrGIu+E
MTJAZgymBNxYBkC+03HVzrkxQMht5d0mpgZAEWe2hqp5MUA6mcUHovAGQCZI
fD3g9zBAlSeDB4A4B0AaaJCPc60wQE1Dkz7ufQdApnd3bXmvMECQQGBSFcEH
QMTSKSAqTzBAiC1M0xoCCEABURQjDFgvQC5hhhMgQQhAVXqIdpppLUBGqu6p
Q34IQJ+wHEF+aSxA3EI/hKG5CEADYgN28XwrQHV70zNT8whAvKliSDl4KkC+
4ugvcCsJQEBdj6z5HipAKjnT1g1iCUCvQh4r4dwoQG//PYJAlwlARTvmaBZ6
KEDNqh9dGssJQKkTtbidvidA2pJMb6z9CUAjLpaLZJMmQEOMXYUGLwpAxevN
MuZcJkAFBF1ON18KQNU6nheZyCZASqAKdkyOCkDpUy2a5WgmQL8UH8E=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.05621743658318},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            
            TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.626753389482538`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {31.032218497590705`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8o4nXjLK8oQN64dwvy
SOQ/6J2VUVutKEDfVqmFon3tP1HKr8tpsClA/AmBZtBQ8j+lX4gYuhUpQIOR
BD6aO/U/qstQyO2wKECF+JAQAbP3Py6/ze+hDyhAZ8hRwvLV+T/bNOLDmdQn
QFqa8FBjuPs/gtxPYek7KECrG0W78Wf9P4ZmEwETRihAXkJExlXu/j+RN/7x
z3QnQErxjfBdKQBAkmlSBHrGJ0AwDFZVS80AQG2VT5bckCdAaPTEOBFlAUDA
iYwUy2gnQBxYWWJd8gFAbC7sJY6kJkBfwE5WinYCQOlZzzunRCZAYf4DKbPy
AkBKiQuwFxonQLaVvjjCZwNAkUc9nh9AJkCvqhQXfdYDQAC4GIq1WCVAURxh
nYk/BECtJu06KjclQMj9nsV1owRAMuVM2toRJEDOEUy2uwIFQLAKPV3VaiNA
vDSKScVdBUA9iaFeoJgjQGmz5tPutAVA/YiKXPNsIkAWQH4EiQgGQMJBYpou
xyFAZgymBNxYBkABxIJCKAUhQMht5d0mpgZAWRr8iTJKIUA6mcUHovAGQCFI
scL/tiBAlSeDB4A4B0Cy70Sx/WEgQE1Dkz7ufQdArtIVA3tfIECQQGBSFcEH
QPELJ4ReUR5AiC1M0xoCCEDTSQJgfGkeQC5hhhMgQQhAnnqYm/GkG0BGqu6p
Q34IQFwXcI13TBlA3EI/hKG5CEAFxZ1eDVEYQHV70zNT8whAUp57IyO4FkC+
4ugvcCsJQJ1Qp6yNQxZAKjnT1g1iCUD6J2tzrjYVQG//PYJAlwlAo+eYagKm
E0DNqh9dGssJQN6LzjFKAhFA2pJMb6z9CUDp4iJcXIYRQEOMXYUGLwpA24Se
IE1hEUAFBF1ON18KQKHyJ8HjWxFASqAKdkyOCkDoG7DpocEJQO1lICQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8qFznPRKArQN64dwvy
SOQ/KanfByN5KkDfVqmFon3tPyB9I0El4ypA/AmBZtBQ8j84yBHuHIwqQIOR
BD6aO/U/uCYBusxAKkCF+JAQAbP3P6COy0hZGSpAZ8hRwvLV+T8AHEDtnWkq
QFqa8FBjuPs/+LNichrrKUCrG0W78Wf9P2vgsynJ0ilAXkJExlXu/j+W7RgS
7JEpQErxjfBdKQBAIp15K0deKUAwDFZVS80AQCKkXKNK8ihAaPTEOBFlAUAY
ofvZ6l0oQBxYWWJd8gFAJw/PkXWRKEBfwE5WinYCQCiLIs1/GihAYf4DKbPy
AkCBL4MEUuMnQLaVvjjCZwNAyegJWBROJ0CvqhQXfdYDQJQj+/yx9yZAURxh
nYk/BEA8AqEibM0mQMj9nsV1owRAXGfD27RQJkDOEUy2uwIFQKYabND8PyZA
vDSKScVdBUBzaNEUzWAlQGmz5tPutAVAAHGo6jN6JUAWQH4EiQgGQHrBgKrr
5SRAZgymBNxYBkBrFtIK3TAkQMht5d0mpgZArUxS5CjnI0A6mcUHovAGQCU0
uPkWGSNAlSeDB4A4B0AdBakVLLgiQE1Dkz7ufQdA6hDxqK3uIkCQQGBSFcEH
QEN217xCXiJAiC1M0xoCCEC8oMRd60chQC5hhhMgQQhAcrSB3lEPH0BGqu6p
Q34IQHMe3BjtZx1A3EI/hKG5CED5T64rfeYbQHV70zNT8whAFIjqdmoxGkC+
4ugvcCsJQHbjOeRd0BlAKjnT1g1iCUAXW0ZNsJsXQG//PYJAlwlA+lVJHikj
F0DNqh9dGssJQNjPF9VE9hVA2pJMb6z9CUB75vP+F+4TQEOMXYUGLwpAeGDT
D/rIE0AFBF1ON18KQGASgMCT5BRASqAKdkyOCkBbOsie024UQDnoIJI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=171.256\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481044297357`*^9},ExpressionUUID->"4f29b0be-560b-4db4-8f7a-\
07a05e021a3c"],

Cell[BoxData["19"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448104924692*^9},ExpressionUUID->"a5393048-4b67-4860-b49e-\
91fef1e74c76"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT++i2jPWFEuQN64dwvy
SOQ/TYYiJVCBLUDfVqmFon3tPy+nAIAMrC5A/AmBZtBQ8j98WBVwXikuQIOR
BD6aO/U/jiDjf5xuLkCF+JAQAbP3P4D0FS2x0C1AZ8hRwvLV+T9ZGrJyJx0t
QFqa8FBjuPs/U2kklmh6LUCrG0W78Wf9P/U6/A4YyixAXkJExlXu/j+MSBJ4
b4QsQErxjfBdKQBALc4OD7cgLEAwDFZVS80AQA97CEMz5StAaPTEOBFlAUDH
VTzom24rQBxYWWJd8gFAljyUcV3tKkBfwE5WinYCQLo4GUm7eSpAYf4DKbPy
AkDq1WUfT/sqQLaVvjjCZwNA4qLFtIg4KkCvqhQXfdYDQG8X48sBhClAURxh
nYk/BEDm2BH3ggIpQMj9nsV1owRAjGtuA6c1KEDOEUy2uwIFQHCQUhTsFydA
vDSKScVdBUBMp5NX1GQnQGmz5tPutAVA3Tm80btKJkAWQH4EiQgGQEnRuVq3
eiVAZgymBNxYBkBxJycHUgwlQMht5d0mpgZAKKzKeKuxJEA6mcUHovAGQNxO
1u5vpCRAlSeDB4A4B0AzRysYXPkjQE1Dkz7ufQdAm+uufFvJI0CQQGBSFcEH
QDVDJRG89SJAiC1M0xoCCEDTQdwdh/8iQC5hhhMgQQhAk+q9Qn79IEBGqu6p
Q34IQFffaqSTJiBA3EI/hKG5CEBb4o3+090dQHV70zNT8whAyn4frSdDHkC+
4ugvcCsJQBN1dTDUmB1AKjnT1g1iCUA21QE4SSIcQG//PYJAlwlA2GZ8jg7U
G0DNqh9dGssJQGv/LqBrxBlA2pJMb6z9CUBlXvouJiIYQEOMXYUGLwpAb6OC
HEqKF0AFBF1ON18KQBb/bTtXYhhASqAKdkyOCkABPpTA+ocVQENyGzA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8oBpBDcTYsQN64dwvy
SOQ/D/j4Px6ELUDfVqmFon3tP/Q0FJUT5i1A/AmBZtBQ8j9zgQe0hagtQIOR
BD6aO/U/udKtdVygLUCF+JAQAbP3P/zLTTm2CS5AZ8hRwvLV+T/zfX/n+qIt
QFqa8FBjuPs/ioDLDnPFLUCrG0W78Wf9P8XWE6PSfi1AXkJExlXu/j8RubyX
ufosQErxjfBdKQBAZ6pXLwrCLEAwDFZVS80AQPi9NsefKSxAaPTEOBFlAUDJ
WsK6b+ErQBxYWWJd8gFAEWUKS++GK0BfwE5WinYCQKmCqs1EQytAYf4DKbPy
AkBC+vU0Ku4qQLaVvjjCZwNAVtdnRkqwKkCvqhQXfdYDQH/P4vFQmipAURxh
nYk/BEDV03LI0T0qQMj9nsV1owRAGAgbbFw0KkDOEUy2uwIFQEpPUasixylA
vDSKScVdBUDReRLv34opQGmz5tPutAVA7vp6ezJxKEAWQH4EiQgGQA5MJ3Kd
nyhAZgymBNxYBkAezqNhuUcoQMht5d0mpgZA7yedMftPJ0A6mcUHovAGQLIu
tJaV1SZAlSeDB4A4B0DPrB+AGkQmQE1Dkz7ufQdALm7c6zakJkCQQGBSFcEH
QKyZ1asmRyZAiC1M0xoCCEBX5p+cYJglQC5hhhMgQQhANYb4uxGiI0BGqu6p
Q34IQGBmslWmLyNA3EI/hKG5CEC5vZwd8S4iQHV70zNT8whAkZ14hxt8IUC+
4ugvcCsJQBjiDJstsCBAKjnT1g1iCUCWw8NFbw8gQG//PYJAlwlAsb3ayTtW
HUDNqh9dGssJQC4TL9j/eh5A2pJMb6z9CUBeiaQYPCEbQEOMXYUGLwpAzsfF
sodXGkAFBF1ON18KQDOQDx444h1ASqAKdkyOCkDop1C5ziUdQOilJdA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.3377170719319453`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Hv4kqUMwvQN64dwvy
SOQ/VHize7wdMUDfVqmFon3tP1kpE3yZgjFA/AmBZtBQ8j+LzmBVSJMxQIOR
BD6aO/U/ETMGmebJMUCF+JAQAbP3Pydhsd3ZzTFAZ8hRwvLV+T9fkXqG4MQx
QFqa8FBjuPs/Sz5+ObqnMUCrG0W78Wf9Pz2sr8GffTJAXkJExlXu/j9smGcB
nCEyQErxjfBdKQBAGeJ+IdQ4MkAwDFZVS80AQKeKA6T6GzJAaPTEOBFlAUBM
rHBXr28yQBxYWWJd8gFAWIjSNBbcMUBfwE5WinYCQIabeTwqwjFAYf4DKbPy
AkCvheTBqCYyQLaVvjjCZwNA53bfflGhMUCvqhQXfdYDQGd/yadkZDFAURxh
nYk/BEBhqRXpQHkxQMj9nsV1owRA/NkZ35PSMEDOEUy2uwIFQKgoyktksTBA
vDSKScVdBUClRWBrSMkwQGmz5tPutAVA1pgJYWlOMEAWQH4EiQgGQAb35ypi
GzBAZgymBNxYBkDATENYsp4vQMht5d0mpgZAPQRN+645L0A6mcUHovAGQCtI
k4FK2S5AlSeDB4A4B0A5f/rJLHkuQE1Dkz7ufQdAKL3f+iKsLkCQQGBSFcEH
QE82sl4JFy5AiC1M0xoCCEC05uuwX/MtQC5hhhMgQQhAM+TiwefILEBGqu6p
Q34IQJNi23U7nCtA3EI/hKG5CEA92hj3Li0rQHV70zNT8whAsGtTZWeQKkC+
4ugvcCsJQGrVjxJmrylAKjnT1g1iCUA1nqXuxeIpQG//PYJAlwlAqf3/sNRl
KUDNqh9dGssJQAvALSDISylA2pJMb6z9CUASzI2jAxApQEOMXYUGLwpA43S+
hwBRKUAFBF1ON18KQF9EKGraayhASqAKdkyOCkCrwK1Z9KUkQMADJjA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+j/FPynsUwQN64dwvy
SOQ/kDsqcKoQMUDfVqmFon3tP6DaJp6VcDFA/AmBZtBQ8j/98AZyvvgxQIOR
BD6aO/U/YpoajG41MkCF+JAQAbP3P4JQ8tNKfTJAZ8hRwvLV+T/jrYCqkYcy
QFqa8FBjuPs/pu5Ls1t9MkCrG0W78Wf9P9JKRuq3vDJAXkJExlXu/j8oTrAi
BQEzQErxjfBdKQBAmUNDTQ0HM0AwDFZVS80AQHi+loZFrDJAaPTEOBFlAUAk
Lk3UkMsyQBxYWWJd8gFAYtbPR2mSMkBfwE5WinYCQAz5SyD8zTJAYf4DKbPy
AkAO1QU+NIcyQLaVvjjCZwNArCVimBlTMkCvqhQXfdYDQL3w4UYfVjJAURxh
nYk/BEAdJFkVLloyQMj9nsV1owRAmE3ytMoZMkDOEUy2uwIFQK4I+iPmBTJA
vDSKScVdBUBUqd493e4xQGmz5tPutAVA1GzqTq22MUAWQH4EiQgGQOIIAVik
gTFAZgymBNxYBkCOUMy3z2ExQMht5d0mpgZAptNkGLEUMUA6mcUHovAGQJGF
uyt07jBAlSeDB4A4B0BYrvk4ILwwQE1Dkz7ufQdABAt3xtiwMECQQGBSFcEH
QAWAF86tgTBAiC1M0xoCCEAtw3mO9CUwQC5hhhMgQQhAPd+iSlqAL0BGqu6p
Q34IQBpbD2B8+i5A3EI/hKG5CEC5I5G7JXAuQHV70zNT8whAY6IIetkZLUC+
4ugvcCsJQFLAHPpH1ixAKjnT1g1iCUAkhzcAjEYsQG//PYJAlwlASdQXc1+D
K0DNqh9dGssJQGieq/5NxSpA2pJMb6z9CUDGV5osZ9YqQEOMXYUGLwpAoFVh
DospKkAFBF1ON18KQLo3TCyODSpASqAKdkyOCkCd8lMTXX8pQNJeH1s=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.483712632950013},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT84dwYCm8o6QN64dwvy
SOQ/VyxWtu/3OUDfVqmFon3tPwgDQjDJnzlA/AmBZtBQ8j/zUCUrS9E4QIOR
BD6aO/U/OCB53QV+OECF+JAQAbP3PzPqHjr43jdAZ8hRwvLV+T869HE5HEU3
QFqa8FBjuPs/I821dvACN0CrG0W78Wf9P3macixy5jZAXkJExlXu/j907A87
DFw2QErxjfBdKQBAVCF/kIkNNkAwDFZVS80AQNXQiWaMsjVAaPTEOBFlAUBx
cOk/QYc1QBxYWWJd8gFANWTEbHznNEBfwE5WinYCQJFx2OsJjDRAYf4DKbPy
AkAYC/iL5LA0QLaVvjjCZwNAQHTk3aoVNECvqhQXfdYDQPseA2kpoDNAURxh
nYk/BED/UcpKcmAzQMj9nsV1owRAlr/cCCa6MkDOEUy2uwIFQD9ttRCSODJA
vDSKScVdBUDzzHV12TcyQGmz5tPutAVADQcq4I+TMUAWQH4EiQgGQETemISn
JTFAZgymBNxYBkBpjpa6KMcwQMht5d0mpgZA9rsoEgF9MEA6mcUHovAGQIxJ
30ToTTBAlSeDB4A4B0D0gm/qddovQE1Dkz7ufQdABPKDThWgL0CQQGBSFcEH
QH8jSdIhti5AiC1M0xoCCEBHRVRZgIEuQC5hhhMgQQhA4FQQH46qLEBGqu6p
Q34IQHKakBaUhCtA3EI/hKG5CEA1kcJTIXoqQHV70zNT8whAhjmnJCMrKkC+
4ugvcCsJQAAl5o+egylAKjnT1g1iCUDk+SwM/fQoQG//PYJAlwlAE5wyMvWK
KEDNqh9dGssJQOakwdJ0vSdA2pJMb6z9CUCkl56JuwknQEOMXYUGLwpA0kGZ
AmHhJkAFBF1ON18KQAwpa3aGjSZASqAKdkyOCkCEW/ffGmskQDXIHmI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8creGgHq86QN64dwvy
SOQ/lKtMLBcZOkDfVqmFon3tPwm6fB38iTlA/AmBZtBQ8j9k8KURt/A4QIOR
BD6aO/U/91/mkZ2AOECF+JAQAbP3P72rnbLwTThAZ8hRwvLV+T9CpnLTic43
QFqa8FBjuPs/8e48Qf59N0CrG0W78Wf9P8/Ur2OsMzdAXkJExlXu/j9APYNB
/ec2QErxjfBdKQBADUvdaZOcNkAwDFZVS80AQFy1ge57CzZAaPTEOBFlAUA4
wmOQHM81QBxYWWJd8gFAcO3Wn/1mNUBfwE5WinYCQNai9x3IRTVAYf4DKbPy
AkA66hWditw0QLaVvjjCZwNAMRVOD5WHNECvqhQXfdYDQBWFbIT4WjRAURxh
nYk/BEA/Ij3P8R40QMj9nsV1owRAdyFBrkvaM0DOEUy2uwIFQNPTvMpukDNA
vDSKScVdBUD+1s/9fVUzQGmz5tPutAVAXz34iu7OMkAWQH4EiQgGQCRBP58i
pzJAZgymBNxYBkAgrOK6umMyQMht5d0mpgZA1Rb4oX7fMUA6mcUHovAGQJul
a8apkTFAlSeDB4A4B0CF72eqszgxQE1Dkz7ufQdAEIrFFcg5MUCQQGBSFcEH
QMBOJlUP9DBAiC1M0xoCCEAmJ15jfYUwQC5hhhMgQQhAYpIRFF1ZL0BGqu6p
Q34IQLehsSIGtC5A3EI/hKG5CEAwHaCICLstQHV70zNT8whAixkGKbecLEC+
4ugvcCsJQJYBDpt63ytAKjnT1g1iCUBTfVi7wR8rQG//PYJAlwlAt73Pahnc
KUDNqh9dGssJQKQnpMO6xClA2pJMb6z9CUCZGveg0q0oQEOMXYUGLwpAKhP4
9y3/J0AFBF1ON18KQCvjz9LP+ShASqAKdkyOCkA7tSURK3IoQEQDKjA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.433794627193092},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            
            TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.02891638872692, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.11592776571655, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.195970473390084`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+TuloY1ZcnQN64dwvy
SOQ/HvzCN10TKEDfVqmFon3tP+J9A/Y05ChA/AmBZtBQ8j8aOANqpZYoQIOR
BD6aO/U/cxPnhjruKECF+JAQAbP3PweG/SGOnChAZ8hRwvLV+T8GlcYcHDAo
QFqa8FBjuPs/6tuCxI1ZKECrG0W78Wf9P8LuMvv9wChAXkJExlXu/j8xMzRe
+TgoQErxjfBdKQBAzK4TKPwdKEAwDFZVS80AQOUcxmP/5CdAaPTEOBFlAUCk
511RCP4nQBxYWWJd8gFAedJQ76clJ0BfwE5WinYCQCx9dzVi0SZAYf4DKbPy
AkB1IL2PLXcnQLaVvjjCZwNAUO6mjeiXJkCvqhQXfdYDQHXyEGq4/iVAURxh
nYk/BECAWnwIdMwlQMj9nsV1owRANyPxSJvLJEDOEUy2uwIFQJ89ZbG/DyRA
vDSKScVdBUDYjfnsnk8kQGmz5tPutAVAuN30wmlII0AWQH4EiQgGQFFZPq5R
qiJAZgymBNxYBkDKxXe0yCoiQMht5d0mpgZADgI1ndLPIUA6mcUHovAGQN4K
laZrqCFAlSeDB4A4B0DoXEIA2hwhQE1Dkz7ufQdAMhXbj1wWIUCQQGBSFcEH
QGxeEU+aXiBAiC1M0xoCCEB1QugwXVogQC5hhhMgQQhAITDh8WFoHUBGqu6p
Q34IQOqyYFNbdhtA3EI/hKG5CEAfNlZpkboZQHV70zNT8whA+3H3Yq9zGUC+
4ugvcCsJQGXBRJSBeBhAKjnT1g1iCUAAKnV+OKoXQG//PYJAlwlAIMsAIb8m
F0DNqh9dGssJQF7XpHI71RVA2pJMb6z9CUBjlBa6br0UQEOMXYUGLwpAiA7x
rQ23FEAFBF1ON18KQHGzHz0aVxRASqAKdkyOCkDO+l5z7FoQQG//INk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+HzoBa+LcpQN64dwvy
SOQ/H7zjgYY6KkDfVqmFon3tP0V5baKtUypA/AmBZtBQ8j+FskbF0h4qQIOR
BD6aO/U/+kJFnE0QKkCF+JAQAbP3PyaNK46fXypAZ8hRwvLV+T/0zKU30QUq
QFqa8FBjuPs/sX8EDMT5KUCrG0W78Wf9PwQ9+oci7ClAXkJExlXu/j8EZwng
/9ApQErxjfBdKQBA91keb4ysKUAwDFZVS80AQM4b6hYz9yhAaPTEOBFlAUDd
10hvFuUoQBxYWWJd8gFAa/uuaaN1KEBfwE5WinYCQID0C6stiihAYf4DKbPy
AkCgiSml5gwoQLaVvjjCZwNAfrC0XHa1J0CvqhQXfdYDQNzW58JGqCdAURxh
nYk/BEDHMhN663cnQMj9nsV1owRACDcNb5s3J0DOEUy2uwIFQN02THqZ5iZA
vDSKScVdBUCQEFPdnbAmQGmz5tPutAVACk/AVPngJUAWQH4EiQgGQOHxXdRZ
zSVAZgymBNxYBkAYi/fB4IAlQMht5d0mpgZAeDOK626wJEA6mcUHovAGQFA5
54RBSSRAlSeDB4A4B0A/W0n8P8sjQE1Dkz7ufQdA46tujf//I0CQQGBSFcEH
QDNuaxxSpSNAiC1M0xoCCEByTVlbNPgiQC5hhhMgQQhANkHyzll1IUBGqu6p
Q34IQJV/WWOb/CBA3EI/hKG5CEC8Ax172S8gQHV70zNT8whAlQkuGGN0HkC+
4ugvcCsJQBxq6SgpTB1AKjnT1g1iCUB9djGErhwcQG//PYJAlwlAr1e1ZCrl
GUDNqh9dGssJQIRgDkVV/hlA2pJMb6z9CUD0J2POcRsYQEOMXYUGLwpAp89h
0iUKF0AFBF1ON18KQK//cXt1RhlASqAKdkyOCkCMbHAdYn4YQETyIpY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=181.256\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448105264982*^9},ExpressionUUID->"524dd56d-232e-4e96-b9ee-\
eeef3325a3df"],

Cell[BoxData["20"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481057434654`*^9},ExpressionUUID->"8bf9d0c6-8c8f-4b77-b033-\
74963eaec831"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9HVOCleukuQN64dwvy
SOQ/EiarUbHvLUDfVqmFon3tP6rbgnziUC5A/AmBZtBQ8j8ZDufq1fQtQIOR
BD6aO/U/HR4C/u7aLUCF+JAQAbP3P0Mtgbnawy1AZ8hRwvLV+T/FKiQOKBgt
QFqa8FBjuPs/BWVntEAxLUCrG0W78Wf9P2a1Zs2joi1AXkJExlXu/j96slCS
rVEsQErxjfBdKQBARFSc4TIPLEAwDFZVS80AQLwm2lwqCSxAaPTEOBFlAUC5
KWLujCksQBxYWWJd8gFAHxj2L2FWK0BfwE5WinYCQLg8L3VNxipAYf4DKbPy
AkC+mirma5ArQLaVvjjCZwNAiXUA4mM4KkCvqhQXfdYDQNIAlH8WBylAURxh
nYk/BEBGNV5uVzgpQMj9nsV1owRAYdnbRXJcKEDOEUy2uwIFQFlplX/95ydA
vDSKScVdBUAfU165DtQnQGmz5tPutAVAMsddxN6iJkAWQH4EiQgGQF+SAtbH
/yVAZgymBNxYBkDdZ6zUCIAlQMht5d0mpgZAD6Kp6ANUJUA6mcUHovAGQDf7
8slopyRAlSeDB4A4B0Du6eUTVLEkQE1Dkz7ufQdAeIvyBRAmJECQQGBSFcEH
QH7mALnhJiRAiC1M0xoCCECjH8Nv/5gjQC5hhhMgQQhABYfY30JgIkBGqu6p
Q34IQAahiI+oWCFA3EI/hKG5CEAnU0Tm3ZYgQHV70zNT8whApKuEa7nzH0C+
4ugvcCsJQHchzxmPwR5AKjnT1g1iCUABD+4ZkOoeQG//PYJAlwlAyBg4yl0u
HUDNqh9dGssJQDS00PSwJh1A2pJMb6z9CUCo+Ls2oXwbQEOMXYUGLwpAMP/4
zo06G0AFBF1ON18KQGgyut3wOxtASqAKdkyOCkD03j7KmHwYQOopI8k=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/oFKj+fPMtQN64dwvy
SOQ/YgKNSNyhLkDfVqmFon3tP7xUjbOjpy5A/AmBZtBQ8j90SMG6yA0uQIOR
BD6aO/U/BVe/yLWTLUCF+JAQAbP3P0XI0GDNdy1AZ8hRwvLV+T/9LOnBCPYs
QFqa8FBjuPs/0d4DiLS5LUCrG0W78Wf9P2mHJ+LPMC1AXkJExlXu/j/1ZYSU
kx0tQErxjfBdKQBAs424QXvfLEAwDFZVS80AQIUMifImcyxAaPTEOBFlAUDl
ozZQ460sQBxYWWJd8gFA+yzzAvBfLEBfwE5WinYCQGGGkFSjDCxAYf4DKbPy
AkDG7KuQbbQrQLaVvjjCZwNAutiCeUSoK0CvqhQXfdYDQCKmE7xk1CpAURxh
nYk/BEDadeVUmYQqQMj9nsV1owRA8vR4vk0/KkDOEUy2uwIFQB2kHjoW3ylA
vDSKScVdBUDWjNL0kkkpQGmz5tPutAVAB0drwquyKEAWQH4EiQgGQANzYpaI
sShAZgymBNxYBkDzP4LwCyQoQMht5d0mpgZAWTMbOVTgJ0A6mcUHovAGQOse
9gUDCidAlSeDB4A4B0Aq4Xwdv8UmQE1Dkz7ufQdASYRVDuZwJ0CQQGBSFcEH
QMax7xHhQCZAiC1M0xoCCEAPxwgcmW4lQC5hhhMgQQhAxeQfaoSXJEBGqu6p
Q34IQHEZHYAPCyRA3EI/hKG5CEC8CV+4RZ4iQHV70zNT8whAlnf0nQ2hIUC+
4ugvcCsJQLMsDKN8DSFAKjnT1g1iCUBBKHgs3FYgQG//PYJAlwlA+pH5D4qE
IEDNqh9dGssJQFvHlIUt8RxA2pJMb6z9CUABFQiLC8EdQEOMXYUGLwpAyX8B
G6ASG0AFBF1ON18KQEBX+Af1KxxASqAKdkyOCkDcX0pdCfgcQAizIi0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.6586103663680474`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/jAFlL9sEvQN64dwvy
SOQ/9nPPT78MMUDfVqmFon3tP3Hmq7gcuDFA/AmBZtBQ8j/cMD+PMqUxQIOR
BD6aO/U/m8eNuPkGMkCF+JAQAbP3PxrSiqwcrzFAZ8hRwvLV+T/9JW7EeMwx
QFqa8FBjuPs/8h+gfJBRMkCrG0W78Wf9Pw7kCOmiFjJAXkJExlXu/j/8DCtj
SmcyQErxjfBdKQBA+HAaVd9JMkAwDFZVS80AQPDZB52GMDJAaPTEOBFlAUDb
uyuXzVYyQBxYWWJd8gFACxPDVTLoMUBfwE5WinYCQPwCS0Xb9DFAYf4DKbPy
AkBshG45ljQyQLaVvjjCZwNA6RXDyHMCMkCvqhQXfdYDQNZy9Zoj5TFAURxh
nYk/BEBYwV7FY4wxQMj9nsV1owRANRWKynOBMUDOEUy2uwIFQDk2hzCl7zBA
vDSKScVdBUBn92teaQcxQGmz5tPutAVA2sjoTIO9MEAWQH4EiQgGQL0zkigP
XzBAZgymBNxYBkBpQ5N+URwwQMht5d0mpgZArPOgI/zcL0A6mcUHovAGQEI0
9HUKuy9AlSeDB4A4B0B/yslQUP0uQE1Dkz7ufQdAOMhE+9RSL0CQQGBSFcEH
QBazTnYtwS5AiC1M0xoCCEDc/oEhiI0uQC5hhhMgQQhA0kg1RGEfLUBGqu6p
Q34IQN/hjTrwqixA3EI/hKG5CECptC1JZ2ksQHV70zNT8whAcRpeffcmLEC+
4ugvcCsJQFQfVV0L6CpAKjnT1g1iCUAzumBOS8QqQG//PYJAlwlAr+gIy/nW
KUDNqh9dGssJQBoySVB8silA2pJMb6z9CUCRmRASZ0EqQEOMXYUGLwpAYW+Q
9gA/KkAFBF1ON18KQBYLPJt+FSpASqAKdkyOCkCPIi1AwUopQDwpIQg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9teVySdGAwQN64dwvy
SOQ/b3bu7/oqMUDfVqmFon3tPw8kGzwJejFA/AmBZtBQ8j/+5MqSeAgyQIOR
BD6aO/U/Cp7jNDY3MkCF+JAQAbP3P6dDjoL4UTJAZ8hRwvLV+T+sjp6DT9Qx
QFqa8FBjuPs/csZo1BDPMkCrG0W78Wf9P0L/phNyfTJAXkJExlXu/j9/vVkR
eIMyQErxjfBdKQBA2d+WqUuAMkAwDFZVS80AQD9P8S+EgTJAaPTEOBFlAUCD
aTZMzb8yQBxYWWJd8gFA0fkur3qZMkBfwE5WinYCQOBA5ZxwwTJAYf4DKbPy
AkAD3MLBefsyQLaVvjjCZwNAC2N4nnW3MkCvqhQXfdYDQGmaWMtAXDJAURxh
nYk/BEBvoYwTJfkxQMj9nsV1owRAVy7pQIJGMkDOEUy2uwIFQFJCGmeKFzJA
vDSKScVdBUBkNoGcVy8yQGmz5tPutAVAqgNpbTDIMUAWQH4EiQgGQGu9E6Mz
tTFAZgymBNxYBkBHbdFgjWkxQMht5d0mpgZAgcC3I9xWMUA6mcUHovAGQGSR
Uo07HzFAlSeDB4A4B0BExnOgWN8wQE1Dkz7ufQdACu0vwf0RMUCQQGBSFcEH
QE/2UiNGjDBAiC1M0xoCCECiYYifOW4wQC5hhhMgQQhAKR4Vr8HTL0BGqu6p
Q34IQEmFxCusSC9A3EI/hKG5CECR+0wr8cAuQHV70zNT8whA1TM2DwjSLUC+
4ugvcCsJQNMPLSgX+CxAKjnT1g1iCUD59pEEWF0sQG//PYJAlwlAOm+Rp/qZ
KkDNqh9dGssJQC39LL8gFSxA2pJMb6z9CUCLi6oWhfkqQEOMXYUGLwpAe3nD
waPhKUAFBF1ON18KQNhjOdnTmypASqAKdkyOCkBZCd0DAmAoQNRDIKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 5.292970675008005},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {22.1095601980663, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/6SWqtj/M6QN64dwvy
SOQ/YKFOgEsKOkDfVqmFon3tP8dMj21QqTlA/AmBZtBQ8j/HQGchn9A4QIOR
BD6aO/U/CGsnInx4OECF+JAQAbP3Pyqykh0vzDdAZ8hRwvLV+T+D3Uyk0Ug3
QFqa8FBjuPs/zOqRLD84N0CrG0W78Wf9PxT7S1XL7TZAXkJExlXu/j8Lxh50
xnI2QErxjfBdKQBAAMDCxlETNkAwDFZVS80AQKU8ah5RxTVAaPTEOBFlAUA4
7xw9gKg1QBxYWWJd8gFATz72Mg0LNUBfwE5WinYCQGHGVahbuDRAYf4DKbPy
AkCeTRXf/d80QLaVvjjCZwNAX3/c4+ZBNECvqhQXfdYDQCIQZSKmwTNAURxh
nYk/BEAWYcU46HYzQMj9nsV1owRAwfkm9I4UM0DOEUy2uwIFQLvelllrjTJA
vDSKScVdBUC8AnFxb3IyQGmz5tPutAVAtyHDukjeMUAWQH4EiQgGQO2dv5ZM
aDFAZgymBNxYBkD0rMG2JwkxQMht5d0mpgZA7syf/zLOMEA6mcUHovAGQPv/
G+RXezBAlSeDB4A4B0Axm7fiOEAwQE1Dkz7ufQdARi+84XINMECQQGBSFcEH
QJsWzIm4tS9AiC1M0xoCCEA2tAz6oRsvQC5hhhMgQQhAeHz5DdqkLUBGqu6p
Q34IQBgD9lRpqCxA3EI/hKG5CEB74U+TyfArQHV70zNT8whAJh7AigJSK0C+
4ugvcCsJQCgHh0L3TSpAKjnT1g1iCUAmeRsfNCoqQG//PYJAlwlAmYSF3csj
KUDNqh9dGssJQJ5aHQv49ShA2pJMb6z9CUDtjzx2vX0oQEOMXYUGLwpAgU49
7/tFKEAFBF1ON18KQGSTJ1tNEyhASqAKdkyOCkBu11aBUtEmQHPZIq8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/1zuXf+S47QN64dwvy
SOQ/OgYaPyV5OkDfVqmFon3tPwc+BQFFujlA/AmBZtBQ8j9p5zShpg05QIOR
BD6aO/U/vJHX1Zt3OECF+JAQAbP3PxPGLVhRCThAZ8hRwvLV+T++OEo75Eo3
QFqa8FBjuPs/wy0n66CYN0CrG0W78Wf9P+3eNhpb/zZAXkJExlXu/j9GLvl/
DrU2QErxjfBdKQBAHtz3ZyFjNkAwDFZVS80AQLgEfd+eCTZAaPTEOBFlAUBU
EfSqRv01QBxYWWJd8gFAPWSFCjimNUBfwE5WinYCQAKFHQUwcDVAYf4DKbPy
AkDDBjfH+Ek1QLaVvjjCZwNA4nnbcTv4NECvqhQXfdYDQGWIwWV3bDRAURxh
nYk/BEBt+681gQc0QMj9nsV1owRAtQwmMaXwM0DOEUy2uwIFQPeiy+ePnTNA
vDSKScVdBUCQQzBGr2EzQGmz5tPutAVAI7a4RKPnMkAWQH4EiQgGQJFXxXBq
wDJAZgymBNxYBkA+0aYnFFsyQMht5d0mpgZAFoA0O0wkMkA6mcUHovAGQGT9
PABNtDFAlSeDB4A4B0AgytQmBWwxQE1Dkz7ufQdAk8z4sPqcMUCQQGBSFcEH
QPgSETZO9DBAiC1M0xoCCEB1XKooXpEwQC5hhhMgQQhAL8rwmxIGMEBGqu6p
Q34IQGZCuoT8Vi9A3EI/hKG5CECQquuQTBwuQHV70zNT8whAJp70AJX7LEC+
4ugvcCsJQMYdmduGIixAKjnT1g1iCUCmcpqbAlArQG//PYJAlwlAF/NytzrK
KkDNqh9dGssJQLOwLtkQ7SlA2pJMb6z9CUBx+8u3WnYpQEOMXYUGLwpAREXQ
GpoUKEAFBF1ON18KQJWyppbxkihASqAKdkyOCkCOti+ulScoQLqCIJU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 4.954793038777975},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            
            TemplateBox[{"10", "10"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.02891638872692, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.11592776571655, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.195970473390084`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.270078445543806`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.339071317030758`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.40360983816833, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.464234459984763`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {30.521392873824713`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/dammZTvMnQN64dwvy
SOQ/OqyJSm81KEDfVqmFon3tP9qJUKgA+ChA/AmBZtBQ8j/2MNjV+ZQoQIOR
BD6aO/U/b18tUBrjKECF+JAQAbP3P9OZrvHheChAZ8hRwvLV+T8TO8p1bjYo
QFqa8FBjuPs/jiEcBsDEKECrG0W78Wf9P1Xg8gY50ChAXkJExlXu/j/IBzcT
12goQErxjfBdKQBAyXJHenwoKEAwDFZVS80AQInwyxOoCChAaPTEOBFlAUAo
yursREAoQBxYWWJd8gFA+DAhwGdsJ0BfwE5WinYCQIuXkZ6OKidAYf4DKbPy
AkBqHftkj9QnQLaVvjjCZwNAbXwAulHvJkCvqhQXfdYDQJfwDD0RQiZAURxh
nYk/BEC/jOOujPklQMj9nsV1owRAGcsy55qAJUDOEUy2uwIFQDuOzq2BuSRA
vDSKScVdBUDqcXmWOMUkQGmz5tPutAVA2P7owWPeI0AWQH4EiQgGQCVDosSd
LyNAZgymBNxYBkDN2iM//68iQMht5d0mpgZAxjSWe2ByIkA6mcUHovAGQKxh
6ZKxAiJAlSeDB4A4B0C+AcsDRsMhQE1Dkz7ufQdAylvQVhSRIUCQQGBSFcEH
QOOLwEA7XiFAiC1M0xoCCEAlDuKSG/QgQC5hhhMgQQhAkkNQu+5cH0BGqu6p
Q34IQJ/6EDXtvx1A3EI/hKG5CEDOHZARaagcQHV70zNT8whAxm5TpqfAG0C+
4ugvcCsJQEyWB81gDRpAKjnT1g1iCUCAlkeVJhUaQG//PYJAlwlAjsPVbk5Z
GEDNqh9dGssJQK4u4YG+RxhA2pJMb6z9CUCAxRBEKKYXQEOMXYUGLwpAP+Jv
YMWAF0AFBF1ON18KQOP2X8iQYhdASqAKdkyOCkDsVRn9VycVQNG4JcY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9i4h0unzEqQN64dwvy
SOQ/267Qlp97KkDfVqmFon3tPyXaNzUoQypA/AmBZtBQ8j/V4dAdavEpQIOR
BD6aO/U/gmt3cJGiKUCF+JAQAbP3P4UpAuJOiClAZ8hRwvLV+T/esBlv6Lgo
QFqa8FBjuPs/nz4qcQfvKUCrG0W78Wf9P17m5GPVSilAXkJExlXu/j+rOadR
JzopQErxjfBdKQBAnDCeeAANKUAwDFZVS80AQITJZTlFzChAaPTEOBFlAUCT
+vAtHh4pQBxYWWJd8gFAJR2/kwzQKEBfwE5WinYCQESWCJyqwShAYf4DKbPy
AkBDHKdFds0oQLaVvjjCZwNA1BDNuxR9KECvqhQXfdYDQLvlVQgptidAURxh
nYk/BEAEqimwGTcnQMj9nsV1owRAZFGJ+2NQJ0DOEUy2uwIFQJhd8Un27yZA
vDSKScVdBUAlLKO9ErkmQGmz5tPutAVAU2PJRNkDJkAWQH4EiQgGQAxU8nbK
8iVAZgymBNxYBkDjw6HX1GIlQMht5d0mpgZA69W2a8UtJUA6mcUHovAGQH6A
j/uEgyRAlSeDB4A4B0CJ8opDwyckQE1Dkz7ufQdATSh/sDy8JECQQGBSFcEH
QFqjQES3nCNAiC1M0xoCCEAnsTTX4QYjQC5hhhMgQQhAC+wwy64fIkBGqu6p
Q34IQJzArcEClyFA3EI/hKG5CEDF7HFTT4kgQHV70zNT8whAD4naHnclH0C+
4ugvcCsJQOuS/dYmxx1AKjnT1g1iCUCKEbqF0HEcQG//PYJAlwlAWJpB+ou1
G0DNqh9dGssJQHr8Gsl0RBpA2pJMb6z9CUBpnp445qIZQEOMXYUGLwpAdi3X
d5QqF0AFBF1ON18KQMbGPjl9bBhASqAKdkyOCkAfu9biu98XQPGbJDU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=191.257\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.7174481068784995`*^9},ExpressionUUID->"4d3d4c6e-9526-485d-b780-\
6a9f55620ae1"],

Cell[BoxData["21"], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448107370051*^9},ExpressionUUID->"6ea29a49-d75f-4d43-8627-\
6c71043d48ba"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9KXDHrAF0uQN64dwvy
SOQ/GbAyPRLhLkDfVqmFon3tP9KHM6G5UC5A/AmBZtBQ8j8/85TE9dctQIOR
BD6aO/U/RWorH90uLkCF+JAQAbP3P7M+ESUUsy1AZ8hRwvLV+T8nwsD/hGQt
QFqa8FBjuPs/7XXKysHPLECrG0W78Wf9Px+VV8HgVC1AXkJExlXu/j9dtD/i
9rssQErxjfBdKQBA3GCC8yNMLEAwDFZVS80AQNaP1D99QyxAaPTEOBFlAUBy
nuK9wtAsQBxYWWJd8gFAQUxlFKeiK0BfwE5WinYCQOte6aksNStAYf4DKbPy
AkDlo6xo7GUrQLaVvjjCZwNAqdCugMfQKkCvqhQXfdYDQMopala56ilAURxh
nYk/BEBt1r35tlYpQMj9nsV1owRAmahLt9osKUDOEUy2uwIFQHKf1S7+JihA
vDSKScVdBUCSntZmQvknQGmz5tPutAVAcDVoeXQ/J0AWQH4EiQgGQABTtbuT
gyZAZgymBNxYBkAFeZx4dCUmQMht5d0mpgZAZqhbbeljJUA6mcUHovAGQP5D
25/FaiVAlSeDB4A4B0C1GjXV+MokQE1Dkz7ufQdAhw60if7LJECQQGBSFcEH
QCvshViBuSRAiC1M0xoCCEB9RwHrjy8kQC5hhhMgQQhAdRc0DFK/IkBGqu6p
Q34IQA7mQBODRyJA3EI/hKG5CEDQC13O4mshQHV70zNT8whAjdSasJmeIEC+
4ugvcCsJQJLjoKvZWiBAKjnT1g1iCUBl3yNuFfQfQG//PYJAlwlAdza8zsvD
HUDNqh9dGssJQCyW6csTDh1A2pJMb6z9CUBlirJDdlQcQEOMXYUGLwpAjLSG
YIZKG0AFBF1ON18KQJckB9NAGxxASqAKdkyOCkCKaUALwvAbQFejKKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+HsXDYWn0uQN64dwvy
SOQ/o6Zzs2cgLUDfVqmFon3tP11ZwcJAqi5A/AmBZtBQ8j+Jejb2TX4uQIOR
BD6aO/U/Q6u5Lp9eLkCF+JAQAbP3PxKCKZOGfC1AZ8hRwvLV+T+t8I2gMF0t
QFqa8FBjuPs/uiJrIIyCLUCrG0W78Wf9PwXJQskZKS1AXkJExlXu/j+aopIc
j04tQErxjfBdKQBAUDyITqCpLEAwDFZVS80AQK96ffcDbCxAaPTEOBFlAUD+
UaJOXgUsQBxYWWJd8gFAXA3+le20LEBfwE5WinYCQMAtyv6zZyxAYf4DKbPy
AkDwWOoNwRAsQLaVvjjCZwNAbnckyUV6K0CvqhQXfdYDQNrdV+BlCitAURxh
nYk/BEAVN/dIKMAqQMj9nsV1owRAYdfOi/rMKkDOEUy2uwIFQMpRnr09rSpA
vDSKScVdBUA+xOstJJspQGmz5tPutAVAMxoLcjdgKUAWQH4EiQgGQI5vhdQR
VSlAZgymBNxYBkBx/M3w7YUoQMht5d0mpgZAh4N5XTgeKEA6mcUHovAGQFme
pv3b/CdAlSeDB4A4B0AsqthvT68nQE1Dkz7ufQdAb7cJiZo+J0CQQGBSFcEH
QG1da+TjTSdAiC1M0xoCCEDt9qeXRl0mQC5hhhMgQQhAYcf4uPeIJEBGqu6p
Q34IQOaAaPpqWyRA3EI/hKG5CEBErKXN/0YkQHV70zNT8whAdf1RGmvIIkC+
4ugvcCsJQHacj/+tSiJAKjnT1g1iCUArIbgZ77ggQG//PYJAlwlApQNHMkWd
HkDNqh9dGssJQJTGt4QZSyBA2pJMb6z9CUAHi4Fw0y8gQEOMXYUGLwpAa8Zk
BdlyHkAFBF1ON18KQKu9tMp6eB9ASqAKdkyOCkDSUHNqYzAdQNBgJkM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 2.9630949377485565`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {194.4, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+b1f97DgIwQN64dwvy
SOQ/AAtI+TW5MEDfVqmFon3tP2UpIfrLLzFA/AmBZtBQ8j/WrnfAveoxQIOR
BD6aO/U/+7pBA8SjMUCF+JAQAbP3P+tmhoinrzFAZ8hRwvLV+T/pnfo6UOYx
QFqa8FBjuPs/v5lJjXZCMkCrG0W78Wf9Px2f4y+vaTJAXkJExlXu/j+aWiSl
NUkyQErxjfBdKQBA63GaERN7MkAwDFZVS80AQNe4IFAeOTJAaPTEOBFlAUAm
FzDf0CsyQBxYWWJd8gFAQ+sy2RU7MkBfwE5WinYCQMf0Sow+NDJAYf4DKbPy
AkCvB62JSjIyQLaVvjjCZwNAdgbOZH/eMUCvqhQXfdYDQId9TTze0DFAURxh
nYk/BEBy6/tRObYxQMj9nsV1owRAju8ZzSQqMUDOEUy2uwIFQH+6aO7rRTFA
vDSKScVdBUAFbvQeSE4xQGmz5tPutAVAjYVEJ4i1MEAWQH4EiQgGQDVFWCq4
qTBAZgymBNxYBkCHbk8o+00wQMht5d0mpgZABP1NG+N9MEA6mcUHovAGQPoY
CPgDATBAlSeDB4A4B0BTR1iiTp0vQE1Dkz7ufQdAQ1eynxhdL0CQQGBSFcEH
QN0bKlYNIi9AiC1M0xoCCEAnx7QcGMEuQC5hhhMgQQhAb3pyG90bLkBGqu6p
Q34IQPzGZ1HxhC1A3EI/hKG5CEDTJ6kiSzstQHV70zNT8whATd7G+Pm9LEC+
4ugvcCsJQCBGkd6uritAKjnT1g1iCUDrT+2SMRssQG//PYJAlwlASoX3hzza
K0DNqh9dGssJQNcgTnRksSpA2pJMb6z9CUCkUkSIanYqQEOMXYUGLwpAKEy4
rTnGKkAFBF1ON18KQE595XquaSpASqAKdkyOCkC8IB7f964nQBIgIBs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9DcSQD6UIwQN64dwvy
SOQ/RD3ib80KMUDfVqmFon3tP4Pz0rvXSzFA/AmBZtBQ8j8iYJ6PAfsxQIOR
BD6aO/U/iT+lWxzmMUCF+JAQAbP3P4TVhmZ/YjJAZ8hRwvLV+T+8QD9f5PIx
QFqa8FBjuPs/dn2I0kYqMkCrG0W78Wf9P7Fi34IUmzJAXkJExlXu/j8LD39u
O5wyQErxjfBdKQBA7PM/KPOIMkAwDFZVS80AQMuQA3odjDJAaPTEOBFlAUBG
1F4cbeQyQBxYWWJd8gFAaeoZvELWMkBfwE5WinYCQF/kz6655DJAYf4DKbPy
AkDTJDa7fKIyQLaVvjjCZwNAungrpvWPMkCvqhQXfdYDQLhsg5xpeTJAURxh
nYk/BEBr2eieSHEyQMj9nsV1owRAN3GUSDJwMkDOEUy2uwIFQBm0UXPHNDJA
vDSKScVdBUD0I7rUC0AyQGmz5tPutAVA3d32leboMUAWQH4EiQgGQMe3q118
qzFAZgymBNxYBkCqjWR/15AxQMht5d0mpgZAD440ZaybMUA6mcUHovAGQOgf
eBmVVTFAlSeDB4A4B0DPB/degSwxQE1Dkz7ufQdAuLIMAtxFMUCQQGBSFcEH
QKphu/jF/TBAiC1M0xoCCEBvJYN+R6wwQC5hhhMgQQhA94ivnllWMEBGqu6p
Q34IQD7vn92tAjBA3EI/hKG5CEBc9U9Hv7ovQHV70zNT8whAxX8EHyYHL0C+
4ugvcCsJQKIH9tW74y1AKjnT1g1iCUCdkhItd30tQG//PYJAlwlAkG+UWtDB
LEDNqh9dGssJQJZtmhSAnytA2pJMb6z9CUDTwwM6rh4sQEOMXYUGLwpAzWwe
nJwyK0AFBF1ON18KQG4u7aPyLitASqAKdkyOCkCSxmNoHCYqQMVeJ04=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 5.142800105804853},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            
            TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            
            TemplateBox[{"10", "8"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.600902459542082, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.006367567650246, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.294049640102028, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.517193191416238, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.699514748210191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.85366542803745, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {8.987196820661973, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.104979856318357, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.903487552536127, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.308952660644293`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.596634733096073`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {10.819778284410283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.002099841204238`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.156250521031495`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.289781913656018`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.407564949312402`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.206072645530174`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.611537753638338`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {12.89921982609012, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.122363377404328`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.304684934198283`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.458835614025542`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.592367006650065`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.710150042306449`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.508657738524219`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {14.914122846632385`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.201804919084164`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.424948470398375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.60727002719233, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.761420707019587`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {15.89495209964411, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.012735135300492`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.216707939626428`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.50439001207821, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.72753356339242, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.909855120186375`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.064005800013632`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.197537192638155`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.31532022829454, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.11382792451231, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.519293032620475`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {19.806975105072254`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.030118656386467`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.21244021318042, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.36659089300768, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.5001222856322, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.617905321288585`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.416413017506358`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {21.82187812561452, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {22.1095601980663, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {583.2, -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360.00000000000006, 222.49223594996212}], 
    InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8Fz7EEydg6QN64dwvy
SOQ/tL+MHEYhOkDfVqmFon3tPws16sTiVjlA/AmBZtBQ8j/firc15vU4QIOR
BD6aO/U/Ad3Hj5BbOECF+JAQAbP3P4cKISuEyTdAZ8hRwvLV+T+j9p6cb2k3
QFqa8FBjuPs/mCB7qZYaN0CrG0W78Wf9P4qPaIJW/TZAXkJExlXu/j8tidd5
03s2QErxjfBdKQBAsCOXb3E7NkAwDFZVS80AQCBldHXI2DVAaPTEOBFlAUCR
i4kFlsk1QBxYWWJd8gFAqbnGCKJENUBfwE5WinYCQLqySegE9DRAYf4DKbPy
AkCwONzga9M0QLaVvjjCZwNAxdJQxExbNECvqhQXfdYDQIQXt4Zq7DNAURxh
nYk/BEB7wNkj4JIzQMj9nsV1owRARr4BEeAoM0DOEUy2uwIFQIAnNQk9xTJA
vDSKScVdBUCfCeBtJ50yQGmz5tPutAVA1411FDkGMkAWQH4EiQgGQB7wl1K8
rTFAZgymBNxYBkABZ0Vk/00xQMht5d0mpgZAu15BKYoUMUA6mcUHovAGQLt+
AhJLwzBAlSeDB4A4B0D6NJzmU2UwQE1Dkz7ufQdAuyNVGz9CMECQQGBSFcEH
QPkpH933GzBAiC1M0xoCCEDfxvi8JJAvQC5hhhMgQQhApY9NFl09LkBGqu6p
Q34IQLWPVoNdji1A3EI/hKG5CED3sohUZMQsQHV70zNT8whAOmny7+HwK0C+
4ugvcCsJQIV2Um5bNStAKjnT1g1iCUBLWaX5ff4qQG//PYJAlwlAyf1u0Dwj
KkDNqh9dGssJQPmJ5bguRilA2pJMb6z9CUDdcmBuRdIoQEOMXYUGLwpAFmEP
sJGJKEAFBF1ON18KQDJmSFqVdyhASqAKdkyOCkByF7b0KZknQBvoJQI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+OlwOV0xE7QN64dwvy
SOQ/TgiY6mvROUDfVqmFon3tPzwBr5sViTlA/AmBZtBQ8j8ptapHgiA5QIOR
BD6aO/U/S78XXC+FOECF+JAQAbP3P86i5DRbEzhAZ8hRwvLV+T/oNg5bsGw3
QFqa8FBjuPs/dhRBBsY6N0CrG0W78Wf9P6xVFPB2CDdAXkJExlXu/j88cpYV
Scs2QErxjfBdKQBANTt6bRFYNkAwDFZVS80AQO0SWGP+CzZAaPTEOBFlAUCI
RTCbueo1QBxYWWJd8gFA38PuKAbWNUBfwE5WinYCQBDTmiFfmTVAYf4DKbPy
AkDl0wmL/jQ1QLaVvjjCZwNAAaUfMmLZNECvqhQXfdYDQEV2mfZ2hzRAURxh
nYk/BEBQG8dGoUo0QMj9nsV1owRAuBjca2coNEDOEUy2uwIFQJERwG2+5DNA
vDSKScVdBUDwLju3o30zQGmz5tPutAVAQYCwpTMlM0AWQH4EiQgGQLEIdgtD
7DJAZgymBNxYBkAI+wbPYYYyQMht5d0mpgZAAosek0lSMkA6mcUHovAGQCSf
rC3VEDJAlSeDB4A4B0AUkejgltAxQE1Dkz7ufQdAcogwThehMUCQQGBSFcEH
QGn+xnx2cjFAiC1M0xoCCEBPPlMJQPEwQC5hhhMgQQhAg2bAZ+YvMEBGqu6p
Q34IQJSqrQUXzi9A3EI/hKG5CEDJosFn9novQHV70zNT8whAIs93FrApLkC+
4ugvcCsJQE07XElsPy1AKjnT1g1iCUD8u2zI/QgsQG//PYJAlwlAB0fnSGvS
KkDNqh9dGssJQF91dlx5vSpA2pJMb6z9CUC8rpepk7QqQEOMXYUGLwpAznr+
QrefKUAFBF1ON18KQGwDdOfx1ylASqAKdkyOCkDU9Kl8I5woQMYHHdo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 5.124304964468561},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            
            TemplateBox[{"10", "9"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {27.631021115928547`, 
           FormBox[
            
            TemplateBox[{"10", "12"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {29.933606208922594`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {972., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0., 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+/37W8qbMnQN64dwvy
SOQ/joIQgOBcKEDfVqmFon3tP/I0eZ0QWShA/AmBZtBQ8j/iAs0cytgoQIOR
BD6aO/U/GeAvfhyrKECF+JAQAbP3P7frWunDbyhAZ8hRwvLV+T/0iVSTrnko
QFqa8FBjuPs/QCPZan+KKECrG0W78Wf9P4tSV4Ns7ChAXkJExlXu/j8/AguW
0nsoQErxjfBdKQBA5JdUf1Z4KEAwDFZVS80AQLavfXcsLyhAaPTEOBFlAUDw
qh2bvoMoQBxYWWJd8gFAzz6KlXffJ0BfwE5WinYCQD3h4QttoSdAYf4DKbPy
AkAD0A9HersnQLaVvjjCZwNAIapOr2QjJ0CvqhQXfdYDQF3WCW+ylyZAURxh
nYk/BEAaZ0pWfTImQMj9nsV1owRA5HiKIIupJUDOEUy2uwIFQDgMuvneKCVA
vDSKScVdBUArU1AGvBolQGmz5tPutAVA7RWBUT0uJEAWQH4EiQgGQCQZrK0F
uyNAZgymBNxYBkBr+6y6pjkjQMht5d0mpgZAny3E2Vz/IkA6mcUHovAGQIEG
9r55kyJAlSeDB4A4B0Bl7BBk0g0iQE1Dkz7ufQdAckHWHbv6IUCQQGBSFcEH
QNNWouts4CFAiC1M0xoCCEBNA6tSGWkhQC5hhhMgQQhAIIcr0KhGIEBGqu6p
Q34IQIY6u0dXix9A3EI/hKG5CEBl2Q8FM1AeQHV70zNT8whA3D0uVU3+HEC+
4ugvcCsJQBwJgInq2htAKjnT1g1iCUA4OVT4O74bQG//PYJAlwlATRWXyatY
GkDNqh9dGssJQLlChxcP6BhA2pJMb6z9CUDIPb21ZU0YQEOMXYUGLwpA9mtk
ZEsHGEAFBF1ON18KQHSMMCNyKhhASqAKdkyOCkAqrxMnCrcWQLvdG5E=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Wk7qy4dYoQN64dwvy
SOQ/YWZT5EE7KEDfVqmFon3tP/ZkExW0DylA/AmBZtBQ8j/MB73lM28pQIOR
BD6aO/U/75s0IhUzKUCF+JAQAbP3P12/LC2dLSlAZ8hRwvLV+T/sm62nSZ0o
QFqa8FBjuPs/cj1+wHTjKECrG0W78Wf9P7Zrp8SSGSlAXkJExlXu/j+8/AEr
FCopQErxjfBdKQBAG/n7JE7AKEAwDFZVS80AQK9ZTdXtoihAaPTEOBFlAUAp
L3mw9c8oQBxYWWJd8gFAkARuOo4NKUBfwE5WinYCQIg9o4yn9ChAYf4DKbPy
AkDZuCYLvYUoQLaVvjjCZwNAjKcKo04mKECvqhQXfdYDQIc7wUws1SdAURxh
nYk/BEDkQoWJXacnQMj9nsV1owRApFSBpqqtJ0DOEUy2uwIFQP51NLgIbCdA
vDSKScVdBUCE/RUfr+AmQGmz5tPutAVALb/esHpvJkAWQH4EiQgGQHql/qUx
PCZAZgymBNxYBkC9F7a8o6wlQMht5d0mpgZAu0p64wh9JUA6mcUHovAGQOeX
/X7XMSVAlSeDB4A4B0DTnqkX7+UkQE1Dkz7ufQdAFJ7e+Ba6JECQQGBSFcEH
QKreuCBXjyRAiC1M0xoCCEBgRiYyy70jQC5hhhMgQQhAYHf9N+JqIkBGqu6p
Q34IQEdYwBIfByJA3EI/hKG5CEC+oHu1cuEhQHV70zNT8whAoYJx3Wm5IEC+
4ugvcCsJQKqmvCV68R9AKjnT1g1iCUAhKSLmudQdQG//PYJAlwlADzzGuTW6
G0DNqh9dGssJQApCQj0f2xtA2pJMb6z9CUDoXr0KthMcQEOMXYUGLwpAkLTC
NDM2GkAFBF1ON18KQEkXFzQZ6xpASqAKdkyOCkD3RKDdTL8YQL0kI70=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"k\"", TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SuperscriptBox[\\(k\\), \\(3\\)]\\)\\!\\(\\*SubscriptBox[\
\\(\[Rho]\\), \\(k\\)]\\)\"", TraditionalForm]},
      AxesOrigin->{-2, -12},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, {-12, 6}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.700480365792417, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.787491742782046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.867534450455582, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.941642422609304, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.075173815233827, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {1360.8000000000002, -116.80842387373012},
      ImageScaled[{0.5, 0.5}], {359.9999999999998, 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{700, 700/GoldenRatio}, {700, 432.62379212492635`}],
  PlotLabel->FormBox[
   "\"Run 0: Spectra for all fields at t=200.008\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7174480272345924`*^9, 
  3.717448107974039*^9},ExpressionUUID->"ca318413-1d62-4ab1-9975-\
f2a3e0f55bf1"]
}, Open  ]]
}, Open  ]],

Cell["Power spectrum plots (all times in one plot).", "Text",ExpressionUUID->"3e1e796f-4847-4949-8a32-e72c3c9d9f43"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"dopower", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"powerminalltimes", "[", "run", "]"}], "[", "fld", "]"}],
             "=", 
            RowBox[{"Min", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"powermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"time", ",", "1", ",", 
                 RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"alltimespowerplot", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ListLogLogPlot", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"powertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                  RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{"time", "/", 
                    RowBox[{"(", 
                    RowBox[{"1.5", " ", 
                    RowBox[{"numtimes", "[", "run", "]"}]}], ")"}]}], "]"}], 
                    "}"}]}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"time", ",", "1", ",", 
                  RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"\"\<Power: k^\>\"", "<>", 
                RowBox[{"ToString", "[", "kexponent", "]"}], "<>", 
                "\"\< |\>\"", "<>", 
                RowBox[{"label", "[", "fld", "]"}], "<>", "\"\<|^2\>\""}]}], 
              ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{
                    RowBox[{"powerminalltimes", "[", "run", "]"}], "[", "fld",
                     "]"}]}], "]"}]}], "}"}]}]}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"alltimespowerplot", "[", "run", "]"}], "[", "fld", 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"fld", ",", "0", ",", 
                 RowBox[{
                  RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
              "]"}], "}"}], "]"}], ",", 
           RowBox[{"PlotLabel", "->", 
            RowBox[{"\"\<Run \>\"", "<>", 
             RowBox[{"ToString", "[", "run", "]"}]}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4221097942853556`*^9, 3.422109800191719*^9}, {
  3.422110104572563*^9, 3.4221101162446623`*^9}, {3.422110800554676*^9, 
  3.422110802289084*^9}, {3.717448136956822*^9, 
  3.717448154139146*^9}},ExpressionUUID->"2b84c568-0e54-4a9e-b070-\
7101f193963f"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IfhDYygUpwN64dwvy
SOQ/jBELKeV0KMDfVqmFon3tPwD/hZci7SXA/AmBZtBQ8j8K24b+1XckwIOR
BD6aO/U/P1oMWxmaI8CF+JAQAbP3P8gVvomXQiTAZ8hRwvLV+T+P4sEUqv8h
wFqa8FBjuPs/pD8twJ81I8CrG0W78Wf9P3gFerv9uyHAXkJExlXu/j8HXJOm
4GMhwErxjfBdKQBAWuQReTo7IcAwDFZVS80AQFDkbZoppSDAaPTEOBFlAUDa
IzZJk9QgwBxYWWJd8gFACR+XUcXQH8BfwE5WinYCQJGKYXkLVyDAYf4DKbPy
AkA/wy/5BwUgwLaVvjjCZwNAGFYo4PcgIMCvqhQXfdYDQPvJfNKazh3AURxh
nYk/BECOQqPYFbgewMj9nsV1owRA7OiKgn8hHsDOEUy2uwIFQDM1ceaI3x3A
vDSKScVdBUDM4xPtYEQdwGmz5tPutAVA9XBrD3kgHcAWQH4EiQgGQHXAfbRr
eRzAZgymBNxYBkBpanMdBDccwMht5d0mpgZAflKbb32+HMA6mcUHovAGQBJA
mTYzzhvAlSeDB4A4B0BDFHkRZGgbwE1Dkz7ufQdAUkxogdPuG8CQQGBSFcEH
QO7PuxESwxrAiC1M0xoCCEBkLaq3FowbwC5hhhMgQQhARds3tmKyGsBGqu6p
Q34IQPCpUmC35BnA3EI/hKG5CEChwzM9HToawHV70zNT8whAmIA/9PwDG8C+
4ugvcCsJQGayGy3ZKRnAKjnT1g1iCUDI+woHeGIawG//PYJAlwlA7CDdyxIV
GcDNqh9dGssJQHlgcT9L8RrA2pJMb6z9CUDkqIW8WaQZwEOMXYUGLwpADZZj
ODWoGcAFBF1ON18KQACzPm4wkRbASqAKdkyOCkC3A9THVvQUwAoRMTo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT96t2pOYjAnwN64dwvy
SOQ/h/DlJReVJsDfVqmFon3tP32Gxk9vsSPA/AmBZtBQ8j9jr1WF8CYjwIOR
BD6aO/U/5Q8ik55PI8CF+JAQAbP3P+c/bmiugSLAZ8hRwvLV+T/H6FmImtkh
wFqa8FBjuPs/EXh2qi2XIsCrG0W78Wf9P4bPZV6JzyHAXkJExlXu/j8YRMLS
kFYhwErxjfBdKQBAC9q77WYyIMAwDFZVS80AQMYTIYxZcSDAaPTEOBFlAUCs
Et+Qs0wgwBxYWWJd8gFA+2QByRE4H8BfwE5WinYCQP9GTdlIjSDAYf4DKbPy
AkAk6DBmLMwewLaVvjjCZwNA2GztOAQlH8CvqhQXfdYDQIgPxkKyUB7AURxh
nYk/BEAvKZPyL0odwMj9nsV1owRAXuYaPag+HsDOEUy2uwIFQJJn3VH0LBzA
vDSKScVdBUBsdq10IaYcwGmz5tPutAVA89enJ0jmHMAWQH4EiQgGQPWReaYJ
/BvAZgymBNxYBkDrNt9oloMbwMht5d0mpgZAsG/C615sGsA6mcUHovAGQPDc
lTwpVBrAlSeDB4A4B0C8m0XuUAgawE1Dkz7ufQdAn+HjBMdHGsCQQGBSFcEH
QNW8dBFlKhnAiC1M0xoCCEDFAkn0wGIZwC5hhhMgQQhAACsgpFdbGcBGqu6p
Q34IQJglbiy7whjA3EI/hKG5CEAsOrwTDYYZwHV70zNT8whA5dNrFa1jGMC+
4ugvcCsJQPXprrTlkhbAKjnT1g1iCUC9wD33AJUYwG//PYJAlwlANu/Ml9jm
GMDNqh9dGssJQC2uAw4TBxfA2pJMb6z9CUCyp0E27LQWwEOMXYUGLwpAG6ZJ
jvHhFsAFBF1ON18KQKFdN5EiTxjASqAKdkyOCkB2efloQC4WwLf+Nbw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8KZXdd1EgkwN64dwvy
SOQ/jsj9Gu8nI8DfVqmFon3tP513ugsefyPA/AmBZtBQ8j/529nciiMjwIOR
BD6aO/U/hOjclTJMIsCF+JAQAbP3P4Pwu7NnFyLAZ8hRwvLV+T+MkzldQ7oh
wFqa8FBjuPs/QtUDpFNSIcCrG0W78Wf9P6m6smnEIyHAXkJExlXu/j96Mgkp
LRMhwErxjfBdKQBACB/woB2TIMAwDFZVS80AQH8CdgZ5GyDAaPTEOBFlAUCK
+XkxAaIgwBxYWWJd8gFAXIsXNctiH8BfwE5WinYCQIQ2JQGSQR/AYf4DKbPy
AkASyMVpvV0fwLaVvjjCZwNArzonrtm2HsCvqhQXfdYDQPrrPeQC1RzAURxh
nYk/BECwtTITJpMewMj9nsV1owRAengQkfmyHMDOEUy2uwIFQH1BFr9BbBzA
vDSKScVdBUBL3TIgXn0cwGmz5tPutAVAgDR5DQN5G8AWQH4EiQgGQP0mHzHL
3RvAZgymBNxYBkCv87b+QAAbwMht5d0mpgZARcfuUyfkGsA6mcUHovAGQICw
I1jvBhvAlSeDB4A4B0D2To9KnCoawE1Dkz7ufQdAPXj07OlfGcCQQGBSFcEH
QKCFP+he/RjAiC1M0xoCCEDPj6J+nYoZwC5hhhMgQQhAjF/TSIMkGsBGqu6p
Q34IQK1vBlHfRhnA3EI/hKG5CEB/aXnpZ9sYwHV70zNT8whACWAQOGAJGMC+
4ugvcCsJQNjlcOK8zhfAKjnT1g1iCUCmlzPfdgIZwG//PYJAlwlAUiBXN3oN
GMDNqh9dGssJQF1HTUsDaxXA2pJMb6z9CUBhPzN8zjEVwEOMXYUGLwpAKKdG
/EXaGMAFBF1ON18KQHQPMOs+vxXASqAKdkyOCkDaoqlx238XwFqLLxo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/xJ+F1j10iwN64dwvy
SOQ/qMs/JRIhJMDfVqmFon3tP5hxIIwuEiPA/AmBZtBQ8j/dtVqtQFgiwIOR
BD6aO/U/sSgHLZrvIcCF+JAQAbP3P93Hy6fJ4iHAZ8hRwvLV+T8x7Gqilfog
wFqa8FBjuPs/R57fpX0CIcCrG0W78Wf9P3Egu0gKyCDAXkJExlXu/j9nqJ91
STEgwErxjfBdKQBA4BV4+EsyIMAwDFZVS80AQACJ9IAtth7AaPTEOBFlAUAP
M1W+TdIfwBxYWWJd8gFAzyLsrQBjHsBfwE5WinYCQO5v/v+3dB7AYf4DKbPy
AkAQ0nHRCP4ewLaVvjjCZwNAWHAbFiFWHcCvqhQXfdYDQKMMsnaA4h3AURxh
nYk/BEAB/XGu6iQcwMj9nsV1owRAluo7UOYOHcDOEUy2uwIFQF8qxfRKfhvA
vDSKScVdBUBv0/SyUZcbwGmz5tPutAVAOhgHVg2WG8AWQH4EiQgGQFP0Ceii
VxvAZgymBNxYBkBlOE9ID0cbwMht5d0mpgZAKTuS0r4AGsA6mcUHovAGQFcM
nS0ehRnAlSeDB4A4B0DYl/NRY3IZwE1Dkz7ufQdAIj/OiocTGcCQQGBSFcEH
QLS/NL/ichjAiC1M0xoCCEAcSByAq8wZwC5hhhMgQQhAO2v4ZJXiGMBGqu6p
Q34IQBoEEMFy2hjA3EI/hKG5CEDPVtV5tUwawHV70zNT8whAfrl5H7wEF8C+
4ugvcCsJQIdPNNLUXRfAKjnT1g1iCUD1+dQINB0ZwG//PYJAlwlAXAeg/doH
GMDNqh9dGssJQLJ7whtNWhXA2pJMb6z9CUAxEIv7LQYVwEOMXYUGLwpA3PZ1
EJI+GcAFBF1ON18KQMA/UdbSUBTASqAKdkyOCkCdyNfgs+kWwOODMts=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/OPMesB3YiwN64dwvy
SOQ/agcH9AZWI8DfVqmFon3tP8jMElJXQCLA/AmBZtBQ8j9Yd+sU7VEiwIOR
BD6aO/U/CTjgSY3ZIcCF+JAQAbP3P4XuR9b/nCHAZ8hRwvLV+T+JOxm7rVwg
wFqa8FBjuPs/errqAgQ7IcCrG0W78Wf9P2ZyHOwC5yDAXkJExlXu/j/Nw8aW
gyQgwErxjfBdKQBA9d/OUdKeH8AwDFZVS80AQMYG3EbcKx/AaPTEOBFlAUBx
rzfwr9EewBxYWWJd8gFAS0t9v7AOH8BfwE5WinYCQPbrIjLSnh7AYf4DKbPy
AkDaJ5I1lZkdwLaVvjjCZwNA5gYLKYDQHcCvqhQXfdYDQH9QIdOsUx3AURxh
nYk/BEDLw26h6BUdwMj9nsV1owRA/l1BXkVHHMDOEUy2uwIFQJzXigGdCBzA
vDSKScVdBUD5z3LYIlobwGmz5tPutAVAYYYPfnvIGsAWQH4EiQgGQNNaYZgx
zxvAZgymBNxYBkBQwA+aUnsawMht5d0mpgZASBPM25MhGsA6mcUHovAGQO6t
8RS1ehnAlSeDB4A4B0A1ZniKM6oZwE1Dkz7ufQdA7/05KV10GcCQQGBSFcEH
QGY9ZXOC9RfAiC1M0xoCCEAXZVxrfZcZwC5hhhMgQQhAVl5nEuZXGcBGqu6p
Q34IQCs0MYV9NBjA3EI/hKG5CECJfM/79RQYwHV70zNT8whAxlBz7L8tF8C+
4ugvcCsJQFcdfubs5xfAKjnT1g1iCUB9XkCbGYEYwG//PYJAlwlA6XD/EdA4
GMDNqh9dGssJQOQos6nM6hXA2pJMb6z9CUBgmBcVtCMVwEOMXYUGLwpAmp/y
nZuhGMAFBF1ON18KQAk85/gq/BPASqAKdkyOCkBL4+oOPdoUwB8kN5A=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9TI4E8igQjwN64dwvy
SOQ/8NcekTHsIcDfVqmFon3tPyiqiM14uiHA/AmBZtBQ8j/RBaMNBGMiwIOR
BD6aO/U/zlNO7jkCIsCF+JAQAbP3P5kUzyGf3SHAZ8hRwvLV+T8zXRldSjkg
wFqa8FBjuPs/bZOrbLJkIMCrG0W78Wf9PwJe9KXkVyDAXkJExlXu/j874zO7
fKcgwErxjfBdKQBAGLn2Gs1xH8AwDFZVS80AQCDtHAb04B/AaPTEOBFlAUAo
53aXpuEewBxYWWJd8gFAI+hDSwJZHsBfwE5WinYCQMyUseWbuR7AYf4DKbPy
AkAX+wCGfzQdwLaVvjjCZwNAI3EtHnlkHMCvqhQXfdYDQHm9nWPvyRzAURxh
nYk/BEAu8P9Fnz0cwMj9nsV1owRA5hZCHz2gG8DOEUy2uwIFQLDKXPNlPhvA
vDSKScVdBUBX0KD8fh8bwGmz5tPutAVA6WUH2OsmGsAWQH4EiQgGQH+rYjxX
kBrAZgymBNxYBkD0doKNxjsawMht5d0mpgZA2t3JepyVGcA6mcUHovAGQH7z
dlQkGhnAlSeDB4A4B0DCnQmIohMZwE1Dkz7ufQdAcCay7FFRGcCQQGBSFcEH
QImvkWIkPBjAiC1M0xoCCEBLp7uZljQZwC5hhhMgQQhAmdOrjbaQGMBGqu6p
Q34IQCAdYoQLoRfA3EI/hKG5CED2BcjlmJIXwHV70zNT8whAyqQJjaLvF8C+
4ugvcCsJQPnTYLCT4RbAKjnT1g1iCUCMgOtIRvMZwG//PYJAlwlAk8TgosoR
F8DNqh9dGssJQAUYN//apRTA2pJMb6z9CUAOrb7IIlQVwEOMXYUGLwpAByRV
3seMGMAFBF1ON18KQAqh5t8RIBTASqAKdkyOCkAeEjmm5akfwNv0Np8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/VzI4VWrAjwN64dwvy
SOQ/uyXpiHNwI8DfVqmFon3tP/eO7M/LxSLA/AmBZtBQ8j8GrHPzbMIhwIOR
BD6aO/U/PvaBt4/NIcCF+JAQAbP3P2Cu/D6NeiHAZ8hRwvLV+T8tNdz9ffQf
wFqa8FBjuPs/b6smKfTTIMCrG0W78Wf9PzmfeNPybh/AXkJExlXu/j9u5ww4
AUMgwErxjfBdKQBAZ9IZxYL8HsAwDFZVS80AQCIBIz5FSR7AaPTEOBFlAUDK
q5w0ZVkewBxYWWJd8gFA+sBTsdROHsBfwE5WinYCQMP2duebYR3AYf4DKbPy
AkDi8R5cKMUcwLaVvjjCZwNAV4yPXmzvHMCvqhQXfdYDQAdpLAxD6BzAURxh
nYk/BEARYI0x4HkbwMj9nsV1owRAqosj6RLmG8DOEUy2uwIFQCepNTXhwhrA
vDSKScVdBUDdwsujDFEbwGmz5tPutAVAerIDpI1oGsAWQH4EiQgGQKxs75Fk
jRrAZgymBNxYBkBNGsReYb0awMht5d0mpgZALxSXJYVrGMA6mcUHovAGQFM2
ThHDIhnAlSeDB4A4B0BHIsTFLxIZwE1Dkz7ufQdAThPQn0iJGMCQQGBSFcEH
QLbC7b/pzxfAiC1M0xoCCEDwVGv1gWgYwC5hhhMgQQhAZFHO8GUUGcBGqu6p
Q34IQFB5Xd4SphfA3EI/hKG5CECcf1e/29gXwHV70zNT8whAVdeG/KdtF8C+
4ugvcCsJQA0iQmHFuBbAKjnT1g1iCUBVliMphZ4YwG//PYJAlwlA4sUhneQi
GMDNqh9dGssJQMOhB3PBERfA2pJMb6z9CUCY1LEVVVsUwEOMXYUGLwpAfCT5
F4uMFsAFBF1ON18KQM9UQMBEkhXASqAKdkyOCkCIPO8MVpcVwBp7OM8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Pf2hfzPgjwN64dwvy
SOQ/zpoHojhPIsDfVqmFon3tP60+qtJI9yHA/AmBZtBQ8j92s/Vsc3AhwIOR
BD6aO/U/kLGyHEjRIMCF+JAQAbP3P6mmA0OCCSHAZ8hRwvLV+T9B5xsiCXAf
wFqa8FBjuPs/KAm52p+JIMCrG0W78Wf9P7slW20MXSDAXkJExlXu/j/RzK2+
dEUgwErxjfBdKQBACDhZJWxuH8AwDFZVS80AQEQnnJXTAB/AaPTEOBFlAUD+
6EBfBbQdwBxYWWJd8gFAGr9UdyxEHsBfwE5WinYCQBVEGXhIzh3AYf4DKbPy
AkByNwtD75McwLaVvjjCZwNAJiJKQ3BGHMCvqhQXfdYDQDhsACbnuBzAURxh
nYk/BEDAdj+ljfwbwMj9nsV1owRA53RR9DuHG8DOEUy2uwIFQDwoae+UGxvA
vDSKScVdBUA8S501DX8bwGmz5tPutAVA5eW1YeLDGcAWQH4EiQgGQISy+hwJ
nBrAZgymBNxYBkAe4RWxkVEawMht5d0mpgZA8M3xTc2sGMA6mcUHovAGQCCt
WrL3QBnAlSeDB4A4B0BSc61HSX8YwE1Dkz7ufQdA82OD9cCJGMCQQGBSFcEH
QKKwmQ5yNRjAiC1M0xoCCEBo5AKccRAYwC5hhhMgQQhAhAf6w24CGMBGqu6p
Q34IQEQ6SHhZ1BbA3EI/hKG5CEDguywWMf8WwHV70zNT8whA7Agko+YqF8C+
4ugvcCsJQHX96SmLkRbAKjnT1g1iCUC4cyXK6rgYwG//PYJAlwlAE4PeKN8f
FsDNqh9dGssJQIvAa1Am0hjA2pJMb6z9CUDzOImR5CgUwEOMXYUGLwpATSK3
DlWcGMAFBF1ON18KQGX6DWifGBXASqAKdkyOCkAke238bskWwE2+MCs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8fXGLzxYgewN64dwvy
SOQ/29MoaWQuIcDfVqmFon3tP7Yx2ib0iiHA/AmBZtBQ8j9fDYraibMgwIOR
BD6aO/U/MqnLH0+GIMCF+JAQAbP3P4LGzbo/hiDAZ8hRwvLV+T9Qj7HoRH8f
wFqa8FBjuPs/o0o+vdg4IMCrG0W78Wf9P6O/yYShOB/AXkJExlXu/j9golkP
JxQgwErxjfBdKQBA0CANpPRqHsAwDFZVS80AQIGwdd+nhh3AaPTEOBFlAUAm
YFD2CUkdwBxYWWJd8gFAynVZ61UEHsBfwE5WinYCQJXqyVh32R3AYf4DKbPy
AkCXtgZKsOEbwLaVvjjCZwNA2btBn99sHMCvqhQXfdYDQNDfCRVueRzAURxh
nYk/BEAKO9B7u6kawMj9nsV1owRAkVTIXw1eG8DOEUy2uwIFQFk1xlwN2xrA
vDSKScVdBUDl2F/dpgcbwGmz5tPutAVADWGiY475GcAWQH4EiQgGQMT+1sXI
2RrAZgymBNxYBkChUvTcQaIZwMht5d0mpgZAHaHUr+7NGMA6mcUHovAGQIgO
kGJ7bxjAlSeDB4A4B0Aai4ZlhpoYwE1Dkz7ufQdA7+HLYGXCF8CQQGBSFcEH
QBsThMAQbBfAiC1M0xoCCEChIzwpAp4XwC5hhhMgQQhAUYU0xBsEGcBGqu6p
Q34IQA/sy5UGLBfA3EI/hKG5CEDWsogxDpEXwHV70zNT8whAVCztjT6zFsC+
4ugvcCsJQBibJEtrIhbAKjnT1g1iCUBbav4xJ/MXwG//PYJAlwlAMWKZJ06p
FsDNqh9dGssJQMp89HcihRbA2pJMb6z9CUAwOSsEzw0TwEOMXYUGLwpAgc3+
kbGAFsAFBF1ON18KQE4IRNwDVxLASqAKdkyOCkAy1zYzlAgXwOTiMwY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+W2aTQFjYdwN64dwvy
SOQ/9l/wPWblIMDfVqmFon3tP5Nakz3a7CDA/AmBZtBQ8j8H4qm3EdEgwIOR
BD6aO/U/cVSFnVRiIMCF+JAQAbP3P9WVGu5dOyDAZ8hRwvLV+T/ybO93CBke
wFqa8FBjuPs/zSQpHjC4H8CrG0W78Wf9Pw8LWQs18R7AXkJExlXu/j9LrHmJ
Z1YfwErxjfBdKQBAZzuD8rwZHsAwDFZVS80AQOca/b+0jx3AaPTEOBFlAUCJ
x+e8uOodwBxYWWJd8gFAKXM0cwXuHcBfwE5WinYCQC6+zeEoihzAYf4DKbPy
AkBfxDCvdaUbwLaVvjjCZwNAmRwHU/xxHMCvqhQXfdYDQMJGJ/zXqxvAURxh
nYk/BEDtv8krLQAbwMj9nsV1owRATUwaMbrIGsDOEUy2uwIFQFhKAPQbuBnA
vDSKScVdBUANp88ZppQawGmz5tPutAVAuLaD7gRtGcAWQH4EiQgGQJlYqcfx
+hnAZgymBNxYBkCenMUwRWYZwMht5d0mpgZA2Q+8hgniF8A6mcUHovAGQClQ
kOxtoBjAlSeDB4A4B0DA8up64xQYwE1Dkz7ufQdAhwbChUSzF8CQQGBSFcEH
QKzuyb8w3hfAiC1M0xoCCEC5elxtI1MYwC5hhhMgQQhAJNO3JKuXF8BGqu6p
Q34IQG9c4BKNVBfA3EI/hKG5CECcY/jxaucXwHV70zNT8whAJalDeDp8FsC+
4ugvcCsJQBTWRqMfARbAKjnT1g1iCUBWFZS5iBUXwG//PYJAlwlA8IWRdOSB
FcDNqh9dGssJQEVwso7+FBfA2pJMb6z9CUDgCt4+8msTwEOMXYUGLwpAcCPN
DtQ7FsAFBF1ON18KQL2/ryO7VxLASqAKdkyOCkD5yCV7bzscwI+kOKU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/gnmsJKbr1v964dwvy
SOQ/B//KQq82IMDfVqmFon3tPzPB+Yxgjx/A/AmBZtBQ8j/WATEUKU4gwIOR
BD6aO/U/+YueOqAOIMCF+JAQAbP3P9UNimJAbCDAZ8hRwvLV+T9POV5Ekz8f
wFqa8FBjuPs/JVU/3D6+H8CrG0W78Wf9P/XpxQZACR/AXkJExlXu/j9L79wl
QiofwErxjfBdKQBAxl9/+bTzHcAwDFZVS80AQHcouwMwshzAaPTEOBFlAUCw
BVdlJUUdwBxYWWJd8gFAx6cWhgJeHMBfwE5WinYCQBhq9LyuGh3AYf4DKbPy
AkCB21i7PjccwLaVvjjCZwNAZ+1v0EVhG8CvqhQXfdYDQPb+jFQvWBzAURxh
nYk/BEDO7NoWZSwawMj9nsV1owRApMTdOpABG8DOEUy2uwIFQPplBCDb8RnA
vDSKScVdBUAee8JAyWMawGmz5tPutAVArrYWJ3pDGcAWQH4EiQgGQIHfr4dk
PBrAZgymBNxYBkDrXkdduioZwMht5d0mpgZAco/iOpV3GMA6mcUHovAGQBbj
B1FLKxjAlSeDB4A4B0ATXBSoyUMYwE1Dkz7ufQdAot2MdxtVF8CQQGBSFcEH
QHTEDTGb4xbAiC1M0xoCCEBpInEHTXcXwC5hhhMgQQhA8Ns1pF0DGMBGqu6p
Q34IQG2ODfUo/BbA3EI/hKG5CEBdU4x/DbUYwHV70zNT8whAkRxHPK12FsC+
4ugvcCsJQM8OKGJPJxbAKjnT1g1iCUAzNZMK+0YXwG//PYJAlwlAElPNR+27
FMDNqh9dGssJQOYEDoa4VhTA2pJMb6z9CUBC9DEEYHcVwEOMXYUGLwpAEB4P
5lkbGMAFBF1ON18KQI7/Wz+e1RTASqAKdkyOCkD0uhWsxCwawIu7K0U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9am0sEQUMlQN64dwvy
SOQ/JZrxKekZ9D/fVqmFon3tP6hmdkyIdeu//AmBZtBQ8j+J6u2WHm8RwIOR
BD6aO/U/zfyM4QtmC8CF+JAQAbP3P42lTFLChCDAZ8hRwvLV+T9YUgEFq6ce
wFqa8FBjuPs/5ksenre6H8CrG0W78Wf9P8E36IVdwR7AXkJExlXu/j9yE020
6/wewErxjfBdKQBAnP+1qm2tHcAwDFZVS80AQPrgXkHquR3AaPTEOBFlAUCE
UYeRVnscwBxYWWJd8gFA5Qq79uiCHMBfwE5WinYCQL6ZylZB6hzAYf4DKbPy
AkA6ICfTm/oawLaVvjjCZwNAkCoLy4oxG8CvqhQXfdYDQDniuyP3zhvAURxh
nYk/BEB1NI2CZJcawMj9nsV1owRADk87vGbQGsDOEUy2uwIFQDh8B7rQzBnA
vDSKScVdBUBwGgFBBhUawGmz5tPutAVA73wsXlhXGcAWQH4EiQgGQLfNZr27
4xjAZgymBNxYBkBM2OHHc0UZwMht5d0mpgZAM02PH1ViGMA6mcUHovAGQNDe
lRvtiBjAlSeDB4A4B0CJLrgEtbMXwE1Dkz7ufQdAX+bCybRMF8CQQGBSFcEH
QBO4myXedRfAiC1M0xoCCEAcTNwq6oIXwC5hhhMgQQhAjRiDozmHF8BGqu6p
Q34IQOQhxfzS8BbA3EI/hKG5CECGEKyKTxoYwHV70zNT8whA+zSCMQniFsC+
4ugvcCsJQFqQFvUiohTAKjnT1g1iCUBbQUHoUDcXwG//PYJAlwlAxflRZshS
FcDNqh9dGssJQGOG56Wz4xTA2pJMb6z9CUAr+enRsmcTwEOMXYUGLwpAUqCp
K7FdF8AFBF1ON18KQCDMZ0EkHBTASqAKdkyOCkAxCBpZim4WwCutOEE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+U4p4o0GcwQN64dwvy
SOQ/Uvm7IUtBL0DfVqmFon3tP9QCMHxIiypA/AmBZtBQ8j9Zb+hHACUrQIOR
BD6aO/U/6ElnnqShKUCF+JAQAbP3P80DsNotxSlAZ8hRwvLV+T8f6cSIrLMo
QFqa8FBjuPs/Nm9w7NUvJ0CrG0W78Wf9P5PWwpdI1yVAXkJExlXu/j/Ihfkb
GoAkQErxjfBdKQBA0da9sWytJUAwDFZVS80AQHJY6owQHCVAaPTEOBFlAUAs
LpQT5h0lQBxYWWJd8gFA9uEFjTbSJEBfwE5WinYCQKr5pSwQ5yNAYf4DKbPy
AkAOSw4DbZgjQLaVvjjCZwNABUNtzs2lI0CvqhQXfdYDQAvCODkRWyNAURxh
nYk/BEDRF8HoXtsiQMj9nsV1owRAI8LgV3/wIUDOEUy2uwIFQEH+2Dvi0SBA
vDSKScVdBUA/p9c4ZlogQGmz5tPutAVApOTmDfnNHEAWQH4EiQgGQHwuZW44
dRpAZgymBNxYBkC3beWNwHUZQMht5d0mpgZATmquR9njFkA6mcUHovAGQKvT
bbJs/RNAlSeDB4A4B0B1sxeEJc8RQE1Dkz7ufQdAZHlwxH6/EkCQQGBSFcEH
QM8PCS0Qvg9AiC1M0xoCCECfiqv1skwNQC5hhhMgQQhA+pac4i1rC0BGqu6p
Q34IQHGK05fdUwlA3EI/hKG5CECSNsg8zZ8BQHV70zNT8whAGzbqbvu//z++
4ugvcCsJQEb98NJmd/M/KjnT1g1iCUB1oAcMvZPwP2//PYJAlwlACEIDwSho
2j/Nqh9dGssJQNQ+PlY6rNO/2pJMb6z9CUA9NVZyi9EEwEOMXYUGLwpAsRiT
qTf5AMAFBF1ON18KQFTatqo/Evu/SqAKdkyOCkAle9RxAGIBwAIQKug=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8IHFi4hIIuQN64dwvy
SOQ/RlfhRMMqLUDfVqmFon3tPwIuA47F9DBA/AmBZtBQ8j9YvOTlrgEtQIOR
BD6aO/U/Bdx3myI+KUCF+JAQAbP3PwdwKKXUsypAZ8hRwvLV+T9Ew6hS3VYo
QFqa8FBjuPs/mgWP2GsXKkCrG0W78Wf9P9zJHkvKYihAXkJExlXu/j/mKsTw
dBYpQErxjfBdKQBA83eR9jv0JkAwDFZVS80AQEMTD0YaFCdAaPTEOBFlAUAI
3IfX0mQoQBxYWWJd8gFAxZGidUGTJ0BfwE5WinYCQKhMAUr//iVAYf4DKbPy
AkBBpYM1xf8mQLaVvjjCZwNAKmWjW0dXJUCvqhQXfdYDQD2DE/j47iNAURxh
nYk/BEC9Vx88li8kQMj9nsV1owRAAee5KoLvIkDOEUy2uwIFQHwuwcI83SNA
vDSKScVdBUCkhk1+WrgiQGmz5tPutAVAW8/Oe6TFIUAWQH4EiQgGQBumsWId
uB9AZgymBNxYBkBXvS9TisIdQMht5d0mpgZAUrjvN5ftG0A6mcUHovAGQFf1
0I3dDhpAlSeDB4A4B0By3trMpe0XQE1Dkz7ufQdA93OpKXQBGUCQQGBSFcEH
QFxunku/2xdAiC1M0xoCCEAEmcvrOI4VQC5hhhMgQQhAf1cJBW1gFUBGqu6p
Q34IQApK7u87YRNA3EI/hKG5CED0fn8QFnoSQHV70zNT8whAit4KWIUFEkC+
4ugvcCsJQM/QTWYSzg5AKjnT1g1iCUCiZctucJYIQG//PYJAlwlAbRBcoFcT
BUDNqh9dGssJQIhBIm8SDPY/2pJMb6z9CUDSRx2Uff/iP0OMXYUGLwpAxJdP
wEvp2D8FBF1ON18KQFDs9+6jxOS/SqAKdkyOCkC/4bzz7QD1v6vHJ1M=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+ObobJGOMtQN64dwvy
SOQ/QjKDX7WFLEDfVqmFon3tP1QNCPgGgC5A/AmBZtBQ8j9J4iGXmeArQIOR
BD6aO/U/713qcDKPLECF+JAQAbP3P7cIwJUCpCtAZ8hRwvLV+T8acC2KVe4r
QFqa8FBjuPs/OViDPg8GK0CrG0W78Wf9PxXrF8Ow8ylAXkJExlXu/j9YuIVo
xa4pQErxjfBdKQBAeSxS/K6fKUAwDFZVS80AQP6t0SVtrClAaPTEOBFlAUDh
hYuWl4goQBxYWWJd8gFAWtesflg3KEBfwE5WinYCQPbFLhsGuCdAYf4DKbPy
AkA9D1AJjocoQLaVvjjCZwNAFgSVUstXJ0CvqhQXfdYDQM871RleJyZAURxh
nYk/BECKwmLkkl4lQMj9nsV1owRA7eJkXztzJUDOEUy2uwIFQNVjEOF7ECRA
vDSKScVdBUAEkRuxdHojQGmz5tPutAVAn4uO7EP+IUAWQH4EiQgGQKaNs+M5
EyJAZgymBNxYBkASdx/N380gQMht5d0mpgZA4HeJrcwtIEA6mcUHovAGQAI1
irOXZx9AlSeDB4A4B0BhSOzn82UeQE1Dkz7ufQdAZ5tuaWdVHUCQQGBSFcEH
QMcOSQ0zgxtAiC1M0xoCCECa6ttHm6QbQC5hhhMgQQhAGT2+PZqyF0BGqu6p
Q34IQLahC7FglBVA3EI/hKG5CEAO5unuAloVQHV70zNT8whAtdqfqvcGFEC+
4ugvcCsJQJ/uSpcbiBNAKjnT1g1iCUDrfh7hvDUOQG//PYJAlwlAgvaJaIh7
DkDNqh9dGssJQG5ErbyHNA9A2pJMb6z9CUDNAa3GNiQFQEOMXYUGLwpA/BQ4
fqpsCkAFBF1ON18KQCqBWIdfBwVASqAKdkyOCkBd8AelGqsJQNjVHx8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/CZzhd5lcuQN64dwvy
SOQ/fP7n3dQCL0DfVqmFon3tP90lQFI/rS9A/AmBZtBQ8j9o2rBFPawuQIOR
BD6aO/U/ntg1xqQQLUCF+JAQAbP3P80yvVtavi1AZ8hRwvLV+T+lrl0OAaws
QFqa8FBjuPs/CQjNSgq7LECrG0W78Wf9Pw4JV3agXitAXkJExlXu/j8RDJGJ
Y7wpQErxjfBdKQBA7MTn717/KUAwDFZVS80AQLcpeZtecSpAaPTEOBFlAUA9
jITjWlgqQBxYWWJd8gFAEeCAqbe3KUBfwE5WinYCQPs7quBz8SdAYf4DKbPy
AkB9QXQwBxgpQLaVvjjCZwNAaHnb5YLSJ0CvqhQXfdYDQOBfZQJS4SZAURxh
nYk/BEDpE9Kglm8mQMj9nsV1owRAz8ZdVSeCJkDOEUy2uwIFQADIMkxJUiVA
vDSKScVdBUClTG7FGJgkQGmz5tPutAVApA8DkVe8IkAWQH4EiQgGQDvfQJLv
GiNAZgymBNxYBkA0KK4RwAkiQMht5d0mpgZAC+BKt/SzIUA6mcUHovAGQEw1
On58SSBAlSeDB4A4B0DRgfUhaHsgQE1Dkz7ufQdAbiiIoBNHIECQQGBSFcEH
QAr5Sithch5AiC1M0xoCCEAtF2cV9VUdQC5hhhMgQQhAzx6eaAvgG0BGqu6p
Q34IQFfKqk18gRlA3EI/hKG5CED+5zRYvjQZQHV70zNT8whAd1yQ30IJGEC+
4ugvcCsJQN05F/WlQhZAKjnT1g1iCUBQ51XgxigWQG//PYJAlwlAonVRZJ+o
FUDNqh9dGssJQMEO3r/YahRA2pJMb6z9CUDma6SdgX0UQEOMXYUGLwpAtuhu
MuQrE0AFBF1ON18KQOlO4nE9Cg9ASqAKdkyOCkCdN1AXLT8TQMYpHXA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+rWBNIPgcwQN64dwvy
SOQ/toMXsDK+L0DfVqmFon3tP4p0/8sHMy5A/AmBZtBQ8j9LNKyu9dctQIOR
BD6aO/U/VI1VsOgKL0CF+JAQAbP3PxdrtB31Ay5AZ8hRwvLV+T84DewcIw0r
QFqa8FBjuPs/vfCkbg05LUCrG0W78Wf9P9m3yLpR5StAXkJExlXu/j/SDH7h
dxQrQErxjfBdKQBAFw4gwIIAK0AwDFZVS80AQJjXw/OAxypAaPTEOBFlAUB1
IUgMD+QqQBxYWWJd8gFA8hAieyLYKUBfwE5WinYCQGa2RYf3tSlAYf4DKbPy
AkCuXr2u5AwqQLaVvjjCZwNA2qfMcDCJJ0CvqhQXfdYDQG8HR2RxxCdAURxh
nYk/BECofS+Y+UUnQMj9nsV1owRAU56i4wdvJ0DOEUy2uwIFQHIe+lTYxSVA
vDSKScVdBUCPgRw0cGYlQGmz5tPutAVArWoROctqJEAWQH4EiQgGQCYcF3X2
riNAZgymBNxYBkAu+XVn5cMjQMht5d0mpgZA0xUhyVMBI0A6mcUHovAGQJyu
K1WYmyJAlSeDB4A4B0Cu6DqI0Y0iQE1Dkz7ufQdAiQGh8U2SIUCQQGBSFcEH
QPHHzejA0SBAiC1M0xoCCEDsB1tZyzAhQC5hhhMgQQhAlezvgneuHEBGqu6p
Q34IQNe3Dxi11RxA3EI/hKG5CEBlZgpSWbAZQHV70zNT8whAH+1GhvntGUC+
4ugvcCsJQJ9aeQuQQRlAKjnT1g1iCUBr5Erj6l4WQG//PYJAlwlAfzrdIsbT
F0DNqh9dGssJQOeAgwAg4xJA2pJMb6z9CUBxGRF64sYUQEOMXYUGLwpA0AVs
8t8eEkAFBF1ON18KQKgNzhxcqRRASqAKdkyOCkAUGzadyXkPQG8fIQY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+L6GTt3EkvQN64dwvy
SOQ/K2sWeSc6L0DfVqmFon3tP6n6YDVVMzBA/AmBZtBQ8j9T99F7UsMtQIOR
BD6aO/U/TSE/E+iQLUCF+JAQAbP3Pwg08Qt7gy1AZ8hRwvLV+T90hzPce4Us
QFqa8FBjuPs/iTgtkIfTLECrG0W78Wf9PzD1/d9xLS1AXkJExlXu/j/pRmVJ
gHkrQErxjfBdKQBAJ2hBJeWRK0AwDFZVS80AQBYqc24caCtAaPTEOBFlAUAu
rYi13zwrQBxYWWJd8gFAXNHjuUp5KkBfwE5WinYCQEjJtkzH/SlAYf4DKbPy
AkAIoOOw0RoqQLaVvjjCZwNAr1aqpdMDKkCvqhQXfdYDQBEQfNooyihAURxh
nYk/BEAKyvZgNa8oQMj9nsV1owRAHcX/F94LJ0DOEUy2uwIFQGEW8UIwEyZA
vDSKScVdBUAmDr/TBdsmQGmz5tPutAVAW/6lJDZDJUAWQH4EiQgGQFSm1GYM
xCRAZgymBNxYBkALOIXFgbojQMht5d0mpgZA5dqWK/5nJEA6mcUHovAGQGPQ
PTUQOyNAlSeDB4A4B0AiQib5GUQjQE1Dkz7ufQdAggUahnE9I0CQQGBSFcEH
QKC81PUu7yFAiC1M0xoCCEBAdgwnJbshQC5hhhMgQQhAjsXTfLJeIEBGqu6p
Q34IQKXAq6wnsRxA3EI/hKG5CEAFCTqXoCQdQHV70zNT8whAT4LuQnCNGkC+
4ugvcCsJQJMILIy9yhhAKjnT1g1iCUB8HFGbug8aQG//PYJAlwlA2GPEKIue
F0DNqh9dGssJQKuFVSWa6RRA2pJMb6z9CUB5tiVPx9IVQEOMXYUGLwpABihQ
3iA7FkAFBF1ON18KQAc5l3nJ5hRASqAKdkyOCkCNyFeoVqoQQEfuGwM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT++i2jPWFEuQN64dwvy
SOQ/TYYiJVCBLUDfVqmFon3tPy+nAIAMrC5A/AmBZtBQ8j98WBVwXikuQIOR
BD6aO/U/jiDjf5xuLkCF+JAQAbP3P4D0FS2x0C1AZ8hRwvLV+T9ZGrJyJx0t
QFqa8FBjuPs/U2kklmh6LUCrG0W78Wf9P/U6/A4YyixAXkJExlXu/j+MSBJ4
b4QsQErxjfBdKQBALc4OD7cgLEAwDFZVS80AQA97CEMz5StAaPTEOBFlAUDH
VTzom24rQBxYWWJd8gFAljyUcV3tKkBfwE5WinYCQLo4GUm7eSpAYf4DKbPy
AkDq1WUfT/sqQLaVvjjCZwNA4qLFtIg4KkCvqhQXfdYDQG8X48sBhClAURxh
nYk/BEDm2BH3ggIpQMj9nsV1owRAjGtuA6c1KEDOEUy2uwIFQHCQUhTsFydA
vDSKScVdBUBMp5NX1GQnQGmz5tPutAVA3Tm80btKJkAWQH4EiQgGQEnRuVq3
eiVAZgymBNxYBkBxJycHUgwlQMht5d0mpgZAKKzKeKuxJEA6mcUHovAGQNxO
1u5vpCRAlSeDB4A4B0AzRysYXPkjQE1Dkz7ufQdAm+uufFvJI0CQQGBSFcEH
QDVDJRG89SJAiC1M0xoCCEDTQdwdh/8iQC5hhhMgQQhAk+q9Qn79IEBGqu6p
Q34IQFffaqSTJiBA3EI/hKG5CEBb4o3+090dQHV70zNT8whAyn4frSdDHkC+
4ugvcCsJQBN1dTDUmB1AKjnT1g1iCUA21QE4SSIcQG//PYJAlwlA2GZ8jg7U
G0DNqh9dGssJQGv/LqBrxBlA2pJMb6z9CUBlXvouJiIYQEOMXYUGLwpAb6OC
HEqKF0AFBF1ON18KQBb/bTtXYhhASqAKdkyOCkABPpTA+ocVQENyGzA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9HVOCleukuQN64dwvy
SOQ/EiarUbHvLUDfVqmFon3tP6rbgnziUC5A/AmBZtBQ8j8ZDufq1fQtQIOR
BD6aO/U/HR4C/u7aLUCF+JAQAbP3P0Mtgbnawy1AZ8hRwvLV+T/FKiQOKBgt
QFqa8FBjuPs/BWVntEAxLUCrG0W78Wf9P2a1Zs2joi1AXkJExlXu/j96slCS
rVEsQErxjfBdKQBARFSc4TIPLEAwDFZVS80AQLwm2lwqCSxAaPTEOBFlAUC5
KWLujCksQBxYWWJd8gFAHxj2L2FWK0BfwE5WinYCQLg8L3VNxipAYf4DKbPy
AkC+mirma5ArQLaVvjjCZwNAiXUA4mM4KkCvqhQXfdYDQNIAlH8WBylAURxh
nYk/BEBGNV5uVzgpQMj9nsV1owRAYdnbRXJcKEDOEUy2uwIFQFlplX/95ydA
vDSKScVdBUAfU165DtQnQGmz5tPutAVAMsddxN6iJkAWQH4EiQgGQF+SAtbH
/yVAZgymBNxYBkDdZ6zUCIAlQMht5d0mpgZAD6Kp6ANUJUA6mcUHovAGQDf7
8slopyRAlSeDB4A4B0Du6eUTVLEkQE1Dkz7ufQdAeIvyBRAmJECQQGBSFcEH
QH7mALnhJiRAiC1M0xoCCECjH8Nv/5gjQC5hhhMgQQhABYfY30JgIkBGqu6p
Q34IQAahiI+oWCFA3EI/hKG5CEAnU0Tm3ZYgQHV70zNT8whApKuEa7nzH0C+
4ugvcCsJQHchzxmPwR5AKjnT1g1iCUABD+4ZkOoeQG//PYJAlwlAyBg4yl0u
HUDNqh9dGssJQDS00PSwJh1A2pJMb6z9CUCo+Ls2oXwbQEOMXYUGLwpAMP/4
zo06G0AFBF1ON18KQGgyut3wOxtASqAKdkyOCkD03j7KmHwYQOopI8k=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9KXDHrAF0uQN64dwvy
SOQ/GbAyPRLhLkDfVqmFon3tP9KHM6G5UC5A/AmBZtBQ8j8/85TE9dctQIOR
BD6aO/U/RWorH90uLkCF+JAQAbP3P7M+ESUUsy1AZ8hRwvLV+T8nwsD/hGQt
QFqa8FBjuPs/7XXKysHPLECrG0W78Wf9Px+VV8HgVC1AXkJExlXu/j9dtD/i
9rssQErxjfBdKQBA3GCC8yNMLEAwDFZVS80AQNaP1D99QyxAaPTEOBFlAUBy
nuK9wtAsQBxYWWJd8gFAQUxlFKeiK0BfwE5WinYCQOte6aksNStAYf4DKbPy
AkDlo6xo7GUrQLaVvjjCZwNAqdCugMfQKkCvqhQXfdYDQMopala56ilAURxh
nYk/BEBt1r35tlYpQMj9nsV1owRAmahLt9osKUDOEUy2uwIFQHKf1S7+JihA
vDSKScVdBUCSntZmQvknQGmz5tPutAVAcDVoeXQ/J0AWQH4EiQgGQABTtbuT
gyZAZgymBNxYBkAFeZx4dCUmQMht5d0mpgZAZqhbbeljJUA6mcUHovAGQP5D
25/FaiVAlSeDB4A4B0C1GjXV+MokQE1Dkz7ufQdAhw60if7LJECQQGBSFcEH
QCvshViBuSRAiC1M0xoCCEB9RwHrjy8kQC5hhhMgQQhAdRc0DFK/IkBGqu6p
Q34IQA7mQBODRyJA3EI/hKG5CEDQC13O4mshQHV70zNT8whAjdSasJmeIEC+
4ugvcCsJQJLjoKvZWiBAKjnT1g1iCUBl3yNuFfQfQG//PYJAlwlAdza8zsvD
HUDNqh9dGssJQCyW6csTDh1A2pJMb6z9CUBlirJDdlQcQEOMXYUGLwpAjLSG
YIZKG0AFBF1ON18KQJckB9NAGxxASqAKdkyOCkCKaUALwvAbQFejKKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -5.433594284955915},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Power: k^2 |\[Phi]|^2\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox["1000", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.73321616779958, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.74306846424259, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.752824639187956`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.76248655009969, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.772056001115843`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.78153474507039, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.790924485420227`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+EMw9H2QwtwN64dwvy
SOQ/BRKDOjSRKsDfVqmFon3tP/bCSRhtyyjA/AmBZtBQ8j/WoVV26eYowIOR
BD6aO/U/w2GzwJ2oJsCF+JAQAbP3PxSRDvPveibAZ8hRwvLV+T8bggiWDBol
wFqa8FBjuPs/lj6JNf32I8CrG0W78Wf9P+h+rJ13sCLAXkJExlXu/j+eKUm9
PsQjwErxjfBdKQBAA1vSQM01IsAwDFZVS80AQPrlOsfJiyLAaPTEOBFlAUAh
9EJ6yV8iwBxYWWJd8gFAL1zQy1qLIcBfwE5WinYCQEGfT0utiSHAYf4DKbPy
AkBg6ZFpJeMgwLaVvjjCZwNA7IBj1wzXIMCvqhQXfdYDQFXUJKqtLSDAURxh
nYk/BECv5ayK5yIgwMj9nsV1owRAykkTIQvFHsDOEUy2uwIFQGraC5W4SR/A
vDSKScVdBUAmNAAGQMIewGmz5tPutAVABf5wLd8SHsAWQH4EiQgGQCNJ/S1d
RB3AZgymBNxYBkCEBSdALQAewMht5d0mpgZAmHnsXDKPHMA6mcUHovAGQHTg
Dakz8xzAlSeDB4A4B0Cq7dTcuIUcwE1Dkz7ufQdALYzTs0sbHMCQQGBSFcEH
QGh3qF6bRhzAiC1M0xoCCEDTIkIg4LgbwC5hhhMgQQhAESNqZ1sQHMBGqu6p
Q34IQBRkFzwNVRrA3EI/hKG5CEAeEyvI7vAbwHV70zNT8whAaUiiWxR+G8C+
4ugvcCsJQFFeJ2vBChvAKjnT1g1iCUCu8EmhS4UawG//PYJAlwlAhW6s/oK2
GMDNqh9dGssJQDZCXA7BIhnA2pJMb6z9CUAPDT7Gkn0XwEOMXYUGLwpAcp8G
l2q5G8AFBF1ON18KQEceHnUkHRrASqAKdkyOCkBfWFYq+vAbwKE2LD8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9buicWZPUswN64dwvy
SOQ/aTta9BiRK8DfVqmFon3tP7ctTl0FxCnA/AmBZtBQ8j8UU4r0eJ0nwIOR
BD6aO/U/KeVITvRlJcCF+JAQAbP3P6yQwUop0CTAZ8hRwvLV+T8Ztg3gQuUk
wFqa8FBjuPs/+XSMe2FjI8CrG0W78Wf9P0gnzIST3SLAXkJExlXu/j/fGFi3
5TAjwErxjfBdKQBAP1wU7dWSIsAwDFZVS80AQES8yBRVQyLAaPTEOBFlAUAB
VmVdULchwBxYWWJd8gFAKxYTGTf1IMBfwE5WinYCQB8AiAfUSSHAYf4DKbPy
AkBPTYx5/98gwLaVvjjCZwNANNoKGMuiIMCvqhQXfdYDQPL0ZNw0zB/AURxh
nYk/BEA0Sa4lRLkfwMj9nsV1owRAwW/XUw+KHsDOEUy2uwIFQGPrpGej8x3A
vDSKScVdBUAUM7nouMcewGmz5tPutAVAOlxImY33HMAWQH4EiQgGQOMrxcnU
KRzAZgymBNxYBkDYQTkTD7QcwMht5d0mpgZApUU8O/gSHMA6mcUHovAGQLcN
ICUj9BvAlSeDB4A4B0BLiHkQbq0bwE1Dkz7ufQdADBZOtjIpHMCQQGBSFcEH
QIM38kw9ARvAiC1M0xoCCECI37wLUysbwC5hhhMgQQhAX/FoP/8sG8BGqu6p
Q34IQMpZ5CD7jBnA3EI/hKG5CEBRp4NDECkawHV70zNT8whAkUhAlQRxGcC+
4ugvcCsJQFhdmqix+RnAKjnT1g1iCUBEpvIrwSMawG//PYJAlwlAKLnVFx2b
GcDNqh9dGssJQNMFpN7CmxjA2pJMb6z9CUBbjm2eKmkXwEOMXYUGLwpAIv5c
0mzLG8AFBF1ON18KQPig58/BKRjASqAKdkyOCkCKVRxkRe4ZwDuGMAE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9WauzELwApwN64dwvy
SOQ/k5aCntdAJ8DfVqmFon3tP7LfFqIWFiLA/AmBZtBQ8j8ENyUz8ScnwIOR
BD6aO/U/BQixQIkhJcCF+JAQAbP3P/Mb/y1SUyTAZ8hRwvLV+T9qBf14uQUk
wFqa8FBjuPs/5azZxf5sIsCrG0W78Wf9P38vhHOaHyLAXkJExlXu/j80M+9n
rGwiwErxjfBdKQBARG19WrcaIcAwDFZVS80AQBNVVO0ThiHAaPTEOBFlAUCL
HePyHOAhwBxYWWJd8gFAiRSfzpLtIMBfwE5WinYCQJzrBCdPwSDAYf4DKbPy
AkD+Gdmth3IgwLaVvjjCZwNA4PZVt6xlH8CvqhQXfdYDQINrYO0+ZB7AURxh
nYk/BEBBerKNGzAewMj9nsV1owRAkGJuupqCHsDOEUy2uwIFQOzN9YTcRB3A
vDSKScVdBUBSU8U0p+0dwGmz5tPutAVA9M4VpaGjHMAWQH4EiQgGQAeWExP8
QhzAZgymBNxYBkB5ubbVUX4cwMht5d0mpgZARcHxZIa0GsA6mcUHovAGQNYd
UrAJlBvAlSeDB4A4B0BsBAM5etgawE1Dkz7ufQdA7rzc7ch2GsCQQGBSFcEH
QHSZi4+LAhvAiC1M0xoCCEBON44UG5MawC5hhhMgQQhAEZHWQy68GsBGqu6p
Q34IQDUrKcjk1BjA3EI/hKG5CECJS5NCZYkZwHV70zNT8whAF6ipid/KGMC+
4ugvcCsJQOJXiBI9cxnAKjnT1g1iCUCt1Uj1sdYZwG//PYJAlwlAuhU1Hr7b
GcDNqh9dGssJQGVQbD3tzRjA2pJMb6z9CUCRtXKV048XwEOMXYUGLwpA77nn
8PfjGMAFBF1ON18KQLYvWsRTURvASqAKdkyOCkDTTaW7zcwawEhTOfE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8nathMW8AowN64dwvy
SOQ/9LDshMsCJ8DfVqmFon3tPzjokNE7tSbA/AmBZtBQ8j+V09eH1L0hwIOR
BD6aO/U/ux8Q7og9I8CF+JAQAbP3P355/GJFHiPAZ8hRwvLV+T9PQehLejci
wFqa8FBjuPs/ZEERbKkiI8CrG0W78Wf9Pw/VOlEOQSHAXkJExlXu/j8NLkIS
TociwErxjfBdKQBA6kht5xA9IcAwDFZVS80AQPSJyrwVfyHAaPTEOBFlAUCJ
QeLTa5cgwBxYWWJd8gFAFUyGK1WFIMBfwE5WinYCQFokEn5uUyDAYf4DKbPy
AkD7T85avwEfwLaVvjjCZwNATP4/OcZbH8CvqhQXfdYDQM5EAfC/dx3AURxh
nYk/BECFYxZYjcodwMj9nsV1owRAL0a58UszHcDOEUy2uwIFQGOMCtWKsR3A
vDSKScVdBUAnIkrTUyYcwGmz5tPutAVApPcqO6fHG8AWQH4EiQgGQJsU2IaA
KBzAZgymBNxYBkA+IQ1iu4gbwMht5d0mpgZAN7Z4UgZxG8A6mcUHovAGQOCd
LV2CIhvAlSeDB4A4B0CidifTvucbwE1Dkz7ufQdA/e/iqThwGsCQQGBSFcEH
QM6qsNBLVRrAiC1M0xoCCEDMF3cNne0ZwC5hhhMgQQhAdOv8ObpfGsBGqu6p
Q34IQNNlUsLPNxjA3EI/hKG5CEDIPOA7/ugYwHV70zNT8whA/JuF0T3lGMC+
4ugvcCsJQJh2J3gUARnAKjnT1g1iCUB6grNrC9wYwG//PYJAlwlABv8PDQx4
GsDNqh9dGssJQH+2H+o0nBjA2pJMb6z9CUAYpvK/HNYVwEOMXYUGLwpAQA+y
PbMiGcAFBF1ON18KQB3N2yBeYRrASqAKdkyOCkDU1ajMYU8awPfyMmg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9OH2euxi8rwN64dwvy
SOQ/ThEYsbvZKMDfVqmFon3tP1yn2yeFESXA/AmBZtBQ8j8DUlj6ElgiwIOR
BD6aO/U/nE/cBu8IJ8CF+JAQAbP3P3ITv/+vLCTAZ8hRwvLV+T/VEmnJ60oj
wFqa8FBjuPs/oTcphOOkIsCrG0W78Wf9Pz5QzQlmbyHAXkJExlXu/j9FxEXK
wNQiwErxjfBdKQBARGDNkgdWIcAwDFZVS80AQEUkr7rThiHAaPTEOBFlAUDR
DckyXkYhwBxYWWJd8gFAO1tjz/93IMBfwE5WinYCQJ7+1L2kbCDAYf4DKbPy
AkCpjh07U58fwLaVvjjCZwNAVccu5w7sH8CvqhQXfdYDQOFzMCH5sx7AURxh
nYk/BEBeotHaehAewMj9nsV1owRAyq+LLCYYHsDOEUy2uwIFQKVk3vG90R7A
vDSKScVdBUDGRTy+7pgcwGmz5tPutAVAEV+PjytkHMAWQH4EiQgGQEnu3HnU
wBvAZgymBNxYBkC9+M1bcuocwMht5d0mpgZABSVo+LsMG8A6mcUHovAGQOzx
gfN6VRvAlSeDB4A4B0CzqgCSXLsawE1Dkz7ufQdAKxnglMDcGsCQQGBSFcEH
QPXz3XOHkBrAiC1M0xoCCEAyhUlb/qcawC5hhhMgQQhAxjEUoWWbGsBGqu6p
Q34IQP5yeN6l9BjA3EI/hKG5CEAwFAmogIEawHV70zNT8whA6cZ5B6jcGcC+
4ugvcCsJQEV2GfoGShnAKjnT1g1iCUCk/J9TErEYwG//PYJAlwlA7MK25HuR
GcDNqh9dGssJQO6z7LsWjhnA2pJMb6z9CUAJ8cP9xZ4WwEOMXYUGLwpAmEiI
AN6XGMAFBF1ON18KQB17Mo05KRjASqAKdkyOCkDTUuqb5+AZwL46PlU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/XRMdIkFQtwN64dwvy
SOQ/2sJQB52zKsDfVqmFon3tP7htiD94VCbA/AmBZtBQ8j/SUcc0UnggwIOR
BD6aO/U/0scvfhBFJsCF+JAQAbP3P1kxdf1UziTAZ8hRwvLV+T/6xac9ZAsk
wFqa8FBjuPs/RJ6vFI+dI8CrG0W78Wf9P2Sx7IIWbCLAXkJExlXu/j/pZ8Dz
ahgjwErxjfBdKQBAjyUPFa/+IcAwDFZVS80AQF+rwRqiKyLAaPTEOBFlAUDj
4aLqzxEiwBxYWWJd8gFAHJstOuz/IMBfwE5WinYCQDLrHFiELSHAYf4DKbPy
AkBwIfQfo18hwLaVvjjCZwNAaGswHZZ4IMCvqhQXfdYDQHaU0lT6hB7AURxh
nYk/BEAxR9s6OmMfwMj9nsV1owRA871sZWYuH8DOEUy2uwIFQBv+qsdn8B7A
vDSKScVdBUBLVOnLvVUdwGmz5tPutAVAbHtN0mjbHMAWQH4EiQgGQI0sB+6g
zhzAZgymBNxYBkDpnMLMZ4gdwMht5d0mpgZAS3DrPRiSG8A6mcUHovAGQN9q
Uh+ucBvAlSeDB4A4B0CUS739QQIcwE1Dkz7ufQdAjA07vSIYG8CQQGBSFcEH
QKJttGhtpxrAiC1M0xoCCEBLy6wBqJMbwC5hhhMgQQhA1g79b5TfGsBGqu6p
Q34IQGHS9D3+0xnA3EI/hKG5CEBX2f+M0GEbwHV70zNT8whAPJo2qyh7GsC+
4ugvcCsJQFSBDOlr8hnAKjnT1g1iCUBGtqBSiuMawG//PYJAlwlAHMTo9yzL
GsDNqh9dGssJQHu1tS1eQhnA2pJMb6z9CUAG0tGrPYgXwEOMXYUGLwpAZAsL
CINeG8AFBF1ON18KQMtv7c+NxRnASqAKdkyOCkCBxBc0R/AYwNuxOXg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Mm/o99uIswN64dwvy
SOQ/0zZ6xTKpK8DfVqmFon3tP68ihkLclyXA/AmBZtBQ8j+FZH3DXygdwIOR
BD6aO/U/6LylklMpJsCF+JAQAbP3P4XA5eOhDCbAZ8hRwvLV+T+1ABU7YcQk
wFqa8FBjuPs/dXlTcsm2I8CrG0W78Wf9P2VSstAi1yLAXkJExlXu/j9SYGFz
gXgjwErxjfBdKQBAI3FrHzPdIsAwDFZVS80AQM7nG3BvpCLAaPTEOBFlAUC9
ghrZw7oiwBxYWWJd8gFAmQBqdprfIcBfwE5WinYCQNDFioximyHAYf4DKbPy
AkDQTaUu3aYgwLaVvjjCZwNA2f134mtOIMCvqhQXfdYDQNn0CLzMAiDAURxh
nYk/BECN7vXY2NsfwMj9nsV1owRA5pnNBl4nH8DOEUy2uwIFQOl93z/xzx/A
vDSKScVdBUCWVoQXBgQewGmz5tPutAVAc/rBE4pmHcAWQH4EiQgGQArmTf1l
OB3AZgymBNxYBkCgCaHqpToewMht5d0mpgZAeYWRzLBvHcA6mcUHovAGQPi0
wE0fWhzAlSeDB4A4B0C7i/nYJQYcwE1Dkz7ufQdAG8WL/0o6HMCQQGBSFcEH
QCOnTQV6rxvAiC1M0xoCCECYkS2ohRAcwC5hhhMgQQhAfD1fS0j3G8BGqu6p
Q34IQBCtq+Fr/xnA3EI/hKG5CEDE0387J9QawHV70zNT8whAwV+Vz+PuGcC+
4ugvcCsJQLnecRhgPhvAKjnT1g1iCUDSryN++jAZwG//PYJAlwlAa2pci6HB
GsDNqh9dGssJQCTI2tZ+GRnA2pJMb6z9CUDTJvTs06MZwEOMXYUGLwpA8kBj
Ok1UGsAFBF1ON18KQCVEwaBsXxnASqAKdkyOCkCWy3Gz2sQawNRWQAk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8+gSDUTOgrwN64dwvy
SOQ/IFj87WgxK8DfVqmFon3tP54vr4s+BSTA/AmBZtBQ8j92DB34z08kwIOR
BD6aO/U/O/E0WopJJsCF+JAQAbP3PxwVQ5/f3yXAZ8hRwvLV+T9cZxrEQdwk
wFqa8FBjuPs/2mB4IymqI8CrG0W78Wf9PxWJ3Ty1uiLAXkJExlXu/j/PN2/A
QrIjwErxjfBdKQBALblhufXEIsAwDFZVS80AQP+NPx8UpCLAaPTEOBFlAUCJ
WKPx3UwiwBxYWWJd8gFA7e1bkJhEIcBfwE5WinYCQKea+efBpyHAYf4DKbPy
AkBmjOLU/9UgwLaVvjjCZwNALtoj3S66IMCvqhQXfdYDQDPHLeVxRyDAURxh
nYk/BEDB17S1N7kfwMj9nsV1owRA2unxZg+/HsDOEUy2uwIFQFRAOJ+EbR/A
vDSKScVdBUBZWD2kNL8ewGmz5tPutAVAQRKOF1ggHsAWQH4EiQgGQC79rj0x
Zh3AZgymBNxYBkA1ZM6X1pwdwMht5d0mpgZA51c2ZhwQHcA6mcUHovAGQAjP
5JfeahzAlSeDB4A4B0DHLdprLLkcwE1Dkz7ufQdALOdeqsxWHMCQQGBSFcEH
QG6MAcJvPRzAiC1M0xoCCECjM8GdDNMbwC5hhhMgQQhAM9mcesRTG8BGqu6p
Q34IQKXGaWbyLhvA3EI/hKG5CEC+QIB84CsbwHV70zNT8whAB5CAaeKcGsC+
4ugvcCsJQPF4jUSkzhrAKjnT1g1iCUATI3Z1bvwZwG//PYJAlwlAamRmG9wm
GsDNqh9dGssJQMp6gMZ6hRrA2pJMb6z9CUAgWZCetd4XwEOMXYUGLwpAmXhP
9BS0GcAFBF1ON18KQJqEU9N3UxnASqAKdkyOCkDR8WLuQZ8bwATjOlo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+ZOuPEMlorwN64dwvy
SOQ/vW/o/8JlKcDfVqmFon3tP9UOwbVnCyfA/AmBZtBQ8j8glfywVAcRwIOR
BD6aO/U//dwKDwcYJsCF+JAQAbP3P4iK0p3YiiTAZ8hRwvLV+T/HrGyHwcUj
wFqa8FBjuPs/2zpTv/FSJMCrG0W78Wf9PwcRj7kRRSLAXkJExlXu/j/VhACg
JeoiwErxjfBdKQBA1/Xj4JIJIsAwDFZVS80AQPccG/KDtyHAaPTEOBFlAUCf
TAb1GoEhwBxYWWJd8gFAkmfkAu+wIMBfwE5WinYCQN+oEBnnRyHAYf4DKbPy
AkBWxN7faIwgwLaVvjjCZwNAomtKX75YIMCvqhQXfdYDQHxDke07AR/AURxh
nYk/BEDvkVwYt60ewMj9nsV1owRACtnJ/s8ZHsDOEUy2uwIFQBXEteNrdB7A
vDSKScVdBUBeHnrlJrccwGmz5tPutAVAqVmQjXIBHcAWQH4EiQgGQAmghaeJ
RRzAZgymBNxYBkCBYy5qYh4dwMht5d0mpgZAyooGt7pAHMA6mcUHovAGQHHE
hTZ9NRvAlSeDB4A4B0Ce8Zpv1cwbwE1Dkz7ufQdA5C8zeWBYG8CQQGBSFcEH
QDF+5rgIJhrAiC1M0xoCCEAm2Q5K8SEawC5hhhMgQQhAgRWfsSppGsBGqu6p
Q34IQBL1bSQoQBnA3EI/hKG5CEDhTjf6SUQZwHV70zNT8whAtXd2YhXvGcC+
4ugvcCsJQOT2HpGilBrAKjnT1g1iCUCqtuDLVr8ZwG//PYJAlwlA/lU3BhKu
GsDNqh9dGssJQDd/pahcwxfA2pJMb6z9CUB9oOfXPYMXwEOMXYUGLwpAPQ5C
PqxpGcAFBF1ON18KQLVUgz2UVRrASqAKdkyOCkD/uhKgxLEYwBgrN5k=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9F+LIEaPwnwN64dwvy
SOQ/TO/hQyDDI8DfVqmFon3tP+0srE4IiSPA/AmBZtBQ8j/aZ7T00jYEwIOR
BD6aO/U/Q5sO7vj7I8CF+JAQAbP3P8x6MyHzaSPAZ8hRwvLV+T8Lcb00cvMi
wFqa8FBjuPs/UWs1b883IsCrG0W78Wf9P/5QWfzBKyHAXkJExlXu/j8NZ2k9
dfshwErxjfBdKQBAqriqSjocIsAwDFZVS80AQFP/AwMlKSHAaPTEOBFlAUCa
Ct47pncgwBxYWWJd8gFAEm/g66/GH8BfwE5WinYCQBQeKRxQKSDAYf4DKbPy
AkC7xeSasyMewLaVvjjCZwNATwUL7x6pH8CvqhQXfdYDQPvYgo+WMh7AURxh
nYk/BED6C/a7Ck8ewMj9nsV1owRAS3Nl4uEbHcDOEUy2uwIFQPeK8wN7bh3A
vDSKScVdBUDDreou/JgdwGmz5tPutAVABp+U+5CqHMAWQH4EiQgGQLNhTpCC
tBvAZgymBNxYBkCr1/i/IcwbwMht5d0mpgZAt3PfnKPBGsA6mcUHovAGQPlf
/UNhhxrAlSeDB4A4B0AQkiqrlpEbwE1Dkz7ufQdA/9mcjr0PGsCQQGBSFcEH
QBeLaysOkxrAiC1M0xoCCEApIl2ebUwawC5hhhMgQQhAb7HzgUo1GsBGqu6p
Q34IQMpQTQslchjA3EI/hKG5CECHkhXt5DAZwHV70zNT8whAVwuPxt5eGMC+
4ugvcCsJQDggEtEaDxnAKjnT1g1iCUAATdeQJMkYwG//PYJAlwlA79TD+ZFn
GMDNqh9dGssJQMc/uISAfRjA2pJMb6z9CUCYxCEBL7sWwEOMXYUGLwpAYf7Y
QDY2GsAFBF1ON18KQDVRxNr8PBrASqAKdkyOCkCgUw87wm8awBRtNsk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+D7oG9RkUUwN64dwvy
SOQ/fGKcXWC7B8DfVqmFon3tPzxGlYORISTA/AmBZtBQ8j9r9tzO8RgUwIOR
BD6aO/U/pEV5Pg7PJcCF+JAQAbP3PzigVqwj0CTAZ8hRwvLV+T+PHvz1wDwk
wFqa8FBjuPs/HegVebjbIsCrG0W78Wf9P+tLs3LJLCLAXkJExlXu/j8BSfXb
w+QiwErxjfBdKQBAH9h3iYo1IsAwDFZVS80AQAShoj6cniHAaPTEOBFlAUDP
RqC9HawhwBxYWWJd8gFAuC3KmJ+IIMBfwE5WinYCQCuS8onMTyHAYf4DKbPy
AkA2w0XM9wogwLaVvjjCZwNAyXJBbfVhIMCvqhQXfdYDQJo1Fg7MiB7AURxh
nYk/BEAABkNrYGwewMj9nsV1owRAT/iwTjisHcDOEUy2uwIFQMkYjG4T9h7A
vDSKScVdBUB9raOHqMsdwGmz5tPutAVAWW79wzGzHMAWQH4EiQgGQCtwhxcU
ThzAZgymBNxYBkCWJ4PAt2AcwMht5d0mpgZASJHyRPtFG8A6mcUHovAGQJdG
gMxqPBvAlSeDB4A4B0DdHon0rxAbwE1Dkz7ufQdA9v2VXx3TGsCQQGBSFcEH
QEhnMtTAIxvAiC1M0xoCCEDdfp0XK9EawC5hhhMgQQhAIySPNY2uGcBGqu6p
Q34IQOw9/jveURnA3EI/hKG5CECno0u5OOgZwHV70zNT8whA2pXSXYYPGcC+
4ugvcCsJQJ1tBhpIgRnAKjnT1g1iCUC9mpt/zvYYwG//PYJAlwlABwmnPdRW
GcDNqh9dGssJQI7V+CiFbhjA2pJMb6z9CUCK8ieW5P4WwEOMXYUGLwpAwYJ/
4NTAG8AFBF1ON18KQGS6QCDZsBjASqAKdkyOCkAgImn3vvYZwKFbOrI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Uc+cU8EcXQN64dwvy
SOQ/Fq+BAwIkH0DfVqmFon3tP/lOkva5YeA//AmBZtBQ8j9f59D7kSPUP4OR
BD6aO/U/4TGIOx2hGsCF+JAQAbP3P8yH1iG0wiDAZ8hRwvLV+T9t2ZKhxq8j
wFqa8FBjuPs/lk0qAhMNJMCrG0W78Wf9P93Hcw4jlCPAXkJExlXu/j9XTqWB
ReUjwErxjfBdKQBAja1DtlxEI8AwDFZVS80AQAq2fN3OuCLAaPTEOBFlAUCD
qBIxkxUiwBxYWWJd8gFALAVQDuJeIcBfwE5WinYCQLYNpwuN7SHAYf4DKbPy
AkCBJhP2IdYgwLaVvjjCZwNAswyEjYTyIMCvqhQXfdYDQOAD6E7ITSDAURxh
nYk/BEA78E+CRmsgwMj9nsV1owRAU1267M4GIMDOEUy2uwIFQKWCpEnm/R7A
vDSKScVdBUC9HRUukeUewGmz5tPutAVAe4gmqh8WHsAWQH4EiQgGQAUcqAFp
dR3AZgymBNxYBkCzm9vzCxsewMht5d0mpgZAf062eQkzHMA6mcUHovAGQFn3
YOIrPhzAlSeDB4A4B0C7lB3qswQdwE1Dkz7ufQdAJvCfoxFiHMCQQGBSFcEH
QNA36VvpwBvAiC1M0xoCCEDKp6a3hvYbwC5hhhMgQQhAhL6UQdnoGsBGqu6p
Q34IQIDtN0pARRvA3EI/hKG5CED3qN5OIGEawHV70zNT8whAdBF7IX4JGsC+
4ugvcCsJQGQC0Q/LvxrAKjnT1g1iCUBS1vNYPCQZwG//PYJAlwlABUVlS3eu
HcDNqh9dGssJQP8RyyloWRrA2pJMb6z9CUBMoiCDa70XwEOMXYUGLwpAGkZe
Mq6MG8AFBF1ON18KQE/zdQNCwxnASqAKdkyOCkABXH5ajn4awB7dL5U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/L+roB6mAoQN64dwvy
SOQ/jdigSkwbK0DfVqmFon3tP4euT0eU6ypA/AmBZtBQ8j/1rrSJ9hIrQIOR
BD6aO/U/o3DhZ9uWK0CF+JAQAbP3P5CcxHZMcytAZ8hRwvLV+T9orzTwTK4q
QFqa8FBjuPs/YRRQWiHoKUCrG0W78Wf9P5hkzAe10CdAXkJExlXu/j9ihExg
v8UkQErxjfBdKQBAJjf0UIwNJEAwDFZVS80AQEOK06hcGiRAaPTEOBFlAUAV
dDIo8UgkQBxYWWJd8gFA3JbqzHD4IkBfwE5WinYCQOPg2hrOpSJAYf4DKbPy
AkD5HM5rKIEhQLaVvjjCZwNAfru6eF21IECvqhQXfdYDQC/1X/sU+x5AURxh
nYk/BEDmLbcEYJMbQMj9nsV1owRA/aov/paQGkDOEUy2uwIFQGsa+3jujhlA
vDSKScVdBUAec3LYnXMWQGmz5tPutAVAavablSyeE0AWQH4EiQgGQB58ruLP
oBJAZgymBNxYBkB0/Uz3bkYRQMht5d0mpgZApm/ovzQiDUA6mcUHovAGQDxA
DHuvIQpAlSeDB4A4B0AdsskJ7l8JQE1Dkz7ufQdAaCgfVbOsBkCQQGBSFcEH
QBsDFAJEMQRAiC1M0xoCCECuVrat+gMDQC5hhhMgQQhAVPTFlr/h/D9Gqu6p
Q34IQDdyayNE0+8/3EI/hKG5CEC8Z16TobjlP3V70zNT8whAE0YaBeWnwj++
4ugvcCsJQDWhAeMNasq/KjnT1g1iCUDRqJQ5Jnr/v2//PYJAlwlALYx+uYgd
97/Nqh9dGssJQMu7LErI6QPA2pJMb6z9CUAUMZfWK1z3v0OMXYUGLwpApZmP
XHMjCMAFBF1ON18KQC3IKkNZz+q/SqAKdkyOCkClruNkiQL5v3HILj4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8WHR0jMiQsQN64dwvy
SOQ/WQN+XA7dKUDfVqmFon3tP27EQuM+FCxA/AmBZtBQ8j9d9hQIWSkrQIOR
BD6aO/U/O73YtAzaKUCF+JAQAbP3P5wXnoFkWytAZ8hRwvLV+T86J7PWTYUr
QFqa8FBjuPs/KD4K1JV4LUCrG0W78Wf9P4C1GrRHOSxAXkJExlXu/j9FZKoQ
AH8rQErxjfBdKQBAvISeGOOoKkAwDFZVS80AQBiPOjNmECpAaPTEOBFlAUB4
lfUoz7AoQBxYWWJd8gFApp1QMlzlJkBfwE5WinYCQDVcGRQWliZAYf4DKbPy
AkBjl54o7YUlQLaVvjjCZwNAgoLcattUJECvqhQXfdYDQEYvU0FqqCNAURxh
nYk/BECy/d0HWIYiQMj9nsV1owRAl7D7191+IUDOEUy2uwIFQOzBGAZ6MB9A
vDSKScVdBUBqtEJLtXMgQGmz5tPutAVAlzOkxO5FHUAWQH4EiQgGQP1ucFvI
4htAZgymBNxYBkBxcp5uIU8ZQMht5d0mpgZAc3gCg3abF0A6mcUHovAGQGTO
VIF7CxdAlSeDB4A4B0DW+7N30w0WQE1Dkz7ufQdATOP70B7UE0CQQGBSFcEH
QJB73Pzy/RBAiC1M0xoCCEAeUU+wVuQNQC5hhhMgQQhAghjL8IYaBkBGqu6p
Q34IQEHyNu4kjwJA3EI/hKG5CECSE8LyVicGQHV70zNT8whAEp5GhMzCA0C+
4ugvcCsJQCwH9nIfeQdAKjnT1g1iCUDCrBVa+gIBQG//PYJAlwlAtm6kjuk5
AEDNqh9dGssJQGh1w+6vcPs/2pJMb6z9CUBob0OEBlbiv0OMXYUGLwpAHaQa
gEjG/b8FBF1ON18KQPzHyACqUfG/SqAKdkyOCkAeyJDIBpHCPxUHIL4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8F65NFi4srQN64dwvy
SOQ/WUxVU/4iL0DfVqmFon3tPyrXAVrp5C5A/AmBZtBQ8j+nHMHQD/0tQIOR
BD6aO/U/zir/50NRLUCF+JAQAbP3P895jYD02yxAZ8hRwvLV+T8Kfw17mGEt
QFqa8FBjuPs/N/6ifGNQLkCrG0W78Wf9P17sfH+kXS1AXkJExlXu/j/1Mu5K
37EqQErxjfBdKQBACTRwKT8rK0AwDFZVS80AQMtaDiLESytAaPTEOBFlAUDd
u31/8ncqQBxYWWJd8gFAJgqvwxdTKEBfwE5WinYCQGctEwCO3CdAYf4DKbPy
AkBs5BvNdpMmQLaVvjjCZwNAYkSBorBsJ0CvqhQXfdYDQG5tfRWdISZAURxh
nYk/BEDRi3zWzaElQMj9nsV1owRAX+hEaKlEJEDOEUy2uwIFQEmBqggp2yRA
vDSKScVdBUDCfltGAkoiQGmz5tPutAVAK4wvNTqsIkAWQH4EiQgGQM5l2qeF
0yFAZgymBNxYBkBdiT51OpshQMht5d0mpgZABM4ypoLBIEA6mcUHovAGQNtj
KqYTlh5AlSeDB4A4B0Ag0gM5DEwdQE1Dkz7ufQdAJhJF9cbiG0CQQGBSFcEH
QMHvPAtM1BlAiC1M0xoCCEDpLF3zbBsaQC5hhhMgQQhAwdQrAD77F0BGqu6p
Q34IQFfhLxS+nRZA3EI/hKG5CECx4mvIH4MVQHV70zNT8whAxU3H7RZbEkC+
4ugvcCsJQIv5s46ppRBAKjnT1g1iCUDhVw1klVQQQG//PYJAlwlAiNMws3Dx
C0DNqh9dGssJQCMdAzpEEg1A2pJMb6z9CUCJrKQWaNYEQEOMXYUGLwpAa87A
NkTz7T8FBF1ON18KQPmD52pCufo/SqAKdkyOCkAnkx5/hf4BQOXqH6M=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/BvIvHOtopQN64dwvy
SOQ/S5+DnfnNK0DfVqmFon3tP6PImRZ0PjBA/AmBZtBQ8j9xaYDZfdgrQIOR
BD6aO/U/bkzEwpZNLkCF+JAQAbP3P5mDoEyu7ixAZ8hRwvLV+T8f5H/wkjot
QFqa8FBjuPs/mRMeonxJLUCrG0W78Wf9P0w8UL5zmy1AXkJExlXu/j95QPVp
/VMsQErxjfBdKQBAf+QZGcBMK0AwDFZVS80AQCwfijedEStAaPTEOBFlAUCb
APgs1OEpQBxYWWJd8gFAyc3Ogft/KUBfwE5WinYCQEVLOwxBNylAYf4DKbPy
AkBeEiS/zlMpQLaVvjjCZwNAQrX02c5qKECvqhQXfdYDQDq53oDQUSlAURxh
nYk/BECpHmefAusmQMj9nsV1owRAf+DmFfdxJkDOEUy2uwIFQJh+5msgDydA
vDSKScVdBUD9gi7szRQnQGmz5tPutAVAhsBGosIfJUAWQH4EiQgGQE0p2iOF
RSRAZgymBNxYBkCyGf6kdOckQMht5d0mpgZA0fj8Iw11I0A6mcUHovAGQDIU
ht4h5CNAlSeDB4A4B0D8JsLdTZQiQE1Dkz7ufQdARlhsfL0SJECQQGBSFcEH
QOzj7TQrlyJAiC1M0xoCCEDJ6/HYAG0hQC5hhhMgQQhAvACo1C4LIkBGqu6p
Q34IQGcRMaK4kh9A3EI/hKG5CEDtBLguKxocQHV70zNT8whA8iPixFTsFUC+
4ugvcCsJQEE8cCT5/BdAKjnT1g1iCUDxAMaMtwsaQG//PYJAlwlAJwonuhgC
E0DNqh9dGssJQIxb5dMRhxhA2pJMb6z9CUBqtYkccikYQEOMXYUGLwpAFm+l
aOY6EkAFBF1ON18KQGwz5q28wxZASqAKdkyOCkAHRSkoMWUUQGeBIh4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/zBx5AACoqQN64dwvy
SOQ/9xqWmAnoLEDfVqmFon3tPzWepMA1FSxA/AmBZtBQ8j9MqWLBB6AtQIOR
BD6aO/U/j+l5gEjOLECF+JAQAbP3P3ESLEq2Fi1AZ8hRwvLV+T81uYAUYFou
QFqa8FBjuPs/Ehm5uFI2LUCrG0W78Wf9P3XnLwPQTyxAXkJExlXu/j9o11F+
YBgtQErxjfBdKQBAYf4gDpofLEAwDFZVS80AQK+/9eDTGCtAaPTEOBFlAUBZ
xR5h6j8rQBxYWWJd8gFAPZsDdl/pKkBfwE5WinYCQBz2RmouCCpAYf4DKbPy
AkDGyy/J9JgpQLaVvjjCZwNA/PuUzeDzKUCvqhQXfdYDQBb2u5h+eSlAURxh
nYk/BECMoKWA0pEpQMj9nsV1owRA2vruFNy4KEDOEUy2uwIFQBY9EuD5TyhA
vDSKScVdBUB82vghtXwoQGmz5tPutAVAWrrCSSuCJ0AWQH4EiQgGQDdyHeFy
xSVAZgymBNxYBkB7dsuUnDQlQMht5d0mpgZA8WHY31n9JEA6mcUHovAGQHiz
JtMyVyRAlSeDB4A4B0CVJ/iyR28lQE1Dkz7ufQdALrVsX2xOJECQQGBSFcEH
QEijAbQ2TCNAiC1M0xoCCECOkEbYkNAiQC5hhhMgQQhA86//DbgcIUBGqu6p
Q34IQEQ5+2Bk6SBA3EI/hKG5CEAiH+rHbKQZQHV70zNT8whA3ezivRuIGkC+
4ugvcCsJQGX1dOi+7xlAKjnT1g1iCUC86n9qyQYbQG//PYJAlwlAvbLXLJuw
GUDNqh9dGssJQO5U3C+4HBlA2pJMb6z9CUAhD3FfDLoWQEOMXYUGLwpAqs7x
5kfqGEAFBF1ON18KQLBlSGf0yRhASqAKdkyOCkAhrGbVzq0NQHFDKAA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT93txYkmzsuQN64dwvy
SOQ/6iQIWMZKLUDfVqmFon3tP6tTAzWsLy5A/AmBZtBQ8j/tXQYok8MtQIOR
BD6aO/U/LcDjCNyaLUCF+JAQAbP3P50HjrM1uy1AZ8hRwvLV+T/VzKlN3Ewu
QFqa8FBjuPs/m87HIiUrLUCrG0W78Wf9P+kk6jdTLy1AXkJExlXu/j+EVEP6
zPwsQErxjfBdKQBASrImMPgVLEAwDFZVS80AQJyHnFXD3StAaPTEOBFlAUCi
hPsGBsArQBxYWWJd8gFA2VV2beqoK0BfwE5WinYCQEvusm7TFytAYf4DKbPy
AkCmYcR1Ur4qQLaVvjjCZwNApI1MXWkNKkCvqhQXfdYDQOQT4ks+zilAURxh
nYk/BEB/RR30kZUpQMj9nsV1owRAJ39PqOrUKEDOEUy2uwIFQDuMavGp5ShA
vDSKScVdBUAudKrQ0O4nQGmz5tPutAVAEEZDY+EzKEAWQH4EiQgGQD1Pm/kO
nSdAZgymBNxYBkDpF9DelK4mQMht5d0mpgZAyiPULD60JkA6mcUHovAGQCCw
lFFmgSVAlSeDB4A4B0BFvThYUPMkQE1Dkz7ufQdATvOZagN6JUCQQGBSFcEH
QDX/P7TF/SRAiC1M0xoCCECKnAwOFKEjQC5hhhMgQQhAyhkjf5FlIUBGqu6p
Q34IQAbWwdyNmSBA3EI/hKG5CEC3wlft4g8gQHV70zNT8whANWPeQ6KgHkC+
4ugvcCsJQMGgLQNfXB5AKjnT1g1iCUAhxg5g1E8bQG//PYJAlwlA4202Dnhq
G0DNqh9dGssJQOlzBsiK6xpA2pJMb6z9CUCy4eQINKYXQEOMXYUGLwpAZv3F
hj8SF0AFBF1ON18KQI51MJpsHRpASqAKdkyOCkBmmT5pN9AZQBMlIfY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8oBpBDcTYsQN64dwvy
SOQ/D/j4Px6ELUDfVqmFon3tP/Q0FJUT5i1A/AmBZtBQ8j9zgQe0hagtQIOR
BD6aO/U/udKtdVygLUCF+JAQAbP3P/zLTTm2CS5AZ8hRwvLV+T/zfX/n+qIt
QFqa8FBjuPs/ioDLDnPFLUCrG0W78Wf9P8XWE6PSfi1AXkJExlXu/j8RubyX
ufosQErxjfBdKQBAZ6pXLwrCLEAwDFZVS80AQPi9NsefKSxAaPTEOBFlAUDJ
WsK6b+ErQBxYWWJd8gFAEWUKS++GK0BfwE5WinYCQKmCqs1EQytAYf4DKbPy
AkBC+vU0Ku4qQLaVvjjCZwNAVtdnRkqwKkCvqhQXfdYDQH/P4vFQmipAURxh
nYk/BEDV03LI0T0qQMj9nsV1owRAGAgbbFw0KkDOEUy2uwIFQEpPUasixylA
vDSKScVdBUDReRLv34opQGmz5tPutAVA7vp6ezJxKEAWQH4EiQgGQA5MJ3Kd
nyhAZgymBNxYBkAezqNhuUcoQMht5d0mpgZA7yedMftPJ0A6mcUHovAGQLIu
tJaV1SZAlSeDB4A4B0DPrB+AGkQmQE1Dkz7ufQdALm7c6zakJkCQQGBSFcEH
QKyZ1asmRyZAiC1M0xoCCEBX5p+cYJglQC5hhhMgQQhANYb4uxGiI0BGqu6p
Q34IQGBmslWmLyNA3EI/hKG5CEC5vZwd8S4iQHV70zNT8whAkZ14hxt8IUC+
4ugvcCsJQBjiDJstsCBAKjnT1g1iCUCWw8NFbw8gQG//PYJAlwlAsb3ayTtW
HUDNqh9dGssJQC4TL9j/eh5A2pJMb6z9CUBeiaQYPCEbQEOMXYUGLwpAzsfF
sodXGkAFBF1ON18KQDOQDx444h1ASqAKdkyOCkDop1C5ziUdQOilJdA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/oFKj+fPMtQN64dwvy
SOQ/YgKNSNyhLkDfVqmFon3tP7xUjbOjpy5A/AmBZtBQ8j90SMG6yA0uQIOR
BD6aO/U/BVe/yLWTLUCF+JAQAbP3P0XI0GDNdy1AZ8hRwvLV+T/9LOnBCPYs
QFqa8FBjuPs/0d4DiLS5LUCrG0W78Wf9P2mHJ+LPMC1AXkJExlXu/j/1ZYSU
kx0tQErxjfBdKQBAs424QXvfLEAwDFZVS80AQIUMifImcyxAaPTEOBFlAUDl
ozZQ460sQBxYWWJd8gFA+yzzAvBfLEBfwE5WinYCQGGGkFSjDCxAYf4DKbPy
AkDG7KuQbbQrQLaVvjjCZwNAutiCeUSoK0CvqhQXfdYDQCKmE7xk1CpAURxh
nYk/BEDadeVUmYQqQMj9nsV1owRA8vR4vk0/KkDOEUy2uwIFQB2kHjoW3ylA
vDSKScVdBUDWjNL0kkkpQGmz5tPutAVAB0drwquyKEAWQH4EiQgGQANzYpaI
sShAZgymBNxYBkDzP4LwCyQoQMht5d0mpgZAWTMbOVTgJ0A6mcUHovAGQOse
9gUDCidAlSeDB4A4B0Aq4Xwdv8UmQE1Dkz7ufQdASYRVDuZwJ0CQQGBSFcEH
QMax7xHhQCZAiC1M0xoCCEAPxwgcmW4lQC5hhhMgQQhAxeQfaoSXJEBGqu6p
Q34IQHEZHYAPCyRA3EI/hKG5CEC8CV+4RZ4iQHV70zNT8whAlnf0nQ2hIUC+
4ugvcCsJQLMsDKN8DSFAKjnT1g1iCUBBKHgs3FYgQG//PYJAlwlA+pH5D4qE
IEDNqh9dGssJQFvHlIUt8RxA2pJMb6z9CUABFQiLC8EdQEOMXYUGLwpAyX8B
G6ASG0AFBF1ON18KQEBX+Af1KxxASqAKdkyOCkDcX0pdCfgcQAizIi0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+HsXDYWn0uQN64dwvy
SOQ/o6Zzs2cgLUDfVqmFon3tP11ZwcJAqi5A/AmBZtBQ8j+Jejb2TX4uQIOR
BD6aO/U/Q6u5Lp9eLkCF+JAQAbP3PxKCKZOGfC1AZ8hRwvLV+T+t8I2gMF0t
QFqa8FBjuPs/uiJrIIyCLUCrG0W78Wf9PwXJQskZKS1AXkJExlXu/j+aopIc
j04tQErxjfBdKQBAUDyITqCpLEAwDFZVS80AQK96ffcDbCxAaPTEOBFlAUD+
UaJOXgUsQBxYWWJd8gFAXA3+le20LEBfwE5WinYCQMAtyv6zZyxAYf4DKbPy
AkDwWOoNwRAsQLaVvjjCZwNAbnckyUV6K0CvqhQXfdYDQNrdV+BlCitAURxh
nYk/BEAVN/dIKMAqQMj9nsV1owRAYdfOi/rMKkDOEUy2uwIFQMpRnr09rSpA
vDSKScVdBUA+xOstJJspQGmz5tPutAVAMxoLcjdgKUAWQH4EiQgGQI5vhdQR
VSlAZgymBNxYBkBx/M3w7YUoQMht5d0mpgZAh4N5XTgeKEA6mcUHovAGQFme
pv3b/CdAlSeDB4A4B0AsqthvT68nQE1Dkz7ufQdAb7cJiZo+J0CQQGBSFcEH
QG1da+TjTSdAiC1M0xoCCEDt9qeXRl0mQC5hhhMgQQhAYcf4uPeIJEBGqu6p
Q34IQOaAaPpqWyRA3EI/hKG5CEBErKXN/0YkQHV70zNT8whAdf1RGmvIIkC+
4ugvcCsJQHacj/+tSiJAKjnT1g1iCUArIbgZ77ggQG//PYJAlwlApQNHMkWd
HkDNqh9dGssJQJTGt4QZSyBA2pJMb6z9CUAHi4Fw0y8gQEOMXYUGLwpAa8Zk
BdlyHkAFBF1ON18KQKu9tMp6eB9ASqAKdkyOCkDSUHNqYzAdQNBgJkM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.368999498172113},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox[
       "\"Power: k^2 |\\!\\(\\*SubscriptBox[\\(\[Phi]\\), \\(I\\)]\\)|^2\"", 
        TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-6.907755278982137, 
           FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            
            TemplateBox[{"10", "5"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotLabel->FormBox["\"Run 0\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.4221101208385005`*^9, 3.4221102189966354`*^9, 
  3.42211045857936*^9, 3.422110805929779*^9, 3.423922643789302*^9, 
  3.424185049605993*^9, 3.424187242719179*^9, 3.445191156333752*^9, 
  3.7174481566828594`*^9},ExpressionUUID->"59be8b09-6642-4738-b68f-\
f7c684f3c872"]
}, Open  ]],

Cell["Derivative power spectrum plots (all times in one plot).", "Text",ExpressionUUID->"e9b1c171-ede6-4e00-9373-7ab2d93f7ca4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"dofdpower", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"fdpowerminalltimes", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Min", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"fdpowermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"time", ",", "1", ",", 
                 RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"alltimesfdpowerplot", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ListLogPlot", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"fdpowertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                  RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{"time", "/", 
                    RowBox[{"(", 
                    RowBox[{"1.5", " ", 
                    RowBox[{"numtimes", "[", "run", "]"}]}], ")"}]}], "]"}], 
                    "}"}]}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"time", ",", "1", ",", 
                  RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"\"\<FDPower: \>\"", "<>", 
                RowBox[{"label", "[", "fld", "]"}]}]}]}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"alltimesfdpowerplot", "[", "run", "]"}], "[", "fld", 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"fld", ",", "0", ",", 
                 RowBox[{
                  RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
              "]"}], "}"}], "]"}], ",", 
           RowBox[{"PlotLabel", "->", 
            RowBox[{"\"\<Run \>\"", "<>", 
             RowBox[{"ToString", "[", "run", "]"}]}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.422110140120121*^9, 3.4221101451827183`*^9}, {
   3.422110609988517*^9, 3.4221106143167253`*^9}, {3.4221106564112835`*^9, 
   3.4221106845368233`*^9}, {3.424187453582607*^9, 3.424187514789743*^9}, {
   3.7174482273103914`*^9, 3.717448244725433*^9}, 
   3.717448275232607*^9},ExpressionUUID->"2296c541-62e1-47cb-b2a0-\
13c40e5d42c0"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/Af2XWY6jiHLnQe8rg76S7uPNyn1dDpgRSF/qBllIiZRiJH
k03M6qjMQ27aKI8bztO+38hdTpMV4SyTOsIppM7z0s4fn73/+Oy9vfdiRMZf
uK5NEITTzv1PuallFIu+wn/X7uxpHGOHOZFR5TL7bf6n8kWj8RBrrPnrgNez
QOMwgRXO6OoWbjB0oebt+pcUoSVmVTHNZPb7oGXpQ2jMqDletpl93ldMAff1
fGnuXbPdPhUq6JkOpGRTbDt/O0lURgPu3lHD5B5jvDnxkr/BMAPz0DUUPkbD
IY2rZyOq6JDl5FHfrzTCTVmCcJm9BVgPJvFGCii41wM/pgUfhhPNigZp2AHc
yAlL6StmgFuBMlVWT8ETFtn308asIIEiv7Oi3I8Hh4NVLLoNjEgQs8fXAHvX
GRh/C7eFhWnvnLGLutiSyf35pOwI6FVGEfUfyTiftEjzm7SDRyb1D0s6Sbv7
HGBVXyiKk+7BN1uvRtddcwRee3PcfIUOVhRQCyOqnED6nn3I4AWBT0f3t1Fn
nOH1gOGWwIvAEhBOyeyZoB6+t1BDbKOnuLYj5QYLDgakm8g711HWGddEWrAL
BKwTn1vpq6hD8oi0+NcFWsLmqjOrfyON51GY8svjrfmuIMfCUyyxuyuo9WuW
fUp/oYit8p60MVcQqC7PyXMXUWAXp+FS6jFoEpU15blMo1yHnQKdDW12fcE+
C7MIi1Sj5E42CMktQb6xM0it5XdrKpwD4lwFd7N4ArHixFqdWxwQBPowEtTj
KEqxLRKVHYdWciW1JF+ESn1CHeP5btBCuaKmpTcgjZcb1Bbp/amijqDeRP9X
jEx3iP66tFBxcgJp/Lhwjnq+q4Ou4rP9tYeGurkw6e+mXf3mO1/jyYOSWFWR
Jx7gi63bNnN0PKBG2izJ+KHka3w94EE2k1QaRMb/AKQwTvk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ou94i8N4w2XVQ+YJqXNP67xzz7SfP2Z
GEnFAxB5FofKkBf6j9YrHKjfe6jptyKng10n7/SDhbIH9JfqSR7X4HPQCRFe
EaAkdeCTystZJ6cLOkS4v3TgeCgJ1S/i8E1Y6ch9JokDqq8LSqbOE3O4vJYx
xWWvyIE/95bZ/1aUdAgSFzQu/SNyIHzjD9/EpdIOXMKJ7lu2Ch3Y1OwVc1xD
zuHru81c0cuFDhy1PjBZLEzBgV/xV3ybHP+BjabRlSenKzq87TT43qsseOCe
XEtDzU0lB7GjV68Yp/AduHA17I2+tIoDS8+C5RFh3Afs1vGKPo5RdXDx+9e9
9BnnAXk9y3dT5qk5REw/4NsyneNAH9sHMY8H6g413Ad46z6xQN2n6eC1wG/X
vpWsB7K3x2asS9ZyyFYWs/g0jenArX6RiYlLtR1S12WV+ykyHfDMOL1T5LmO
w0rhQ8EhkQwHdjg0PTquoeew+EP+bMuyP/tnHFi7uzJL36HPZu+D3IJf+5t9
jIrEwgwcNjyxv2On9XP/7h29bB++GTikv+mKjTH7vh8SnoYOa8zDVLuXfNuv
NdFFf7GFkcPaxQz7gj982p/4d/7hmptGDrsdrnjnbvuwP3Cv6YbQKmOHipB6
3V0vX+7v1ARqkDZxeLfHLEFgyof9B6a+ucGxx8QhvzSQ/cLNN/u/M3rkPoox
deBykip5P/P5fv28xYx7/po6vAx+No81/c7+tFv/pk6dZ+aw+vv/aWtC7+yf
6xallW9v7nDe9kM5a+Or/ZDwMnfYsPmDv/uiJ/uPFnmvVmy0cLjM5bXk7/Wb
+yHhZ+lgEORR/tP6gb2JN9OVK4csHWptX0jPmH/NHhKeVg7f2j6tq71wdP9i
5Z1/2lmsHe6e5RRi2f/RHhK+1g7vBW33xf17vB8AwXFHbg==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB3Ckw8RS59AtnIc6XE7c5Wn5fXpWepDlMk/rWOcxittQlqfU
tJ2GrkM4yy6ass4ueTi+X4ybrjbmPGYYNqwT85SGW9r547P3H5+9t/detKjk
oPt6Ojo6Lnv3P79Z2vCY1HUiyP4v58qgI2ZH8cQKuoYwa49XJzvYYe1fHxiD
mntB5dY4q70rd5tmBMOust1EOIaZElcrBd0Ujqalc0JvUfGqw2J5n8gM9Bta
lxdElvt9MuRXy4svRZtjx18P+cIqClTE0cg8ORnvTL4ntmlWwM+MW1nrJOO7
0q0bXAkV0IFRw6YBM9yYdy1cQbeGVspCtyr1MO7xxSUUji2kHefLwwhTLGWH
ZfSJaLBW9zzMs8MUT1o/y84cs4NkYxQgzDiE+4c4aibVAXJeDg+JqkywX4OJ
+Wy4I8xMltUKxknYxtX79+uqE1DA+JhA+k7ChaQViv/0SZDSl5V8S4P9fU4w
P9EtT5Po4oSvEbEN0c4QOTeyucXTx+OvyEVciQuEPPHJcrTXoKuxyhbyPANK
E4vnbs5pUDPkzijorrAUmBmSWrGLSvGntox4JlhHBtaLa7dQ3nX3FArHDcgW
ISk5CRuorVlAWtl0g17hoiG/dxVpPU+Db9QOOq9ZQc5FF5k1Xu6gDjJ61Omx
jLi74u7MMXeovPOTx01aRbfb2Z+DH3tAT91mgVHXLCpw2itQWVB9qi/mrIEa
YaF61FDOAr804ynN+gz6o+v/YCacDbJRzzdNTycQM6lGV77LhkHTElmw7RTi
jWuEwqoz0CqKME7vVKHKy6HOyYQnpH6RbjA6GpHWyxMOEgn9FsoR1JMSUE/L
8QLV29DC7KVppPXzhpj8c7MfzJsJVoCeStXlDfJFo3WBrI/QevrAETFT8iNP
QdTYt+y80PeFd9tO7vTYBULr6wuCC6wylnKA+AduHE+q
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ou9ZoK1H2OY0gHTpLT5xzX+2S/P6FOa
HSl/ACLP4sB0UWSpnpfcgfq9h5p+K3I6fGxepfTuvtQB/aV6ksc1+By6q17+
r7OROvBJ5eWsk9MFHTKiNLrF5opD9Ys4OG2x3hEVLHpA9XVBydR5Yg6+4pdS
sn4IH/hzb5n9b0VJB4en5XLFrCIHwjf+8E1cKu1wwyfI9pO00IFNzV4xxzXk
HBplT6QetRc4cNT6wGSxMAWHF7u5OgQ/8x/YaBpdeXK6ogPDZ/u3sR78B+7J
tTTU3FRy0Je/nRJ+iefAhathb/SlVRym7XNue5DEc8BuHa/o4xhVB+88ucf5
7GwH5PUs302Zp+ag/MxXY9VOtgN9bB/EPB6oO+zK0NmuFMUMdZ+mw+7jreu3
WLAeyN4em7EuWcthxqbqE2xpjAdu9YtMTFyq7dDw3zBHfDPDAc+M0ztFnus4
nOV6pxJ86v/+HQ5Nj45r6Dnc+7VR7rfyr/0zDqzdXZml71CQL8p/4O7P/c0+
RkViYQYO6relO26Lfdq/e0cv24dvBg65hQqr3A582g8JT0OHklXRd7W9Pu3X
muiiv9jCyCF2a+WJp4s/7E/8O/9wzU0jh5teB+9k+H3YH7jXdENolbHDe+Xf
fa+vPN7fqQnUIG3iwDnh9jufkkf7D0x9c4Njj4mDs+O76LQPL/Z/Z/TIfRRj
6uD4+8h87cob+/XzFjPu+WvqkDw59dSc3ev2p936N3XqPDMHjeqmGyePP9o/
1y1KK9/e3EHvRd2UzSJr9kPCy9yBS+PdroD4Q/uPFnmvVmy0cEiX557at+Hk
fkj4WTr0imms9tq/x97Em+nKlUOWDrUvLkmc67piDwlPK4ecSy9Ndfgv2i9W
3vmnncXaYa3pHZvLTU/tIeFr7dBy9nvrT5Gn9gCyYUdw
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ov9U5kzLYsPKR4wTUqbf1zjn31b//O6
u1/kDkDkWRy28K7XTp8sc6B+76Gm34qcDrn5H4qVciUP6C/VkzyuweewU4Bh
yrtkyQOfVF7OOjld0OG0/ifG/dViUP0iDnHi1+PvGYscUH1dUDJ1npiD+b48
9drrQgf+3Ftm/1tR0sFH5BA7zyWhA+Ebf/gmLpV22JkuVzQ/XfDApmavmOMa
cg4LDj96a8vHf+Co9YHJYmEKDre3qyzn7+A5sNE0uvLkdEWHjEnrFnh28h24
J9fSUHNTyeFok9ijgC+cBy5cDXujL63iwOavziGrz3XAbh2v6OMYVYcHPnwp
kjvYDsjrWb6bMk/N4XGeKL9TEsuBPrYPYh4P1B3O/vRk2bORGeo+TQfupsR9
BjKMB7K3x2asS9ZyMP6g/TWbh+nArX6RiYlLtR38/Jr/Wyb+3u+ZcXqnyHMd
B5Mz88Lv7Pq7f4dD06PjGnoODczqszaI/dw/48Da3ZVZ+g4lcwuP9Vh+39/s
Y1QkFmbg0Pr8I8OBv5/3797Ry/bhm4HDtLMz+AqtP+yHhKehg0l+wsaKsA/7
tSa66C+2MHJQm9h9vXzJq/2Jf+cfrrlp5MAhkXfUae3z/YF7TTeEVhk7eC5R
10g3frq/UxOoQdrE4en+yW8aqh/uPzD1zQ2OPSYONTKrhV843d7/ndEj91GM
qcNNuaKwqO+X9+vnLWbc89fUIUdgpb3Dyqv70279mzp1npnDrSfa0gbCN/bP
dYvSyrc3d4h4qSjiGnHYHhJe5g5PpfbXuZRe3n+0yHu1YqOFQ2fvS//l24/Z
Q8LP0qGh5LbnyX1X7E28ma5cOWTpYGHcI/Ii6KE9JDytHLJP1Bf94L1uv1h5
5592FmsHZd1lJ85UP7WHhK+1Q9y9BRNu7jq/HwB4H0M4
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ou93olCQY9dCgdMk9LmH9f4Z/9qwyyX
ZcoKByDyLA5vn0fIzDkufaB+76Gm34qcDu9WVD+xN5I8oL9UT/K4Bp/DJXlf
zdlMEgc+qbycdXK6oAOrlWznocuiUP0iDhKJRV2rXggfUH1dUDJ1npiD99Iv
m1p+CB/4c2+Z/W9FSYerh1tz2GyEDoRv/OGbuFTa4bD8/67FEQIHNjV7xRzX
kHMojp234ooA74Gj1gcmi4UpOGyfvU1vRR3XgY2m0ZUnpys6PP8t7RTykuvA
PbmWhpqbSg5y245d+dDPdeDC1bA3+tIqDvNm3lVd2MFxwG4dr+jjGFWHhCk9
D3+GsB6Q17N8N2WemkP1o4XTHKtYD/SxfRDzeKDuoLa4VO6WFQvUfZoObRlH
toRYMB7I3h6bsS5Zy+HZ11Wb4lcxHbjVLzIxcam2w1Yz7sqz0n/2e2ac3iny
XMehUiniTLLF3/07HJoeHdfQcwgovVX7KPP7/hkH1u6uzNJ3qLgRrCos9Ht/
s49RkViYgQPPUi72oqLP+3fv6GX78M3A4cffo0d45d7vh4SnoQOnaUzV5T/v
92tNdNFfbGHk4PfQYxJP0Kv9iX/nH665aeQw1bDxD7fGk/2Be003hFYZO3SF
nxf5tPT+/k5NoAZpE4eWgjT+pVz39h+Y+uYGxx4Th3/fnpboxTzY/53RI/dR
jKlDe03hu4cOl/br5y1m3PPX1GFy5x7GhKXX96fd+jd16jwzh0kSQh37cjbv
n+sWpZVvb+7gNvfDj8K+HfaQ8DJ3SGHd97/qyp99R4u8Vys2Wjg0XFq1br71
FntI+Fk6fJi+YoXDrw57E2+mK1cOWTo8O2Jv1uz21B4SnlYOIt5Hss+/O2G/
WHnnn3YWawdmoZlbgk+/sIeEr7UD51G/jotfXtoDAHUcS54=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ov93Z68mOQdCgdMk9LmH9f4Z/8n/fBh
cwHpAxB5Fgf/A6VOTw9JHKjfe6jptyKnQz5Hq/6WaMkD+kv1JI9r8DlYLHq1
0fqk2IFPKi9nnZwu6BC44mdBerAoVL+IQ9V+v7hTZsIHVF8XlEydJ+ZQpfkp
cF2B0IE/95bZ/1aUdJj849Oacj6hA+Ebf/gmLpV2SL7ZwrBCVODApmavmOMa
cg5r756bHGPFd+Co9YHJYmEKDkt2n7L1Osd9YKNpdOXJ6YoOWR/KVWLYuQ7c
k2tpqLmp5LC/4+KuxifsBy5cDXujL63i0JBTt4uxguOA3Tpe0ccxqg5Zew8d
va/OekBez/LdlHlqDgbbZA2cRZkP9LF9EPN4oO4Q8eH6kn+HmKDu03QwXrFm
Qs81hgPZ22Mz1iVrOVwW/qcupchw4Fa/yMTEpdoO9UL2YVfS/+z3zDi9U+S5
joPcGf0tOuU/9+9waHp0XEPPYd2M6Oym75/3zziwdndllr7D8SCpk59vftvf
7GNUJBZm4LCKMydt354P+3fv6GX78M3A4Vsvv8akI5/2Q8LT0MFPgGedkPrb
/VoTXfQXWxg5TLj9Pd6n8/n+xL/zD9fcNHIQFdydsbry6f7AvaYbQquMHc4v
e+5a3/pgf6cmUIO0icPzjz4Tma0e7z8w9c0Njj0mDpYvJ5/8efH6/u+MHrmP
YkwdZh/s3fGx7uB+/bzFjHv+mjpE60j/uvn25P60W/+mTp1n5pBVt8vp/oZN
++e6RWnl25s7KEuZyZf1HLGHhJe5w5WNW2Q+y+3bf7TIe7Vio4VDJneMX+/p
h/aQ8LN0aOAOZ2azeGpv4s105cohS4ewDcqnWu7dtoeEp5XDl0s5xksWLrVf
rLzzTzuLtYOfXPbq9Def7SHha+3woHTXJ/7rF/cDABUdS5M=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB3CceZinbjium4fzeM7DIYdzy++TZOo0D1uUpxBmipOxxWyJ
tmqliJvSnEyyqW6draFj3y/iHC0y0qlwShh5zNGcK+388dn7j8/e23sveho/
JkNHS0vL/eD+55C1XSaL9pvYehzJ/Zhvg9lpmQ1ShppIl5TfTTGnYc1fF9ac
Jo+eLKLi6929ZXt0QyBF82QjI9aY1exFlTJMYeHbk8biCiu86bRUJ6slQ6jE
hDXXYnnYtwCqZ89O+hVz7LycVyAQUiBHKRHqVpGxavo5sUenguqDwSfTHTMc
J949m9pMgzqGtG4gwwy3lZ9JlDJsgaR413HKyRj3c3E1JdYeyJP0+owBQyxm
JxTJaungVznzjMYxwtO2N0tL5A7QsxllFb6sj0cnYldYNCcQrf/MDInRx8Ei
E8vvic7gpeq/GBxHwnZenNUaoQu8FPPELW0kfF9vnRI+6wrgH6nfUqxzuM8N
lA0ZY8ed1ehye1KW6BITcIpo1SH+L5p6YFGV2uwOOEeRvOT5B53OGu60WPAA
t8LSbJnNLuqAsjkpwwtyK4Qho47b6BF+JSnKZkHeG0mCRLmNyiN88ymx3iC3
H3Kodd1Ako4KvXWlN3Buk3xM9daQxtMHBt/WkOf5i4hZFcpqCvSFp78U3T8a
F1HqfkNfidwX5mXFhmkbsyi6m/36XPExyEqILUyxlKM7bgcFmh94yERUXpAC
YcHKZ4MuP7iQuGUkMJ5FO9rhOXOJbFDxmYt5thOIlduk3bXPBtthUdbVxkmU
OaUWCIT+cG2MNLQ82krUh8Uz+UQAhNFH2j0fDhEarwAoqqo+X55dhvrzeS/o
NwIhr5XEJGrGCY0fByqj1EdOpC4Tfjyd8fFeDhT0KTsGvRWExjMI9tj3dN9H
fCWaHDtVt3S5kDaVZPVlZpPQ+HLBJZnVrGDPE/8A7LBJbw==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB3B3ebqJRee4bqMrl/Mwx3Ghq34fTSipueWh0Pw0D6sVmf44
lJCaDXm4GzF3dDFLZ9huEfp+kZ0rTUIekuUo7GQ0YfOwtPPHZ+8/Pntv773Y
ccmieKqBgYHL3v3PD7b2CTzWGvE6PYQxSx7BgrgEuZq7SyTXKR+Sniys/xtC
pGn14SqSibO6enK22DQoKlxuK8tkYl6dG1PNtQCWxNFF5GqD/zgsVmrKLUHV
LovqoDD2+3S4EiuTqGotMUeXkiaVMeCafEZuwbfC29P1xBabCdXSRv++7kM4
omUzhKxjgUqYxzdcNMetuRej1Vw7iOANqoT3DuI+IS5jhB+F81pnsl1Lwy2C
KLGmnA3MNFoRJ9MMT9s9fpQ5cQy4IzoBpJvgz6PhSzyWAzT0XRb5FRrjs03m
1rPRHDiXPzQWM3IA27v5LktkJ0Ds3ZQ4x6XiIuMVRtAPR6h91UALLqXs73OC
CmWW4mqvAb79Jiap6aYzOOZn2wrrd9DkM3oJWecCo7UxvZwbG+hC0sd2+rwr
WDFjGrjyTdQGOVo11w3i1p8Mf1Kuogqs7BDf4gGtW2dkrF5DuZf4qYxwd1Bm
fCsta11FHW2Fxivr7vBOomqIf7GA9J4eEJCnClQ9X0LOJf48hQ8fsKFncwue
Q+SOvDdzgg+hU2Fmfj0zKLRL0ByW7gk/d4pSNAXfUb7TXoHlBW+xozX3pRZh
6dK4aacXvCcrzwSN96MNStAdbbQAmObzsfQINeLdVVA6dwRg3aWZFWRglDC5
K5XKTgJVDEa71GJUHXDdOZnwhirN3xonk2FC7+UNBYmRg19sOlBfanAjO9sH
xGPF5afNtITezxfu62qqftEXCK9g6shIjy8MBFAydmGM0HuegoXARNEUTUko
jrdvPzUUwhhtwIMU9xN6XyEM/X5QUPN1jfgHpQhGEw==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/DzdDvFDXGxE35y8nzIxVF+Hw9rntoinY2TebrpwcPUP8o6
hyYz1S1izAk7bZQ8zPK473dynZMV0cPRsCO3luoSueYp7fzx2fuPz97bey8i
LTcuU59Cobjv3/8ct7YXsJnrZOdGudWWiRHmpAka5S67pIm2IexRoC3W/Q2h
Sfy2Nl1pg4XDI8VbhDGQftdVXxRHMVvqZSN3oQN1SdHoEc/Aa05f6xQ15qC2
7eWQIsZB3xLIj/rxWjsLzPqWd6NawoC8wDjTxRVzvD3fSm4RNhDUXmqwITTD
CV3ac6lSJmxii15ODR13l0Tx5S52sD5dRlRNHMayIPyQwXOApzlj7tuXabiL
k1SgqCEg1qmqvoNOw/N2pUWFSkeAUU1FYjIVT77nrbKZTnCnMpw45GyMgztM
rZb4LMheoO09NjbA9l7cH1USZ9jzbTL2bKXge1QNI2LxBIjeNBukyPUO9rkC
q6unWJq0ja6+SM7qSHeDhxltCcS1PTR731KcKnWHKJvR5cyqLRSZ9brfUu0B
85TCCVueFvVBsUru4gW/m6fCmhVrqBY/Gyy4wgbL+vCE00UbqCTGN5/B8wZC
JrwQ+FyDBvsqqZo/3kB+ForbMr4jnacPsLS3E3g5K8hNHM5uCfAFzYyQeStq
GaXuNL4sVPqCqOuYPDRkDsUOczov3jwJPWZ11jHTH1C5636B6Qeha2Ifh4V3
CFevfqIN+YHnK4mWLphDm3oR2So+B2S7waqwimHEzmnRG9rhgDP1wSWZ4gkS
zO5WV0tOwRkcff5uWTlqOJvolkv6Qwwv5Rc3ZIrUefnDtDSzGE+OI1l+dDsh
CgCJsmiH2J0ldX5cCHEc6Mt2+En6RevPzIxwIW79iDc/conUeQYCtb4W02nD
ZMvx/u0ywyBQr/LHwqdUpM43CNbV3UYDFX/JfxE2SC4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/DDeTodqnPRD9eJ7pxyyIVYv8/GGjlJcbUwUWQSTf5IaR6u
GD3euJHnzTR5GnpA6PvdNS5RmeTpPDSkJwlDHg5p1x+fvf/47L2992KHxZ4M
V6dQKDZb9y/fGrMi+MQC2fWNeu1OlR4IwiKK5dwNktf4qziObopVfyr4UvxH
1rx24aRWWeoaWxdak/02A2KZmF9mayLn6sPUmaaokDQjPG/5Pa8jZzsQ3lw7
tMr432dAVpAB6lMaYqufV+KlRUww6h8U72TuwMrRx+Qa2wQ+rE6UO2gY4tN1
yz6hZQTw0UXxhW46rhcfC5JzzaGfoXTWrNDDba44iynaA76E8EdFAw3XCQIT
OnLYEBIvu1FrqoNHzW8lJw5agHlhSTFHWxt3fxJN8wlL4FoQx4cHtPCRGrrR
RJAV5AdzV4zt1TDL1mUmu2gfDN2tiF7gqOP7WrNMz88c0OjIbdcu3ESqfdaQ
P8EJKM9WoksNwZE153kwXsBRo1Up0dADhiS0zAb8bc1Etb7LyCuys4nxdT8Y
1gtLaCVLqBFSx+VcW7id+YS18moe5eLq5oQoPtC2PXN7sTmHxEKHOKbIDgxi
9A+w3GdQc+M9rdklO6B0UjMUVyeRytMe0if7ftfPTiGexINf6uwAD715XZEC
BQpdL36dOOgAetTANnHpMPJrFdQGXD8I781kihWnMZRhvVUgHIF4vhhHLx9C
WDo9oNPiCG6nvJZ9drejP2qel8eDBCDM7OnP9WhB/JhStZZ1Aeg/0jViucrI
iKENqbToEFAS5NJ3WTKy8OhZXizpBPQRmmI+Q0GqvJwgPDrvS3NlEmqL865k
pziDSFKQ0hP+kVT5uUDL03PN7Lkx0tFbvbdX5gLt6xvETTxPqjwPQ8GRmTSR
+yBZurdJmU51BeEbycsTpoukytcVpkw0HautV8i/gK9EpA==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ou9QUZOzO71ag6mSWnzj2v8s19+dmVs
wVcBB4g8i8OHaR21WXKCB+r3Hmr6rcjpMPH+saiPy5gO6C/Vkzyuwefw21X1
4o33XAc+qbycdXK6oEN9yvcU4yvCByD6RRze8Ks8ufhb4IDq64KSqfPEHBLr
fWce+it44M+9Zfa/FSUduq1zmJdI8R8I3/jDN3GptIOws1a0QjHfgU3NXjHH
NeQcpgnMeTw3lfvAUesDk8XCFBxMbEO1Tn1nP7DRNLry5HRFB6MgxdZ5QlwH
7sm1NNTcVHK4lFp8ZXsR24ELV8Pe6EurOPA/vR/kWst6wG4dr+jjGFWHuG0v
91z9zXRAXs/y3ZR5ag4v2rjXV95kONDH9kHM44G6Q2fXWrv8Tf/3Q9yn6SBh
9sq0aenP/dnbYzPWJWs5bIusS2xf92v/rX6RiYlLtR227duo61j6fb9nxumd
Is91HH7qr3tSXPRt/w6HpkfHNfQcSmqeJ2Y1fdw/48Da3ZVZ+g4arrUrOc5/
2d/sY1QkFmbgIPxCXvt4+Nv9u3f0sn34ZuDwTejatYK7j/dDwtPQIeSdzoFg
nwf7tSa66C+2MHJoq49IefLo7v7Ev/MP19w0ckgInfkogPXm/sC9phtCq4wd
mv7HCz33urK/UxOoQdrE4UhQ59/Xr6/sPzD1zQ2OPSYOH/dJx9YrnNr/ndEj
91GMqUPtxTubTNxX7dfPW8y456+pw1cppriNj3fbp936N3XqPDOHA2tb/kjM
u24/1y1KK9/e3KH9XMnypDfb7CHhZe4gOCFASEX5mP3RIu/Vio0WDnEZbgnd
Rg/sIeFn6bDjxLG5R7+/sjfxZrpy5ZClg+/J8mWuN97aQ8LTyoEl71rTG/cb
9ouVd/5pZ7F2UJj1vmci32d7SPhaO1RIJ/X02X61BwD0zE0g
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0HtIkwEUBfBppokoSHMpgm7ztbl9+9zc0jlqxwozzcAyA6fUfDHUfCGZ
tnxbmmSIroWiC2yDCOejwMk2MkVMCyzR8E1YKZmWRq3MV0b743K5HA5cfozk
nPNpthQKhbM///aou3c66flDyv+Ts+d+jgdRcrpmmLUrNQZ9U1elcvA/t0N4
TE3sxngQSs0DFVsMRwgq60UKMQlSy/MYZrngZUHtz1QFie++n5tH1K5o3hzK
Wo0jrX0qKNyqh72dPPh9yS1QtdFwkHQa43dxsb2gk24xPFC2I7mZ9YnApe7f
MXKtJzi605yoYyR6KqMSh1leqJxqKnpmIjAk6W+kxdOhlq4tzckIdItkRSNq
Bswe1OjyxwQWvKrKlNNMKAtH5XkHCLyZjF8lPX1R06PL4zYROK53dvuQ6Adm
q8OE6ywBb574a1ObP64nvCvW3yFQb79Oi3wfAIx7HB4UEtb/2JBltBvCCrnI
7E1S6FMCca3swryxhYOZe9QGuZaDFyVmdpqAgzOKV33UZS5UWsOYooMNAyoW
h1k8RGZSWjay2XjQ32EsyiChoQ4V8DNZqDwryKfFB0EzGfA6w+gPo+Gu/bol
CJtzz3O94vysnnwQ87I21f4d2HCKbA8VQFjm/7G00RfyHc2gclqAwagVQQjV
B7FmUdfF4mDQ6jRXtu8zUcveL3gK4c5PlRt1TPSrVqcOmYSQzCZh5iQTv2wi
ry4mijClJDtP9NFBZrfbmHZE0Fn0K90mOtJndlWqtqN4VOPYW5dLR2tEQmCO
NAQlE74OGZteVq8QNAmZKW7V7hjKj37CKA/Fjcxw9YDzEaufGKZoerV4mQph
tO3ExIAYyqWnlw0RTlbPMBQ1m9/uBTug3adv+7adBFpLBX3NycXqK8Eti0UY
vO2Kvx6hKCs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1AEcBvBjWDJGnd/Y3XDccefc/X53OVw33VPLS2gmUV7aHMtbQ/Ri
mpRjKvMy041l7uY9yetWCEt0XdLGOC3WMGXVUtMttHkprfvju+eP757t2YeV
mHXmoimNRuPv37984+CcTDJ+ydcXbQteZFCQJCZrdNw9uXqyzFVJF+H/3wxv
q2XSYakIt0bGlNssS6j1zKe5CSKQLUJHHdcGBTSL9NpVCgb21wcTNXYIK3NV
0D+Rxj4d3Y0lucoACpxvl6+q1ATsVDY551Mp7Cy2yrdZjlhSxDVvWpI41/v7
tKKFAaKzNHLcmkJfUUi8juuEZ75KehCTglY2Wk1Eu4CI0Z6t6SDRK4nLm6hh
IegaYzrpJoVFp+Lb+fOu8Fvb8R9/JcT0XPQayWDDy61JeyiNxLEua/uP8Rwk
mbf2mLpQcBZKf9xXuyP+S5wuRU+iwmKdCF72gGqvYY5TJzTu4yFcsCix5wtx
qf9CaleSJ+xWDNnp2QIsVNKrFC18KEo0AbOFApxKnRykf/aCTXYcTZcmwACU
KzquEMVO3dr2eT5qRzuH8tJJBL4seF15l4eiMHEOEU2BiKg317R5Ymig3GJ9
k0K5JMbKaYpn9BRhiZxJlD/mwbPqJNnkJwZ/2z68sJwLxa5mPH9ejGixqJc3
44GIEUlP1I0j+FC/lXBF5457vP0Cwxsbjd4VpWkeGFWtvT8w7I3j+dc7Hknd
sWUSnLESL4GmQSowLLNBZjaZDO9K8Dw08eeJKTaSF/ZUKrUPfO1k3TslbNQH
xnpmyX1R9+Rg8UY62+jlC5425V1UgCu0OaEdrEI/MGP/bDH9mUY/KZKsCtd8
qhnwDjXV68ekWB3tmw2NdDR6HkX7wxDb5kgCTW6DO3fMZOD49Ysd9HSjrwyl
bZmG77TD+AteciIQ
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0GlI0wEYBnAVrw4rzaZr6dy8drn9t5xOhe0JOjwKMfBIDZrmVXlnqQzN
A7RLE5tXeWFGtpRUWjOVPBsmhoWZCknO5kEiFpWGBy3ah5fnw8sDDz9aVPLZ
GCMDAwO27v7lW1tqLI/yU9LYony1O5EPYVRsvZqxI/msVWaIKwj8/xvjYXiF
zfgGH7m9A/mbtF1YKL44qDERgNfMJasZ+6CgOqxG9BL44bRcM1JpiQSjzsx+
Ml/ft4ax1PxBgy8fzt9SrsrrSDigWowLWCSwNftYskkjg5ziNdnygkBo+8YZ
aTMFo9VDFjNaAh0F/pFqhj227K6Y+AcSGPbpKyeFOODY2J8TVN2+dmFE1kgl
DY6bU+mBagKz9oU3ZNN0LEWmUqzuEBj/GLLCozghek/o170qAuI2i0Pzkc44
/GHZrHuWAJXrtXq/zgU28or8kgQCJaZrJN8vrjCW+aU//c7V72Pi0Wjtp9oc
Hi6/PB/fFs3CXFijiVUwFzOl1mXSZjakPPb6sJYLv/jRLutFDnKuLzwJa3OD
CvkaNYML35gLVQqOG6r6WruzLvGwv6OfWfyag4LTgjRSCAGZYklV/ouFbtVd
07XfBBhr6iRHS7bek4/RVbGrrQMLrLLjvCaRAMr+I9JSSxak2/WDsmkBrOLK
w9KKmAjqFT4Pzj4KP4PQ3lNdTNxk6goUd2hFbRNJGQz0yVemzHvcIXnHEYcZ
MrBu6JuoiRQiJ+9W7r0WF/CSmgx7toUIema2kGrjgtiZHbm8zgOyweS5Vpkz
ak+Gs5Ilnij0ENQo+c56L09EZBtei9twwnBagIKWJ0JmTSer+j1d7+eF1WJv
yzExHe4BRhMTA164PanBuYN0vac3VHkWoQ3Ljmhy7NoqMvbReXoO9czT9b4+
KNkUvaGy7fAXkcomXw==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEYB/BjGDOWjRu7Dedcd+6c3++Hw7nVfSvzkpOXynst8jbJodI0
LXmZaanQJeY1OywjtBaOCOeSP8omRZiX0YyVNfP+ktb1x7Pnj2fffZ99mNGy
oFhtGo3GP5q/+6O5VRzBWJf4P9i/7OZHQRgdV63mHkh0z1vkbfuQ+HfXgX71
7UKlJ4l7Pf3Zu0wDRO/n3g2roEAoHCzUXGNwW+Of+HhQ+G27XD5cagKTjnaq
aeR/3hTbJ1Z3Fp0osFdSbsqr6JhV1PbyvlLYm6mX7DItoNXlIiz7QCKkbcsv
SsGAz5kg0cs3FNpzzkaquZYY5QfaES8oqMR9JfRga3RnZhHKQxJtwoiM4VIm
2HnWUzVWFGYsc7MyJ2zQ6JUUulFP4vOX4FWCYYvJ8Z30gQUSJ1uMzBYi2aD1
rHCNzChYOYh+Pq06jghpSb70qP+R3hrde5YD/2p6wnYmqfnPDuk3lJ1XvElc
e3spoeUqDw0NJZuGyQQmH5sWRSn46GW9U9/VIuGTMNJp+sMe8z0dpP4zB3Qg
e17NdUCxKjTUf1mA533NyoxEArXRc0PtBgLkSB3T6MEkxjNMl2RJ9lB2FOqt
bZAoH9hsHEzhazwpMHZGBPFdfPCKPIg6N0fEVi7ElL3mIWq/eiBzwhGDNsOi
h995COwRtl684wTB3vsLjWM8FNgdBRjOGNW/FRByioc++eo3/W5nBJ5bF3xq
tsOmlvf1+UghAg47h4pPc0Ek12l17wtRYxjmbh7DQdzkgVxe5YLtqUVHlYKD
Ss9wnkziClqFsfzYK67GyxWUPUs858aBKs23iXnfDX3asrLhMrbGTwRdTnhR
aiMLzr7aY2P9IuwtsSQT07YaT3cUKBNF5lu2qGN17uXriDE9QqOrvNgaXzF+
SX2zU7NY+AMCkSpT
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0GlI0wEYBnA1OxQbirZcE3Xq5ubm/vsvp25qe6QI88AD1NBlaCieOa0I
0/CYeZApossheYDMKJs0hZyoJJaKXYqYV7DyKDczkS4DDzLah5fnw8sDDz9G
Sm5MqoWZmRn34P7lK0eXNIL+U1pqNGOX6QQQpaS1jbP3pRElhnSOXoD/f0sI
H1tt0v2EKB4aKdthWOEa1TeyMJEEoebTxtkUfIma50Y8JPHdw9g80WQHV2qn
fV4eaeo7IP9i8su4GySYX+XXla1UGC8HP9JUkdjVd0p3GDR42qlX17Uk4rV/
IpLVdER3Tbw13CXRowiVjbOdkTCmP1TZR2I0YLiBGucKhcC9UZZLQitKLJho
YkCrezMSuERC71xeUrTghm3r0HD1SRJT7+M2CLoH+MJgN8pZEme6j59YkTGR
NMZtcVeTcOGLNxtbWbDpIaqfdJKoPbJFDfnkiW+cD6upPQLTPg62OL1uN0Ei
q+9SevcVL3x0c52PyRdgsc6hPlnNRXlh5FxUJYEL6a/7HdZ4oPm2l4R1EtCh
bHmczcft6mlPzQM+VMOagYJMAvczM+oMGXwowoX51DgBgqYk8haNNwZ0945s
/RYgY92/qSbY2+RJ4ln2KsVqjgev+nNEh78QktqabArVG8l7bS+KFoTgnKpa
ZxbzED0kehp76zSMgQXvxAYuqjkHBboPjsbaLNlOcjGs3Jg/NugDW3sF1d+T
i23zkJxlmQhK9eEfn9fYIK52mA/uiSB3CiLiXThIW9xXKlt9oc/Ri9t72Wg5
n+CVK/WDo/t2hbWYY/LyQ5bqjt+EnI3R/LAuRqk/CrNVEscolslPjF+s2enF
50z4hFnMzIyIUR9hMRlvwzJ5SjBW0RBEm2Wiw71/t9IyACu5Xc28JKbJNwCq
ZWmLrcYJfwHsch+m
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEcBnCvl1pv7Mh13o5zzh33u9+Pw2Vzzx95p2ILK7UdOm+LppeN
MXFJr2fCqNVJ51hrCWXIqXMmo1HLy7gWxlYr1iTR7rC0rj++e/747tmefVgp
ufFnLMzMzPjb9zeHHV1lBHNVYmicKLhRJoQoRVY/yN2SSPVFUeNDQvz7W6Hv
QJy50ZpEca+u1Mjaicay1fvNbhQItYAxyN2Lpmz6M9oKiRX213tDtbZIiOhY
ohJJU58O9hGzhcznJDwXz12oUTqg6CLHPm2NxMZMk8TIYoDSjI4SGhKJbb9j
pWom+hz5yqRZEu3yqORBrgscrQ0yDZvCQLC2yiHBDXcfefH6bSi0iU7mD9Wy
MCmf6p/8RWLG5crlwml3NExOhbypJvF+ImGJYLJRPmynJnNIhLTssV9I9kRs
ZsgdFUXBVSD+Xq3k4PEOo9PHJBIK2rJDxJwX8vV2jNNO//d5o26041u+JYns
zlMZLak8ZGm3QrZ6hNBX0Culaj7e6Tf2iRVCRGa87aZ/8YEyMiCqJVqILpTO
D3IFYDcYFrzXCdRpn/bkZxEYGfsZzzxIQB5D5TkkCDFHSErQKkBP123a8poQ
H3x7lYpwgcmThMFjv5W0SgBe5WFCFURhms0M6Gz3hXSzvr9wmkJq5+znq82+
iOsVtR4v8IOadHndoPDBde/tAtMfm7Yi40OjD7Q1S1M2Gn+Edxa2G27ysW4e
cXY+WYSj4y1RLyP4IHJU5ppNEap1JK5Z8SDTb9XUKANw/oWKCpvwxoOwE7xc
SSDK0xl1ameeySsQu9KqijfjuBjIi37CKgnCJfeYW5Z+XJOfGGPOOlr6Igf+
0Rbj4zoxWPTyH7VTHJPnIXTJNRXHGByoPLo3yq2CEbo77hUj1MvkGwzZiIH5
Sc/GH8z6KQs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEcBnBilrVaxMVu4eTlfnfc737H4RKeLbXLUam8leIub1ExU+sk
QpGaZNcNpbOmC/Outgh1lJ2TWjNadxV2jBkzK0vzVlrnj++eP757tmcfhiT1
ePwWIyMj9sb9ywEb+wSSvhigflPEOjZIgi9JqFIz1wNOXn1+rWsPhf9/U0QR
u7Iq8ijkdPfmrTDMcfdjbJhQRoFUcmzVzB2w8DCrmNJQ+OE081BTZgFXcet3
7YfNvhViSjMLxt9RcJ5Ny5AraBD5Zwte1VBYHX0WsMKwhV9Dc0/VdR4iWn+H
iJV0XChPNK5k8NCWHxStZtrBVp/NGPbhoc9XJaOFO6DmjsnTZToPrfzTUk0Z
A8ENaRHNqTyM2t28kaV1ROTtIU/aNwqfRsLnSLoTCh5J97N6Kfg3bbeeiHZG
863JnloXHuw5gvkHChdMXxnLDn1C4Z7ZAk047orEHE1NXNzmPgLiOusZSCmk
vDyT1HSOhVWt7ZhsiAtdiVWpWMlGLXNAFNfKxeGk9x1W025QHoxNEWq4aEee
Xs3k4HO5ufj8ES7KVY2d0mQSZkvTLAmdi/xgXjotnAtV8IHINgWJzvZis4Vf
XPiZhqw0CUiDJwW2UJYbpOWAVRpIVm84CHKWNW5SDsRrVW+ztDwwu8eWHRs4
CO3mt4RleuCoV9tZ890cFBEbBbonXkzNtsT8dIdKPvdla5cnPCb1PdP9blgy
Fl7UR/Mhk3y97FvJBnmp2rhrjQ8/nc0Sx52NBN26XK7wQkvKifjE+yw8PnSK
lRrgjeSREsuEZsLg5Q2+QjnfpyfQly6qZ+T6oG7tT8twPGHwE2Cbyt2hX0TA
U7RleLhXAMvB4mqTnYTBcx8mMl4XGoUSqN7bsVpo6ouYQGayLoVp8PVFvaox
alHphL8d9iqs
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEcBvBjhiK9ccvLXJeX7s6534s7HK17KjWchEVvqGN5SXmtliby
spR1IUkxL8uurYiorRO3nJedl1rNZHkZRS8sK5O8zLG0rj++e/747tmefdgR
CUGn9RkMhtPa/c2ebawownpOMsE4Jp1XExBFRFVqOKuS+ZS3h16ZUvj3N0DS
1xqljZJChqota5m9DiOkJJ9WUCAUAksNxwxlGrlyyZDGrP1UaXfJZlj15dXa
1P/vm2PFIb7j0msKDt8TzxdXMDHLqkorCKShHX0oWWZbwuyz8dQDJo0jDYsH
ZQpraE2dIn2jaTRm+4ZqOLZYTLQKHvOh0enZWsQM2Y6ZQaPyaySNBtGJ1O4S
NoabnUrehNAYtc25mja4AyZb24PpSQrv3odME9b20OpL9w/PUdhdt8FiItQB
Z3PixXeFNFgC8Y87FY6YsmjvStGncctwhun9cScGkn+X2n2hdPu4OKoO74y8
SSHuRVhMXSQPIou8npRMCkP55oUyhRPErrmk4icJn5jeJvNvfEQvxIXHGlFQ
ImtcwxFgqGvSL1tF4l7rk+bUMwRULrc5G0+SyPajk5khJGL3FaUH2pBoVsoN
Z+ZJ1P6qstOOEDpPCnuFcxfWNxPgFXoR1e40Mnq6AwJWBJCtVLanDdJw7/Ja
7g8iEKgSPQ2+7ALmM/+LzmoBbnDXCtZCjKxmsq/LBWgtnv5g3CJEn7fIS8Zy
xoKe97nxUBHGPsk9Zh7zQcRX67WsiPDoubNPdCwfUUOrxcUVrkiyCr+y4MhH
+YHjvASJGw6zgsNMJnk6Lze4vDzlL+3goTNZWsPOdEf9pHHv0gBX5yeGFe0T
kNbIhVCq39/fJkbh/U1bovfwdJ4ekCUUzDMkPFTbNWlzDTzBNNlVlm7B0/l6
In+HM9S+XPwBmg0lhA==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1AEcBnBvSWtsFhf71bkT7vyO+73k4py5p0jezlsLE38QQou6meZt
ykvHFk1lSsOW1Kw5sV7O25LiJqvZIrE5jVXTSWqWl0Np3R/fPX9892zPPvyU
nJg0MxMTE9HO/cs3Dk7pFLEivzvxp9DGjIYkJb1ZK9yWm+wNXpd00/j/t0Ca
O39jlGJQ0j9YauDvwQf1pYH+bwyoVrGjVmgDQ89R89ctDH65LDSM1NtCn361
8mEHY+zbYaFxwzfqCwNX/YXcuiYOXtwJqc47xmJT90Bu4DviYPM81ZHJIq5z
TZHcSqAhwaVVEsKiqyw0USvkQn+xwXZfIYsh2cBNTiwPkxpeFFfKolNyOn+k
ng+3/fTsmIiFjlt+uWjKGQF6dspexmJsInaRIlygXQm95u/Fwl9tbT+f6IqO
3e1VoSwLJ7F06VaTG/Is36WW6BjUWC5zgj8JoCpW+OnGGOM+dyj1hmjpMwbn
nidlqM+QqPnh+NaFZDB93a42uVWEkp6MJf1xBiEZo912Xz2wK3uFGxzBQIPS
Oa1QjOqKQEHlUxq3B9p787MoSI7Hk5o2GmXhrJITS0OVHSk0KGj0aqotl3/T
sNhSEPPFtNGTwYaD1Zq5KQ2yNpBq8WFx8kT8vYhGCslbza+KplgExHU1OyRR
iO6XPD5VcBgzBBlr7Uyhyn2nQHhBoH1ywOGlGAN1ix+t+ryQU6AkZggxVk2D
z88lSrA5fDb6Z7knqOwW074tCd4L2pzDZJ5In96uq2s6AoVueG293wONQQlk
jtwbvKBanVotMnp5Qx/5/QZDeGBIGfaIf8UHoRWrKr9pkdFPikleRG5qJwmv
MLPx8UEp7scEVmblkUZPXwjDNe3SYRIth7o3VRYyRBR/LlBnkkZfGfp43NlV
tQB/AXAEJJc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, -12.618567796898633`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower: \[Phi]\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ov9w5Sq/cdtlA+YJqXNP67xz377jvke
6Y8UDkDkWRw+P/ipeniv7IH6vYeafityOjion2o/wyB1QH+pnuRxDT6HnzmG
R73XSBz4pPJy1snpgg68scEvp+4WgeoXcRDZdfoZw1zhA6qvC0qmzhNzmGl5
bG1SvPCBP/eW2f9WlHQQ/yjOJsMmeCB84w/fxKXSDkZPJ61iDxc8sKnZK+a4
hpzDg2hLxqpq/gNHrQ9MFgtTcHj8f923+g6+AxtNoytPTld0qHrwbrMOE/eB
e3ItDTU3lRwufj2kW5DAfuDC1bA3+tIqDvbRP1qWXOI4YLeOV/RxjKpDy/TO
yTcdWQ7I61m+mzJPzaEqk0X84G2WA31sH8Q8Hqg7PHfNvV9xmgHqPk0Hlvqk
1HgDhgPZ22Mz1iVrObRJfpxt/fnv/lv9IhMTl2o7bNiucv/zzv/7PTNO7xR5
ruMgw7KY80LS9/07HJoeHdfQc6jd9uXCzktf9s84sHZ3ZZa+g5iSxC3O9s/7
m32MisTCDByeh7cU3Wb+vH/3jl62D98MHEIrvnZPy3q/HxKehg666os4Z1S8
3K810UV/sYWRw9b3ORPMXr/an/h3/uGam0YOkdfMeEttXuwP3Gu6IbTK2CFX
vEr78a4n+zs1gRqkTRy4l37XfuP+bP+BqW9ucOwxcWDdu19v2oJL+78zeuQ+
ijF10L2uIZlTeG6/ft5ixj1/TR1W1spt83m/2D7t1r+pU+eZOfTNnu876cch
+7luUVr59uYO6Rd2ZL9OOWIPCS9zhw4Hv1+bii7aHy3yXq3YaOGw2HyHd/vM
F/sh4WfpIOzgK6QsPMnexJvpypVDlg4MQbwTnmfct4eEp5VDx4bJd1mDb9ov
Vt75p53F2iGyb49q+t5j9pDwtXZ4oSvtcqb6kj0AEspHUQ==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ov9IZFjOpm7FQ6YJqXNP67xz960T88k
74v8AYg8i4PVoahnm3XEDtTvPdT0W5HTIa5To0nBV/qA/lI9yeMafA6T382w
4TsqfeCTystZJ6cLOrDv2vB+2kxxqH4Rh9fH704PMxc5oPq6oGTqPDEHcQvr
xLOdIgf+3Ftm/1tR0qGrzF9XNVvgQPjGH76JS6UdTl4xdqlvEjqwqdkr5riG
nEOINePmSTd4Dxy1PjBZLEzBISvF7HJIG/+BjabRlSenKzrYH/95k3sT74F7
ci0NNTeVHLZ4xC4xWct54MLVsDf60ioOUzz8cgVvch6wW8cr+jhG1aGRL3LN
uW0sB+T1LN9NmafmcMRR/O7PxawH+tg+iHk8UHfwvKZyg0OKCeo+TYeApC8/
pcIYD2Rvj81Yl6zlsLvOZNvcO//23+oXmZi4VNvBJLrAtu8f0wHPjNM7RZ7r
OMQel33FYPNj/w6HpkfHNfQcvt9StPis83P/jANrd1dm6Tu4PW9eEaj7Y3+z
j1GRWJiBA9u71e16YT/2797Ry/bhm4GDervdw2e/Pu6HhKehw5/OjmW7Jn/Y
rzXRRX+xhZFDODND8jWxj/sT/84/XHPTyOHcFXW/j8Iv9wfuNd0QWmXssEzm
0ebCnHf7OzWBGqRNHNx+2P7+cfTl/gNT39zg2GPiYJE/f26Q34P93xk9ch/F
mDpUx7Y6Tr9+e79+3mLGPX9NHeJ2x3PqBl3bn3br39Sp88wc1sZNabO7eGX/
XLcorXx7c4fwSS1/Ladu3w8JL3OHJ1udF+qeOWx/tMh7tWKjhcNF5xs+J46d
2g8JP0sH/1CVM4Ixu/ebeDNduXLI0uH9nHc9Eln37SHhaeXAu2UOy7zcK/aL
lXf+aWexdpjQdNeq3fkuNHytHS6IpydFCh/YDwB0B0e0
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/BjN0vmlnYunJzzkHPqTri4u/H7rMR57MGcibaou9EDDW2Y
rRyjLA9XnaNxtBu2LKEHZ+j7nUiYyk0bt7qJyizjunEnT6WdPz57//HZe3vv
xUzPPi+xJpFIfrv3P8ecGFIufZWY1v4ILJN5Yl66tGmEtUNUGziu0hUmtvzJ
EJIQZ6dNccG3BwZlm0xbwNKkwZoFZ8xt4TiPsCggydfgGJMLNnotPh5VOoBH
+Yq5L8xpr0+FMk5t8puDNOz962aeQkWD0KTYjbB8Gt7StxKbTGcINzTWG00O
OKlrPS6thQ4vtMr2MhIVd5dEp46w3KAmo9uu9bkDHhbihzSxO1SJio+9jHbA
XbyUglElEwKfyNWifnusdyu9UzTjAdqkKy704P3402fxEpfuBZpIxpfJRTsc
1mHvOJ/qDYtr7/h9ChvM4PCXH6mOQAXkCpivbHGVjYEmmvWBqHZyGzFE3tvn
CwPJysb4TDK+1nMxo+MyG+YfXGo1T/xFumqqPK3FDxgRowkmBhlHZYz3UheO
As1c6/iteRNpQDY3wuIAc2artGdsA9XhZ30FV7kgktUJjONmVBIbkEMT+wM8
PZR5Vr+O+jSVNgaTPww2Xdcxcs3I4nkcJA1zdLn5N2LLw7nqkACo9Kr/QBGt
orTtprdFMwHQsmpM+6MyonMDvM7EwkDQssXqrFvL6J7vboEeBPFb+YHaxGWE
FUvT+/qD4L2g+WTF5DwyW4luzKXyYEhXHfo18jviZqmt+rd5MJHwk1JJmkVS
3Y5CoToBpyanT+vMetQYcYGdTQSDzO+wj0g2jixewXBgrQG3OXYSwzkx7czi
EJBZa91Z94eQxY8PulgFIRO1oqAY66mpQT6sWK1vDrjOEhZPAUh22HfPFI4h
tWfvVjlZCBye62v3hY+ExVcIwlJKnsYjn/gHK1lNZw==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0sFHAYB3AunZMwOYduuc67wx266zjlntRCrj9YscIa1rkkStpSlHdT
E8btmrgTO03lfd529PvtpBtWaMxrzdjNXNbOy2QcpZ0/nn3/ePbdvvvQ41Mj
bhMMDAw8Du5/DtvShCzqJt+2bjIwZsAFc+KFMpXbPn80k1YSWOGI9X8jUFzU
xDfu2ODn/crcXboJZEd1bFfX0TBLzrRTuZmDsWeyiJhOw+tOK1VDEktIVNdy
E7tPHvbJUOREWvoUZYedf91PF0spUFzN1N16ZI11Pxv4u3Q76I8GxUyjFY5q
274aJ6dCiXk/T7xmhdvzrsSo3OwhifZmqjTNEg8G4ApK5GkgWzyo2hFY4jZO
dMaQhA5N+X4dLjxL/NM+PztzxgE8vd5DaYMpHpuMXGVRncC0qWv88UszHNhs
Zr0U4wznmrXe4V9NMI3p/7tS6gItBWzquMQEvyJqKSELrhDcqlukjhIP97nD
9rOgz8A+iu92x4qaExjAGF4QqSwIeLaUXB4n9wDZxg6hfZiAQ0UjveRlT6iR
t3/j2hviHshdVLkxwZUvILoS99Fr3KTISGJBYdccvytiG+UJfNMokd5w48X5
4tgje0jRU0LUbnnDiFeQ5NjWJtJ7+kBXqMQnWbOBGOWXWPV+vvAu2kaWPqZF
cXuygcwZX5iL5CUGf19H4f2c1utPzoAXiaBU4zVU7H5QoLKBQpFNj/9YQ1i8
Ok3qY4Om4IRqxWEZ/TEMubcYw4HugvKU2C8axEqpN+zb48DHp+oEXY8aCWf3
xWLpWchRnCpjoDlUc/kmI5XPhXnBhRXR1ATSe3GBsans5JljNJgW9oGe4wdz
145njRV3IL2fP7x9iFr+zvcgdhhhYkLpD8aV0jLPglq+3pMHhQP266Q7SlTv
2KsrMgoAoTormypHfL1vAHCbNYN9hZ3oH8FzSv0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0sFHAYB/Aj2ZmEOefsRHfIIc7JhS7uaVORt6mhReMUncxL1lZiCc1b
q466XWrOHzetDVc0wtHv14mLa4oj7lq35iWU5C0vOy9p549n3z+efbfvPrSk
zLPJhgQCwX3n/mcfxSGFSV3mpl2jVw39dsTspJQaBWOL6xs9kBtEo2H93wha
NNbVAVM2OL9TXqijmcDleD6HyaJgZq2nrYKxH9ZFt9PrJih40Wnmaa/IEn6q
/elO9ra7fRJM1OwdUVrYYOdfWdeFYjJoPG+Kp5XWeEP7nKuj2YLK3COXlWaF
YxvXwnm1VFDLuq4YRlnhpqIz8QqGPbRRqC/fRljibg5+RI45CN9Sed2n6Za4
kR2X0yuiQUZkwlBZrDnW2t+9k6emg4DcpG0Wm+LPwzGzTKoTuCzJwjlhZjhQ
amY9Hu8Mw/WUry2VROzg6T/3WHwIYuoPhLtHEvED43ly8HcX0KmL3Xm6Pbv7
XIFvZjfCFhnhtDcX+dJLblDWD5ob6QSseUiq4NW6Q4JXZdK7jwQcwle2kaYO
Q3uqoVxiR8CtUDimYHhCQ5XpytprHXqCG2Q5V5kgEdb1uKjWUVGYdzY5xgss
C2fuVdavIlnrfeP5FS+oNrHIZEn/Ir0nC7xLM7SgW0RuFUFMiZ83BAeuLCU+
W0a8zZquPLU3EKrbe4gnFlBUJ/tV9K0j0C84HuFDn0dlrjsFqg8UW7SV0m3m
EBbOjhI7fECqEhWS4ybQqkFw+lg8G0pC80PO0cYRM0Ni0LHJhm2UxUuwUqEU
zZZQKD4KC+XlAovpPlR96oJbJtcXlH8W4whOn5DeyxcSvkiJ/O33qDs7tI5W
4Af5IedJ2nEl0vv5Q7L9FvMkS8b1CTUcGpL7Q8FMwAdB4iBX73kMmieTgxrX
B5HEsW2jxIgDoy8mB+T7RpDelwMKD9Wc6Q85+gcHQUlU
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/BzIVIeivNwuDt5OuQcfji39fu0hLibZYvytB3LrJvHZGO2
PG2WrQfVTVMhhsUIc6LD9zsPXTJh0y3G4VKXhyJPlaelnT8+e//x2Xt778WK
Tw2/QaVQKK6H9z8/WDASOfRNUtzkQeh02mEiPrFS7nxA/hAuEEM2TKz5a4N0
VDtoNsUK3+npK9hl6UP9vNcjJjbDnFp3S7mzITgpw0aJLQu8br9YPlRmAg1W
WWP8WfOjvil4COi7sg4z7LCclimpoME1EPDE78/gPWUducuyhNr6yHTv6yY4
svWPUFRLh6jcRqOdvtO4rTAkRu5sC2CcZqN6boQH+fgxLYIJ7e8WCIMxI9xK
RGcPlbEg/fu5vJGwk1hpW5SXO2kH21qGGwkl+njsU8QKh24Pw14BArbxCXy+
+ZTZlxgHKP7oWlVdcgwz3Hk/n1Q4Qkhxpl94nC6+r7tGC55zgsBqz9Asls7R
PjY0jDM4im0tLH4Tm9Sc4AK9bg8lHco9NPXAtFRU6wrP2nWn86Ip+HLScJep
2g1k+aILDMd91AkFKrmzOxjJ9XoH+v+ip7hJln2TA5xyxfTtqC1UKPDMoEV4
wKXiOrX01yaSdd7TXdv2gN2lJrGT+SbSeHJhhxE0k/lyHbmUBnBq/DwhnB2t
WDRdRaL9yv7cSU8An+m3I02r6EoP0XI1xwsqhdIJ8fQauss+LNC9ITBHSp33
VyMsWfms1+0Nx5cWk5lCFfqtFZysiiEg/xZ3lV+gQJyUGq3ufQKsGfvM1w4y
lDh1IJFU+MBozhy1ZKAdvQiMckklfYFrbWJATnUijZcvLEjZy5NF4+RgRmgj
K98PGqvWvq5G1pMaPx4kCwUhPhfbSO9Q6sREHw++RcTEVr2aIzWe/sDdaNBR
o3Gy5mzXXrE2H3zjplpmGjtIjS8fqm0nFZZPZtA/5vRIQA==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ot92sk5GfsVFQ+YJqXNP67xz37xwqrV
setkDkDkWRx2PXeXqtgmfKB+76Gm34qcDn+W913lKBU7oL9UT/K4Bp+DvOfD
ryKFkgc+qbycdXK6oIOOw6/7mdGiUP0iDh+UpYqz40QOqL4uKJk6T8zh5y6D
MwZuIgf+3Ftm/1tR0qHIM9hetV3gQPjGH76JS6UdbuxxLr0sJXRgU7NXzHEN
OYf06R7Hz8fzHDhqfWCyWJiCw/7jVnqyP3gPbDSNrjw5XdFhyhpWrZxHnAfu
ybU01NxUcnir8DmqPZjtwIWrYW/0pVUc5ETmu8gXchywW8cr+jhG1aFtt6HB
PQPWA/J6lu+mzFNzEMjPeqSlwHGgj+2DmMcDdQcjo/WuV+YzQt2n6TBT5kDY
JF7GA9nbYzPWJWs5OAd2WURE/dl/q19kYuJSbQcNZ4fpnAp/93tmnN4p8lzH
wfKG1d4j+3/t3+HQ9Oi4hp4D8+4iLYO33/fPOLB2d2WWvkNTkqiB1N7P+5t9
jIrEwgwcmMp0jHMMPu3fvaOX7cM3A4e7Ev+8Od++3A8JT0OHhye2ik3d8Xa/
1kQX/cUWRg52C/au6TJ5vz/x7/zDNTeNHJbXXL/1KuT5/sC9phtCq4wdPAtn
+8+NfLG/UxOoQdrE4evJpw/OHH20/8DUNzc49pg4/Jwu8+xK7pX93xk9ch/F
mDqcXpNqvTnl6n79vMWMe/6aOtRLPpX4o3tif9qtf1OnzjNzYJT+fCCh/cT+
uW5RWvn25g51IRsvzoo8YQ8JL3OHq3vdrnNob9x/tMh7tWKjhYOcgXuQWN1m
e0j4WTpc7FeSfvCk0N7Em+nKlUOWDrEvMlqNKt/aQ8LTysFNfMqydZsO2y9W
3vmnncXaIapqm9OKwwug4Wvt8FhX4dSZNVvsAbBmQ/k=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ot9+OynD74sVDhgmpQ2/7jGP/ukDX8/
F5YoHIDIszhMWnZ1j+06sQP1ew81/VbkdNjbtZnDQOzJfv2lepLHNfgcypPq
Y09ySR74pPJy1snpgg4Ppy3Z4T5bFKpfxIGLV+C7h5TIAdXXBSVT54k5NNtE
/d6eIHLgz71l9r8VJR2ei7duYb4jcCB84w/fxKXSDt1HBfru1wke2NTsFXNc
Q87h4XJz0wObeQ4ctT4wWSxMweGDbDXXo1+8BzaaRleenK7o4HPky8zVrtwH
7sm1NNTcVHKQncTx9U4Lx4ELV8Pe6EurOGSJp6k9tOE4YLeOV/RxjKpDrXvF
p8hClgPyepbvpsxTc7j2kdUpyY/1QB/bBzGPB+oO0120QjpbGaDu03SY8kBA
sT2O8UD29tiMdclaDl9+LrdW0vy3/1a/yMTEpdoON6+5fl19799+z4zTO0We
6zismGemWLPl+/4dDk2PjmvoOWyWPPK+tfbL/hkH1u6uzNJ3sNnuu/Y15+f9
zT5GRWJhBg7zFwtYcFZ/2b97Ry/bh28GDvc3dj2KV3+zHxKehg7imc/esJ16
u19roov+YgsjB4tov6XTFr3cn/h3/uGam0YOls5su2KmP9sfuNd0Q2iVscPX
u415HVFP9ndqAjVImzjcWZ5x95ri0/0Hpr65wbHHxOHH93dtydvv7v/O6JH7
KMbUIen9823XM1ft189bzLjnr6mDukghj4vR7v1pt/5NnTrPzGHV6Us39sY3
7p/rFqWVb2/uMOEK08Pl6bvtIeFl7tC5adJ+jUeH7Y8Wea9WbLRwCJjsuC/y
4Kb9kPCzdPhxg0PAQOSavYk305UrhywdzgUaBmzyeGwPCU8rByGlT8vcdZr2
L1be+aedxdrh7vonfcVCK6Dha+1Q9Lrs+QSuc/YADRBOKw==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBmIQfUpCPk1f+ov9wr6Epn5OpQOmSWnzj2v8sz/t8mnm
9//yByDyLA6HeI/1JSZJHKjfe6jptyKnQ9dk9tmBZSwH9JfqSR7X4HP4/sNA
l2+C5IFPKi9nnZwu6GDZHX2lIVQCql/EYf4HrsLOIrEDqq8LSqbOE3NYdjmW
wVNa+MCfe8vsfytKOuwW2sm/f4nggfCNP3wTl0o7KFTIFBaLCB/Y1OwVc1xD
zuHmmaVF97fyHzhqfWCyWJiCwy+XimsPbgkc2GgaXXlyuqIDm775/6ocvgP3
5Foaam4qOUxONYr1PMh14MLVsDf60ioO2jebzs36w3nAbh2v6OMYVYf2yKXf
3/1iPSCvZ/luyjw1h6bJAbaGx9kO9LF9EPN4oO4QyOCtEVrODHWfpsPE9n97
z0QyH8jeHpuxLlnLwb/SducBV4YDt/pFJiYu1XYolq65ZmHHeMAz4/ROkec6
Dofinh5cycJwYIdD06PjGnoO1XsXhJ6S+bl/xoG1uyuz9B2abny9Edr4fX+z
j1GRWJiBw0LmMnb1lG/7d+/oZfvwzcDBOVbgS8apj/sh4WnokPdsoXLA2s/7
tSa66C+2MHJYJ8Vz3Pvuh/2Jf+cfrrlp5PCpynje4gfv9gfuNd0QWmXs8LLR
JkZo76f9nZpADdImDnVFt3ySpn/cf2Dqmxsce0wcfKvjOnX+PN3/ndEj91GM
qcNOoabVXbsf7NfPW8y456+pg9Ez3/Syt4/2p936N3XqPDOHrPlGPSEcp/bP
dYvSyrc3d/i9a12XXlzrfkh4mTvknHKXEni60f5okfdqxUYLh4yZ8tGve3L3
Q8LP0iG7ToBN3OXmfhNvpitXDlk6LE7QuPrd4oE9JDytHPwOq7mq7Nu0f7Hy
zj/tLNYOfg2vfAvfHLGHhK+1Q3W5klKE6YP9AKesRQ8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB3B3KLaIXFdcHZeHzpG7cLhO/T6L3TyUYYviVFQ3y8TM1pin
O+bSllguajmt66iZ05nKefp+52EXqbExDzOLq7CuHBnhKO388dn7j8/e23sv
RkpG7C2ymZmZ1+79z8GjziI2bZVQoZ2lhjg3zE0R1WmZO4SqvyS8ttcFm/4W
8Ol+DM+W7IwLu3okWwxrGHR8ItkKWkBspY+jlmkL0eMHHQJTj+MVt8WnA9X2
0Ch28gwdctrrU4AvZdCHRo5g9x+Z2TI5FXhi1e++Zio2ztQTWwxHaNC3hkf1
OeB49Z+LyUoalIacFbXMUXBLcYRQy6TDlfTl2MQiO9zPx4+ocS7wt7qQRV2z
x2puYs5ANQPUky9YZY/t8Qy9pChv8gR4sAdW7tJt8fBYnJ5Nc4OxZxVznAhb
fE5lc1gndAejuNA7mDiAnX14v6rkHtBkJu2v+GmFy/cZqGFfTsL3GLoiKcBy
b58n3KwRGEg0C5z2PilVdYMFh4LINotRZDz1kFKZrPQCubBl3JBnjsNTP2oo
896QPTGsqJo1ojaQzGmZPvA5+ps7Z2QT1eCmjpzbbKiJZjNt9m+i4gu+WdQ4
DqzlH4tfmd5CHW0P9hnWOKCVL8+3C9eRyfM0ZNYXjJeS1hCrMpStCPIF0lfL
65rOZZS8XdebN+kL96QdksuCVRTTxX1zKdcPprPehZh/MKAyz90CzR80+g1V
+HkDwjL9hFWnPzzvbmx2y15A66Sw9DkhFxxyC3IdwuYR+46C1LnNBbu3rVXl
JB0STe3IZPIAoAcnDW4SOlQrSGBlEIEgrYtRMaxHkckrEIweyC/ftQf1Z0U2
MsRBMLx0SpfAmEUmPx7UJ3Slmo93I/9I8uhoDw8mXq/mpylGCZPnGVh2uWY+
+1JJKFw1RqkFHySC2vZXG+2EyZcPvMyrvGyOGv0DGZVK8A==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0GlI03EYB3CV5YnGcJuTOXXmdDrbvP55gXumlTPzRWFGHuWsRKw0VuQJ
eQSxoKnkMMuDskmhLhUll8rvlzLnFZhZOs0Dk0q8RpZOp5axXjx8Xzx84cuH
lZp19qqZiYkJ9+D+5RDdJY3P+CWIieA3VXv3CYjUtDoNZ1+gV88sRU2YgvFP
AlnsXukFMg3f7ektNrCsQGyd4N8oNQO+gueo4dhBjstq0zfCEf90X3oyWEmG
DNXYwPwXB2zsU8DTsipKxKNi9vLN2/JaGmQvL5dmYirenW0QGFiOsM8Q0rGS
jM+36mPFCgZ01vy57mxvj9tKTiVpOM4wsX0H3JwOY3UYfkSLdwWP6mHMjCTj
ViIxd7CSBQGSiFCt1hbPOt8rLNC6wchikd1guQ0e/RS/wme4w7PxBvVmvxUO
V9pSvyaxQZSnDneps8AuvJC1iloPkHQkT5UpzbHMXEcTzXsCfS7vaEEl6f8+
L1CleBgyySR87U1yuvKyNywWlrVZc03xVCmlXKzgQuz6ELVZYoKj04dVlO8+
oDUI2RBpQJ1QvKDh8CBm57PFoGQHPcbNXbkZfIBsoVIet4VKTvtLaPG+cKmI
l1ul30ZdnQ/NdZu+wJKmPH3H/I2Mnn7w/kEW00GygbzLj/Prg/3BwGsfJYQb
SLxX11eg9YcBmXSd/UqHzvQQLefyAiAqUfi8P2cFSb0OCoxA6BjukA0xVhGW
r0xadgdCvn3DzK3qNbRlKrqxkERAcXSz6xXdHOJn1pt27xEQy1SI9ZRplDa1
L5fXHoMfXj1OqwnTqOZkgneWIAgC2oPsbBo0yOgVBCsv/T5WvH6L1JKYRlZR
MFDCZ09QXnxARr8QyDen+BCpfSgwxmx8vDcEDEdaLh7KmBQYPUNhfWSM02kz
Jqg/otq9TwoDeqHZEjduABl9w6CCzSTiVF3oL8XaRhM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0GtIk3EUBvApMhe5yNClTKZzLm/pTF06bb4nGmVtigpZ6oScKerwklSg
iZlG5R2tYURu2JxIMW9hTrz83zRZOmyKik5DwuENzczM2+bImB8Oz4fDAw8/
uig7JsWSQCB4H93/HHFwTmVRt7FNhxVk+8wV2KJUmdrDhP2M67w3nc8E898K
eP3hpfU8J3jcN1BsoJ+Aiuh0qqaKCiyFr6Pa4xQk842ZUYUH2Jbb6pvhOlvo
tXmx1z2xgJn7dpD5oOBza6ctzlzLuS+RUqA+Ysx0YLTFjfNNmIHuCD6cnYnm
OTJ+q30vIklBBZ879P73+6fxjpIbQrUHDWppu4kyxkl8KBR/SYl1gUfMyHEl
l4y3sxPyhuvoUJQTpF0T2eDztKdFBTpXcFN/6WCeJeFjU7HrLKob8PzeLQYI
rPGwFrK9XsiEqJCmytFGK9zZl7PxSnoOlPKO+JhkK7yKuEkJ/+EOOgv4xHAl
HO/zBHVw220hbkLirsS0lmQvcCkTqfScfTRbbVeTpPCGXW1jRlw6Ab+epum2
Wz4PPPH0Q0fqLlJB8YLawxc+tooTSia20Wtc2ZOXwYLv3BUuSbOFSgT+uZRY
P4hWl/f/0m2hHlUlcXPHD8SXSeUS/m9k9rwAqr2urBTPDeRVw2PJg/3BZXF4
qTpyGSUdygYLdP7gXk5khDQsoeg+dtvN/AC4dKZBsEVaQaWeRwVqIKRTKdxv
jXqES9ZnSL2BEGhN8Ve36tGuRXjmgpANV2Zl7D9/8xArS27Re8iG0WmGpHBj
DKXOmiQS6UUAoqMDJ1iD6q/Ge2VjQWCI7yodaW3HzF5BUEW2pknf8rGhXP4H
+pNgmKqYEQydmcHMfhzQhhENzdg4Fsi3nJwc4ECEfbOCUbaAmT1DQFzb4XR3
aA6TM7qNz61CgUvOjrymbTn2DQXl14btwVUV9g9YUUbd
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0GlI0wEYBnAvpCgNa877mJu6zfT/33R5lXsCE/OKjk0wDaYlUzNFi7C8
J5iVpdmYSKlgi9QpOhVnTpyrNUzyAM0DETFKwlFmVpZOMtqHl+fDywMPP1pq
zrkrFmZmZn579y/fOnqkEy6b/JXdsYnOKBK81PQmPXOXv9igel12mYP/fyvc
rltbNB7iomRIW75N2w9rW1uq5UkOCHmAk55pi/Fl9jA7nsAG43PDqMwOiuyP
rb1DpKlPQXmW711FEgfea7nXpY1UuJXKLmSIOdhZes7fpjmhaINOimdIJHZv
xYvkLlDZZOiefSWglMQk65nukCsn+8tq/KEL19RRhZ7Q1Q0udbkGoJt3sWBU
RkO/xaPpHwn+WHKvKC2c90LqVIWr3MEfkzNCA+HCQP6OxrF8ww8RnTb2H5K9
oc0ziEaa/eAREPrlcaMPXkQ8SRmZZuOB9To1etkX1IJg1XEG27SPheIJQe2J
RRay+lPEnWlsyHqOWJhXMbHwkFIrkvuhw7FGkkb64rR4bICyehSt9Vasd2of
qFC+omcGQEFWh1F13qjXdAwWZBK4JJsS/KlmQBLHzaMKSdxvE9h5NNMxqKq2
Xv9JwnA18jdDSDd5ckBXTt0r6/MCuzaSaAnhwrGteOtUAw0iY9OrwnkuLL+b
aV++p+HsEK9LcCsQRjKcsfrNE1WsvYJLEMK4Av3Bdk9opIa5feogiISsiDcG
d/wyj85eSeaB7x2z5FriDuJai7nayEO+Iup87x1npC/sSqWNx6CqVDgEbjrj
aVQSO4cfDMn8bNDsTQeTVzBSbsw5GDPtocuLbaeVhSCV0Cauudma/EKhEEgC
1dkUBMVaTE9rQ5HX4aqMz6WYPMMQV+QzPsw/jBb6wE6lVTiGaH2h4gM2Jt9w
JPR8OqPOsMdf3ZwoJA==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEcBnAihdjoOhk77rzcOdf9fnec1+WeGVJ6wxwTNVo6Cs2axZCX
djJhxnmLs2XeZizKEEpkN5RS1w7NS1pMDPNuXkrr+uO754/vnu3Zhx4e63fr
iJqamu3h/c3B02YRhMm6UNnfNKY5x4MgPKJSzjoQhpfETxtKePj31wT3c+N4
lwYfD7t703fp2vD4pnRryCFBVHON5Sx9vBhVjOhfJbBqOV82UGyA9QxOsoTx
v0+B//wgS72eB6uFe/elMip0KZc1d3h87E3WCHfpxuhfDvLX+cBDYPP2pbBq
E5A+QWkRRjy0ZFwIkbNoKIrcvm2kxkO/a08BVWSOLDtxfm0XiWbBtYSBYjoy
Wjl9Gg9ITNIepSaNMbDqN+Dw5iSJT19Fi4SJJdzb3q4ZuJBwa9I79SPECu8C
ny67GZMw4zovFcqsYUsG5M1xCORqrVC9p5nwTsr7kskmVPtsQHjaPGG6E7jT
FipuuslG9UZ68U8RF+N5lPywalvE655bk5ecwXnxUAdljoNswfRQljUH7Uif
kbO4MHQLntj4zkZJT2NnQhSB4a3hK2d1bJBxkR9HFZEonRoZ8MpnorM9R2tl
kwSrfiGRNstUefKwpG/w/vVHJtj5HkSVEx+1lRYjThQmwvYr+5LG+Dhqnltv
rWcN327B84BEO8SYhQhSSy2RZXNYMLHH9eCA8hsSBnqki6PHu+wxq/w9mFDD
wJa6d/RMiADugvZlHXULEDFV6l37AmS2RJXffUlHxPiBVCpzwOMt11fZdeao
8ApmxwodkWguSTkRyVB5OUI6UvQLMjr643wa6GlOmGKlFCY/o6n8nFHg4xnN
VNJg73NEoeh1BntCWyEuM1V5ukBRUyfy3KGiyqJjL1PTFaG+rV6jx0xVvq6o
8F3Y3N2g4g+UrifU
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1AEcBnBEpdFKHHbzcuflzuF+v99xeTnxWFepQ2SphTVvl7JSskk0
r7EsoTrMcsaF3ohMh3OG0k2UZsTRzGSrpEhG87a07o/vnj++e7ZnH0ZUwolY
HS0tLcet+5dvzazEBH3J573v4/bgai74UeJKFXvTZ09s8UDAKIn/f12kRpye
SSwnka7syVpj6ENcEqQkDlEgarjmKvZuGFoPCsg3PCzafivvK92L7mpqxElN
afrGuJvaYmCgpGD3/XKSRErDclLZUIwLhfXJWp81hjl+6ClCvHbwcKrpT0Bk
DR3bspcftXVSeJF9LFzFtsTV1OP2rXUUegVd92ih1pCFJM/3tJNo4oel9JUy
ULQp1k6NpTBpmZORpmaifXZJ5uxJ4cNI6BxBt0VdX4b7KouCd4OhyedwO2Su
xU+tyElYcT1+3pfaY4MM+82qIXFn+wLNb4qFcOlYc1gDodnngAdm6q6JIgLx
8oi4hmgO5rLyIl93cDFeaFwcWeOIbnm67+KMM47G9bcZf3GC+JrowEsvLlqR
Na1ic2EyfmWlKtcJZV31ipQLBAKrHGju9U7I9ucl0kJJfCoxMjvX6QhFa8H2
hWUSA3ThMyKEo/GksGoZGJNfzgGnWEjI3HnQndhotJx1QORG5as0NQ/6zvN1
+ZNsBCv5jSevu6DdX5KrOsvGLYetAt0VlQc/CprlLHRJ5sZ2drhCGL2Agnh7
rGj7XZwO52NIMfguiM0CcUmm3bHBxxOmXwtELIjHNyUS6X6UeOZvTo3YoOLw
GU6CjxvsFMnSXwVMjZcb6np2WVi3MdGbKHrKyHQHvbb0yMNJhsbPA6LbN4zO
VzDhKtIZHu7xwOhXi316fKbG0xN9Bha63jkWkNm0refpCiAsfJ51099U4ytA
v99QZu6yKf4CZMksLg==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H8slAEYB3BkNywZOxe7ja5w791x772vu5Di25LIr2k5RD8wt0Molab0
w0mqqZsi1ELZNctS2roY5ka66ZAtt5w12VmTMUSTOtS17o9nzx/P892e58NJ
zz+UaWNlZSUw17/+3s1TRrJ/hBKaG+crVoWQpMsatMRGqL8mWOqU7of/c1vw
vKWmKRcaV7p7FSaOPcqmVF3qIQqkSuiuJbYg6ntdymAYjSWvmQcDNc7YG8m8
uxBIW/JM7JfH5li/puA9e+psdT0LArlmUPGJxtrE01ATxx1jAp2+ooVGYttq
TJqKjQ1Pw+mTRhqvSg+magkPlPVTkX8O0OgP1txjSbchbdiByzZQaJOkFA3U
cPA4cyZPPklhwuPa1WLDdqgdGOnnViiM6KVzJNsLzZ9Nu5NbKYS0OrpOpXqj
TbTUVKik4CkMmq+q98HxPfEx8wEU7jAWWRGTXOwjNdPD5ZTlPh6+NTPW4y9R
yHlzVN6awYeg5bK+JYnCuJJZmaYSoNDpsOvXRhEi5boO5rQvtMsh15sDRWiH
wqglhPDOuO8b8VaEWs3zzqJsEopWx+wkFxKl0XQBS2ree1Jlv1pMorP9NmNx
RQTZyOawHonI4kkhqmcoi44Tgl8ZRjaZXcM3PZwyJvohbb2hr9hAw0RmJNup
/RDfLXmZcMEfubIPOiPHDzd55gBbDF6Fl7N2zhea6rkxuy4xUut6VvKUAvy0
jsg1pkrA6qvqiy7jg8xrsu5alyBlrt3jhIEH2fhGdXX9Tiz7xHGVF3l4FH6E
nx8aAMEZt1KGO8/iFYCtEf7vBha46C+IauGUBJr/sC6+9YWw+AVBXNI4PVtL
QBxlMzraG4T8TvVM7EeuxXMXsnJ0L/RcAk07OtbKbYPh+2t+NOEYYfENxrMS
Rc3Qbx7+Al8rK4g=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwt0H0s1HEcB/AjKm3hhpOu0eXp7ne6+/2+XJ42907tRshUd9RdQrKLPKQi
pifazJoijB6cSldLnaJNxMU8TGhNwzz8YU03ZcwsovJQWvfHZ+8/Pntvn8+L
F5d66JQpi8USrs+/7N3mlCDmLkgN0fd+vLBnIIlLqOrmr0ndNjTe+fCewf+9
GdjFab1R+wiu6Ntzl3kWqOk40ul7iYFYK3Lo5lti0G1YLIsm+O4ydbennA11
wPY8QwMx9m2hVeZ06jIIXKfTzpdpONDpG2e57whWxp9Il3kOaDpaSPaeI4is
+xkWq+XiZYWQR/IJ6vMOqLr5joDcxMKQSdDl31bCUexEQaq1LMyRoE6izOop
56HFeXdJuJpg3PH61ZzRXbCruijPiiPoH1LMiLkusIk5eCY5kCCgdqvdF5Ur
rGRyxwsPGTiJfGdLNW64f7Yuqtic4ObGOU7QZ3ewVYdV0zRjvE+AeBn5M/Ob
QdKb4+rakxQ+PdD0zK//P3bLtjhWK8Tr+eaBjBsMgtV9TbZfPZB2+Vtog5JB
I3InuvkihJckFWXqaFS06ZqzEsXwMY94nJJCIy+UpHMU63miq/9XMI3mxsKN
c4s0nj7jVMpdaaMnA3ubAe5bEQ2qeL+42odAYbtYOh1EI3a1qiNnlMBlR1Ji
aAyNCL3klTzbE8JpRXANR4QCwXqB64XOBH2RSacIbWUzI5tbvNA+GTDUIvTA
kklQ8oRKAqrPr1VjRUGcUm3SsirB6aDyuaplCglja2Vlmj1Y+VhJsXoFqJQd
o1Kl3uBNBnb0sSmjlzeGLQWB4kgButJDnvOu+cBG5cTaEs43+vmiybq0hBp1
h1eI6eBguy+olNJNhilXo6cfHt1mL3i1uqPauWkl38wfTvXMklIqMPr6g5Xt
6T4ST+EvJzYfFg==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEYB3AvNwvTprjoCpeXfs7L/X6/7pxzm/tqLUQaCy2c7nAu5iVp
S7PlpbIUqYhpXOuoxhJZxdCuM11opaLFRuYm1V1NiMpLaV1/PHv+eL7f7dmH
LcuKSjEzMTHxWp+/e8DBWc5lLYhrGmtbzRUk+DK5UkusiQe2imuyMyn8uzMg
XQx3L3hO4XSPpmiZbQnWJquGLwIa3EZfRy2xEWlxc89EUTTm3D7V9lfbwj7p
1UmdkDb27TD+QuL9PpSGuz47t6qeiQNdPWsLGhorE7fEy2xHPDUEVE6racS2
/dgvbWThtkOF80gTjfvF++K1hBOqz2a5z6/S6BOprzJjXDA9Fiz5sJ5v48fl
9VezcS8ul/cQNCaczhTkj+7ABZWnK1lJY2gkxsBlueFGitBJl0EjsMXGXhfv
jvw3ifqL6TScfYVfK+s9sPlJNnHcj0a5xSwzZHInSmPnBeWM//95Ys7x+keb
VQrpjxIULUkcTBI316KmKYxdsrssbfTCIFwjI15SCFUMdtrNeAM6iVKZRaED
RVNawhdSjeStPJlCjfpuV14aF5OFsSXkNgrF4XQOM4ZEnPW4qnqGRFdHmcXs
IglZkIyReI40elIoIxIknUdJcC7v4ar8113VFa/JgySkq8re/FEakbEZyBeS
iOzht0af2oVrUFg3PODivOd6gcXDkfna4EBbLtRVhncbunlIPXRCdmXKB0um
IRlT8XzoeIbveksfcDNVpt2rfDQ5uy3dsfKGfGytqqreDxGpv4Y/m3uhbu9h
TpZYgDSNo61DO8foJcDjeZeEXh4HfTlhzexCf+iDc3bXlnoa/YTQDdYJrLYQ
4IWZDQ9rhGgfsg1tjiaMngFg/PZzOVZCQOXauVLCEOFnkEigz/Ew+oqwPTlh
fPqbG/4A85EoIg==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1AEcBvBjTteKanEcheNO55y7+/24jm7cs6nzeibykpfVnZLeMNmK
aQ6VtSRXXWRzjNjyNqqFHDPGDZWWY9hSsdWSmd2svC+t64/vvn88e7ZnH6Yy
I+q8OYVC8dy5v3/E3jlV4LgirduMNmoHhRApU6v1nG1pmYSb2bifwL/cAjUz
7lpNJoH8nv7CDeZubC1bZvWuEhDU8xl6jjWUlQ4l6SISRtaPyuHyAyiMNI6H
3iRNfRvMt6ga1cUk2D8zszVaOhqWwl4m7uSbsw3SDSYDH0NlCx06EnHtq3JF
vSM4EW2uVDNvvCgKTdJznPA0MFButcsbg5K+R/RYF9zofXLnRDOJdlFiznA5
Eyy+3FA2SmLW6ZYqb9oVysmxoIsPSXyYiF0UOLKwdy3MZfMdiYBWK9v5JDas
J6gBPjt7nPl+S4+17mhmKysY0SRKLZfpwV+OoGf5q8w59v8+DxxmnbblJ5C4
3JGc1prCRYXc+GqEQWLmgY1aUe+JVtq62zcqiZC00S6b7zycej7r/2mJQCcK
5/QcPgxXFiJaXhOo6GvpzrkkwBzNLP5ZAYGicDKLHitEaeTbjjEFge7O+5bL
v4RoGD9n325DmDwJqG93e2YvCcFVHxfU+ZKIb13zddEJodiqHsibJmGx5/rQ
VJsQJ3tEbTG53qCq7N63FAhx12On4OgDr4Gc0hW2EH2axSmazgf+n2tDE1QC
/DYLvjqXJIJD4r6zeet8CNLrzHRbInS5qbvZmXykzmxrNNqjSKml5U4zvFAl
S+BmSMWI6ju0HjTJM3mJwSoWU0pkPAxmhTUxC3wRYrC7dqbI0+TnhzRt07Z8
kAufMHODod8PQ3GVvAuTXJPnMdTEKKzveXBR59a1WWwhwRtxOK/UimvylaDK
GH0wOd8DfwAwUSPX
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw10H0s1HEcB3BPM7SS4aTbcKHOOfe735c7jta9JxPRjC0PdTZPiYyzS81J
C8d68NCukkinumFJpK1hmDtCWCthw4SoNUuiNXkureuPzz5/fPbe+7MXK04a
dsZAT0/PdWf+7oF99okU86c4VS65lRHDhyAusaqPvS2WXlz8vs6h8e9uBHMn
5mHTLBpXOrryNlim2P40cCvThICq5tn2sffATDXnIfQk+OE0X9FfZoHaoyV5
q6FEl7dCfYlKETJCw/lrekapigFZb9LI3rcEm1M14g2WLXx/11jKLhNENK2e
iK1m7vREWWQqCF4ojkv62HYYn777JCiHoMdHc5sR7gBxyDKVn0vQJDgt7y9j
QZEsDH7TSTBll5+TPX4AQ2u8xqxygnej4QsU0wkz+FyZriU40rDbek7iDMPJ
Lq18g8CeJ1q8ozqIXfGZqgvNBCXGS4yAmUNIrogchOT/fy6QPiqydF6jkdIc
ndQQz0EEbx55/gQTN62UsdWuCPPdf/aGDUFg0mCr1RcuEoS5lREUQQvyZvvY
PNQZJqfyX9O4p3nWJj9HIaXDUu3+koYimMgY4XwcSx2KKU6m0dZSbLy0wkeu
ptlxMpzWedJIUIYV+9jT4Cj9KLUXgV/v+YeR03zEblV1Z48TmH2jtFsWNEI7
BM9PZrkjZCXM0b+Ij+suOwGmBx7HXqsSpfGhKV0YM2n3gIuddaN2mMIv/YDU
WYkAgQWvXOsDKFBpav32LQGUG8GuyxoeEie2S0tVQoy6C81N3rvhgf8pjlTs
iWFzN7bNKlfn5Ym1FaVRZDQXPbKgp6xcL3hLlbXr5RydnwhuW9xOB2suPIIM
Rka6RCgsrGMUrHF0nt64JO/Wqj+6QO3YunnVyAdj8aLx4fscna8Pokw/GBrE
sPEHMjYlIA==
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw1kHlI03EAxb3QykqKJQ1Nm1dz022/b5snuYeZrizCQCPP1BTNY2pRKtrU
SSnkmcvQuYGif3iVEnhMyRQbJqJ4ZEpaqJiWlXiDBy2afzzeH4/He3wYEeJb
UXo6Ojpsjf75x7OW0VyzDeHlZBv9ZU8eBBHRSjXzQOh1aU48dIzC/9wA0vVR
1aQvBUl3b84u4yis7iqKdHcpcGs5dDXzJPKFtUHmixTWbJYrBspPIXfiabQk
gmj7NHRBGLawRsH2Z9JDmcIUjzLzRr1ZBHuzdcJdBh0tEV9zaJUEt1t2boTX
msHYRJLoLidolV4LVjMtsLIuZK7nEfS797wwDTiPwWL99HPPCVoEQWkD5Qx4
j4eaJywQzFrkZmVMWSH2B73L8xPByETACtfMBmELw80dmtyj+cSZ+WBbjNk4
qTKqCSw5rr/LFHboTGXXbRYRFBqumoq+XUB7vFQem3b4zx5xU0sKUTJBXFtI
THMkC87JZSKSRDBdRCsJr2WD/tbvgZpPcDVmsIP23QEb1p3jxiBoR86cmsnB
zMyWbHGJwqueJlXafS7UbQ0hGQ0UpNdJimkAD/UF9ySTxRRU7QWGq1s8mBTy
oxorD3lSWLJMpcv8KbBKvLg1LgTDRtuh2Q4UwveVfRlTmp3W43pfrlDw6xa8
8U+/iPpw1U7/Pg/59pqCGR9iW+kTn0YeemQrn4908bGd91pxR7O7rStKmAsW
wOOPcqZJjwduYo1u174AwZs3fd51chE9fSCTKZzQLzGwtDPioso7kCUWOqPa
aGtCNe+o5eWMqtLTjo8zHdGf4tvAyHZBsbgscOS9g5afK14mVNCylGzwffXG
x3tdMdan79Zs4aDl6YaheAu5nLBRY92x98zAHYmcXzVrHLaWrztKP0TGmNux
8BcjUSvK
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, -10.35246471318078},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"FDPower: \[Chi]\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            
            TemplateBox[{"10", "6"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotLabel->FormBox["\"Run 0\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.423922646093395*^9, 3.424185051355573*^9, 
  3.424187251649128*^9, 3.424187464377925*^9, 3.42418751626135*^9, 
  3.445191157823781*^9, 3.7174482465325804`*^9, 
  3.717448277894292*^9},ExpressionUUID->"e330b64e-7a23-4b50-bd18-\
903f18f070c6"]
}, Open  ]],

Cell["Number density spectrum plots (all times in one plot).", "Text",ExpressionUUID->"39fb4dda-a944-4dee-945e-463fb6bd931b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"donumber", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"numberminalltimes", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Min", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbermin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"time", ",", "1", ",", 
                 RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"numbermaxalltimes", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Max", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"numbermax", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"time", ",", "1", ",", 
                 RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"alltimesnumberplot", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ListLogLogPlot", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"numbertable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                  RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{".7", " ", 
                    RowBox[{"time", "/", 
                    RowBox[{"numtimes", "[", "run", "]"}]}]}], "]"}], 
                    "}"}]}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"time", ",", "1", ",", 
                  RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "5"}], "}"}]}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"\"\<Number: \>\"", "<>", 
                RowBox[{"label", "[", "fld", "]"}]}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", "0"}], 
                "}"}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{
                    RowBox[{"numberminalltimes", "[", "run", "]"}], "[", 
                    "fld", "]"}]}], "]"}]}], "}"}]}]}], "]"}]}]}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"alltimesnumberplot", "[", "run", "]"}], "[", "fld", 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"fld", ",", "0", ",", 
                 RowBox[{
                  RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
              "]"}], "}"}], "]"}], ",", 
           RowBox[{"PlotLabel", "->", 
            RowBox[{"\"\<Run \>\"", "<>", 
             RowBox[{"ToString", "[", "run", "]"}]}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.422110150401568*^9, 3.4221101568235664`*^9}, {
  3.4221104856267543`*^9, 3.4221105264244127`*^9}, {3.422110832133407*^9, 
  3.4221108331490517`*^9}, {3.71744846900219*^9, 
  3.717448487756378*^9}},ExpressionUUID->"5b3e7c40-a66e-4c69-831c-\
c8ab136d8f44"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.033333333333333326`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+BXFTIrrntv964dwvy
SOQ/GH8x/KtI77/fVqmFon3tP7XE3uHxCuu//AmBZtBQ8j+YNLPZW/bhv4OR
BD6aO/U/zyPivmEw5L+F+JAQAbP3PyeF4fShVOa/Z8hRwvLV+T/111TDweva
v1qa8FBjuPs/cNo8sYl457+rG0W78Wf9P02CqgpUaum/XkJExlXu/j/lByBQ
pWPlv0rxjfBdKQBASxSh3ffq4r8wDFZVS80AQIn3kmkqV+G/aPTEOBFlAUCh
1FZ400/uvxxYWWJd8gFA+Bn49uP/5b9fwE5WinYCQDqnfg5Mjuu/Yf4DKbPy
AkCiGvLGGj7nv7aVvjjCZwNAdWl/dxWG7L+vqhQXfdYDQMsbVXjj4+K/URxh
nYk/BECHV5NbAl7mv8j9nsV1owRA9YMjEDMf6r/OEUy2uwIFQMiycLhRqOW/
vDSKScVdBUDDAckcRbjmv2mz5tPutAVAXbdfxaS+578WQH4EiQgGQPmXeDZD
ueW/ZgymBNxYBkAdF0f7m9Tlv8ht5d0mpgZAk8EsWdfK5r86mcUHovAGQNGI
JXMXZue/lSeDB4A4B0B5FxoYDbjkv01Dkz7ufQdAu7byroe56r+QQGBSFcEH
QEq+GEGz0eO/iC1M0xoCCEC86EUQAOLrvy5hhhMgQQhA98scE24V6r9Gqu6p
Q34IQPI5ZGYluuW/3EI/hKG5CEB7i7Z+YDPpv3V70zNT8whA298EgE1s57++
4ugvcCsJQEmipN1bRuS/KjnT1g1iCUDxQ1wzXTDwv2//PYJAlwlAZ3R2VVAI
7r/Nqh9dGssJQA+xaC35n92/2pJMb6z9CUAZaIrFKWTjv0OMXYUGLwpAMeEJ
q+qH7b8FBF1ON18KQMe462g25de/SqAKdkyOCkDs8+p7ow3iv6F4WxM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06666666666666665, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT83KVDlqTGsv964dwvy
SOQ/qXIc4cVwwT/fVqmFon3tP9S7y91jsME//AmBZtBQ8j+ii/7L3ISiP4OR
BD6aO/U/1NOirzrbwL+F+JAQAbP3P3uh5d7thda/Z8hRwvLV+T8XYGwwQ2DV
v1qa8FBjuPs/RGFOhmaO3b+rG0W78Wf9PygzQaQ5CeS/XkJExlXu/j+FivfZ
HV7gv0rxjfBdKQBATwAidyWU2r8wDFZVS80AQPCcpUnaPtm/aPTEOBFlAUCg
xKdhEo/nvxxYWWJd8gFAOWbv5c3s4L9fwE5WinYCQJZKACY7a+m/Yf4DKbPy
AkAcO/s5Q9jiv7aVvjjCZwNAURsdl4BV57+vqhQXfdYDQNqJgLYVGOK/URxh
nYk/BECcNxtuaFzjv8j9nsV1owRA8n2VK6q/5r/OEUy2uwIFQHPDDwsq2eC/
vDSKScVdBUDkM7w7TDTkv2mz5tPutAVAM5S7kBdS5b8WQH4EiQgGQPb5P9hJ
OeO/ZgymBNxYBkAp0G6loa3jv8ht5d0mpgZAZF34UXpA4L86mcUHovAGQHCF
xWSgbeK/lSeDB4A4B0CF4B3IT0bhv01Dkz7ufQdAVM/3IaLH47+QQGBSFcEH
QLtdrMuz0Ny/iC1M0xoCCEAMVClXnM7kvy5hhhMgQQhAG0etwOjc5b9Gqu6p
Q34IQOksRMh0hOO/3EI/hKG5CEA2wvWZFjTmv3V70zNT8whAuaJwmUcx47++
4ugvcCsJQA3sR1JKv9u/KjnT1g1iCUC2ajyridbqv2//PYJAlwlAP/zkCf9N
7L/Nqh9dGssJQLWl213fp9O/2pJMb6z9CUAnQ76cw0bZv0OMXYUGLwpAeHBs
KiAH5b8FBF1ON18KQCFNmsWoQ9a/SqAKdkyOCkCBObE+1hrnvxwSVBc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09999999999999999, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Jd+6QujvuP964dwvy
SOQ/lvrxFBOR6T/fVqmFon3tP3AfCCvzkt8//AmBZtBQ8j9MGOdbUw7dP4OR
BD6aO/U/Ugfd6fexbj+F+JAQAbP3P9cjtuHdere/Z8hRwvLV+T8VkEe/0X6V
v1qa8FBjuPs/S8nmU7tixr+rG0W78Wf9PwrBlSHXtNq/XkJExlXu/j/Rw3Ci
i5rVv0rxjfBdKQBA6fGo2KKl0r8wDFZVS80AQHFR9ECZLdC/aPTEOBFlAUBj
5BZUq2vkvxxYWWJd8gFAYnko2VA73b9fwE5WinYCQI167aVAleW/Yf4DKbPy
AkD5WQ7DbKrev7aVvjjCZwNA+HW8szgw4r+vqhQXfdYDQIYtilk8Qd2/URxh
nYk/BEA4Cjak0RXhv8j9nsV1owRAhdUaQ73W4r/OEUy2uwIFQGkfzPAUjdm/
vDSKScVdBUD25EoBn9rhv2mz5tPutAVAqtf5q0bm378WQH4EiQgGQDyfmNAw
NOG/ZgymBNxYBkBkULG1kzfcv8ht5d0mpgZA5nYJ1m9m3b86mcUHovAGQMAl
LqJzBOG/lSeDB4A4B0B9cSr+7HLev01Dkz7ufQdA8kNgcjR74L+QQGBSFcEH
QIJ2VUElI9a/iC1M0xoCCEAoKI7xH9Pjvy5hhhMgQQhACXxbKba15b9Gqu6p
Q34IQNpDybKpg+K/3EI/hKG5CEAqu/WMxqTjv3V70zNT8whAkc5e7eX837++
4ugvcCsJQDFUi8Hvl9y/KjnT1g1iCUBnNCn+fDvqv2//PYJAlwlA1ArBg0r4
6L/Nqh9dGssJQKB6TrkHzMi/2pJMb6z9CUDodcVBUt/Hv0OMXYUGLwpAI7mF
+fcf678FBF1ON18KQP6/9lIZCMy/SqAKdkyOCkAhgUssacvnv0P5WCE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.1333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/hnhPdK5MAQN64dwvy
SOQ/vhvq0pjM8T/fVqmFon3tPwYqWdQafeQ//AmBZtBQ8j/gAA3q4jbiP4OR
BD6aO/U/yZEn0sDbyj+F+JAQAbP3P+uEpfEYKLI/Z8hRwvLV+T8IA7Sy/abJ
P1qa8FBjuPs/Ar07NWk/gD+rG0W78Wf9P06groW05c6/XkJExlXu/j+fk0w/
FznBv0rxjfBdKQBAg4xYeDTYxr8wDFZVS80AQLQDSozlccC/aPTEOBFlAUDW
/ivotXvevxxYWWJd8gFA5hUHsOX41L9fwE5WinYCQBQDj/U/pt+/Yf4DKbPy
AkB2812PvlXYv7aVvjjCZwNAllpqLLXQ17+vqhQXfdYDQAEHis1ETdq/URxh
nYk/BECSWVtl16XZv8j9nsV1owRAc2ep1jwW37/OEUy2uwIFQKaRQSawmda/
vDSKScVdBUASzDVIlsPcv2mz5tPutAVA9sZrVjAL278WQH4EiQgGQO89CbtW
wd+/ZgymBNxYBkDVtjrgNibYv8ht5d0mpgZAbUjFtw161b86mcUHovAGQPfA
TIg6f9a/lSeDB4A4B0BStdNzCTvZv01Dkz7ufQdA64XgmKDf2r+QQGBSFcEH
QEubNVNDC9G/iC1M0xoCCEDZ0TbIIxDhvy5hhhMgQQhAh/0WNPAJ4r9Gqu6p
Q34IQC3czqSRcd+/3EI/hKG5CEALTv7x+Rzjv3V70zNT8whAUp6PPKnJ2b++
4ugvcCsJQAJmvaJP2Ne/KjnT1g1iCUD9OrT2wLvnv2//PYJAlwlA4N/t5cd9
5b/Nqh9dGssJQOZgSyRDnMa/2pJMb6z9CUDhd/5z9wbAv0OMXYUGLwpAhx4S
yo58678FBF1ON18KQMNM0v86zZS/SqAKdkyOCkDw7KVq4RXgv20YVVU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.16666666666666666`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+lUrlPIVABQN64dwvy
SOQ/zalS/zew9D/fVqmFon3tP4SA+AwAo/A//AmBZtBQ8j/K3nb3MOjoP4OR
BD6aO/U/Ur4QXj171D+F+JAQAbP3P4aPl0nwhtE/Z8hRwvLV+T+T8x+DXMbe
P1qa8FBjuPs/oIl8BEDxuT+rG0W78Wf9P0cj3Da2bsG/XkJExlXu/j9sXruX
R36nv0rxjfBdKQBAga5dYtqedD8wDFZVS80AQO5waD34SJK/aPTEOBFlAUBA
7Lg7AA/SvxxYWWJd8gFAz6xLkJoF0b9fwE5WinYCQBiqw+lEGNq/Yf4DKbPy
AkAKIRIHU6TPv7aVvjjCZwNA1LKiRS2807+vqhQXfdYDQFpuOUOEENe/URxh
nYk/BEBCRwT1HdHUv8j9nsV1owRAXKtsGNZy2r/OEUy2uwIFQAi7DdSk69C/
vDSKScVdBUDDRqXaP2vXv2mz5tPutAVAK4UfZIkY0r8WQH4EiQgGQHHODNWu
DN+/ZgymBNxYBkAJGsbnyR3Vv8ht5d0mpgZAXdiGdhVJ0r86mcUHovAGQH+l
+d4bENO/lSeDB4A4B0Blh4MHlQfWv01Dkz7ufQdAh2M+fUO517+QQGBSFcEH
QNmgiEqvH8q/iC1M0xoCCEAAsqvH3Hjfvy5hhhMgQQhA9K29XJ2H379Gqu6p
Q34IQDerSHdodte/3EI/hKG5CECcb+NpgOXbv3V70zNT8whADUkI1Z3w17++
4ugvcCsJQFj7uqNwade/KjnT1g1iCUCSQtjehNzmv2//PYJAlwlADSEh0PqU
4b/Nqh9dGssJQIUmzVUtGsu/2pJMb6z9CUAtppATex2zv0OMXYUGLwpAaHHt
3w+H578FBF1ON18KQKYQEtRGl6M/SqAKdkyOCkCC6AL1eo3YvxmWSaI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19999999999999998`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9h+mhvRCsCQN64dwvy
SOQ/yaiIeTQ4+T/fVqmFon3tP4Jn8umon/Q//AmBZtBQ8j9ozAVjQ+noP4OR
BD6aO/U/LaxCRpOn3D+F+JAQAbP3P9XlK0+3z9Q/Z8hRwvLV+T+dBf0U3wXi
P1qa8FBjuPs/lVKYjF7nxj+rG0W78Wf9Pw6CPuUWerQ/XkJExlXu/j/w/qng
8XGlv0rxjfBdKQBASx+pWXblwz8wDFZVS80AQGbewP2xO6U/aPTEOBFlAUBf
uALQou25vxxYWWJd8gFAKKdo200ayr9fwE5WinYCQLHToTAFO9W/Yf4DKbPy
AkDgALs1UBO9v7aVvjjCZwNArXicaBR7xb+vqhQXfdYDQLFeBwVJBNS/URxh
nYk/BEDs3/KumlHMv8j9nsV1owRAMjfDwCGS1b/OEUy2uwIFQN9zjV8CJMe/
vDSKScVdBUDubIXmolTUv2mz5tPutAVA3SOaqaudwr8WQH4EiQgGQMQLTXCF
/dm/ZgymBNxYBkAbn2eOu/LRv8ht5d0mpgZA0AQ0hWwwyL86mcUHovAGQDXH
uA51oc2/lSeDB4A4B0CciFqa/z/Qv01Dkz7ufQdA0kJE0Vtr07+QQGBSFcEH
QMAfoBCwlse/iC1M0xoCCEBP4aCRl+TZvy5hhhMgQQhAyXbfyeqc2r9Gqu6p
Q34IQD2wQALIDNG/3EI/hKG5CEBnvYM0zVTXv3V70zNT8whAEQZFaYje2L++
4ugvcCsJQGXBz/GEps6/KjnT1g1iCUA0ADSuYfLov2//PYJAlwlADRLRyirP
2r/Nqh9dGssJQJrtxn4C8bC/2pJMb6z9CUD1NP00KdSwv0OMXYUGLwpAORg7
dq+g6b8FBF1ON18KQHW6d7Hjb6g/SqAKdkyOCkAxwSGBpinxv/GVT1g=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/SPqfu5oMAQN64dwvy
SOQ/6CaTGq6p/T/fVqmFon3tP+2c2h0d7fc//AmBZtBQ8j9U17e36ersP4OR
BD6aO/U/lBbAUE4Q5T+F+JAQAbP3P+MeJiG6k94/Z8hRwvLV+T8+Sywj97Dm
P1qa8FBjuPs/vAMS38+izz+rG0W78Wf9P0U5ZSrpg9E/XkJExlXu/j+Ke21o
BYm2P0rxjfBdKQBAqm6Akyttwj8wDFZVS80AQDM9uLrcLcM/aPTEOBFlAUA7
31kdOjWaPxxYWWJd8gFAo4iz7s/Epr9fwE5WinYCQNoCOS7UDcG/Yf4DKbPy
AkCdKjwr5Dmlv7aVvjjCZwNAgWt5ftDPvb+vqhQXfdYDQH+mTG/QKtC/URxh
nYk/BEBRWmdHqlC3v8j9nsV1owRACkFbdbFJ0L/OEUy2uwIFQJ4bmAO0+r2/
vDSKScVdBUBgBO8X2hbPv2mz5tPutAVAUN47a9UMtr8WQH4EiQgGQKYVgBQp
Z9O/ZgymBNxYBkBRdfb8bT/Rv8ht5d0mpgZA71CZEO7qtL86mcUHovAGQAeQ
jQP+nMm/lSeDB4A4B0DHZM1yi8PLv01Dkz7ufQdAFRNaQRN+yr+QQGBSFcEH
QNLtHKQgMMC/iC1M0xoCCEAPgwyfsbnVvy5hhhMgQQhAyQf7bmux279Gqu6p
Q34IQAntBrkKSMu/3EI/hKG5CEBfrwTC6EvWv3V70zNT8whAo/FrbSzm07++
4ugvcCsJQPtwT3xVLsi/KjnT1g1iCUBklO64PCvlv2//PYJAlwlAPLs7JkRy
1r/Nqh9dGssJQKDwEeimyc6/2pJMb6z9CUB9c+2ePdefP0OMXYUGLwpA4c72
v+Qy4b8FBF1ON18KQLOS9xvzt5M/SqAKdkyOCkDMPAhbhlfhvyMESJI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/m6e6ZXZQFQN64dwvy
SOQ/ZRlVZ607AEDfVqmFon3tP8eT8mbHcvg//AmBZtBQ8j+HtnWwSOfwP4OR
BD6aO/U/wtLM0vlt6j+F+JAQAbP3P357jy+Ub+E/Z8hRwvLV+T9tp5YDqyfo
P1qa8FBjuPs/2QJLvELU2z+rG0W78Wf9P+dwgjZLt9c/XkJExlXu/j/uSUER
MVLBP0rxjfBdKQBADnHxxgYHzD8wDFZVS80AQHCT9ZsacMg/aPTEOBFlAUCq
pNCFGVCrPxxYWWJd8gFAcUTF4WySo79fwE5WinYCQMJi6GN8ycC/Yf4DKbPy
AkBHfr+tj4m2P7aVvjjCZwNAub5hYnfxrb+vqhQXfdYDQF7mG2Az5Mq/URxh
nYk/BED8Bi7hoauuv8j9nsV1owRA63ZonPbIxr/OEUy2uwIFQMvfU8A1/LO/
vDSKScVdBUDBMnOZyDbNv2mz5tPutAVA51sgpKn4nb8WQH4EiQgGQBRhTkK+
WNK/ZgymBNxYBkB8Mxj/LzjNv8ht5d0mpgZArFkMuNKtqr86mcUHovAGQFBG
lRDR7cO/lSeDB4A4B0CUe5/QenPCv01Dkz7ufQdA/MFQAhhDw7+QQGBSFcEH
QAb5rzuBrcG/iC1M0xoCCEDt8ga7bcjQvy5hhhMgQQhA4+/y/k7h1L9Gqu6p
Q34IQMnuwVxdFMO/3EI/hKG5CEALQWZEywXRv3V70zNT8whA/MJ7IgM2zL++
4ugvcCsJQGMXciqMu8K/KjnT1g1iCUAgk80eayPkv2//PYJAlwlAgzjdJGn/
xr/Nqh9dGssJQL+HSaaykNS/2pJMb6z9CUDuzCihHBW4P0OMXYUGLwpAlruw
H10j5r8FBF1ON18KQMmja+pbjao/SqAKdkyOCkBKf665zePev/QNUCQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9wrm/8gbMQQN64dwvy
SOQ/5TL7PoweAkDfVqmFon3tP6AignWWUPo//AmBZtBQ8j/HZGaB05jyP4OR
BD6aO/U/DqgceRdG7j+F+JAQAbP3Py9zI/fzpOQ/Z8hRwvLV+T9ZOEaYL2Du
P1qa8FBjuPs/rNrpgoQf2z+rG0W78Wf9PwUDtYfQcdw/XkJExlXu/j+AjdWd
TyLSP0rxjfBdKQBAAWrDMIFs1D8wDFZVS80AQKVknIzOINc/aPTEOBFlAUAG
XLcRyW+5PxxYWWJd8gFAK3X3m88Skz9fwE5WinYCQOstXTrRwLe/Yf4DKbPy
AkCCTummIG/DP7aVvjjCZwNAIok9pDuagT+vqhQXfdYDQHmaT+LKy7+/URxh
nYk/BEC8a5RQpPyhP8j9nsV1owRActkVifiuu7/OEUy2uwIFQI0zZiN17IQ/
vDSKScVdBUDBKPIXyYLHv2mz5tPutAVA87HSK1Q/pD8WQH4EiQgGQEOOXAMZ
VNK/ZgymBNxYBkDEFhBT5fjCv8ht5d0mpgZAJQPyKZKrfT86mcUHovAGQCZy
XCa+Gra/lSeDB4A4B0Dz1IeGMN28v01Dkz7ufQdAdXGCW/JSpr+QQGBSFcEH
QASNm/iMdKe/iC1M0xoCCEDGWIre41/Kvy5hhhMgQQhAJXhbkz/T1b9Gqu6p
Q34IQFicntjfBMS/3EI/hKG5CEAvRpMEErvRv3V70zNT8whAseIlSDc6xr++
4ugvcCsJQKiz/7bw5ae/KjnT1g1iCUALJSwgdrThv2//PYJAlwlA3WpA9djA
xL/Nqh9dGssJQHezpx83JsC/2pJMb6z9CUAmFM+kuL/QP0OMXYUGLwpAPEVV
CZzS4L8FBF1ON18KQKMT2xqsXdE/SqAKdkyOCkCNEiHMqNDHv0MkQxs=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/59EtF/xIfQN64dwvy
SOQ/NH03F8jcAUDfVqmFon3tPwo7wPa4hfs//AmBZtBQ8j/7cnwvyCz1P4OR
BD6aO/U/MaJUacs58T+F+JAQAbP3P+6KZrx7y+U/Z8hRwvLV+T+ZgO6im1Dx
P1qa8FBjuPs/ffvEBo954T+rG0W78Wf9PyMANeOageA/XkJExlXu/j/2bKZ/
dgzVP0rxjfBdKQBADshq7Yqv2T8wDFZVS80AQLa2BRJLYNw/aPTEOBFlAUCO
VssnkQ3KPxxYWWJd8gFAYRoFyA88uj9fwE5WinYCQOIRJ8i8xaG/Yf4DKbPy
AkAkeKmuQmrNP7aVvjjCZwNALbgpxsSQuT+vqhQXfdYDQNXOuKq0uZq/URxh
nYk/BEAuKi3L3OK+P8j9nsV1owRABZCKq9v3sb/OEUy2uwIFQCZ9fWYa7a8/
vDSKScVdBUDCltUH6ky8v2mz5tPutAVApgdS9uXJtD8WQH4EiQgGQP++C4T8
ece/ZgymBNxYBkBWeHV6aui2v8ht5d0mpgZAFRNKL6FGtz86mcUHovAGQIMm
DFpobaS/lSeDB4A4B0ASnr/0jGKev01Dkz7ufQdAzv7/qUpXkD+QQGBSFcEH
QNmxd7f62rK/iC1M0xoCCEBWelGs4B/Kvy5hhhMgQQhAh3oyDn7lzb9Gqu6p
Q34IQF0LulFiBsS/3EI/hKG5CEAccHBb08fSv3V70zNT8whAwggSmeO9wb++
4ugvcCsJQKoB1Zx/8qK/KjnT1g1iCUDUJbZD4bLcv2//PYJAlwlAHVxYmnsx
p7/Nqh9dGssJQHRBjbZ8GrS/2pJMb6z9CUApPbHoQpvPP0OMXYUGLwpAkkji
zWeL3b8FBF1ON18KQOBCI4rGftU/SqAKdkyOCkCuTd9KnsrRv7FhSBY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.36666666666666664`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ystapNUIrQN64dwvy
SOQ/roSPRfi+A0DfVqmFon3tP56CZLwMqAJA/AmBZtBQ8j9TxkTi17r5P4OR
BD6aO/U/HZ/RPQAB9D+F+JAQAbP3PxfIqsOVCOk/Z8hRwvLV+T+yfV19RAbx
P1qa8FBjuPs/B5eza4/A4D+rG0W78Wf9P4uYw5EF1OE/XkJExlXu/j+hp/6i
rqPZP0rxjfBdKQBAqs/FO1yA2z8wDFZVS80AQK4PGxgTmNs/aPTEOBFlAUA2
orjZYPHRPxxYWWJd8gFAbg9/SpsV0T9fwE5WinYCQGC2G0PUqYu/Yf4DKbPy
AkD0jQ05ly7RP7aVvjjCZwNAzn1+yRJrwz+vqhQXfdYDQBMkeMvl4WM/URxh
nYk/BECehBy0s7DNP8j9nsV1owRAmf+qJ9dyoL/OEUy2uwIFQDfyESfWibs/
vDSKScVdBUABl6EKp/uiv2mz5tPutAVA9PK8VJz6uj8WQH4EiQgGQNw4IWIm
jL+/ZgymBNxYBkA3rLyQNW6Ov8ht5d0mpgZAsHYK+FAIvT86mcUHovAGQMaH
h1yJOpY/lSeDB4A4B0AN7vluk8ygP01Dkz7ufQdAV5ZnwFansD+QQGBSFcEH
QDNdYzrHnqA/iC1M0xoCCEAIe5CbZdK/vy5hhhMgQQhAuKyY+wkhyb9Gqu6p
Q34IQG+Q4NZM87m/3EI/hKG5CEBCCSGc6abTv3V70zNT8whA6ZG36ioOtL++
4ugvcCsJQEplI87A8Ws/KjnT1g1iCUB6C+CVonzav2//PYJAlwlAKqneHwcC
qj/Nqh9dGssJQB39Qr3ER70/2pJMb6z9CUCWO23htlLCP0OMXYUGLwpAhafC
gh7L5L8FBF1ON18KQNenxe9Fh8M/SqAKdkyOCkCsFuLg2ivMv04LRMg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.39999999999999997`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ailg5OF42QN64dwvy
SOQ/nzqHiULZKUDfVqmFon3tP/WyJMQUkyFA/AmBZtBQ8j9PW/yoStAUQIOR
BD6aO/U/MHdeqjN8FUCF+JAQAbP3P6XNAhEIF+0/Z8hRwvLV+T8VbrboXFHy
P1qa8FBjuPs/w0KGpbVO4T+rG0W78Wf9P0Zu1Jix6eQ/XkJExlXu/j/jmHd0
DaLYP0rxjfBdKQBAWdr/1ksF3z8wDFZVS80AQMxisVNW69w/aPTEOBFlAUA6
7YZXGdfSPxxYWWJd8gFAPya+5PLD0T9fwE5WinYCQAE7wSr3ybg/Yf4DKbPy
AkDw01jaDETVP7aVvjjCZwNATO/HhV7jzz+vqhQXfdYDQLNfgtrNYLA/URxh
nYk/BEDABiliIkzQP8j9nsV1owRAt+QD1Zxvqj/OEUy2uwIFQM17PbkngMM/
vDSKScVdBUA2AFs+KceHP2mz5tPutAVA79ufYaupwD8WQH4EiQgGQPtCll7z
yGo/ZgymBNxYBkCcwUDPm5KOv8ht5d0mpgZA4O7yEMP8wD86mcUHovAGQIDb
cJfIHq0/lSeDB4A4B0B6fJujv464P01Dkz7ufQdAM2hqrMZStz+QQGBSFcEH
QH2KTwFAiWs/iC1M0xoCCEApfhtkreC4vy5hhhMgQQhAn0XCsSClwb9Gqu6p
Q34IQOPYnUHCALK/3EI/hKG5CEAmfZ/ozvPPv3V70zNT8whACh3btVh1p7++
4ugvcCsJQNbJlXZ1qsI/KjnT1g1iCUD8s/+tBXHVv2//PYJAlwlALIABvmJ1
jT/Nqh9dGssJQNBof1vGM8I/2pJMb6z9CUC9hkUEvSHWP0OMXYUGLwpAKfEN
l4Ot4b8FBF1ON18KQAmjqhD43sg/SqAKdkyOCkA1TXdERdm7v35LQlY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.43333333333333335`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9DJOsEZ747QN64dwvy
SOQ/5roWdmHsOUDfVqmFon3tP1DBHwKJdzhA/AmBZtBQ8j8iWDxsMh43QIOR
BD6aO/U/WrFx8XM7NkCF+JAQAbP3P1e9zVox0TVAZ8hRwvLV+T+en9z5KPc0
QFqa8FBjuPs/xvWXmQDRM0CrG0W78Wf9PzQZiWEeYTNAXkJExlXu/j+8YahW
CVEzQErxjfBdKQBAB4rWmKvDMkAwDFZVS80AQG+D90w+SjJAaPTEOBFlAUDv
NrZfyCQyQBxYWWJd8gFARzB64DO5MUBfwE5WinYCQNh+KPgKbDFAYf4DKbPy
AkBvuzifyD4xQLaVvjjCZwNAJbm1hmf/MECvqhQXfdYDQL3DcTGBrTBAURxh
nYk/BEBK1Uby9zkwQMj9nsV1owRAbFiXyyZGL0DOEUy2uwIFQKFH51iBNC5A
vDSKScVdBUDWORpg2hEtQGmz5tPutAVAJKapiuGWK0AWQH4EiQgGQMj9stNd
QypAZgymBNxYBkA3HQ1kPwYpQMht5d0mpgZAehveoB5/J0A6mcUHovAGQD/7
n0N1ayZAlSeDB4A4B0AkOX0ZdkolQE1Dkz7ufQdA1C9oANLVJECQQGBSFcEH
QFN9FcZPgSNAiC1M0xoCCEDAtSr5EfsiQC5hhhMgQQhAqZtAE81eIkBGqu6p
Q34IQDh9UXq3VyFA3EI/hKG5CEBxC5LB5v0fQHV70zNT8whA99GeZm7qHkC+
4ugvcCsJQOglkbjRGxxAKjnT1g1iCUClqjvwafMYQG//PYJAlwlAJ1Mogv90
FkDNqh9dGssJQNucnCrOgBNA2pJMb6z9CUAWQwybI14FQEOMXYUGLwpANAWz
nxeeBkAFBF1ON18KQLuSYPlHSwpASqAKdkyOCkATiRiVPXkJQCW3Hu4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9+Fgl+oxI7QN64dwvy
SOQ/YlTJAC/oOUDfVqmFon3tP00nymmrpDpA/AmBZtBQ8j/y806sV384QIOR
BD6aO/U/wL5Htev0NkCF+JAQAbP3P41BFsu4MTZAZ8hRwvLV+T/EDk4EJmY1
QFqa8FBjuPs/SesV5Xx+NUCrG0W78Wf9P+9O/bKCUjRAXkJExlXu/j/unvZD
fX00QErxjfBdKQBAs+e94326M0AwDFZVS80AQC4qztnWWjNAaPTEOBFlAUBU
Z9U/3MozQBxYWWJd8gFAlfyqoevtMkBfwE5WinYCQO/JIOf/YzJAYf4DKbPy
AkA+2hDZVrAyQLaVvjjCZwNAMZgZZOsCMkCvqhQXfdYDQM1vM9aWLTFAURxh
nYk/BEAtMn/LifgwQMj9nsV1owRAEkFunmpUMEDOEUy2uwIFQENCgYq1dzBA
vDSKScVdBUCh+G3JLv4vQGmz5tPutAVAiwrVrxOLLkAWQH4EiQgGQNh57QGN
QCxAZgymBNxYBkBke0yFS/grQMht5d0mpgZAPv3s1NXcKkA6mcUHovAGQECE
GaJ6LSpAlSeDB4A4B0BpwbwyK9woQE1Dkz7ufQdAMay/5+SEKECQQGBSFcEH
QBAzLohWkidAiC1M0xoCCEBXGxFgqxAnQC5hhhMgQQhAMkRhOqBAJkBGqu6p
Q34IQDTRYVBS9CRA3EI/hKG5CEC7nv9WZ3skQHV70zNT8whAQnW4GVwUJEC+
4ugvcCsJQKLu3mpkJiNAKjnT1g1iCUBNQn0p/ykhQG//PYJAlwlAXgVXoEGo
HkDNqh9dGssJQNl8wdd3PBpA2pJMb6z9CUBnGwtycRsXQEOMXYUGLwpA5dff
JNp5FUAFBF1ON18KQC94wBxVxRFASqAKdkyOCkCeWrXcBkoOQIYjJK8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ix1N8Ias7QN64dwvy
SOQ/JsQd+y2DOUDfVqmFon3tP6ocuFIe5TlA/AmBZtBQ8j8v7jz4xNA4QIOR
BD6aO/U/5DHiMgmAN0CF+JAQAbP3P8TV/1Tb+zZAZ8hRwvLV+T+abzOyy7w2
QFqa8FBjuPs/xACK6o34NUCrG0W78Wf9P2ZUXURySTVAXkJExlXu/j9VCWR/
Fgk1QErxjfBdKQBAhFUXsxeDNEAwDFZVS80AQKjStvgiajRAaPTEOBFlAUA/
4yx9fvgzQBxYWWJd8gFAXkYpm8qQM0BfwE5WinYCQMpsxo1/WTNAYf4DKbPy
AkDdXWS9DHEzQLaVvjjCZwNAsB251sq9MkCvqhQXfdYDQH7OFOju2TFAURxh
nYk/BECXAd5K2pcxQMj9nsV1owRA10TPWZZAMUDOEUy2uwIFQONq7e1y1zBA
vDSKScVdBUBabkQtLUMwQGmz5tPutAVAcJoBMtZDL0AWQH4EiQgGQLbGxxa5
3S5AZgymBNxYBkDoDelM+CctQMht5d0mpgZAz+AVraGbLEA6mcUHovAGQLmb
WVTnvStAlSeDB4A4B0AahCteHDcrQE1Dkz7ufQdA1p7y1od/KkCQQGBSFcEH
QJOv7gKJ4ylAiC1M0xoCCEDGdKbKFDkpQC5hhhMgQQhAmWYinEmzJ0BGqu6p
Q34IQIAX66VnUSZA3EI/hKG5CECSP+5YTdwlQHV70zNT8whAqSI7BRETJUC+
4ugvcCsJQAZ2kpp1qCRAKjnT1g1iCUDNPeJKDDUjQG//PYJAlwlATFQoDGQo
IkDNqh9dGssJQBlrXb/HAiJA2pJMb6z9CUDKqmvtcyYgQEOMXYUGLwpAND8G
rtKWIUAFBF1ON18KQAMhRiDHQyBASqAKdkyOCkA4LFhxGMYfQLfsInI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5333333333333332, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+iNkxZFqY7QN64dwvy
SOQ/F5PzkSIMOkDfVqmFon3tPx2wDfaNjDlA/AmBZtBQ8j8yhdPOTv84QIOR
BD6aO/U/bmxZi8LdN0CF+JAQAbP3PxSuVPKmhDdAZ8hRwvLV+T/e+Nkn3uU2
QFqa8FBjuPs/s2+/8JrcNkCrG0W78Wf9P7cVy+JWujVAXkJExlXu/j8iALcQ
bYs1QErxjfBdKQBAdAU8dh9BNUAwDFZVS80AQDtIg6JP0DRAaPTEOBFlAUBl
kRCVkp00QBxYWWJd8gFAJEhMV+0RNEBfwE5WinYCQP3dLXjLejNAYf4DKbPy
AkCy06LG/rEzQLaVvjjCZwNAp/OyGMMLM0CvqhQXfdYDQPAfLR9RfTJAURxh
nYk/BEBzijDF5yEyQMj9nsV1owRA2DOW4sHJMUDOEUy2uwIFQCrQ1dipbjFA
vDSKScVdBUCUaR67pscwQGmz5tPutAVACEILb24AMEAWQH4EiQgGQDfxmdM6
ly9AZgymBNxYBkCOVt2j5HguQMht5d0mpgZAQw5Xz761LUA6mcUHovAGQP3T
5QXdwixAlSeDB4A4B0DBskolpkMsQE1Dkz7ufQdA4bcqEOYALECQQGBSFcEH
QKAi8hKlLCtAiC1M0xoCCEAcNWWCWW0qQC5hhhMgQQhADRubevWWKUBGqu6p
Q34IQD2jOCS8IihA3EI/hKG5CEBluhf0/5MnQHV70zNT8whAXLXGhFEfJ0C+
4ugvcCsJQPcYXdJoCidAKjnT1g1iCUDsOpaWZBomQG//PYJAlwlATTbMXIs+
JUDNqh9dGssJQNdDE0ubPCRA2pJMb6z9CUCCLUkBBV8kQEOMXYUGLwpAeyCO
J5PKI0AFBF1ON18KQCQ1zuivuCJASqAKdkyOCkAw8VmocUYjQJDeIik=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5666666666666667, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8NdiQG+pY7QN64dwvy
SOQ/zhNe4Ld3OkDfVqmFon3tP7E2pQjKAjpA/AmBZtBQ8j9DgFVxuaU4QIOR
BD6aO/U/4ZlfWWSgOECF+JAQAbP3P3bJ2WQ9yjdAZ8hRwvLV+T9psS1CFaU2
QFqa8FBjuPs/DZNWqS7kNkCrG0W78Wf9PxrYhBIzRTZAXkJExlXu/j99WWPX
w7Q1QErxjfBdKQBAY1HtmaaDNUAwDFZVS80AQM5RNiGaFzVAaPTEOBFlAUB9
FokH/Ro1QBxYWWJd8gFAn/n52FBENEBfwE5WinYCQIWE6wclHDRAYf4DKbPy
AkAdLFbRqDU0QLaVvjjCZwNALZKZzK6FM0CvqhQXfdYDQMHGpDIT1DJAURxh
nYk/BEAqTSKxj9syQMj9nsV1owRAfZohv/dYMkDOEUy2uwIFQFOBKWXqcTFA
vDSKScVdBUAp/PWwKD0xQGmz5tPutAVAnrUWMPOcMEAWQH4EiQgGQCH/gkOU
PzBAZgymBNxYBkB0SdEbOAMwQMht5d0mpgZASELm3/8uL0A6mcUHovAGQIEZ
LeGMlS5AlSeDB4A4B0C9VGfdJHMuQE1Dkz7ufQdAIty5KWtuLUCQQGBSFcEH
QLEJzZLCjSxAiC1M0xoCCEBFcemBqJQsQC5hhhMgQQhAG5gDv/WIKkBGqu6p
Q34IQOLnt1VYcylA3EI/hKG5CEAVVOMeJGgoQHV70zNT8whAsuZJLCweKEC+
4ugvcCsJQBet8jENAShAKjnT1g1iCUBB5+CglMMmQG//PYJAlwlAydzBRkw9
JkDNqh9dGssJQA/en6SQPiRA2pJMb6z9CUDl70NdSM4kQEOMXYUGLwpAHo0j
l9jII0AFBF1ON18KQJnmokylUiRASqAKdkyOCkBP6KQKyUEhQFXQINA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9IdNCUdEs7QN64dwvy
SOQ/ap+5emw+OkDfVqmFon3tP2muhEj3ATpA/AmBZtBQ8j+mYohH7BA5QIOR
BD6aO/U/SKfnXlBeOECF+JAQAbP3PxfJiEUpljdAZ8hRwvLV+T90bqGXfxg3
QFqa8FBjuPs/P7qECb7zNkCrG0W78Wf9P3Q1c7oCpzZAXkJExlXu/j9rqKY1
Gfk1QErxjfBdKQBAfMdyMRXhNUAwDFZVS80AQHYmvJ95iTVAaPTEOBFlAUBE
IwaBMzw1QBxYWWJd8gFA2WZLatymNEBfwE5WinYCQCNpSy0bRTRAYf4DKbPy
AkDoIw47FoI0QLaVvjjCZwNAXshul9/pM0CvqhQXfdYDQJ3i2YufTDNAURxh
nYk/BEB2aMFlEhUzQMj9nsV1owRAmEEiNghdMkDOEUy2uwIFQIa3UBw65jFA
vDSKScVdBUBLc2TEK9wxQGmz5tPutAVAG2dMeoslMUAWQH4EiQgGQHvFy6/K
szBAZgymBNxYBkBOB6bPZzQwQMht5d0mpgZAMaEjSpk6MEA6mcUHovAGQAGA
Llgiqi9AlSeDB4A4B0DXiI5JwB8vQE1Dkz7ufQdAQeaw6T/pLkCQQGBSFcEH
QF+JoxUagC1AiC1M0xoCCEBrRaNaZlstQC5hhhMgQQhAPr5J1GvJK0BGqu6p
Q34IQK9h1hT9bipA3EI/hKG5CEBvNmVxacUpQHV70zNT8whAoaOCJNfNKEC+
4ugvcCsJQEVab66RaChAKjnT1g1iCUAXwNplD7wnQG//PYJAlwlAgfYn87bK
JkDNqh9dGssJQKAwMj8AVCVA2pJMb6z9CUDMBctjuG4lQEOMXYUGLwpAmJZv
kWo2JUAFBF1ON18KQN6tRh2HDyVASqAKdkyOCkCyqKJn+K0iQJPqG9U=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT84dwYCm8o6QN64dwvy
SOQ/VyxWtu/3OUDfVqmFon3tPwgDQjDJnzlA/AmBZtBQ8j/zUCUrS9E4QIOR
BD6aO/U/OCB53QV+OECF+JAQAbP3PzPqHjr43jdAZ8hRwvLV+T869HE5HEU3
QFqa8FBjuPs/I821dvACN0CrG0W78Wf9P3macixy5jZAXkJExlXu/j907A87
DFw2QErxjfBdKQBAVCF/kIkNNkAwDFZVS80AQNXQiWaMsjVAaPTEOBFlAUBx
cOk/QYc1QBxYWWJd8gFANWTEbHznNEBfwE5WinYCQJFx2OsJjDRAYf4DKbPy
AkAYC/iL5LA0QLaVvjjCZwNAQHTk3aoVNECvqhQXfdYDQPseA2kpoDNAURxh
nYk/BED/UcpKcmAzQMj9nsV1owRAlr/cCCa6MkDOEUy2uwIFQD9ttRCSODJA
vDSKScVdBUDzzHV12TcyQGmz5tPutAVADQcq4I+TMUAWQH4EiQgGQETemISn
JTFAZgymBNxYBkBpjpa6KMcwQMht5d0mpgZA9rsoEgF9MEA6mcUHovAGQIxJ
30ToTTBAlSeDB4A4B0D0gm/qddovQE1Dkz7ufQdABPKDThWgL0CQQGBSFcEH
QH8jSdIhti5AiC1M0xoCCEBHRVRZgIEuQC5hhhMgQQhA4FQQH46qLEBGqu6p
Q34IQHKakBaUhCtA3EI/hKG5CEA1kcJTIXoqQHV70zNT8whAhjmnJCMrKkC+
4ugvcCsJQAAl5o+egylAKjnT1g1iCUDk+SwM/fQoQG//PYJAlwlAE5wyMvWK
KEDNqh9dGssJQOakwdJ0vSdA2pJMb6z9CUCkl56JuwknQEOMXYUGLwpA0kGZ
AmHhJkAFBF1ON18KQAwpa3aGjSZASqAKdkyOCkCEW/ffGmskQDXIHmI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/6SWqtj/M6QN64dwvy
SOQ/YKFOgEsKOkDfVqmFon3tP8dMj21QqTlA/AmBZtBQ8j/HQGchn9A4QIOR
BD6aO/U/CGsnInx4OECF+JAQAbP3Pyqykh0vzDdAZ8hRwvLV+T+D3Uyk0Ug3
QFqa8FBjuPs/zOqRLD84N0CrG0W78Wf9PxT7S1XL7TZAXkJExlXu/j8Lxh50
xnI2QErxjfBdKQBAAMDCxlETNkAwDFZVS80AQKU8ah5RxTVAaPTEOBFlAUA4
7xw9gKg1QBxYWWJd8gFATz72Mg0LNUBfwE5WinYCQGHGVahbuDRAYf4DKbPy
AkCeTRXf/d80QLaVvjjCZwNAX3/c4+ZBNECvqhQXfdYDQCIQZSKmwTNAURxh
nYk/BEAWYcU46HYzQMj9nsV1owRAwfkm9I4UM0DOEUy2uwIFQLvelllrjTJA
vDSKScVdBUC8AnFxb3IyQGmz5tPutAVAtyHDukjeMUAWQH4EiQgGQO2dv5ZM
aDFAZgymBNxYBkD0rMG2JwkxQMht5d0mpgZA7syf/zLOMEA6mcUHovAGQPv/
G+RXezBAlSeDB4A4B0Axm7fiOEAwQE1Dkz7ufQdARi+84XINMECQQGBSFcEH
QJsWzIm4tS9AiC1M0xoCCEA2tAz6oRsvQC5hhhMgQQhAeHz5DdqkLUBGqu6p
Q34IQBgD9lRpqCxA3EI/hKG5CEB74U+TyfArQHV70zNT8whAJh7AigJSK0C+
4ugvcCsJQCgHh0L3TSpAKjnT1g1iCUAmeRsfNCoqQG//PYJAlwlAmYSF3csj
KUDNqh9dGssJQJ5aHQv49ShA2pJMb6z9CUDtjzx2vX0oQEOMXYUGLwpAgU49
7/tFKEAFBF1ON18KQGSTJ1tNEyhASqAKdkyOCkBu11aBUtEmQHPZIq8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8Fz7EEydg6QN64dwvy
SOQ/tL+MHEYhOkDfVqmFon3tPws16sTiVjlA/AmBZtBQ8j/firc15vU4QIOR
BD6aO/U/Ad3Hj5BbOECF+JAQAbP3P4cKISuEyTdAZ8hRwvLV+T+j9p6cb2k3
QFqa8FBjuPs/mCB7qZYaN0CrG0W78Wf9P4qPaIJW/TZAXkJExlXu/j8tidd5
03s2QErxjfBdKQBAsCOXb3E7NkAwDFZVS80AQCBldHXI2DVAaPTEOBFlAUCR
i4kFlsk1QBxYWWJd8gFAqbnGCKJENUBfwE5WinYCQLqySegE9DRAYf4DKbPy
AkCwONzga9M0QLaVvjjCZwNAxdJQxExbNECvqhQXfdYDQIQXt4Zq7DNAURxh
nYk/BEB7wNkj4JIzQMj9nsV1owRARr4BEeAoM0DOEUy2uwIFQIAnNQk9xTJA
vDSKScVdBUCfCeBtJ50yQGmz5tPutAVA1411FDkGMkAWQH4EiQgGQB7wl1K8
rTFAZgymBNxYBkABZ0Vk/00xQMht5d0mpgZAu15BKYoUMUA6mcUHovAGQLt+
AhJLwzBAlSeDB4A4B0D6NJzmU2UwQE1Dkz7ufQdAuyNVGz9CMECQQGBSFcEH
QPkpH933GzBAiC1M0xoCCEDfxvi8JJAvQC5hhhMgQQhApY9NFl09LkBGqu6p
Q34IQLWPVoNdji1A3EI/hKG5CED3sohUZMQsQHV70zNT8whAOmny7+HwK0C+
4ugvcCsJQIV2Um5bNStAKjnT1g1iCUBLWaX5ff4qQG//PYJAlwlAyf1u0Dwj
KkDNqh9dGssJQPmJ5bguRilA2pJMb6z9CUDdcmBuRdIoQEOMXYUGLwpAFmEP
sJGJKEAFBF1ON18KQDJmSFqVdyhASqAKdkyOCkByF7b0KZknQBvoJQI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number: \[Phi]\"", TraditionalForm],
      PlotRange->{-1, 5},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox["50", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.003065458786462, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.090076835776092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.170119543449628, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.24422751560335, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.313220387090301, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.3777589082278725`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.033333333333333326`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9XbSBEZgbsv964dwvy
SOQ/YJgnBqm16b/fVqmFon3tP+DfohWwuOe//AmBZtBQ8j8o7EGcnYfuv4OR
BD6aO/U/vVVr0MX16L+F+JAQAbP3P/aqZd+7C+W/Z8hRwvLV+T9ENp16Le7j
v1qa8FBjuPs/mj9D/PCi5L+rG0W78Wf9P6RK9AuJl9W/XkJExlXu/j8N/Wqq
wkTuv0rxjfBdKQBAnk30oB3h4r8wDFZVS80AQCh5VBEwHey/aPTEOBFlAUDh
FzQBMODqvxxYWWJd8gFAbGcep8op479fwE5WinYCQKeDFkwJX+y/Yf4DKbPy
AkBVQmnIyZjjv7aVvjjCZwNAhOAoo0dX6r+vqhQXfdYDQNqQcAzJ1OG/URxh
nYk/BEBycOjlkD7lv8j9nsV1owRAxLQRNr144b/OEUy2uwIFQHEwOSgQy+m/
vDSKScVdBUDfMchwAWXjv2mz5tPutAVA2JFpSqYp4r8WQH4EiQgGQIiI0ozJ
xuG/ZgymBNxYBkDEG5NI/cznv8ht5d0mpgZA1vj9iIJ04r86mcUHovAGQM/P
v14PVeS/lSeDB4A4B0AOw9tEHtbmv01Dkz7ufQdAv93J51IQ57+QQGBSFcEH
QJ/c8gvIJem/iC1M0xoCCED2fYqjPJ/qvy5hhhMgQQhACYaO2dFY6L9Gqu6p
Q34IQBCRimj8pOO/3EI/hKG5CECYWDnmCZvnv3V70zNT8whA0/JUvwbX5r++
4ugvcCsJQHbFP8uo6ue/KjnT1g1iCUAlbX0Zp7Xmv2//PYJAlwlAWfxB12SP
7L/Nqh9dGssJQD57s72Cj+m/2pJMb6z9CUBhp6i5gsTbv0OMXYUGLwpAwUBI
VTUm8b8FBF1ON18KQLxxrwRKUPG/SqAKdkyOCkD4H+ersuv0vwTxXGM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06666666666666665, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+g4YPc34mqP964dwvy
SOQ/WlOGjeiU5b/fVqmFon3tP3RuYXsp9eQ//AmBZtBQ8j8bKzfKgdrpv4OR
BD6aO/U/bmvXPwLM57+F+JAQAbP3P68+QnWofuS/Z8hRwvLV+T/g1yc9i5nj
v1qa8FBjuPs/cpmte9ez5L+rG0W78Wf9P3pa2g+kpNO/XkJExlXu/j/7hnjx
7F/uv0rxjfBdKQBACjP9hVsW4r8wDFZVS80AQLDOCy+y4+u/aPTEOBFlAUD/
pwL2KCHrvxxYWWJd8gFA1ke8aUBC479fwE5WinYCQJWBK1A8aey/Yf4DKbPy
AkDCPrVjpJnjv7aVvjjCZwNAZ4XLG+ge6r+vqhQXfdYDQOrGeooDK+K/URxh
nYk/BEBMbPfm2Tnlv8j9nsV1owRAb2TvJV1m4b/OEUy2uwIFQM8Gu/treem/
vDSKScVdBUAF8ruqJcHjv2mz5tPutAVAirdozVkn4r8WQH4EiQgGQD8fRBTn
juG/ZgymBNxYBkCGH5k9p8Hnv8ht5d0mpgZAb/+QfMm44r86mcUHovAGQDVs
S4RAUOS/lSeDB4A4B0DJj4Q48Ojmv01Dkz7ufQdAgvJZ1xCr57+QQGBSFcEH
QKEcq1bQTei/iC1M0xoCCED+W952Ygbqvy5hhhMgQQhAGJcOCiyP6L9Gqu6p
Q34IQH2OLXR9MuO/3EI/hKG5CECl1AP1im3nv3V70zNT8whAuPZMb6dU5r++
4ugvcCsJQGPuPclRBui/KjnT1g1iCUAhFxuD/STnv2//PYJAlwlAL4SCWo/T
7L/Nqh9dGssJQO01uXpe8ui/2pJMb6z9CUCn7omj0I/bv0OMXYUGLwpAHW79
00PG8b8FBF1ON18KQOiLzfs27e+/SqAKdkyOCkBtY+vgbyb0v9eFWs8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09999999999999999, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8zfnxxZmG2P964dwvy
SOQ/vniYigH8yb/fVqmFon3tPzfIs+rbwvY//AmBZtBQ8j+xcnp08xLMv4OR
BD6aO/U/AKc9uef65b+F+JAQAbP3P3k7UthGJ+O/Z8hRwvLV+T/wZbE7a//j
v1qa8FBjuPs/YSa9QQVf5L+rG0W78Wf9P0MzuaNpJdS/XkJExlXu/j8LeHHE
0Bnuv0rxjfBdKQBAkaLNB8Ue4r8wDFZVS80AQJVNgoJpC+y/aPTEOBFlAUBn
8JqjoznrvxxYWWJd8gFA6C/t4Nhs479fwE5WinYCQNnPho9GWOy/Yf4DKbPy
AkCsLd4amOzjv7aVvjjCZwNAVZ+vqQIq6r+vqhQXfdYDQOO8U47P9+G/URxh
nYk/BEAlyDQTni7lv8j9nsV1owRAbaPsQUrS4b/OEUy2uwIFQJysO53q1ui/
vDSKScVdBUAnLCZSgC/kv2mz5tPutAVA75/3nxpy4r8WQH4EiQgGQFqJQMir
++G/ZgymBNxYBkDgrh2vs57nv8ht5d0mpgZAznKNAxOK4b86mcUHovAGQOhd
omZsReS/lSeDB4A4B0BD0WOTCBzmv01Dkz7ufQdAil/4PKYG5r+QQGBSFcEH
QKhsieAPwOi/iC1M0xoCCEB+9VImDpjpvy5hhhMgQQhAGYbNVqt66L9Gqu6p
Q34IQONbK689heK/3EI/hKG5CEAgl62wnPjmv3V70zNT8whAnTEoVOeD5b++
4ugvcCsJQBOIkRI0xue/KjnT1g1iCUC3vVlboonnv2//PYJAlwlAFhhRG9SM
7b/Nqh9dGssJQCf3QrZ/d+m/2pJMb6z9CUBf+l7voALdv0OMXYUGLwpAp9Pw
Y6cm8L8FBF1ON18KQGtp3C5m4fK/SqAKdkyOCkA/HfSqXzH1vw/HVyI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.1333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8RywBVijPlv964dwvy
SOQ/vNTLAwlf47/fVqmFon3tP13jPqvBJvc//AmBZtBQ8j+0mFHydI7XP4OR
BD6aO/U//kE6P0hU5b+F+JAQAbP3P9Nv6kRPkOO/Z8hRwvLV+T9yQuHb8sXi
v1qa8FBjuPs/gH1GHX7p5L+rG0W78Wf9P2VRmbMwxtS/XkJExlXu/j9WUAZE
BF7uv0rxjfBdKQBAYRy0zERy4r8wDFZVS80AQFpCKG9Q3eu/aPTEOBFlAUC/
pTHf/MjqvxxYWWJd8gFALDkFuyh0479fwE5WinYCQDm7KPyPAOy/Yf4DKbPy
AkCLIWCKbH/jv7aVvjjCZwNAydBhS7E06r+vqhQXfdYDQIdqOuS5gOG/URxh
nYk/BEBlrqJgZQ3lv8j9nsV1owRA6ao7H3cw4b/OEUy2uwIFQE/MUugcKum/
vDSKScVdBUBcNlC4yQXjv2mz5tPutAVAB41584+o4b8WQH4EiQgGQG4yCLdZ
KeK/ZgymBNxYBkDBGH9rytPmv8ht5d0mpgZADinGOqIb4786mcUHovAGQCha
nLNZL+S/lSeDB4A4B0A3cxaW467nv01Dkz7ufQdAe0cYhB1C5r+QQGBSFcEH
QLabN65c2+e/iC1M0xoCCEAIQvluxZjovy5hhhMgQQhA0hO1/+uL6L9Gqu6p
Q34IQNOMqLdOguG/3EI/hKG5CECx1dxGZibmv3V70zNT8whAZ6cVaRyt5b++
4ugvcCsJQMwZVJnKR+e/KjnT1g1iCUB23A/M/FXmv2//PYJAlwlAlEVwOv20
7r/Nqh9dGssJQM+VFaR4XOm/2pJMb6z9CUBye5jpK1vWv0OMXYUGLwpA8LfO
SCBw8L8FBF1ON18KQIegxCYsUfK/SqAKdkyOCkCRmMVYAOD0v/eyURY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.16666666666666666`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8ageyk/DPiv964dwvy
SOQ/cZglILZw27/fVqmFon3tP3lruM62du8//AmBZtBQ8j+MlOZzE93uP4OR
BD6aO/U/3qa1CUfA5L+F+JAQAbP3PxdXQV0uyuW/Z8hRwvLV+T9LHma7oFvj
v1qa8FBjuPs/3CXo/Nb647+rG0W78Wf9P26BIRtm19S/XkJExlXu/j9sqkIl
QEzuv0rxjfBdKQBASahfA72w4r8wDFZVS80AQGEV3R4ceuu/aPTEOBFlAUAa
vtNquPHqvxxYWWJd8gFAGbMq5300479fwE5WinYCQGKWEZ2t++u/Yf4DKbPy
AkAAlxbLYpzjv7aVvjjCZwNAZjUGUcYo6r+vqhQXfdYDQJ4376ZesOG/URxh
nYk/BEAd2cj9hNvkv8j9nsV1owRA3ectsr2g4b/OEUy2uwIFQEaqX0F+yem/
vDSKScVdBUBxqbguTEHjv2mz5tPutAVAnBF5lOc84r8WQH4EiQgGQAsOHHp0
l+G/ZgymBNxYBkD/EsSE4DDov8ht5d0mpgZAADsMTGzS4b86mcUHovAGQI8J
UsOuEOS/lSeDB4A4B0Bq3lWTTa/lv01Dkz7ufQdA/r5G1oXB5r+QQGBSFcEH
QBFXq4WJdue/iC1M0xoCCEB03pq0ltjpvy5hhhMgQQhAFoffBSVE6L9Gqu6p
Q34IQOSbXs3QteK/3EI/hKG5CEAhgObkkDTov3V70zNT8whA5gjQaCfM5r++
4ugvcCsJQDLUy8ozaOe/KjnT1g1iCUDzffSM3+Tlv2//PYJAlwlAZEZJOmgR
7b/Nqh9dGssJQDjXQOH7muq/2pJMb6z9CUCxbE8SVq7Zv0OMXYUGLwpAkQJb
D+Om778FBF1ON18KQPu/QHQVz++/SqAKdkyOCkD+q+MJPUv0v2h3V2o=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19999999999999998`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IssRrMaXov964dwvy
SOQ/gTFtjaul47/fVqmFon3tPwpKDTFmf9E//AmBZtBQ8j8ZfmNH7PwAQIOR
BD6aO/U/Lzhr/jwV57+F+JAQAbP3P/CeMDh2ReW/Z8hRwvLV+T/4zNYkW6Pj
v1qa8FBjuPs/h6pdcpzk47+rG0W78Wf9P44V2I6FHNW/XkJExlXu/j9mANCP
XmTuv0rxjfBdKQBA+dmX5OoO4r8wDFZVS80AQN/0L9XHweu/aPTEOBFlAUAT
Wpf9ENvqvxxYWWJd8gFA6Zvm9llg479fwE5WinYCQP5oiKs6Auy/Yf4DKbPy
AkBKQgJ+iWjjv7aVvjjCZwNAJNodHLpk6r+vqhQXfdYDQMgkW1VoHOK/URxh
nYk/BEBmNDysNVblv8j9nsV1owRAWRmnmv+C4b/OEUy2uwIFQIOUtef8bOm/
vDSKScVdBUBE2/zSI2fjv2mz5tPutAVAbw2E+PEh4r8WQH4EiQgGQG5wSFuE
w+G/ZgymBNxYBkATh1tWPNznv8ht5d0mpgZATyQCy8hZ4r86mcUHovAGQPen
e9722uO/lSeDB4A4B0DPGRWlZ9/mv01Dkz7ufQdAyOEyIGIz5r+QQGBSFcEH
QL2V1eGRyOe/iC1M0xoCCEAEoOHCa6Dqvy5hhhMgQQhAGyem9e1D6L9Gqu6p
Q34IQNk5eEn+UOO/3EI/hKG5CEArvFEIaiTov3V70zNT8whAOp0TH7Uo57++
4ugvcCsJQCx8RfG4/ee/KjnT1g1iCUAygSMW943nv2//PYJAlwlArlZxXNIH
7r/Nqh9dGssJQNy5Xx1qtOm/2pJMb6z9CUD0P6eTOvPbv0OMXYUGLwpA44AT
ATWQ8b8FBF1ON18KQMRQHSOzTfG/SqAKdkyOCkCV426ygDvzvzRjVVU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/ni9hpFfDQv964dwvy
SOQ/2OpJ5JWlzL/fVqmFon3tP4D1CQWk6PQ//AmBZtBQ8j+Hx7/M/PMJQIOR
BD6aO/U/vj+YWSC65r+F+JAQAbP3P3nO0BIYTOW/Z8hRwvLV+T+28a6s5Hbk
v1qa8FBjuPs/QiGrahQm5b+rG0W78Wf9P0RrN59+/NS/XkJExlXu/j9cQD91
nqHuv0rxjfBdKQBANGLS5Z714b8wDFZVS80AQO/AKmTc0eu/aPTEOBFlAUBN
thkZVnbqvxxYWWJd8gFA2tSKGwHW4r9fwE5WinYCQC0rPfeJKey/Yf4DKbPy
AkAsfGhe6rbjv7aVvjjCZwNAeHB3mTD26r+vqhQXfdYDQCpfT3GaNOK/URxh
nYk/BEBThlibQlvlv8j9nsV1owRAIFKInaVd4b/OEUy2uwIFQMdGdRuWRem/
vDSKScVdBUB3a/5vsNnjv2mz5tPutAVAhqB3iE6S4r8WQH4EiQgGQP9Ej6rT
1OG/ZgymBNxYBkAzVYksIaDnv8ht5d0mpgZANfF+0hCz4r86mcUHovAGQGtg
wVWnL+S/lSeDB4A4B0C3EOVWQcXmv01Dkz7ufQdA+I9vaugY57+QQGBSFcEH
QH96gq0fgei/iC1M0xoCCECGnnjgdGLqvy5hhhMgQQhA83et50956L9Gqu6p
Q34IQO1hPCumjuO/3EI/hKG5CEDGbBVlJ7Xnv3V70zNT8whA3t6yigKI5r++
4ugvcCsJQIE1BcUA+Oe/KjnT1g1iCUDXHyfDwVnmv2//PYJAlwlA8EGgrihj
7b/Nqh9dGssJQCWxMNSJjum/2pJMb6z9CUCd11fhq/Ldv0OMXYUGLwpAAAnc
aubM8L8FBF1ON18KQGp5LS+z/PC/SqAKdkyOCkDBJDCiToL0v8zgWZ4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8gqo5e7E+2P964dwvy
SOQ/5OX/zsXg67/fVqmFon3tPxsXymNoOvY//AmBZtBQ8j+CAaPpq3ISQIOR
BD6aO/U/273vZhHn5r+F+JAQAbP3PwNR4EgNKOW/Z8hRwvLV+T+R9QYFqhzk
v1qa8FBjuPs/3e+fk0wG5b+rG0W78Wf9P7G8sqGshdW/XkJExlXu/j/6r28j
IEfuv0rxjfBdKQBAQbkI6qMS4r8wDFZVS80AQPwpSTlH0Ou/aPTEOBFlAUBH
dNo5puTqvxxYWWJd8gFAM8bVEp9l479fwE5WinYCQNtitm4tI+y/Yf4DKbPy
AkDO7K1Frpzjv7aVvjjCZwNA1EKH8ART6r+vqhQXfdYDQGmerisp5+G/URxh
nYk/BEBk/3avxm3lv8j9nsV1owRALFjOEpCB4b/OEUy2uwIFQJqqAk5lkOm/
vDSKScVdBUBmEVj1Rafjv2mz5tPutAVAwciHl0L54b8WQH4EiQgGQJD1Czq5
yOG/ZgymBNxYBkCZdPL2Ib7nv8ht5d0mpgZAgiXpny2r4r86mcUHovAGQM4Z
QH5LgOS/lSeDB4A4B0AYNPKH//Lmv01Dkz7ufQdAfrjZDRoi57+QQGBSFcEH
QDxEMuPR2Oi/iC1M0xoCCEBjoseY0ojqvy5hhhMgQQhA2xvyeWRs6L9Gqu6p
Q34IQGu6VDyO8uO/3EI/hKG5CED/Y/V0nLHnv3V70zNT8whA5MopRNGO5r++
4ugvcCsJQLunKd6s+Oe/KjnT1g1iCUClIy5Qdafmv2//PYJAlwlAxwPnUStF
7b/Nqh9dGssJQHRXQjFxVeq/2pJMb6z9CUC4EW8h3zDcv0OMXYUGLwpAR6ZU
tGyS8L8FBF1ON18KQCDEqiV8+PC/SqAKdkyOCkAoAwnNDd70v/P9WLc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+GCm3q9K65v964dwvy
SOQ/s6RxamAJ0L/fVqmFon3tP2gzoBw/KOE//AmBZtBQ8j95WJ1+RhUXQIOR
BD6aO/U/OL0tK9mB57+F+JAQAbP3P0KUDWFvg+W/Z8hRwvLV+T8PwCQwJdTk
v1qa8FBjuPs/x/tk/XGv47+rG0W78Wf9P95uxaF9/dS/XkJExlXu/j9Uh0W8
jm7uv0rxjfBdKQBAaLVTOXYo4r8wDFZVS80AQJxGVdA30eu/aPTEOBFlAUBD
c0r2rt3qvxxYWWJd8gFAvCJAaaZI479fwE5WinYCQHlliyXkOuy/Yf4DKbPy
AkBNNCz7Vefjv7aVvjjCZwNAHadb3fI56r+vqhQXfdYDQPizeDHC5+G/URxh
nYk/BEDlfOolJi7lv8j9nsV1owRAW7VuhBxU4b/OEUy2uwIFQKToGNGgROm/
vDSKScVdBUDB33+ozU7jv2mz5tPutAVA7RE3UKhi4r8WQH4EiQgGQGtZ5dx2
s+G/ZgymBNxYBkD+OVPxaLnnv8ht5d0mpgZATcOvOJhD4786mcUHovAGQPZz
0HlM/uO/lSeDB4A4B0CEZe3T20nnv01Dkz7ufQdAdcfP5s4957+QQGBSFcEH
QMv3i1Bl+ua/iC1M0xoCCEABz46+Ktbovy5hhhMgQQhAriH4cT79579Gqu6p
Q34IQLiJCskrHOO/3EI/hKG5CEC4lTE4yIPmv3V70zNT8whAfxuF9XcA57++
4ugvcCsJQLqBaqIs8ui/KjnT1g1iCUC584aW2hvnv2//PYJAlwlAX/LLzRla
7r/Nqh9dGssJQGfbd4/7kOe/2pJMb6z9CUB0GNgkc2/cv0OMXYUGLwpA9pB5
XhWI8L8FBF1ON18KQDGX1aqf6vG/SqAKdkyOCkCVxbeQXOryv6SXXLw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT98C04nvsXOP964dwvy
SOQ/8QQqiX9w7j/fVqmFon3tPxqpYneLUdc//AmBZtBQ8j+9JYvg2s0bQIOR
BD6aO/U/DARg6QPc5r+F+JAQAbP3P02VOSkCJ+a/Z8hRwvLV+T/YZDQxvtTj
v1qa8FBjuPs/vWHljehG5L+rG0W78Wf9P3fDsNR7itS/XkJExlXu/j8s2ExV
/yLuv0rxjfBdKQBA/gGhkI3j4r8wDFZVS80AQBHn2yVSp+u/aPTEOBFlAUBz
jOPuMbPqvxxYWWJd8gFAoi5j2/MW479fwE5WinYCQNHjXp7Izeu/Yf4DKbPy
AkAM3hf79vfiv7aVvjjCZwNAmFcLAVxE6r+vqhQXfdYDQLn42QV5BuK/URxh
nYk/BEBgdYRey0vlv8j9nsV1owRAQASLG8U14b/OEUy2uwIFQEtpsSFbIum/
vDSKScVdBUDLnj0zmkTkv2mz5tPutAVApAk8DPO14r8WQH4EiQgGQNJt30pv
xOG/ZgymBNxYBkDvFbbeD0Lnv8ht5d0mpgZARY84/sMC4r86mcUHovAGQKaK
w61nBeO/lSeDB4A4B0DB3lB3sjnnv01Dkz7ufQdAhVh8az1s5b+QQGBSFcEH
QOi3a9AvOOi/iC1M0xoCCEAiKqC4oE3pvy5hhhMgQQhAxuHHpNZl6L9Gqu6p
Q34IQGkz9zs3uuG/3EI/hKG5CEATRiJOCaPmv3V70zNT8whAbOXR4EHQ5L++
4ugvcCsJQMOqETJFTee/KjnT1g1iCUDvUCvf8DTmv2//PYJAlwlAJfzABSH9
6r/Nqh9dGssJQMbhFlnRFum/2pJMb6z9CUC03Pfdu0bav0OMXYUGLwpAu13J
0bx38b8FBF1ON18KQHSvSFPFNfK/SqAKdkyOCkCW+OoXUwX1vwMfVbQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.36666666666666664`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U8QE8X7shQN64dwvy
SOQ/G6Xpd6KuI0DfVqmFon3tPwCrIDLIm/U//AmBZtBQ8j8E1uothyggQIOR
BD6aO/U/KkzTa3w95L+F+JAQAbP3P2u9Qft/4OW/Z8hRwvLV+T9/cbbalfPi
v1qa8FBjuPs/1o1T4ABW5L+rG0W78Wf9P+fLo+9z4NO/XkJExlXu/j9uG5OF
+Bnuv0rxjfBdKQBAcYm2GLsY4r8wDFZVS80AQGSJbkdxIOy/aPTEOBFlAUDj
nHvWuBDrvxxYWWJd8gFAn7Jjm/Jf479fwE5WinYCQA1n8lDjHuy/Yf4DKbPy
AkCRC6W0DK3jv7aVvjjCZwNAPc8IFQdJ6r+vqhQXfdYDQN2kRCfK3OG/URxh
nYk/BEAIUj1p7zblv8j9nsV1owRA2JWQDg434b/OEUy2uwIFQNR/cIgit+m/
vDSKScVdBUD3zye6CpHjv2mz5tPutAVAf0UEW9BI4r8WQH4EiQgGQEoxMi/E
ouG/ZgymBNxYBkBIginB9dLnv8ht5d0mpgZAhs1dRu4h4r86mcUHovAGQJ6U
nSDL1eO/lSeDB4A4B0CUUxU1fAPmv01Dkz7ufQdA0r85ZiLi5b+QQGBSFcEH
QAv6b3jvS+i/iC1M0xoCCEATF8NE9vnpvy5hhhMgQQhATjrKCGV1579Gqu6p
Q34IQKA+IJVcF+O/3EI/hKG5CEBMkSo6pH3nv3V70zNT8whAXk8hGXfr5b++
4ugvcCsJQOtD1RFNaOe/KjnT1g1iCUA2ha2pbj7mv2//PYJAlwlAlK9xWqKb
7L/Nqh9dGssJQMNxMesUt+i/2pJMb6z9CUBcTMo+hcjav0OMXYUGLwpAAaNf
47sA8r8FBF1ON18KQBAmSUkCcvC/SqAKdkyOCkCleV0fbS30v0IWS4Y=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.39999999999999997`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/lHIM2rhkzQN64dwvy
SOQ/AYrqkR3oM0DfVqmFon3tP/Ks1HHaXCpA/AmBZtBQ8j/3nO2C/7UoQIOR
BD6aO/U/mLXCkLhlGUCF+JAQAbP3P5Srx1b+NhNAZ8hRwvLV+T8jpgVxegCT
v1qa8FBjuPs/QEPMcOoK4L+rG0W78Wf9P1bdAXtBJNG/XkJExlXu/j8ryw5M
uKrtv0rxjfBdKQBADWVor1kk4b8wDFZVS80AQIgQ1mDf6uq/aPTEOBFlAUAG
XOcBRVbrvxxYWWJd8gFAijC9J3tS479fwE5WinYCQNsu+EE59uu/Yf4DKbPy
AkCohq4NiQzkv7aVvjjCZwNA+nUPSXwd6r+vqhQXfdYDQDqbM0QbNeG/URxh
nYk/BEAxeg7xGkPlv8j9nsV1owRAhC2UaArM4L/OEUy2uwIFQDWrMEMgh+m/
vDSKScVdBUBzbYTuQ4rjv2mz5tPutAVAwOUhK9cw4r8WQH4EiQgGQAI6b868
uuG/ZgymBNxYBkC7qTDT7u7nv8ht5d0mpgZAsvAHOT924r86mcUHovAGQNyv
o3JJ8OO/lSeDB4A4B0B1kqqhkrXmv01Dkz7ufQdANJOXQ+hf57+QQGBSFcEH
QNtwLWz5oui/iC1M0xoCCEAxY+T1Nm/qvy5hhhMgQQhA+0m4KE696L9Gqu6p
Q34IQKlx2qkncOO/3EI/hKG5CEAIb2OxnPDmv3V70zNT8whACWSMu+JF57++
4ugvcCsJQC8tQcFRc+i/KjnT1g1iCUDbehNmzzrlv2//PYJAlwlAHIILod6o
77/Nqh9dGssJQKJS0ENADeu/2pJMb6z9CUA38wEo5b3bv0OMXYUGLwpAA6hT
Pld78L8FBF1ON18KQIhT3LRMIvK/SqAKdkyOCkCrwmhq88zzv+CYTCk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.43333333333333335`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/HzWVmJpE5QN64dwvy
SOQ/OhmRNou0OUDfVqmFon3tP15/4cwv9jhA/AmBZtBQ8j/tmi3BMBs4QIOR
BD6aO/U//HCCjs6rN0CF+JAQAbP3P7jmhRpGPDdAZ8hRwvLV+T8V+gpn1qE2
QFqa8FBjuPs/29Vb6/IGNkCrG0W78Wf9P7qOccfp2DRAXkJExlXu/j8RLiF+
hl0zQErxjfBdKQBAHTr4//NaMkAwDFZVS80AQJTPTpiJPTJAaPTEOBFlAUCV
46iZQfMxQBxYWWJd8gFAFUSovPxHMUBfwE5WinYCQPjbhI1QyzBAYf4DKbPy
AkC9QCwWly8wQLaVvjjCZwNAVHOLS7w+L0CvqhQXfdYDQIdGTOsS6y1AURxh
nYk/BEDbEJVlnZwsQMj9nsV1owRAiPzx9FJkK0DOEUy2uwIFQDsrdq1WRypA
vDSKScVdBUCN4BeDfOsoQGmz5tPutAVAOcWs+NN4J0AWQH4EiQgGQKZ13fCd
ZyZAZgymBNxYBkBN5dOwUmclQMht5d0mpgZAPNMgtkFIJEA6mcUHovAGQOoM
PHSvYSNAlSeDB4A4B0B2V7eYopkiQE1Dkz7ufQdAKZAhGdoaIkCQQGBSFcEH
QCkhlQ9GLCFAiC1M0xoCCED01p1wCLUgQC5hhhMgQQhA2N7Br2m2HkBGqu6p
Q34IQKBjIL1jbRxA3EI/hKG5CEBIzpeIBJkZQHV70zNT8whA4+3PTuhHGEC+
4ugvcCsJQLNOEn25mhVAKjnT1g1iCUCxnuWgY+MQQG//PYJAlwlAZ7Lj+K0+
DkDNqh9dGssJQBX8dPJCzA1A2pJMb6z9CUCf1N3ZtUAQQEOMXYUGLwpAn4HM
bQ8lCEAFBF1ON18KQE+2vq1TOBBASqAKdkyOCkAn784qvlgPQCQoK0I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Nmkt6cCo7QN64dwvy
SOQ/RMou5eNROUDfVqmFon3tP4GgRZH4NjlA/AmBZtBQ8j8X5H6XJbM3QIOR
BD6aO/U/4HtjUpBzNkCF+JAQAbP3P6O9y6S99zZAZ8hRwvLV+T+jp0xfFtQ2
QFqa8FBjuPs/TgRzxqhMN0CrG0W78Wf9P8PJPmMVdzZAXkJExlXu/j+rOPDV
Cr41QErxjfBdKQBANsn6PwQsNUAwDFZVS80AQOi4z1BhqjRAaPTEOBFlAUA7
WWeIvugzQBxYWWJd8gFA+e5sZckDM0BfwE5WinYCQEE9Oz7BzzJAYf4DKbPy
AkC/4QRjOlEyQLaVvjjCZwNAkHJdyXOXMUCvqhQXfdYDQHZQKUbqSDFAURxh
nYk/BEASROtdm/kwQMj9nsV1owRAj1bN5DNVMEDOEUy2uwIFQPMcHEjBWi9A
vDSKScVdBUB27NyB5kUuQGmz5tPutAVAcnrrjwKELEAWQH4EiQgGQKGGv4Ms
7ypAZgymBNxYBkBSW6fvW1YpQMht5d0mpgZAi8lm1GXYKEA6mcUHovAGQFzA
ivLwcyhAlSeDB4A4B0A3o788RpwnQE1Dkz7ufQdALBXtLxRWJkCQQGBSFcEH
QEcmpICYsyRAiC1M0xoCCECEg1k8mQojQC5hhhMgQQhADVeJ2JHkIUBGqu6p
Q34IQOFpxoNBoSFA3EI/hKG5CEDeMXH/AA0hQHV70zNT8whA/1plEkobIEC+
4ugvcCsJQPvldoHKOSFAKjnT1g1iCUBeQfJvV8MfQG//PYJAlwlAqh0vCq5F
HUDNqh9dGssJQELfqRXLPBxA2pJMb6z9CUC4M3aeicAWQEOMXYUGLwpAUzYP
kmviEEAFBF1ON18KQPAYqCJlMRVASqAKdkyOCkDZwjedH3QUQPMAI1s=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+1K4RzZrM5QN64dwvy
SOQ/7B/smg8/OkDfVqmFon3tP3UWINmvUTlA/AmBZtBQ8j9jWB0qgKg4QIOR
BD6aO/U//0mAxRPkOECF+JAQAbP3P7s1hUNdrDdAZ8hRwvLV+T+B42OD9FY3
QFqa8FBjuPs/szLpg+E1N0CrG0W78Wf9P/m431Va1jZAXkJExlXu/j8UgAQR
D7w1QErxjfBdKQBAtYoSd8WGNUAwDFZVS80AQAH5WA/zBTVAaPTEOBFlAUCQ
eW0Db8U0QBxYWWJd8gFAC+Xlxrr3M0BfwE5WinYCQIOjyq/0oTNAYf4DKbPy
AkB0dvYmje4yQLaVvjjCZwNAcvP9z3fgMkCvqhQXfdYDQBrzhuiq/jFAURxh
nYk/BECE2YfvMK4xQMj9nsV1owRAEMxvD439MEDOEUy2uwIFQKhbPfc/3DBA
vDSKScVdBUD9UN0RCCQwQGmz5tPutAVA1zpkGUZZL0AWQH4EiQgGQFmPHgeq
sS5AZgymBNxYBkCYddne8PItQMht5d0mpgZA4sNWO1K2LEA6mcUHovAGQN6n
dCzytitAlSeDB4A4B0B2K3NdfdgqQE1Dkz7ufQdAWFASKVLNKUCQQGBSFcEH
QDehDvRyzShAiC1M0xoCCECYRk7JbnUoQC5hhhMgQQhA/Oen/TkpJ0BGqu6p
Q34IQFWsXLw41SZA3EI/hKG5CEDGi6BCZ3AmQHV70zNT8whANK4Cg874I0C+
4ugvcCsJQPaG+AK83SJAKjnT1g1iCUDELcr0aKgiQG//PYJAlwlASTJqj+Bs
IUDNqh9dGssJQIOntfZTuSFA2pJMb6z9CUBwafJT/i4gQEOMXYUGLwpAH1X8
Yc5KGUAFBF1ON18KQFws7Ean1xlASqAKdkyOCkB06SCGGNsbQO3HLK0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5333333333333332, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U982Vf3s5QN64dwvy
SOQ/9VCLhPHpOEDfVqmFon3tP1lRKHzonDpA/AmBZtBQ8j/E8enzQWg4QIOR
BD6aO/U/CIKXcOexOECF+JAQAbP3P8b5gLZ42jdAZ8hRwvLV+T98NBaAk1g3
QFqa8FBjuPs/LAczKYCEN0CrG0W78Wf9P8wYzHMZMjdAXkJExlXu/j806aBZ
ULc2QErxjfBdKQBAL6ldwvXjNUAwDFZVS80AQJJuq+/qXTVAaPTEOBFlAUA4
utYQBt00QBxYWWJd8gFAb63J4jygNEBfwE5WinYCQM9zaX6UMzRAYf4DKbPy
AkDv2QGQv/szQLaVvjjCZwNAZGrQr4ZpM0CvqhQXfdYDQDe78JaLozNAURxh
nYk/BEAsAHiSd/AyQMj9nsV1owRAnbz/PzKcMkDOEUy2uwIFQJdA+Y92LzJA
vDSKScVdBUCIAEoC7esxQGmz5tPutAVAhx0hDf2QMUAWQH4EiQgGQBiuhVhd
jjBAZgymBNxYBkBzqPsVZbYwQMht5d0mpgZAffCDRT2GMEA6mcUHovAGQB7J
EMqJ8y9AlSeDB4A4B0DcDGSsvpMuQE1Dkz7ufQdAeHhqtJ6LL0CQQGBSFcEH
QENi/r0sJS5AiC1M0xoCCEDydtoDuSotQC5hhhMgQQhAfM9QnJ4DLUBGqu6p
Q34IQD9JlXDL6CpA3EI/hKG5CEBmbWpH9mQpQHV70zNT8whAjfQGq6OzJ0C+
4ugvcCsJQNlnTGUvpCdAKjnT1g1iCUDaNgaQRp4nQG//PYJAlwlASslVi15P
JkDNqh9dGssJQHl2/K74FCdA2pJMb6z9CUD9io22/IgmQEOMXYUGLwpAUh0m
6FYrJUAFBF1ON18KQKsuZnDyDyZASqAKdkyOCkCaUnuYVXkmQAxWKWA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5666666666666667, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8OSfuhK1M6QN64dwvy
SOQ/2fTlHXwjOkDfVqmFon3tP3wxOGxEWjlA/AmBZtBQ8j/+oBOgkNU4QIOR
BD6aO/U/jErk40RaOECF+JAQAbP3P2yjXr6MIzhAZ8hRwvLV+T+7vexaHgc4
QFqa8FBjuPs/JczNc8ZwN0CrG0W78Wf9P5BcVNEyvzZAXkJExlXu/j/opwuA
ALw2QErxjfBdKQBAjvNoFpQuNkAwDFZVS80AQE1n3dvTgDVAaPTEOBFlAUAi
PGWZJHc1QBxYWWJd8gFAKIBCah0oNUBfwE5WinYCQPqaz/OesTRAYf4DKbPy
AkA7hZN2wRY0QLaVvjjCZwNAkcwPZocyNECvqhQXfdYDQBVJ7OUQkTNAURxh
nYk/BECNQ7eJv8QzQMj9nsV1owRA84uD6x4sM0DOEUy2uwIFQMedVAm28zJA
vDSKScVdBUAB+EegNsoyQGmz5tPutAVAUvud7igdMkAWQH4EiQgGQLux80/1
YDFAZgymBNxYBkAkisbd4AwxQMht5d0mpgZADa9U4SLQMEA6mcUHovAGQM5t
PoYmkDBAlSeDB4A4B0Abu2IaNswwQE1Dkz7ufQdA4vp9bZxzMECQQGBSFcEH
QP9SJgGE8y5AiC1M0xoCCEDgsw8jvsIuQC5hhhMgQQhAExbXKd2DLEBGqu6p
Q34IQMK+m+k1sStA3EI/hKG5CECOAjQXP3opQHV70zNT8whA9iEWaK7HKEC+
4ugvcCsJQI0ZYvu8myhAKjnT1g1iCUCpPjunQGwoQG//PYJAlwlAIR+IY2x8
J0DNqh9dGssJQMM7+3z0BCdA2pJMb6z9CUD8NZvuNYElQEOMXYUGLwpA38Ti
y5WoJkAFBF1ON18KQJNXFuz5BSdASqAKdkyOCkD/LbUSR3YmQEP6JZ8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT99g9G70ZQ7QN64dwvy
SOQ/F5M1lOMqOkDfVqmFon3tPzwyAAJWxDlA/AmBZtBQ8j9hJFwOlB05QIOR
BD6aO/U/Hc7RkiuOOECF+JAQAbP3P+ZXyzM4IDhAZ8hRwvLV+T/VsyCpyvc3
QFqa8FBjuPs/fQv/AoxuN0CrG0W78Wf9PzdGfKX4HzdAXkJExlXu/j93kQbK
ksI2QErxjfBdKQBAIhzthMNuNkAwDFZVS80AQLBVtl2yAzZAaPTEOBFlAUBD
aDoSOoc1QBxYWWJd8gFAMU5RoUhyNUBfwE5WinYCQDDqmsIhCjVAYf4DKbPy
AkBMDX4rUsQ0QLaVvjjCZwNAsIHOraZRNECvqhQXfdYDQJE1uZiY/zNAURxh
nYk/BEBEZfTh7MUzQMj9nsV1owRA+uXMrndkM0DOEUy2uwIFQOslREjCOjNA
vDSKScVdBUAXoLARfasyQGmz5tPutAVAT/sx/LmZMkAWQH4EiQgGQDrGIu+E
MTJAZgymBNxYBkC+03HVzrkxQMht5d0mpgZAEWe2hqp5MUA6mcUHovAGQCZI
fD3g9zBAlSeDB4A4B0AaaJCPc60wQE1Dkz7ufQdApnd3bXmvMECQQGBSFcEH
QMTSKSAqTzBAiC1M0xoCCEABURQjDFgvQC5hhhMgQQhAVXqIdpppLUBGqu6p
Q34IQJ+wHEF+aSxA3EI/hKG5CEADYgN28XwrQHV70zNT8whAvKliSDl4KkC+
4ugvcCsJQEBdj6z5HipAKjnT1g1iCUCvQh4r4dwoQG//PYJAlwlARTvmaBZ6
KEDNqh9dGssJQKkTtbidvidA2pJMb6z9CUAjLpaLZJMmQEOMXYUGLwpAxevN
MuZcJkAFBF1ON18KQNU6nheZyCZASqAKdkyOCkDpUy2a5WgmQL8UH8E=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6333333333333333, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8creGgHq86QN64dwvy
SOQ/lKtMLBcZOkDfVqmFon3tPwm6fB38iTlA/AmBZtBQ8j9k8KURt/A4QIOR
BD6aO/U/91/mkZ2AOECF+JAQAbP3P72rnbLwTThAZ8hRwvLV+T9CpnLTic43
QFqa8FBjuPs/8e48Qf59N0CrG0W78Wf9P8/Ur2OsMzdAXkJExlXu/j9APYNB
/ec2QErxjfBdKQBADUvdaZOcNkAwDFZVS80AQFy1ge57CzZAaPTEOBFlAUA4
wmOQHM81QBxYWWJd8gFAcO3Wn/1mNUBfwE5WinYCQNai9x3IRTVAYf4DKbPy
AkA66hWditw0QLaVvjjCZwNAMRVOD5WHNECvqhQXfdYDQBWFbIT4WjRAURxh
nYk/BEA/Ij3P8R40QMj9nsV1owRAdyFBrkvaM0DOEUy2uwIFQNPTvMpukDNA
vDSKScVdBUD+1s/9fVUzQGmz5tPutAVAXz34iu7OMkAWQH4EiQgGQCRBP58i
pzJAZgymBNxYBkAgrOK6umMyQMht5d0mpgZA1Rb4oX7fMUA6mcUHovAGQJul
a8apkTFAlSeDB4A4B0CF72eqszgxQE1Dkz7ufQdAEIrFFcg5MUCQQGBSFcEH
QMBOJlUP9DBAiC1M0xoCCEAmJ15jfYUwQC5hhhMgQQhAYpIRFF1ZL0BGqu6p
Q34IQLehsSIGtC5A3EI/hKG5CEAwHaCICLstQHV70zNT8whAixkGKbecLEC+
4ugvcCsJQJYBDpt63ytAKjnT1g1iCUBTfVi7wR8rQG//PYJAlwlAt73Pahnc
KUDNqh9dGssJQKQnpMO6xClA2pJMb6z9CUCZGveg0q0oQEOMXYUGLwpAKhP4
9y3/J0AFBF1ON18KQCvjz9LP+ShASqAKdkyOCkA7tSURK3IoQEQDKjA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/1zuXf+S47QN64dwvy
SOQ/OgYaPyV5OkDfVqmFon3tPwc+BQFFujlA/AmBZtBQ8j9p5zShpg05QIOR
BD6aO/U/vJHX1Zt3OECF+JAQAbP3PxPGLVhRCThAZ8hRwvLV+T++OEo75Eo3
QFqa8FBjuPs/wy0n66CYN0CrG0W78Wf9P+3eNhpb/zZAXkJExlXu/j9GLvl/
DrU2QErxjfBdKQBAHtz3ZyFjNkAwDFZVS80AQLgEfd+eCTZAaPTEOBFlAUBU
EfSqRv01QBxYWWJd8gFAPWSFCjimNUBfwE5WinYCQAKFHQUwcDVAYf4DKbPy
AkDDBjfH+Ek1QLaVvjjCZwNA4nnbcTv4NECvqhQXfdYDQGWIwWV3bDRAURxh
nYk/BEBt+681gQc0QMj9nsV1owRAtQwmMaXwM0DOEUy2uwIFQPeiy+ePnTNA
vDSKScVdBUCQQzBGr2EzQGmz5tPutAVAI7a4RKPnMkAWQH4EiQgGQJFXxXBq
wDJAZgymBNxYBkA+0aYnFFsyQMht5d0mpgZAFoA0O0wkMkA6mcUHovAGQGT9
PABNtDFAlSeDB4A4B0AgytQmBWwxQE1Dkz7ufQdAk8z4sPqcMUCQQGBSFcEH
QPgSETZO9DBAiC1M0xoCCEB1XKooXpEwQC5hhhMgQQhAL8rwmxIGMEBGqu6p
Q34IQGZCuoT8Vi9A3EI/hKG5CECQquuQTBwuQHV70zNT8whAJp70AJX7LEC+
4ugvcCsJQMYdmduGIixAKjnT1g1iCUCmcpqbAlArQG//PYJAlwlAF/NytzrK
KkDNqh9dGssJQLOwLtkQ7SlA2pJMb6z9CUBx+8u3WnYpQEOMXYUGLwpAREXQ
GpoUKEAFBF1ON18KQJWyppbxkihASqAKdkyOCkCOti+ulScoQLqCIJU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.7, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[
          1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+OlwOV0xE7QN64dwvy
SOQ/TgiY6mvROUDfVqmFon3tPzwBr5sViTlA/AmBZtBQ8j8ptapHgiA5QIOR
BD6aO/U/S78XXC+FOECF+JAQAbP3P86i5DRbEzhAZ8hRwvLV+T/oNg5bsGw3
QFqa8FBjuPs/dhRBBsY6N0CrG0W78Wf9P6xVFPB2CDdAXkJExlXu/j88cpYV
Scs2QErxjfBdKQBANTt6bRFYNkAwDFZVS80AQO0SWGP+CzZAaPTEOBFlAUCI
RTCbueo1QBxYWWJd8gFA38PuKAbWNUBfwE5WinYCQBDTmiFfmTVAYf4DKbPy
AkDl0wmL/jQ1QLaVvjjCZwNAAaUfMmLZNECvqhQXfdYDQEV2mfZ2hzRAURxh
nYk/BEBQG8dGoUo0QMj9nsV1owRAuBjca2coNEDOEUy2uwIFQJERwG2+5DNA
vDSKScVdBUDwLju3o30zQGmz5tPutAVAQYCwpTMlM0AWQH4EiQgGQLEIdgtD
7DJAZgymBNxYBkAI+wbPYYYyQMht5d0mpgZAAosek0lSMkA6mcUHovAGQCSf
rC3VEDJAlSeDB4A4B0AUkejgltAxQE1Dkz7ufQdAcogwThehMUCQQGBSFcEH
QGn+xnx2cjFAiC1M0xoCCEBPPlMJQPEwQC5hhhMgQQhAg2bAZ+YvMEBGqu6p
Q34IQJSqrQUXzi9A3EI/hKG5CEDJosFn9novQHV70zNT8whAIs93FrApLkC+
4ugvcCsJQE07XElsPy1AKjnT1g1iCUD8u2zI/QgsQG//PYJAlwlAB0fnSGvS
KkDNqh9dGssJQF91dlx5vSpA2pJMb6z9CUC8rpepk7QqQEOMXYUGLwpAznr+
QrefKUAFBF1ON18KQGwDdOfx1ylASqAKdkyOCkDU9Kl8I5woQMYHHdo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, 0},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Number: \[Chi]\"", TraditionalForm],
      PlotRange->{-1, 5},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-0.6931471805599453, 
           FormBox[
            TagBox[
             InterpretationBox["\"0.5\"", 0.5, AutoDelete -> True], 
             NumberForm[#, {
               DirectedInfinity[1], 1.}]& ], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox["50", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox["100", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.916290731874155, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.703782474656201, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.991464547107982, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.214608098422191, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.396929655216146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.551080335043404, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.684611727667927, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.802394763324311, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.003065458786462, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.090076835776092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.170119543449628, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.24422751560335, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.313220387090301, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {7.3777589082278725`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotLabel->FormBox["\"Run 0\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.7174484894122972`*^9},ExpressionUUID->"e039d370-54a7-46a4-bd13-\
aea5984ade92"]
}, Open  ]],

Cell["Energy density spectrum plots (all times in one plot).", "Text",ExpressionUUID->"b2713133-0de4-4882-8fac-2895652ca46f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"doenergy", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"energyminalltimes", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Min", "[", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"energymin", "[", "run", "]"}], "[", "fld", "]"}], 
                "[", "time", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"time", ",", "1", ",", 
                 RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
             "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"alltimesenergyplot", "[", "run", "]"}], "[", "fld", 
             "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{"ListLogLogPlot", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"energytable", "[", "run", "]"}], "[", "fld", 
                    "]"}], "[", "time", "]"}], ",", 
                  RowBox[{"Joined", "\[Rule]", "True"}], ",", 
                  RowBox[{"PlotStyle", "\[Rule]", 
                   RowBox[{"{", 
                    RowBox[{"Hue", "[", 
                    RowBox[{"time", "/", 
                    RowBox[{"(", 
                    RowBox[{"1.5", " ", 
                    RowBox[{"numtimes", "[", "run", "]"}]}], ")"}]}], "]"}], 
                    "}"}]}]}], "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"time", ",", "1", ",", 
                  RowBox[{"numtimes", "[", "run", "]"}]}], "}"}]}], "]"}], 
              ",", 
              RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
              RowBox[{"PlotLabel", "\[Rule]", 
               RowBox[{"\"\<Energy: \>\"", "<>", 
                RowBox[{"label", "[", "fld", "]"}]}]}], ",", 
              RowBox[{"AxesOrigin", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{"kmin", "[", "run", "]"}]}], "]"}], ",", 
                 RowBox[{"Log", "[", 
                  RowBox[{"10", ",", 
                   RowBox[{
                    RowBox[{"energyminalltimes", "[", "run", "]"}], "[", 
                    "fld", "]"}]}], "]"}]}], "}"}]}]}], "]"}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"GraphicsGrid", "[", 
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"alltimesenergyplot", "[", "run", "]"}], "[", "fld", 
                "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"fld", ",", "0", ",", 
                 RowBox[{
                  RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
              "]"}], "}"}], "]"}], ",", 
           RowBox[{"PlotLabel", "->", 
            RowBox[{"\"\<Run \>\"", "<>", 
             RowBox[{"ToString", "[", "run", "]"}]}]}], ",", 
           RowBox[{"ImageSize", "\[Rule]", "500"}]}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.422110161073648*^9, 3.4221101771052055`*^9}, {
  3.717448501933277*^9, 
  3.7174485197330894`*^9}},ExpressionUUID->"d057cf37-128d-4091-9ea1-\
c4d45636ec61"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+6A/MhjH4vwN64dwvy
SOQ/y/evQDOVLcDfVqmFon3tP3Zyu4hV7CvA/AmBZtBQ8j/I6hwaTxAqwIOR
BD6aO/U/k8MHGVU2KcCF+JAQAbP3P78la6WHeijAZ8hRwvLV+T/VusEI3SAn
wFqa8FBjuPs/Ttk5bzYZJ8CrG0W78Wf9P/oUj0rNmybAXkJExlXu/j947rim
D80lwErxjfBdKQBA4DzuFrUmJcAwDFZVS80AQOjYdMgUkyTAaPTEOBFlAUBR
B2MzO/EkwBxYWWJd8gFA9J9MLCsFJMBfwE5WinYCQBcnG31M/SPAYf4DKbPy
AkCYyBfzxlsjwLaVvjjCZwNADdPiMS9ZI8CvqhQXfdYDQEW5ERB2bSLAURxh
nYk/BEAwfTCH/lUiwMj9nsV1owRAmYshbitHIsDOEUy2uwIFQLScDGm7uiHA
vDSKScVdBUBTnuGfroghwGmz5tPutAVATUes+dRXIcAWQH4EiQgGQE4r070t
+iDAZgymBNxYBkABwaPfHL8gwMht5d0mpgZAuvj1EXaVIMA6mcUHovAGQKPV
HNfYZyDAlSeDB4A4B0CU+53d5gcgwE1Dkz7ufQdAdHoQHyY0IMCQQGBSFcEH
QJjVLo2uJB/AiC1M0xoCCEAoAX58c8YfwC5hhhMgQQhA9R9ZdX8tH8BGqu6p
Q34IQFL2Ne+9Rh7A3EI/hKG5CECo6awkDV8ewHV70zNT8whAUaV1PT7RHcC+
4ugvcCsJQJb41VCSFx3AKjnT1g1iCUBeZrc4CUkewG//PYJAlwlAQuWSruus
HcDNqh9dGssJQJqHZY0OfBvA2pJMb6z9CUAr150Qc8IbwEOMXYUGLwpAjJc1
b+O7HMAFBF1ON18KQG7BpTAaQxrASqAKdkyOCkD+KaO2ULwawMLNNKo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/arxLf8RcuwN64dwvy
SOQ/p8fBjzuTK8DfVqmFon3tPyVGmb+sGSrA/AmBZtBQ8j95QMpUhfcowIOR
BD6aO/U/1x56LapKKMCF+JAQAbP3PwSQfWmi2CfAZ8hRwvLV+T+SoSMfsgEn
wFqa8FBjuPs/Slmj9dGUJsCrG0W78Wf9P1nKCIXFTSbAXkJExlXu/j8a9nod
sIIlwErxjfBdKQBAvEhMh8bQJMAwDFZVS80AQA6r90ogSyTAaPTEOBFlAUCi
O+YXtookwBxYWWJd8gFA18OP94W3I8BfwE5WinYCQO7dmkhN3iPAYf4DKbPy
AkD+M2GhBRgjwLaVvjjCZwNAU7ydMY4II8CvqhQXfdYDQFVEnAJZYyLAURxh
nYk/BECV46sP8CciwMj9nsV1owRA65JF078SIsDOEUy2uwIFQFbrOYxVbyHA
vDSKScVdBUCY0yey82EhwGmz5tPutAVAIMjKs2EyIcAWQH4EiQgGQMVn2Vuc
0yDAZgymBNxYBkA+70Uo3J0gwMht5d0mpgZATzBJ1B8uIMA6mcUHovAGQLua
lIExGSDAlSeDB4A4B0C66YQWTKMfwE1Dkz7ufQdAia/RTCmMH8CQQGBSFcEH
QG4VNEVaeh7AiC1M0xoCCECz9FsOvuUewC5hhhMgQQhAgCoz/IioHsBGqu6p
Q34IQOkKvGFhAR7A3EI/hKG5CEA6SuKeiQAewHV70zNT8whAAfv0oOhLHcC+
4ugvcCsJQHt0m2TLSxzAKjnT1g1iCUA5AFMULpgdwG//PYJAlwlAqzRoBLB2
HcDNqh9dGssJQJ2tMY9O3RrA2pJMb6z9CUCGFN0KA+wawEOMXYUGLwpAyAOT
1HasG8AFBF1ON18KQGPoVkqfKRrASqAKdkyOCkApbgSuzV4bwD9cNHc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8ZY//V03sswN64dwvy
SOQ/RqvatsKAKsDfVqmFon3tP1RVXBwkiynA/AmBZtBQ8j/EPnCWqT4owIOR
BD6aO/U/7zpcUuoTKMCF+JAQAbP3P9jyFI/kXifAZ8hRwvLV+T8CZ6Qf/msm
wFqa8FBjuPs/oSrzuZMKJsCrG0W78Wf9P3W6cDkw6CXAXkJExlXu/j/2hulc
My8lwErxjfBdKQBABL82GF+WJMAwDFZVS80AQI3Tiq4zByTAaPTEOBFlAUC9
aDQF8FskwBxYWWJd8gFAtqO/J4qUI8BfwE5WinYCQBp/P61koyPAYf4DKbPy
AkA7isc3V+IiwLaVvjjCZwNAekVs6/q3IsCvqhQXfdYDQGn4Q1c4LiLAURxh
nYk/BEBrpj06vAUiwMj9nsV1owRAPUKbVxLWIcDOEUy2uwIFQLK3U8mrLyHA
vDSKScVdBUC1uNpXZD0hwGmz5tPutAVAITp2X/7dIMAWQH4EiQgGQJpmEhLF
tCDAZgymBNxYBkBdCLKmEEYgwMht5d0mpgZAVE9MDRUWIMA6mcUHovAGQAnz
4RvRAyDAlSeDB4A4B0AQSAIauGMfwE1Dkz7ufQdAlxEDeBskH8CQQGBSFcEH
QB0IyA4jER7AiC1M0xoCCEDdvDCmLccewC5hhhMgQQhAZfWJP3ClHsBGqu6p
Q34IQOmMyuHX4h3A3EI/hKG5CEDhJa5Y3q8dwHV70zNT8whApuame7PmHMC+
4ugvcCsJQOqrLweHWhzAKjnT1g1iCUCW6PqN3IYdwG//PYJAlwlAhJv2d6YN
HcDNqh9dGssJQBK5E7BdahrA2pJMb6z9CUAg3v3tsxYawEOMXYUGLwpATxKl
undwHMAFBF1ON18KQFyabPwuphnASqAKdkyOCkDLHvl5mXUbwHvgM6Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Phk2gy2gqwN64dwvy
SOQ/vAjURjX2KcDfVqmFon3tP/6mMKQdTCnA/AmBZtBQ8j/N85AtsREowIOR
BD6aO/U/kWj5ZySwJ8CF+JAQAbP3P3hjx2gsECfAZ8hRwvLV+T9tPQ3PUPwl
wFqa8FBjuPs/YMDq9XywJcCrG0W78Wf9P19MV5KfjyXAXkJExlXu/j+tgOHG
S8gkwErxjfBdKQBA0H11fgZdJMAwDFZVS80AQEUsgq+XyCPAaPTEOBFlAUCq
8ME6dQkkwBxYWWJd8gFAsi12E3hTI8BfwE5WinYCQCdUtUjnRyPAYf4DKbPy
AkD9U/vzDbEiwLaVvjjCZwNAI5YPmDJUIsCvqhQXfdYDQOLFKrp9FiLAURxh
nYk/BED+EBU3XMIhwMj9nsV1owRA3273feehIcDOEUy2uwIFQCDa54dqGCHA
vDSKScVdBUDJxKgnUwYhwGmz5tPutAVA1lbwcje3IMAWQH4EiQgGQLn03Tkv
oCDAZgymBNxYBkBKNR+G3yUgwMht5d0mpgZA86Mux2muH8A6mcUHovAGQELM
2RUVTx/AlSeDB4A4B0CRDoj00hAfwE1Dkz7ufQdA3/9lhhLDHsCQQGBSFcEH
QGVyMd7Ivx3AiC1M0xoCCED3aW8Sam8ewC5hhhMgQQhAzAUxmCUwHsBGqu6p
Q34IQD6UuNWViR3A3EI/hKG5CECIb4aAbp8dwHV70zNT8whAMPkE5pKDHMC+
4ugvcCsJQAQyE/vnDhzAKjnT1g1iCUCSK03BajcdwG//PYJAlwlAQwpHHGOe
HMDNqh9dGssJQAUZBVLDWBrA2pJMb6z9CUABJuUNDdkZwEOMXYUGLwpAcqf+
dHR8HMAFBF1ON18KQP4xYpgo3BjASqAKdkyOCkBluXN6In8awLZPM+Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8U6ZQUGwgqwN64dwvy
SOQ/vNkQ7i1+KcDfVqmFon3tPwQy9LhnayjA/AmBZtBQ8j+ntEO1KKEnwIOR
BD6aO/U/xtVFMqBvJ8CF+JAQAbP3P4jb9/E5oibAZ8hRwvLV+T+WIkQH/Wgl
wFqa8FBjuPs/mWvmY3B9JcCrG0W78Wf9P2crqL/3ViXAXkJExlXu/j9TQOTD
1ZkkwErxjfBdKQBAqz6CRBn9I8AwDFZVS80AQIq92vWWjiPAaPTEOBFlAUAS
SSTPhqQjwBxYWWJd8gFAiQJJFIMyI8BfwE5WinYCQLMaH252GiPAYf4DKbPy
AkBAcQU2x2siwLaVvjjCZwNA+1hzJwkzIsCvqhQXfdYDQNnzdD+f+yHAURxh
nYk/BEC0T/bRH5shwMj9nsV1owRAv0agqpF8IcDOEUy2uwIFQCxWRkur6iDA
vDSKScVdBUDEtATBP9sgwGmz5tPutAVAmxqYi5NvIMAWQH4EiQgGQFHvF9kJ
miDAZgymBNxYBkB6XIqhAA0gwMht5d0mpgZAPhId3mR6H8A6mcUHovAGQLU5
/+lVFx/AlSeDB4A4B0Dx4AJISd0ewE1Dkz7ufQdAKc8bOP2PHsCQQGBSFcEH
QJLd7JLPfx3AiC1M0xoCCEAczjTvwkQewC5hhhMgQQhAE8AKRnTmHcBGqu6p
Q34IQIMa0UV4CR3A3EI/hKG5CEBcNHyBSfkcwHV70zNT8whAu3fVreNlHMC+
4ugvcCsJQB3IpKfLBhzAKjnT1g1iCUAbKm6m9xkdwG//PYJAlwlA9tCM9iEh
HMDNqh9dGssJQAgePonXfBrA2pJMb6z9CUAPqKt+ZqMZwEOMXYUGLwpAZzHH
73X9G8AFBF1ON18KQDlugVtQnxjASqAKdkyOCkAn5ExS9QQawDi3NIM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/Zv5lV6nYpwN64dwvy
SOQ/Oc58U1C5KMDfVqmFon3tP9yv1RMGyCfA/AmBZtBQ8j9W360HrocnwIOR
BD6aO/U//XT2UYAcJ8CF+JAQAbP3P7f2QtaSeybAZ8hRwvLV+T9I4XcDJzUl
wFqa8FBjuPs//m8k1PtNJcCrG0W78Wf9P/lYhCJr4iTAXkJExlXu/j80BSuG
HZIkwErxjfBdKQBAjKMO1ueqI8AwDFZVS80AQKZuPTV/ayPAaPTEOBFlAUD1
HQl3T0UjwBxYWWJd8gFAmWqzc2wQI8BfwE5WinYCQBTNtuTv8CLAYf4DKbPy
AkD8vAUNaiUiwLaVvjjCZwNALfwmoDfpIcCvqhQXfdYDQKjyS49E4SHAURxh
nYk/BEBVbKT+KmQhwMj9nsV1owRAGY7Jcz5UIcDOEUy2uwIFQDbRxpB4viDA
vDSKScVdBUAM+YViw8AgwGmz5tPutAVALx4usxIoIMAWQH4EiQgGQKc/BTeI
cCDAZgymBNxYBkB7x0cCAuUfwMht5d0mpgZA8c4Wq3cUH8A6mcUHovAGQPkm
3YnE0R7AlSeDB4A4B0BvQOc6V38ewE1Dkz7ufQdAK9FfZgRJHsCQQGBSFcEH
QFb0o2ETah3AiC1M0xoCCEDTzyIZNOodwC5hhhMgQQhA8wvPfjWWHcBGqu6p
Q34IQOVior67oRzA3EI/hKG5CEDZStzkBq8cwHV70zNT8whAAUiG+yZzHMC+
4ugvcCsJQJ7l+mCBhBvAKjnT1g1iCUBhaAZBY1sdwG//PYJAlwlAllZLjNSa
G8DNqh9dGssJQF5HETdZ5hnA2pJMb6z9CUAxAoLYCJsZwEOMXYUGLwpAoTgR
Qto/HMAFBF1ON18KQAm3AB0FkxjASqAKdkyOCkDgNrsvy8UcwLFhMzk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8WBHphzogpwN64dwvy
SOQ/B+yOOyP3J8DfVqmFon3tP+T7b74cOSfA/AmBZtBQ8j8vkx5vFisnwIOR
BD6aO/U/LoZR2VSfJsCF+JAQAbP3P2OPG56nICbAZ8hRwvLV+T9L5SgCet8k
wFqa8FBjuPs/5xMy/68hJcCrG0W78Wf9P+M1hHpCdiTAXkJExlXu/j/ykXpX
qkgkwErxjfBdKQBApaeKaOuqI8AwDFZVS80AQOPJutHoMCPAaPTEOBFlAUBQ
O2QiLgAjwBxYWWJd8gFAo/3KDgm7IsBfwE5WinYCQASkX8rliCLAYf4DKbPy
AkB0A4jut/0hwLaVvjjCZwNA9eElGaDMIcCvqhQXfdYDQM0gKt3zvyHAURxh
nYk/BEB58N3qzh8hwMj9nsV1owRAlP6g2mkoIcDOEUy2uwIFQFX42C02nCDA
vDSKScVdBUAJKTFZz5ggwGmz5tPutAVA44rHmkQIIMAWQH4EiQgGQKVKmsty
OiDAZgymBNxYBkDSt0vt5NYfwMht5d0mpgZAsePRyHSlHsA6mcUHovAGQA8Y
Qsm+rx7AlSeDB4A4B0BSVz02H1cewE1Dkz7ufQdAOs/fIkvkHcCQQGBSFcEH
QOqX3cG6LB3AiC1M0xoCCEA60ZFSJKUdwC5hhhMgQQhAx1A3Y9ulHcBGqu6p
Q34IQK5/cSTzaRzA3EI/hKG5CEDHbQk9nJ0cwHV70zNT8whAzhyi5JkiHMC+
4ugvcCsJQCNTS/BmTxvAKjnT1g1iCUAkkrno1OEcwG//PYJAlwlASgbfXKxT
G8DNqh9dGssJQPCfH5BLmBrA2pJMb6z9CUDdspN67zUZwEOMXYUGLwpAvdWD
njQxG8AFBF1ON18KQClbXSyisBjASqAKdkyOCkD1jmzKfKUawN5rO6I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9MiTjbEFcowN64dwvy
SOQ/Z5aLrOCdJ8DfVqmFon3tP5I4+8AhLCfA/AmBZtBQ8j/z9Gf6Gt0mwIOR
BD6aO/U/r/lmhZFLJsCF+JAQAbP3PwJ7uI9a/yXAZ8hRwvLV+T/DStp0K8ck
wFqa8FBjuPs/mgmE8TTCJMCrG0W78Wf9P7fzlKqFRSTAXkJExlXu/j8z1y53
9jAkwErxjfBdKQBAa4rTftSEI8AwDFZVS80AQJ57QoJYHCPAaPTEOBFlAUDM
+IWsKfIiwBxYWWJd8gFA+oA46SO4IsBfwE5WinYCQKWPx5hphyLAYf4DKbPy
AkB/zma2qLshwLaVvjjCZwNAYnKkIx2vIcCvqhQXfdYDQFovR5ocqiHAURxh
nYk/BECg5HYEsw8hwMj9nsV1owRAZLwqqjUBIcDOEUy2uwIFQB3epRSDiCDA
vDSKScVdBUB5fgjtcJEgwGmz5tPutAVAX7on0tzWH8AWQH4EiQgGQCe3dkQG
MiDAZgymBNxYBkAxEacCgqwfwMht5d0mpgZASROYZDmHHsA6mcUHovAGQIhP
H7P0gR7AlSeDB4A4B0BRAHcp0AwewE1Dkz7ufQdAfBkoGR+rHcCQQGBSFcEH
QI+dZ8jYOB3AiC1M0xoCCEDjz2PlXFYdwC5hhhMgQQhA0jOeh0g5HcBGqu6p
Q34IQGOUui9aKBzA3EI/hKG5CEA7ooZi40gcwHV70zNT8whAEfQFPWPFG8C+
4ugvcCsJQIPY9ImkIxvAKjnT1g1iCUD60NcPDMEcwG//PYJAlwlAu72bxmCk
GsDNqh9dGssJQJdVr0Yy6xrA2pJMb6z9CUCXLmVt0vUYwEOMXYUGLwpAxJL9
AmXPG8AFBF1ON18KQNSmr6rljRjASqAKdkyOCkAUAG+m1GgawNQTOE4=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+1T3bdowImwN64dwvy
SOQ/pZDG4YlzJ8DfVqmFon3tPwUrc0ZJKyfA/AmBZtBQ8j8DWTBHW8smwIOR
BD6aO/U/elmNc2IqJsCF+JAQAbP3Pw8IMCUS4iXAZ8hRwvLV+T8vyHk5FHUk
wFqa8FBjuPs/fUqUfYzVJMCrG0W78Wf9P5vFLVJgKyTAXkJExlXu/j+MCXWP
b+8jwErxjfBdKQBAfwza3sJZI8AwDFZVS80AQNx2pxOGyyLAaPTEOBFlAUB5
tdd9qOAiwBxYWWJd8gFAXMSms6WgIsBfwE5WinYCQMwbFzxFeCLAYf4DKbPy
AkAhAAQngJ8hwLaVvjjCZwNAcBgOHa2QIcCvqhQXfdYDQLGSdE0jgSHAURxh
nYk/BEDMK3a3EuIgwMj9nsV1owRAwLb0PsTfIMDOEUy2uwIFQM2GbkioXSDA
vDSKScVdBUDj3wb6An0gwGmz5tPutAVA+wSX0C+UH8AWQH4EiQgGQNxjFXzo
MyDAZgymBNxYBkDxwg2olV0fwMht5d0mpgZASl6KGiJOHsA6mcUHovAGQBhR
8tUaPh7AlSeDB4A4B0AMJ4bC9e8dwE1Dkz7ufQdA8iuPjus/HcCQQGBSFcEH
QC7zirrA3BzAiC1M0xoCCEBdCO2WcR8dwC5hhhMgQQhAt8dnG2ZKHcBGqu6p
Q34IQHWUSoEFMhzA3EI/hKG5CEBbMguML1YcwHV70zNT8whAl8e5i6uXG8C+
4ugvcCsJQLDxXBVMwBrAKjnT1g1iCUDdiqvkuHMcwG//PYJAlwlA9C51HmiT
GsDNqh9dGssJQBGCOkxiJBrA2pJMb6z9CUBjx5HcuksYwEOMXYUGLwpA70ry
/H8mG8AFBF1ON18KQPlDiKQDrxfASqAKdkyOCkCNz2TqYjoZwOUfMeg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9aomkeU4wewN64dwvy
SOQ/ss9y/wmuJ8DfVqmFon3tP9RiZwlzICfA/AmBZtBQ8j88LJeDPYwmwIOR
BD6aO/U/qDvIUg30JcCF+JAQAbP3P7cLXHUv2iXAZ8hRwvLV+T94+G8XhDck
wFqa8FBjuPs/asaKut2cJMCrG0W78Wf9P2OfPyMzDCTAXkJExlXu/j8qHRAO
vNwjwErxjfBdKQBA0Ysa+vEyI8AwDFZVS80AQL9yjBBqpCLAaPTEOBFlAUDu
03qv6K0iwBxYWWJd8gFAL6x5/Tp4IsBfwE5WinYCQDnEpmNHXCLAYf4DKbPy
AkCIDEG5wXghwLaVvjjCZwNA3w85ZGdjIcCvqhQXfdYDQBnTgvelUCHAURxh
nYk/BEB7LsKLiLcgwMj9nsV1owRAm4reYtTNIMDOEUy2uwIFQLWNPFUhRCDA
vDSKScVdBUC4R4Z9glggwGmz5tPutAVA+BnVNg5sH8AWQH4EiQgGQKNNm+/I
/x/AZgymBNxYBkC/KQ5YgCMfwMht5d0mpgZAyW7bdC/5HcA6mcUHovAGQJcA
hg/1Dx7AlSeDB4A4B0AV1gk4/5sdwE1Dkz7ufQdAsFht/DQEHcCQQGBSFcEH
QLVc6auW+hzAiC1M0xoCCEBL23LGyB0dwC5hhhMgQQhAr93ynm3dHMBGqu6p
Q34IQMJqO+HlMhzA3EI/hKG5CEC/zgKWrmccwHV70zNT8whAhwGMWXN0G8C+
4ugvcCsJQK6n5VZCtxrAKjnT1g1iCUCNwxszFgkcwG//PYJAlwlAmvfWl0gc
GsDNqh9dGssJQJkdJYkK9BnA2pJMb6z9CUCM/lGFElsYwEOMXYUGLwpAbYXt
SXXlGsAFBF1ON18KQGoClFEEbRfASqAKdkyOCkD8ibAgEJkZwH7+NSg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT96AnrpGKj4v964dwvy
SOQ/jODTNcQDJ8DfVqmFon3tP6hEhqeMySXA/AmBZtBQ8j8i2pGs6+UlwIOR
BD6aO/U/441DkBeMJcCF+JAQAbP3P/iewECRmiXAZ8hRwvLV+T8+BnmajTkk
wFqa8FBjuPs/9OkYA+ugJMCrG0W78Wf9P6KRsoV48SPAXkJExlXu/j8+sqjR
ALMjwErxjfBdKQBAM/CuVX8gI8AwDFZVS80AQMu5z+0LpyLAaPTEOBFlAUBL
3msYsIMiwBxYWWJd8gFAW57atvAgIsBfwE5WinYCQA11U2tpTyLAYf4DKbPy
AkCclk4enGIhwLaVvjjCZwNAgJdpsyVHIcCvqhQXfdYDQNrTIAmSQCHAURxh
nYk/BEDFxSHpBn0gwMj9nsV1owRAU3HmQrO4IMDOEUy2uwIFQIKiaGP1KyDA
vDSKScVdBUByR6Fo8zEgwGmz5tPutAVA5SeoN5BRH8AWQH4EiQgGQOUEJ5sr
wB/AZgymBNxYBkD3M3xxItUewMht5d0mpgZAWWLKY7vfHcA6mcUHovAGQLUc
zzSIzx3AlSeDB4A4B0BGBb/rR1odwE1Dkz7ufQdAhyVMnbHQHMCQQGBSFcEH
QOgYS6DJjBzAiC1M0xoCCECTNNtVbcscwC5hhhMgQQhAcWfEOAu2HMBGqu6p
Q34IQEKytPUM+RvA3EI/hKG5CEAZbWA0l3QcwHV70zNT8whAP+pHVc41G8C+
4ugvcCsJQOH6Far/jBrAKjnT1g1iCUAhPf/3FeUbwG//PYJAlwlA52nES/i4
GcDNqh9dGssJQHMhnPdyLRnA2pJMb6z9CUB4u4rrL8QYwEOMXYUGLwpAJVIN
g5mlG8AFBF1ON18KQDmLgS2DKBjASqAKdkyOCkAF3leSJV0ZwInfOh0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/qT/8RoeUdQN64dwvy
SOQ/TNM8S6cz7r/fVqmFon3tPy9yJ+taaxHA/AmBZtBQ8j90M9Xq5SUdwIOR
BD6aO/U/7qPyieaXGsCF+JAQAbP3PzAYbskfRSXAZ8hRwvLV+T+AMb5anwAk
wFqa8FBjuPs/2nlukT6KJMCrG0W78Wf9P6zsMUM9tSPAXkJExlXu/j/uaRLV
RbIjwErxjfBdKQBAJoT0/gv9IsAwDFZVS80AQKSpZfvPlSLAaPTEOBFlAUCb
ykOTi3YiwBxYWWJd8gFAX4T9T8MWIsBfwE5WinYCQC6vOaVCEiLAYf4DKbPy
AkAzn1U/UD4hwLaVvjjCZwNAfo/WYl8SIcCvqhQXfdYDQN8Dove4HSHAURxh
nYk/BEAoqiDYgG4gwMj9nsV1owRAuGpzEbaLIMDOEUy2uwIFQHjiDQJhEiDA
vDSKScVdBUBxHKqO4RYgwGmz5tPutAVANifbFCU0H8AWQH4EiQgGQH7vlSeJ
Ox/AZgymBNxYBkAdGgEKXNEewMht5d0mpgZAaQBH8NPIHcA6mcUHovAGQKk5
JkGrqB3AlSeDB4A4B0BCJ2lbBhcdwE1Dkz7ufQdA+hO5x86zHMCQQGBSFcEH
QFj+DJ+dpxzAiC1M0xoCCECOPV8z/qwcwC5hhhMgQQhAf44EUxZ4HMBGqu6p
Q34IQNCxmTsw1xvA3EI/hKG5CEDjz7mrEjgcwHV70zNT8whAg8odPDcSG8C+
4ugvcCsJQKh84Ngx+RnAKjnT1g1iCUDYZK8Sf5MbwG//PYJAlwlAEvWcIUjd
GcDNqh9dGssJQPb1E6uqDxnA2pJMb6z9CUBxKmfE5/IXwEOMXYUGLwpAXGAc
7IRAG8AFBF1ON18KQLGYz9wF/RfASqAKdkyOCkAhYKhX8+kYwLjhM/0=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/6PR2IWq0pQN64dwvy
SOQ/bSpR12INKEDfVqmFon3tP6YUFhogpSZA/AmBZtBQ8j/rclweKDwlQIOR
BD6aO/U/hSP2Uyp3JECF+JAQAbP3PyX9L3iBgiRAZ8hRwvLV+T8wIuKEeJkj
QFqa8FBjuPs/8VR2fx37IUCrG0W78Wf9PzcWhu8LuCFAXkJExlXu/j+nuNCh
vykiQErxjfBdKQBA8OEVBYmQIUAwDFZVS80AQPF8IWwRFCFAaPTEOBFlAUBh
K8+Z1zkhQBxYWWJd8gFAszWLaQTNIEBfwE5WinYCQP7mj6QWkiBAYf4DKbPy
AkDpJYJ5IJMgQLaVvjjCZwNAmXos0+FrIECvqhQXfdYDQBE4+yRLGiBAURxh
nYk/BEAEvDo03wIfQMj9nsV1owRAgVIjpmU8HUDOEUy2uwIFQCYy2vPNpRtA
vDSKScVdBUDKpHffUegZQGmz5tPutAVA47cjX0tzF0AWQH4EiQgGQFulGV+K
SBVAZgymBNxYBkAoxOiz+0gTQMht5d0mpgZArow1F8GtEEA6mcUHovAGQFND
OL1K5A1AlSeDB4A4B0C2FFTJtTMKQE1Dkz7ufQdAMdhcMXQ0CUCQQGBSFcEH
QIS3FhltrQRAiC1M0xoCCEDOpgLASVIDQC5hhhMgQQhAAQ+ZeoqgAUBGqu6p
Q34IQDNBAexAfvw/3EI/hKG5CECqJ3lCIg7zP3V70zNT8whA2ALhGcoS8D++
4ugvcCsJQAWBGwFM7Ng/KjnT1g1iCUCdcKCjw6rUv2//PYJAlwlAy+jroVv1
67/Nqh9dGssJQKUg8+Pkhfi/2pJMb6z9CUAws/Wz8UoNwEOMXYUGLwpA0wsl
NpF4C8AFBF1ON18KQOqaJu5HPgfASqAKdkyOCkA4Ta1+X3wHwEqqIcg=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+IwTwHDvAnQN64dwvy
SOQ/UeRWUW/ZJ0DfVqmFon3tP2R4pu4+yypA/AmBZtBQ8j/LYdPqgdYnQIOR
BD6aO/U/GTxyWfDaJUCF+JAQAbP3P4HXshnXMiVAZ8hRwvLV+T+a4C4qyWsk
QFqa8FBjuPs/+dvH+0ZNJUCrG0W78Wf9P4Q9HGP4kiNAXkJExlXu/j84n7nG
U3YkQErxjfBdKQBAQOQS2Gt5I0AwDFZVS80AQLJaj4GVMSNAaPTEOBFlAUDL
ZiLJRYEkQBxYWWJd8gFAEo09uXQvI0BfwE5WinYCQAy9uu7GgCJAYf4DKbPy
AkAuCw5X1nAjQLaVvjjCZwNAWP41r+JtIkCvqhQXfdYDQE2bb5Z/GiFAURxh
nYk/BEDLm2wpYP0gQMj9nsV1owRAgeQlrbr9H0DOEUy2uwIFQEX+k67biyBA
vDSKScVdBUACwu2Vob0fQGmz5tPutAVAKoq9crpVHUAWQH4EiQgGQMKLa59c
QBlAZgymBNxYBkBr1V7YlSkZQMht5d0mpgZAX9duOtRoF0A6mcUHovAGQAzc
kyCHdRZAlSeDB4A4B0B1ngsdRT0UQE1Dkz7ufQdAvRHhVBz1E0CQQGBSFcEH
QKmqe3MudRJAiC1M0xoCCECB+lHT7NQRQC5hhhMgQQhAVMGunMaQEEBGqu6p
Q34IQEw/T/svqQxA3EI/hKG5CEBju4bpqHsLQHV70zNT8whAxC+JNkiECkC+
4ugvcCsJQLQ1f34heAdAKjnT1g1iCUAD4JVh4yYAQG//PYJAlwlApUFunsnp
8j/Nqh9dGssJQGjomM12msI/2pJMb6z9CUAExg/kp+vhv0OMXYUGLwpAAKFq
9fGR7L8FBF1ON18KQIOstxEK+/u/SqAKdkyOCkDbnGUEd60CwB2LLTk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+qDT2ZjxspQN64dwvy
SOQ/9N1i6tIGJ0DfVqmFon3tPxXZBwTrUylA/AmBZtBQ8j9VqPcirnsoQIOR
BD6aO/U/BlEbzhrpJkCF+JAQAbP3P9SEPAUryCZAZ8hRwvLV+T+Nqbh2Vxcn
QFqa8FBjuPs/K15xSjFDJkCrG0W78Wf9P4CLRqLpfyVAXkJExlXu/j+blfnY
nI8lQErxjfBdKQBANlA+BrQIJUAwDFZVS80AQA8uYehGTiVAaPTEOBFlAUDa
5kHfJN0kQBxYWWJd8gFAJHSte0t3JEBfwE5WinYCQCJPykYWaiRAYf4DKbPy
AkArkXC4tfMkQLaVvjjCZwNAdx7qscnlI0CvqhQXfdYDQFk1G/PHciJAURxh
nYk/BEDWGkahijwiQMj9nsV1owRAROo0CIbWIUDOEUy2uwIFQDv1CfGcSSFA
vDSKScVdBUBrm7eJ8WYgQGmz5tPutAVAEF+FyHHJHkAWQH4EiQgGQJ9/5EM3
dx5AZgymBNxYBkBRr1gNvIgbQMht5d0mpgZAVuDDX4jlGkA6mcUHovAGQGF4
XWxrlhlAlSeDB4A4B0Abl3KQEfQYQE1Dkz7ufQdAAb7MY6ToF0CQQGBSFcEH
QJ1kYmTdFhdAiC1M0xoCCEB6hbc1BSUWQC5hhhMgQQhA4usOwxZ2E0BGqu6p
Q34IQHK655M7FRFA3EI/hKG5CEAiSoVSpn8QQHV70zNT8whATwSqIul8DkC+
4ugvcCsJQJZ9NOrCgg1AKjnT1g1iCUBPJlYpJFwIQG//PYJAlwlA4ZQ0cdW+
BEDNqh9dGssJQNHALkfUwwRA2pJMb6z9CUBUcGKOqNb7P0OMXYUGLwpACiUP
r/BCBEAFBF1ON18KQPLmGuooCf8/SqAKdkyOCkDtF8Btiyn9P/JDHmI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8NoAfwTx8pQN64dwvy
SOQ/2rmumXQUKEDfVqmFon3tP/V1QA0yrihA/AmBZtBQ8j9PfCkYW+AoQIOR
BD6aO/U/RHRIRxirJ0CF+JAQAbP3P3zkKuxD3SdAZ8hRwvLV+T/jR5sH8m0n
QFqa8FBjuPs/lXkmyXoJKECrG0W78Wf9P553SCMPZSZAXkJExlXu/j9txepP
t5gmQErxjfBdKQBA2tyASTmFJkAwDFZVS80AQC2DVI2iGCZAaPTEOBFlAUA3
ph9dhSkmQBxYWWJd8gFAIyQys1Z4JUBfwE5WinYCQC3B5TFkryRAYf4DKbPy
AkD88b9tU3UlQLaVvjjCZwNAXvbPLJeDJECvqhQXfdYDQIVC5Y4WuyNAURxh
nYk/BEAD49/TvFEjQMj9nsV1owRARPe9YAnpIkDOEUy2uwIFQIrtW02XeiJA
vDSKScVdBUAxYKm6bnAhQGmz5tPutAVAJLejXQgjIEAWQH4EiQgGQCyI7E8y
6h9AZgymBNxYBkC77b7nkCoeQMht5d0mpgZA4p5Tq3AUHUA6mcUHovAGQNlN
AfXEoRtAlSeDB4A4B0Ak5MAhPgwbQE1Dkz7ufQdA+GoPG4jqGkCQQGBSFcEH
QCz+e7yHqhlAiC1M0xoCCECsn5TnCo0YQC5hhhMgQQhAuC86al8/F0BGqu6p
Q34IQN1/DQartBRA3EI/hKG5CEDczkrrBO0TQHV70zNT8whAkdYARWNdE0C+
4ugvcCsJQFvLqlz/hhNAKjnT1g1iCUBxC67w2PMRQG//PYJAlwlAbi9ALEaN
EEDNqh9dGssJQNcL0HYZqA1A2pJMb6z9CUBIQLFvWc8OQEOMXYUGLwpAJogz
L30SDUAFBF1ON18KQEhmh/m3VwlASqAKdkyOCkDRx6Y4rSIMQIUzHgw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/j15UizRYpQN64dwvy
SOQ/dziGL735KEDfVqmFon3tP7vc/2JWlilA/AmBZtBQ8j/arLDAKTQoQIOR
BD6aO/U/GLH/DQopKUCF+JAQAbP3P0c22xdJbChAZ8hRwvLV+T8vwL9U7Okm
QFqa8FBjuPs/dgcZOkYXKECrG0W78Wf9Py8QNZ1ieidAXkJExlXu/j9w5bHA
lOkmQErxjfBdKQBAEaVIcpYKJ0AwDFZVS80AQOZTUoUMqCZAaPTEOBFlAUC/
ra14fSMnQBxYWWJd8gFA2vHVxjndJUBfwE5WinYCQNMtIPq88CVAYf4DKbPy
AkDWTI2zeX4mQLaVvjjCZwNAu/Rd3L52JUCvqhQXfdYDQPMeQV5AZyRAURxh
nYk/BEAVGfZhbsMkQMj9nsV1owRA+jIbwDcIJEDOEUy2uwIFQApTrQD+gSJA
vDSKScVdBUCwnNPULFkiQGmz5tPutAVA337dJJJaIUAWQH4EiQgGQGwLirLO
3CBAZgymBNxYBkCn0bxXVqEgQMht5d0mpgZAhAFSa6kDIEA6mcUHovAGQNaU
t6jQQx9AlSeDB4A4B0Bk1XAivGgfQE1Dkz7ufQdAOPb7QUDGHUCQQGBSFcEH
QK3x2vidbBxAiC1M0xoCCEDRLZGmktwcQC5hhhMgQQhAbgmD0xolGUBGqu6p
Q34IQCwmfJHXUhdA3EI/hKG5CEBe705Zw5UVQHV70zNT8whAnlIFhaFYFUC+
4ugvcCsJQCSqpIiDdBVAKjnT1g1iCUDJzxuxV0UTQG//PYJAlwlAKBOVzD2K
EkDNqh9dGssJQG2X2XPIsg1A2pJMb6z9CUBt/q0qgUQQQEOMXYUGLwpA+k1S
3cgKDUAFBF1ON18KQHYbjDhExA9ASqAKdkyOCkBWQuYXHxAEQDp3Ijw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8o4nXjLK8oQN64dwvy
SOQ/6J2VUVutKEDfVqmFon3tP1HKr8tpsClA/AmBZtBQ8j+lX4gYuhUpQIOR
BD6aO/U/qstQyO2wKECF+JAQAbP3Py6/ze+hDyhAZ8hRwvLV+T/bNOLDmdQn
QFqa8FBjuPs/gtxPYek7KECrG0W78Wf9P4ZmEwETRihAXkJExlXu/j+RN/7x
z3QnQErxjfBdKQBAkmlSBHrGJ0AwDFZVS80AQG2VT5bckCdAaPTEOBFlAUDA
iYwUy2gnQBxYWWJd8gFAbC7sJY6kJkBfwE5WinYCQOlZzzunRCZAYf4DKbPy
AkBKiQuwFxonQLaVvjjCZwNAkUc9nh9AJkCvqhQXfdYDQAC4GIq1WCVAURxh
nYk/BECtJu06KjclQMj9nsV1owRAMuVM2toRJEDOEUy2uwIFQLAKPV3VaiNA
vDSKScVdBUA9iaFeoJgjQGmz5tPutAVA/YiKXPNsIkAWQH4EiQgGQMJBYpou
xyFAZgymBNxYBkABxIJCKAUhQMht5d0mpgZAWRr8iTJKIUA6mcUHovAGQCFI
scL/tiBAlSeDB4A4B0Cy70Sx/WEgQE1Dkz7ufQdArtIVA3tfIECQQGBSFcEH
QPELJ4ReUR5AiC1M0xoCCEDTSQJgfGkeQC5hhhMgQQhAnnqYm/GkG0BGqu6p
Q34IQFwXcI13TBlA3EI/hKG5CEAFxZ1eDVEYQHV70zNT8whAUp57IyO4FkC+
4ugvcCsJQJ1Qp6yNQxZAKjnT1g1iCUD6J2tzrjYVQG//PYJAlwlAo+eYagKm
E0DNqh9dGssJQN6LzjFKAhFA2pJMb6z9CUDp4iJcXIYRQEOMXYUGLwpA24Se
IE1hEUAFBF1ON18KQKHyJ8HjWxFASqAKdkyOCkDoG7DpocEJQO1lICQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+TuloY1ZcnQN64dwvy
SOQ/HvzCN10TKEDfVqmFon3tP+J9A/Y05ChA/AmBZtBQ8j8aOANqpZYoQIOR
BD6aO/U/cxPnhjruKECF+JAQAbP3PweG/SGOnChAZ8hRwvLV+T8GlcYcHDAo
QFqa8FBjuPs/6tuCxI1ZKECrG0W78Wf9P8LuMvv9wChAXkJExlXu/j8xMzRe
+TgoQErxjfBdKQBAzK4TKPwdKEAwDFZVS80AQOUcxmP/5CdAaPTEOBFlAUCk
511RCP4nQBxYWWJd8gFAedJQ76clJ0BfwE5WinYCQCx9dzVi0SZAYf4DKbPy
AkB1IL2PLXcnQLaVvjjCZwNAUO6mjeiXJkCvqhQXfdYDQHXyEGq4/iVAURxh
nYk/BECAWnwIdMwlQMj9nsV1owRANyPxSJvLJEDOEUy2uwIFQJ89ZbG/DyRA
vDSKScVdBUDYjfnsnk8kQGmz5tPutAVAuN30wmlII0AWQH4EiQgGQFFZPq5R
qiJAZgymBNxYBkDKxXe0yCoiQMht5d0mpgZADgI1ndLPIUA6mcUHovAGQN4K
laZrqCFAlSeDB4A4B0DoXEIA2hwhQE1Dkz7ufQdAMhXbj1wWIUCQQGBSFcEH
QGxeEU+aXiBAiC1M0xoCCEB1QugwXVogQC5hhhMgQQhAITDh8WFoHUBGqu6p
Q34IQOqyYFNbdhtA3EI/hKG5CEAfNlZpkboZQHV70zNT8whA+3H3Yq9zGUC+
4ugvcCsJQGXBRJSBeBhAKjnT1g1iCUAAKnV+OKoXQG//PYJAlwlAIMsAIb8m
F0DNqh9dGssJQF7XpHI71RVA2pJMb6z9CUBjlBa6br0UQEOMXYUGLwpAiA7x
rQ23FEAFBF1ON18KQHGzHz0aVxRASqAKdkyOCkDO+l5z7FoQQG//INk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/dammZTvMnQN64dwvy
SOQ/OqyJSm81KEDfVqmFon3tP9qJUKgA+ChA/AmBZtBQ8j/2MNjV+ZQoQIOR
BD6aO/U/b18tUBrjKECF+JAQAbP3P9OZrvHheChAZ8hRwvLV+T8TO8p1bjYo
QFqa8FBjuPs/jiEcBsDEKECrG0W78Wf9P1Xg8gY50ChAXkJExlXu/j/IBzcT
12goQErxjfBdKQBAyXJHenwoKEAwDFZVS80AQInwyxOoCChAaPTEOBFlAUAo
yursREAoQBxYWWJd8gFA+DAhwGdsJ0BfwE5WinYCQIuXkZ6OKidAYf4DKbPy
AkBqHftkj9QnQLaVvjjCZwNAbXwAulHvJkCvqhQXfdYDQJfwDD0RQiZAURxh
nYk/BEC/jOOujPklQMj9nsV1owRAGcsy55qAJUDOEUy2uwIFQDuOzq2BuSRA
vDSKScVdBUDqcXmWOMUkQGmz5tPutAVA2P7owWPeI0AWQH4EiQgGQCVDosSd
LyNAZgymBNxYBkDN2iM//68iQMht5d0mpgZAxjSWe2ByIkA6mcUHovAGQKxh
6ZKxAiJAlSeDB4A4B0C+AcsDRsMhQE1Dkz7ufQdAylvQVhSRIUCQQGBSFcEH
QOOLwEA7XiFAiC1M0xoCCEAlDuKSG/QgQC5hhhMgQQhAkkNQu+5cH0BGqu6p
Q34IQJ/6EDXtvx1A3EI/hKG5CEDOHZARaagcQHV70zNT8whAxm5TpqfAG0C+
4ugvcCsJQEyWB81gDRpAKjnT1g1iCUCAlkeVJhUaQG//PYJAlwlAjsPVbk5Z
GEDNqh9dGssJQK4u4YG+RxhA2pJMb6z9CUCAxRBEKKYXQEOMXYUGLwpAP+Jv
YMWAF0AFBF1ON18KQOP2X8iQYhdASqAKdkyOCkDsVRn9VycVQNG4JcY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+/37W8qbMnQN64dwvy
SOQ/joIQgOBcKEDfVqmFon3tP/I0eZ0QWShA/AmBZtBQ8j/iAs0cytgoQIOR
BD6aO/U/GeAvfhyrKECF+JAQAbP3P7frWunDbyhAZ8hRwvLV+T/0iVSTrnko
QFqa8FBjuPs/QCPZan+KKECrG0W78Wf9P4tSV4Ns7ChAXkJExlXu/j8/AguW
0nsoQErxjfBdKQBA5JdUf1Z4KEAwDFZVS80AQLavfXcsLyhAaPTEOBFlAUDw
qh2bvoMoQBxYWWJd8gFAzz6KlXffJ0BfwE5WinYCQD3h4QttoSdAYf4DKbPy
AkAD0A9HersnQLaVvjjCZwNAIapOr2QjJ0CvqhQXfdYDQF3WCW+ylyZAURxh
nYk/BEAaZ0pWfTImQMj9nsV1owRA5HiKIIupJUDOEUy2uwIFQDgMuvneKCVA
vDSKScVdBUArU1AGvBolQGmz5tPutAVA7RWBUT0uJEAWQH4EiQgGQCQZrK0F
uyNAZgymBNxYBkBr+6y6pjkjQMht5d0mpgZAny3E2Vz/IkA6mcUHovAGQIEG
9r55kyJAlSeDB4A4B0Bl7BBk0g0iQE1Dkz7ufQdAckHWHbv6IUCQQGBSFcEH
QNNWouts4CFAiC1M0xoCCEBNA6tSGWkhQC5hhhMgQQhAIIcr0KhGIEBGqu6p
Q34IQIY6u0dXix9A3EI/hKG5CEBl2Q8FM1AeQHV70zNT8whA3D0uVU3+HEC+
4ugvcCsJQBwJgInq2htAKjnT1g1iCUA4OVT4O74bQG//PYJAlwlATRWXyatY
GkDNqh9dGssJQLlChxcP6BhA2pJMb6z9CUDIPb21ZU0YQEOMXYUGLwpA9mtk
ZEsHGEAFBF1ON18KQHSMMCNyKhhASqAKdkyOCkAqrxMnCrcWQLvdG5E=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.838905943113543},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Energy: \[Phi]\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.523560759066484`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.811242831518264`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {17.034386382832476`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {{}, {}, 
         {Hue[0.031746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8l9p2BGrcrwN64dwvy
SOQ/6F05+GfwKcDfVqmFon3tP/IrbpHwpSjA/AmBZtBQ8j/Gf4slECkowIOR
BD6aO/U/WLqWDWIQJ8CF+JAQAbP3P2mpdfZJLSbAZ8hRwvLV+T/ZgEkcH4sl
wFqa8FBjuPs/flxOjVYWJcCrG0W78Wf9P/zoWqWxBCTAXkJExlXu/j8dddNN
DtIkwErxjfBdKQBARrNG6gq6I8AwDFZVS80AQI45Kdfn8CPAaPTEOBFlAUDZ
uLruOIYjwBxYWWJd8gFAW45dI1m7IsBfwE5WinYCQBr+csBhASPAYf4DKbPy
AkDPlScOxCwiwLaVvjjCZwNAWvFBzQ1RIsCvqhQXfdYDQLBPK3gXhyHAURxh
nYk/BEBt+dTDmn0hwMj9nsV1owRAzNZbwFEEIcDOEUy2uwIFQL/z0fuLTSHA
vDSKScVdBUDKcmUJCK8gwGmz5tPutAVAvY7lKNdkIMAWQH4EiQgGQC0B9huA
KCDAZgymBNxYBkCqqSOxGFYgwMht5d0mpgZA4IgT1IGcH8A6mcUHovAGQI6p
rwpleB/AlSeDB4A4B0DR2y5vN2sfwE1Dkz7ufQdA9R4h47gWH8CQQGBSFcEH
QBYrt5K6/x7AiC1M0xoCCEAB9Skw7NgewC5hhhMgQQhAuLtPTxI7HsBGqu6p
Q34IQOwcWrugUB3A3EI/hKG5CECizOgz138dwHV70zNT8whA6ORcapMaHcC+
4ugvcCsJQOPsWYZa8BzAKjnT1g1iCUCpCPyVv34cwG//PYJAlwlAoG3nQ1Dy
HMDNqh9dGssJQHn0DVyuSxzA2pJMb6z9CUBL0ooMRJAawEOMXYUGLwpAhLsk
Lr/XHMAFBF1ON18KQGBoUTvcnBzASqAKdkyOCkBJIJJ3E0MdwBKbNzQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.06349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT92X1CpYpIqwN64dwvy
SOQ/ir1k4f1hKsDfVqmFon3tPxS80kUViibA/AmBZtBQ8j9SrQa/T4kowIOR
BD6aO/U/6uVm8nWjJ8CF+JAQAbP3Pyz+riExxCbAZ8hRwvLV+T+74KoGLB8m
wFqa8FBjuPs/Ds5/0sGqJcCrG0W78Wf9PxFtADA+giTAXkJExlXu/j9Ab6rq
t1olwErxjfBdKQBApxBDHHYuJMAwDFZVS80AQBj7iVt+ZyTAaPTEOBFlAUDQ
g7846/0jwBxYWWJd8gFA+vHVLZcrI8BfwE5WinYCQLxxQNLjaiPAYf4DKbPy
AkAmkUDaq5AiwLaVvjjCZwNAtARaw3irIsCvqhQXfdYDQNL2KSbh5SHAURxh
nYk/BECKqQCeD9IhwMj9nsV1owRAJPfrxcxTIcDOEUy2uwIFQM+MES+alCHA
vDSKScVdBUDHYbKhVf0gwGmz5tPutAVA8jL3WMapIMAWQH4EiQgGQLumZt1l
ZiDAZgymBNxYBkAKmu67zZMgwMht5d0mpgZAhtoBD8oNIMA6mcUHovAGQExv
il++6B/AlSeDB4A4B0DL3rAqeNkfwE1Dkz7ufQdAvyuWyvmQH8CQQGBSFcEH
QBJIS0uCRh/AiC1M0xoCCEDs7D1LRSMfwC5hhhMgQQhAk8LwYCGbHsBGqu6p
Q34IQJQ7K7hQlx3A3EI/hKG5CEB/VSHnissdwHV70zNT8whAthK6m2tYHcC+
4ugvcCsJQDymS3vfPh3AKjnT1g1iCUCUMNNKP9QcwG//PYJAlwlAblvnz7I/
HcDNqh9dGssJQPvvQ7F5ehzA2pJMb6z9CUCklsfhbswawEOMXYUGLwpA8aB6
d+k8HcAFBF1ON18KQEciMtSDgBzASqAKdkyOCkCATPy8MEodwOW/Pqk=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.09523809523809523, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9tiofuB98rwN64dwvy
SOQ/iMNg6xnCKsDfVqmFon3tPwsjW1GuOCbA/AmBZtBQ8j+S6TlUoYUowIOR
BD6aO/U/DCGfQViXKMCF+JAQAbP3P/g6uk10qSfAZ8hRwvLV+T+cdO6PzAon
wFqa8FBjuPs/bIvPdFt4JsCrG0W78Wf9P4xve4fKRyXAXkJExlXu/j/RFUs0
QwgmwErxjfBdKQBAInNG2u3SJMAwDFZVS80AQKAucvHa/iTAaPTEOBFlAUDV
DWgEZYckwBxYWWJd8gFAh2cu5vesI8BfwE5WinYCQDmDrFcn3iPAYf4DKbPy
AkA4InvbygEjwLaVvjjCZwNAk5p2OrMOI8CvqhQXfdYDQJLPoVB/PiLAURxh
nYk/BEBeA7JBbCYiwMj9nsV1owRA3s0uadypIcDOEUy2uwIFQJDxN8zo0yHA
vDSKScVdBUC++TvBPkkhwGmz5tPutAVAqZgdOhfvIMAWQH4EiQgGQEU4yedo
qSDAZgymBNxYBkD43ow3asogwMht5d0mpgZAMCa0Gx8wIMA6mcUHovAGQFdW
JiAdJiDAlSeDB4A4B0AkqyePQg8gwE1Dkz7ufQdAEpGPIOy1H8CQQGBSFcEH
QHlFQCcAqR/AiC1M0xoCCEAj5P8dj2UfwC5hhhMgQQhA+9ukYtbjHsBGqu6p
Q34IQNC76BrlyB3A3EI/hKG5CEBajua66QAewHV70zNT8whANG5N/iJ/HcC+
4ugvcCsJQPjmojb3dB3AKjnT1g1iCUASQDZZAxwdwG//PYJAlwlAYCCCtzyP
HcDNqh9dGssJQAcYP0C9wBzA2pJMb6z9CUBL/ZVJXxcbwEOMXYUGLwpAbk1f
HTQGHcAFBF1ON18KQAU8maOFax3ASqAKdkyOCkCHczI72rkdwMsqMG8=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.12698412698412698`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT97R5v0wdwvwN64dwvy
SOQ/NETPEtF4LcDfVqmFon3tP6nAFVqIjCfA/AmBZtBQ8j/QuV2BQ4IowIOR
BD6aO/U/ftJFh3Z0KcCF+JAQAbP3P4JnO4NYaijAZ8hRwvLV+T+limVcXZEn
wFqa8FBjuPs/3up4Ue0CJ8CrG0W78Wf9P8ZWqiSquyXAXkJExlXu/j/fMVHu
QWwmwErxjfBdKQBA9NAg0ucrJcAwDFZVS80AQLyLQsVGRCXAaPTEOBFlAUCB
5PVuQb8kwBxYWWJd8gFANG2gPlTmI8BfwE5WinYCQNnhbEswCyTAYf4DKbPy
AkDUBlP1vigjwLaVvjjCZwNAyxZHD843I8CvqhQXfdYDQItKgX0CXCLAURxh
nYk/BECtEn8w9EUiwMj9nsV1owRAKA+r93q+IcDOEUy2uwIFQGMk5MQk9SHA
vDSKScVdBUCcQDF4b1AhwGmz5tPutAVAxh07GXf6IMAWQH4EiQgGQHFV4iWC
wiDAZgymBNxYBkDonc3GSNIgwMht5d0mpgZAK9M+ixhcIMA6mcUHovAGQNYY
m/tVNiDAlSeDB4A4B0C5knH4QjkgwE1Dkz7ufQdAs04xZGvcH8CQQGBSFcEH
QHrf4GyFqh/AiC1M0xoCCECurqynmWEfwC5hhhMgQQhAnukHZiIAH8BGqu6p
Q34IQG6K3f5MwR3A3EI/hKG5CEBBjVp/wv0dwHV70zNT8whAGJg4abKaHcC+
4ugvcCsJQJzhih60eR3AKjnT1g1iCUCIAENjHwkdwG//PYJAlwlAnUepC2XH
HcDNqh9dGssJQDlQAdN/zxzA2pJMb6z9CUBghGTAur0awEOMXYUGLwpA6kaU
Aa4oHcAFBF1ON18KQJVvGVUSVh3ASqAKdkyOCkDIpGRQVrQdwFZQNgw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.15873015873015872`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/1pE31T/kswN64dwvy
SOQ/2Z3g8EQDK8DfVqmFon3tP0tgBmV77SbA/AmBZtBQ8j+R7MBaQgEmwIOR
BD6aO/U/JIicw6BfKMCF+JAQAbP3P5ncfiSisyfAZ8hRwvLV+T/BFAwYzOQm
wFqa8FBjuPs/dn55bydZJsCrG0W78Wf9P5l+jOknNyXAXkJExlXu/j+tYune
gvclwErxjfBdKQBAJfpOoDHKJMAwDFZVS80AQNKWYW0u5iTAaPTEOBFlAUBK
u5EU/XQkwBxYWWJd8gFABeJ9wpCcI8BfwE5WinYCQPP9ALfhzCPAYf4DKbPy
AkCV8qQ6TPIiwLaVvjjCZwNA7we6a0EFI8CvqhQXfdYDQHPfFCRKMSLAURxh
nYk/BEAxCBkdUBkiwMj9nsV1owRAS1f8E3WfIcDOEUy2uwIFQLOJ+gpr3CHA
vDSKScVdBUDNLt82KTQhwGmz5tPutAVA5Oy9GPjlIMAWQH4EiQgGQOYWhLnY
nSDAZgymBNxYBkDSoHvQhs4gwMht5d0mpgZAmk03VAIwIMA6mcUHovAGQJd9
RhsPHiDAlSeDB4A4B0DPmp6sKgQgwE1Dkz7ufQdAX5oBpSXFH8CQQGBSFcEH
QLHWMqkIeR/AiC1M0xoCCEC3m52KumYfwC5hhhMgQQhA/pkcYhXXHsBGqu6p
Q34IQHHLlnXryB3A3EI/hKG5CEAEsUqfBiMewHV70zNT8whArBl3ls+iHcC+
4ugvcCsJQC4m2rTRYx3AKjnT1g1iCUAo4bxH+eEcwG//PYJAlwlAQIz5ZiV7
HcDNqh9dGssJQHI+TOgw4RzA2pJMb6z9CUAqTwWeKd4awEOMXYUGLwpAtN4H
8TftHMAFBF1ON18KQG+OXsDGpxzASqAKdkyOCkDdy0pdknwdwJStOhM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.19047619047619047`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT90VWbVgCUswN64dwvy
SOQ/Jh+IcMkxKsDfVqmFon3tP41uI0zkPCfA/AmBZtBQ8j/xMJ104J4iwIOR
BD6aO/U//kkYfpiIJ8CF+JAQAbP3P+iUKTjqwSbAZ8hRwvLV+T8M8wmI/xEm
wFqa8FBjuPs/bedwWISQJcCrG0W78Wf9Py0lWYNkgSTAXkJExlXu/j/QBFN5
LE8lwErxjfBdKQBA+ddTpbciJMAwDFZVS80AQHELIKzhWiTAaPTEOBFlAUBQ
87KTw+8jwBxYWWJd8gFA4d2AMhskI8BfwE5WinYCQLW/yQu5WyPAYf4DKbPy
AkALog8KaIUiwLaVvjjCZwNAmed3DCmoIsCvqhQXfdYDQDoGV6y63SHAURxh
nYk/BEDOQSrVC80hwMj9nsV1owRAMvwf9yhPIcDOEUy2uwIFQIHlSknEjSHA
vDSKScVdBUBqmMFkEPIgwGmz5tPutAVATff/3QqkIMAWQH4EiQgGQHUByUGe
ZCDAZgymBNxYBkAg9cOHq5AgwMht5d0mpgZAgRZ+9lQDIMA6mcUHovAGQCop
xGKm0R/AlSeDB4A4B0C4Gzh4F9AfwE1Dkz7ufQdA0CMfNQxaH8CQQGBSFcEH
QIsWoUieLh/AiC1M0xoCCEBpN7C7ui8fwC5hhhMgQQhA0+kVMCiLHsBGqu6p
Q34IQPAvODrHlB3A3EI/hKG5CEANMrw7btwdwHV70zNT8whAa1GRzBttHcC+
4ugvcCsJQGu7amdZOB3AKjnT1g1iCUAbGEbRXtwcwG//PYJAlwlAt0l6OpZh
HcDNqh9dGssJQP/yHAu2jRzA2pJMb6z9CUDE3rccbs4awEOMXYUGLwpAawIJ
PP0qHcAFBF1ON18KQIKaeJqh0hzASqAKdkyOCkAX5nP6YgsdwMOGMKQ=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2222222222222222, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8w37Y/oIsqwN64dwvy
SOQ/F07UsArVKMDfVqmFon3tP+Qd5W+0mSTA/AmBZtBQ8j9GR8lZu6QfwIOR
BD6aO/U/O6ggBjD5JsCF+JAQAbP3P72Mx3V/PSbAZ8hRwvLV+T8myuRZaZ8l
wFqa8FBjuPs/BVK0WeopJcCrG0W78Wf9Pykxzgf2CiTAXkJExlXu/j9KXPXh
kOIkwErxjfBdKQBApg4Dv6C1I8AwDFZVS80AQK9HX+gW9iPAaPTEOBFlAUAp
CAuQFokjwBxYWWJd8gFA5HyDDjS/IsBfwE5WinYCQA6NHrbDBiPAYf4DKbPy
AkBCev72+jYiwLaVvjjCZwNAczwR3PZiIsCvqhQXfdYDQJiUORe6lCHAURxh
nYk/BEDwOrq/uYYhwMj9nsV1owRAhLTY86kJIcDOEUy2uwIFQJgfwkHUSyHA
vDSKScVdBUAKh/yqr7wgwGmz5tPutAVA1fJLdnhxIMAWQH4EiQgGQIwVREYv
LyDAZgymBNxYBkCeYcIN51ggwMht5d0mpgZAOYSUv/SuH8A6mcUHovAGQGTh
w+L1fR/AlSeDB4A4B0Au33Zs1XIfwE1Dkz7ufQdA/o9XKC4hH8CQQGBSFcEH
QJeSXs5U9B7AiC1M0xoCCEBFR2a77dkewC5hhhMgQQhAZv5kV1lHHsBGqu6p
Q34IQHuDoHe3VR3A3EI/hKG5CEDUCZq5rIodwHV70zNT8whAkr7AvwMYHcC+
4ugvcCsJQHv8QNYD+RzAKjnT1g1iCUDwG5Xb+nkcwG//PYJAlwlAJCrhpSoT
HcDNqh9dGssJQPaXuCW4URzA2pJMb6z9CUCb0ZhyH7kawEOMXYUGLwpAJvpI
6y/HHMAFBF1ON18KQF0O/m1xjRzASqAKdkyOCkCvoKVEFS4dwKKdOpc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.25396825396825395`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9Dq9O0590pwN64dwvy
SOQ/nAv3tKomKsDfVqmFon3tP+H+m2KmdSTA/AmBZtBQ8j84wDGyXzgawIOR
BD6aO/U/FdfXQugBJ8CF+JAQAbP3P1gD/P0CQSbAZ8hRwvLV+T/vLuQ4YJ8l
wFqa8FBjuPs/lj23y1gtJcCrG0W78Wf9PxWHid1zFCTAXkJExlXu/j+mbI9I
/OEkwErxjfBdKQBAFBiQ6Em8I8AwDFZVS80AQIt46der+iPAaPTEOBFlAUAG
BkkRW5QjwBxYWWJd8gFABIymDXTMIsBfwE5WinYCQHjF8ypwCiPAYf4DKbPy
AkCn5SRfRzkiwLaVvjjCZwNAPKOfGHtcIsCvqhQXfdYDQIHcBv5ykyHAURxh
nYk/BEAV35frS4shwMj9nsV1owRAKgndPjYPIcDOEUy2uwIFQGzi7z+jUyHA
vDSKScVdBUDGF+efhrwgwGmz5tPutAVAFG9Jr79qIMAWQH4EiQgGQBa/8W8n
MSDAZgymBNxYBkC4MI5GZF0gwMht5d0mpgZAIQ+LsQmzH8A6mcUHovAGQB03
SH/LjB/AlSeDB4A4B0AJQpAgGX0fwE1Dkz7ufQdAqWg0WZ8mH8CQQGBSFcEH
QKFYgzlbAx/AiC1M0xoCCEBgWOZpreIewC5hhhMgQQhAAZS6RpxJHsBGqu6p
Q34IQEBPPH/bZR3A3EI/hKG5CEAfbTJkxo0dwHV70zNT8whAvZp8Xz4cHcC+
4ugvcCsJQEYfDaBa/BzAKjnT1g1iCUAeae9AyoYcwG//PYJAlwlAvTGNao4S
HcDNqh9dGssJQKHiiFt+bRzA2pJMb6z9CUDW3vvguZ8awEOMXYUGLwpAyqa0
IkG7HMAFBF1ON18KQABe4JoDjxzASqAKdkyOCkCn988Zf0cdwG2WMWw=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.2857142857142857, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/f2y38nW8rwN64dwvy
SOQ/6sp0kOYUKsDfVqmFon3tPwZvyb1lTCfA/AmBZtBQ8j/UEhZUQcsXwIOR
BD6aO/U/JaeaAwMYKMCF+JAQAbP3P76U9b6IRifAZ8hRwvLV+T96lD+OEZ0m
wFqa8FBjuPs/yP7hBDX+JcCrG0W78Wf9P7ErOG0E6iTAXkJExlXu/j/6sgex
c7IlwErxjfBdKQBAm8TqH7mAJMAwDFZVS80AQM93WhgdsSTAaPTEOBFlAUDr
QWVF3z4kwBxYWWJd8gFAUDCTRvxsI8BfwE5WinYCQPHZH7JKpCPAYf4DKbPy
AkA1MLe/680iwLaVvjjCZwNAH2gzCRnhIsCvqhQXfdYDQGMWoIRTEiLAURxh
nYk/BECXS/JGtv4hwMj9nsV1owRAkZMnIC99IcDOEUy2uwIFQEnCLKXduCHA
vDSKScVdBUA0eU+HehshwGmz5tPutAVA+GG4iLbQIMAWQH4EiQgGQJRacbaV
iSDAZgymBNxYBkCBgVflarIgwMht5d0mpgZAepJHsZgzIMA6mcUHovAGQLyu
W5fmCiDAlSeDB4A4B0BDCrAi0AwgwE1Dkz7ufQdAjjVfrp+0H8CQQGBSFcEH
QLc5l29eSx/AiC1M0xoCCEAZREPGzCkfwC5hhhMgQQhA71PakOGyHsBGqu6p
Q34IQN49FCdgvB3A3EI/hKG5CED/QcLdItQdwHV70zNT8whAfS6Phl6SHcC+
4ugvcCsJQNL7QmvYfh3AKjnT1g1iCUDig2EecfQcwG//PYJAlwlAnly7L3WQ
HcDNqh9dGssJQNPKKDmmbBzA2pJMb6z9CUCMY3dT9/cawEOMXYUGLwpAsDB4
XPAIHcAFBF1ON18KQEkbaPltGB3ASqAKdkyOCkAd9MGFfxQdwHhoN+Q=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.31746031746031744`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8S+MVuRw4uwN64dwvy
SOQ/V+VyzfRuKsDfVqmFon3tP/fz94NuuinA/AmBZtBQ8j9ul1g+18wWwIOR
BD6aO/U/VL0BkguNKcCF+JAQAbP3Pwd0U0D8lSjAZ8hRwvLV+T8rcZqBV6In
wFqa8FBjuPs/8WqTOPX4JsCrG0W78Wf9P+qFA37uuSXAXkJExlXu/j8DlS1P
kGgmwErxjfBdKQBASHv+6usyJcAwDFZVS80AQPNsN57RQCXAaPTEOBFlAUAo
sf5J8L0kwBxYWWJd8gFAUHxs333gI8BfwE5WinYCQDkP8AoJCCTAYf4DKbPy
AkC4RKjmVyAjwLaVvjjCZwNAJstpwro4I8CvqhQXfdYDQFbp4gotZCLAURxh
nYk/BEBUwUd+4kkiwMj9nsV1owRADwKkqLa+IcDOEUy2uwIFQOpL1n6t9CHA
vDSKScVdBUCW3wHEi2QhwGmz5tPutAVAjqR7tZALIcAWQH4EiQgGQMq8u0AN
vCDAZgymBNxYBkCysdHhStkgwMht5d0mpgZAd7s9l55KIMA6mcUHovAGQCek
wX+lIyDAlSeDB4A4B0DmbEDUvTEgwE1Dkz7ufQdA2A1DfC3CH8CQQGBSFcEH
QMGwGklntR/AiC1M0xoCCEAy+pOxxHcfwC5hhhMgQQhAaDTzvJH7HsBGqu6p
Q34IQCxXGHEZyB3A3EI/hKG5CEB0KWeMdA0ewHV70zNT8whA8XI4RAh/HcC+
4ugvcCsJQA1hLy2veR3AKjnT1g1iCUDNRnMm2gQdwG//PYJAlwlAALK4HBhQ
HcDNqh9dGssJQCAUJCv/xhzA2pJMb6z9CUAiF4UfwPwawEOMXYUGLwpAD04q
ka5qHcAFBF1ON18KQIDIuAGlTx3ASqAKdkyOCkCNyt2Eq70dwHG3N2I=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.3492063492063492, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9gMCRZ5rUSwN64dwvy
SOQ/DTFCtZYJB8DfVqmFon3tP+EH/DjHhyXA/AmBZtBQ8j/hqNi1MZkMwIOR
BD6aO/U/1zE43Z/EJ8CF+JAQAbP3PxVSzOnPLyfAZ8hRwvLV+T9925eN0mQm
wFqa8FBjuPs/BcXcVN/vJcCrG0W78Wf9P2X+MthhyiTAXkJExlXu/j+1LHhz
J5glwErxjfBdKQBAeUjSfTlsJMAwDFZVS80AQEsyTjw/pCTAaPTEOBFlAUD4
uae1szEkwBxYWWJd8gFA0yW/gzRfI8BfwE5WinYCQK+KAVZ5lCPAYf4DKbPy
AkAQ6Q0aPL0iwLaVvjjCZwNA51nNHg/WIsCvqhQXfdYDQGmiR0KBBiLAURxh
nYk/BECUCT0A4vQhwMj9nsV1owRAiX+ilbVxIcDOEUy2uwIFQIdJ3T8ztyHA
vDSKScVdBUDGOhYCRxchwGmz5tPutAVAdd7ieCzHIMAWQH4EiQgGQLNHG50p
gSDAZgymBNxYBkBi4baz+qwgwMht5d0mpgZAHYuJ9R4bIMA6mcUHovAGQPnh
ihw9AiDAlSeDB4A4B0B8szs2SeUfwE1Dkz7ufQdA5oUEhlN+H8CQQGBSFcEH
QCMxNxrLah/AiC1M0xoCCEB11iC3aUQfwC5hhhMgQQhAeVdCCMCYHsBGqu6p
Q34IQN7d5G8Esx3A3EI/hKG5CEBkbExwYusdwHV70zNT8whAQOz2pZRnHcC+
4ugvcCsJQK97qaP9RR3AKjnT1g1iCUDmByrrK9EcwG//PYJAlwlA7ve+z8NR
HcDNqh9dGssJQNEgOJdkihzA2pJMb6z9CUDClvLK6dYawEOMXYUGLwpAe/av
4y9hHcAFBF1ON18KQOKX5ANvtBzASqAKdkyOCkCvBWlExl8dwJKpONc=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.38095238095238093`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT++OUKxMFoYQN64dwvy
SOQ/S/uLFZPWHkDfVqmFon3tP8FQRI9sFfk//AmBZtBQ8j/xe/Y8mCPzP4OR
BD6aO/U/qQ8+foK7EcCF+JAQAbP3P4kEEXgIoxbAZ8hRwvLV+T8Ct2f9jGQk
wFqa8FBjuPs/DSYysEvaJMCrG0W78Wf9P632uzkD7iPAXkJExlXu/j9xk9DU
q9QkwErxjfBdKQBANGG81CeqI8AwDFZVS80AQIewruEa6SPAaPTEOBFlAUDx
YKg7oJgjwBxYWWJd8gFAJiiSbV7IIsBfwE5WinYCQLxP5O7UBCPAYf4DKbPy
AkAcnxXmpz0iwLaVvjjCZwNA/lFB8MRWIsCvqhQXfdYDQE8T/xTrhSHAURxh
nYk/BEDzamSGU4YhwMj9nsV1owRAb0xWYZYBIcDOEUy2uwIFQOvshsH3UCHA
vDSKScVdBUBNCHnTsrggwGmz5tPutAVAxVFHBk1sIMAWQH4EiQgGQAt3BR1+
LiDAZgymBNxYBkArM1nQsF4gwMht5d0mpgZAnBJLxRSpH8A6mcUHovAGQN3W
FdGMdx/AlSeDB4A4B0DiMNDojnIfwE1Dkz7ufQdA+iR1rYErH8CQQGBSFcEH
QHS/+4/C+R7AiC1M0xoCCEC7yLgz39wewC5hhhMgQQhAoaw7KBJRHsBGqu6p
Q34IQNM/PXsaUx3A3EI/hKG5CEAJfMclf3MdwHV70zNT8whAiCjnrdswHcC+
4ugvcCsJQMqCr311CR3AKjnT1g1iCUAsjGFYN1ccwG//PYJAlwlAFFB7Qxhd
HcDNqh9dGssJQDmYimBighzA2pJMb6z9CUDMK5K/tJYawEOMXYUGLwpAreTr
jLOzHMAFBF1ON18KQOfjEbXT1xzASqAKdkyOCkDCM2/CkAEdwDv4Nns=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4126984126984127, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8W/cVi6N8oQN64dwvy
SOQ/fGL5PRvJKkDfVqmFon3tPwAXopxyeCpA/AmBZtBQ8j+XslHcya0pQIOR
BD6aO/U/lHIPZM2PKUCF+JAQAbP3PzXP+SGqVilAZ8hRwvLV+T/39A8Ee7Mo
QFqa8FBjuPs/yTgd8Q0AKECrG0W78Wf9P1Yx6RZjGiZAXkJExlXu/j9lWdhN
yJAjQErxjfBdKQBAxmUK0J/xIUAwDFZVS80AQBegSfwSFSJAaPTEOBFlAUAq
g+pGx9ghQBxYWWJd8gFAI6pXsarVIEBfwE5WinYCQKNdpel8KyBAYf4DKbPy
AkBTZYzprn0eQLaVvjjCZwNA0j0CHMnNHECvqhQXfdYDQK9YWoc6sBpAURxh
nYk/BEAOME1LgJYYQMj9nsV1owRAGGy/F4OkFkDOEUy2uwIFQGVENtx65BRA
vDSKScVdBUDQOnXe1Z8SQGmz5tPutAVAQ4NQ2FUqEEAWQH4EiQgGQG+obfaa
7gxAZgymBNxYBkBkm3ac7cIJQMht5d0mpgZAo0YX7FIRBkA6mcUHovAGQJdw
7pSZOgNAlSeDB4A4B0CS1nKd7toAQE1Dkz7ufQdAzrnfxVc9/z+QQGBSFcEH
QA4jp+tqNfk/iC1M0xoCCECclLwEo9r2Py5hhhMgQQhAen9KPEvV6j9Gqu6p
Q34IQBeD353yc9Y/3EI/hKG5CECV9h8uf9/Rv3V70zNT8whA42LB90f+4L++
4ugvcCsJQAiVTX8O8vG/KjnT1g1iCUDzyu9E584BwG//PYJAlwlAMvsmH4TB
BMDNqh9dGssJQKhgMKyZqQTA2pJMb6z9CUC5IUQZPV8BwEOMXYUGLwpAcv8X
1M4yCcAFBF1ON18KQLGTWiJyaADASqAKdkyOCkDjxxmlke4AwOT/MIM=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.4444444444444444, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8XhKWZMMEqQN64dwvy
SOQ/GU/D+168KEDfVqmFon3tP/7ERNATvSlA/AmBZtBQ8j8JDZ9MlawnQIOR
BD6aO/U/XQjd1/8AJkCF+JAQAbP3P2ZPH4rBvydAZ8hRwvLV+T9usEITYhwo
QFqa8FBjuPs/3bxlKNyiKUCrG0W78Wf9P/VfXjMSfChAXkJExlXu/j+0nM++
kYQnQErxjfBdKQBAgxZI17jUJkAwDFZVS80AQB8EGj8vOyZAaPTEOBFlAUBF
Nm9U0RolQBxYWWJd8gFAZLgUFpOwI0BfwE5WinYCQKpSTWdyoSNAYf4DKbPy
AkCEB064L/ciQLaVvjjCZwNA9fxYM3/UIUCvqhQXfdYDQGVLPpm5hSFAURxh
nYk/BECVN/MJ6S4hQMj9nsV1owRANrYu5BotIEDOEUy2uwIFQLKNbEopQR5A
vDSKScVdBUBWm3sdYpgcQGmz5tPutAVAOWNTgE+QGUAWQH4EiQgGQOwAHTWP
3xZAZgymBNxYBkCCCtLn6iAUQMht5d0mpgZAV4uq3UuUE0A6mcUHovAGQOTt
GRJHNxNAlSeDB4A4B0AwfYLiF+8RQE1Dkz7ufQdAWNbeXkyKD0CQQGBSFcEH
QI1CsqAuxglAiC1M0xoCCEA57A4sROADQC5hhhMgQQhAWdRg6JIGAEBGqu6p
Q34IQJI4bmdhW/8/3EI/hKG5CEBR20bEQA38P3V70zNT8whANtlKo53d9T++
4ugvcCsJQPUKU5G4CABAKjnT1g1iCUCH0QPZH5P2P2//PYJAlwlALNBQDPWc
6z/Nqh9dGssJQGJQ1ld+s+U/2pJMb6z9CUCdvSwMhPHjv0OMXYUGLwpAGDST
D24fAMAFBF1ON18KQErhLCfH8eu/SqAKdkyOCkDdtw1+tn/vv/zrIos=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.47619047619047616`, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT/L5U4u7G8lQN64dwvy
SOQ/OvYlCFOaKEDfVqmFon3tP9qORpFEUyhA/AmBZtBQ8j+i1UxxikIoQIOR
BD6aO/U/6VkOPEi6KUCF+JAQAbP3P8iBRDNpLShAZ8hRwvLV+T/Q9gfmnFgo
QFqa8FBjuPs/O66p+oC8KECrG0W78Wf9PylLTRg8nChAXkJExlXu/j8n5WEq
tfgmQErxjfBdKQBAsl09MzgPJ0AwDFZVS80AQPtlzG9wiCZAaPTEOBFlAUD9
Sqc31ncmQBxYWWJd8gFAegSRvEFHJUBfwE5WinYCQC45UEv++iRAYf4DKbPy
AkDUanQDJ+8jQLaVvjjCZwNAFeJGGpkqJECvqhQXfdYDQLmYVR/4uCJAURxh
nYk/BEDrKUIogGciQMj9nsV1owRAaIFnw9xQIUDOEUy2uwIFQN6oiF/3VSFA
vDSKScVdBUDLL0fUJyggQGmz5tPutAVAi1Tc8mHyHkAWQH4EiQgGQBkiBkxk
IB5AZgymBNxYBkDLtA8ZYRkdQMht5d0mpgZAzYQmxBMUG0A6mcUHovAGQBwx
GJO8gxlAlSeDB4A4B0DWSgpovzMYQE1Dkz7ufQdA3bva6FOCFkCQQGBSFcEH
QHfeUtsy6hRAiC1M0xoCCEBf+j/RLZ4UQC5hhhMgQQhAfp7+yOljEkBGqu6p
Q34IQPkBcWGwGRJA3EI/hKG5CED9nV36cqgRQHV70zNT8whAwC5Gm48XCkC+
4ugvcCsJQLLamt1wWwZAKjnT1g1iCUBoToF8uiYGQG//PYJAlwlA8voZTRnZ
AUDNqh9dGssJQEG7QV9JnANA2pJMb6z9CUBGIAdMnB38P0OMXYUGLwpA7PMa
X7Odrz8FBF1ON18KQM2iBVD9LdE/SqAKdkyOCkDz931IZf7qP+gWIWo=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5079365079365079, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9PSxUcPtcmQN64dwvy
SOQ/cW1EOwhtJ0DfVqmFon3tP1TxhurYECxA/AmBZtBQ8j9Vi7xE/qwoQIOR
BD6aO/U/6zR0Jf8iKkCF+JAQAbP3P1yezojTMClAZ8hRwvLV+T/aw76yedko
QFqa8FBjuPs/xrGSimbKKUCrG0W78Wf9P61rNrdLtSlAXkJExlXu/j86Tzsp
fEEpQErxjfBdKQBAWK8IQb4PKEAwDFZVS80AQPbc2y64dSdAaPTEOBFlAUBn
IBN01t4mQBxYWWJd8gFA7+sN5APGJkBfwE5WinYCQICeyGmxSSZAYf4DKbPy
AkBc9DiVvjAmQLaVvjjCZwNAmQlPZmxhJUCvqhQXfdYDQJBMVP0nIyZAURxh
nYk/BEC64wjyvQglQMj9nsV1owRAXd2tcM+mJEDOEUy2uwIFQNhDG6ErEyRA
vDSKScVdBUArBU9kLM0jQGmz5tPutAVAemnOJUlVI0AWQH4EiQgGQID2qqDh
jyFAZgymBNxYBkDfRKl+4hoiQMht5d0mpgZALC6nID/xIUA6mcUHovAGQAom
8QUlDyFAlSeDB4A4B0Du7YJ5NcgfQE1Dkz7ufQdAutjQjMMMIUCQQGBSFcEH
QOyk/Q5qsh9AiC1M0xoCCEAkaBwZHR4eQC5hhhMgQQhARnpeZoUzHkBGqu6p
Q34IQBkc//3TUxpA3EI/hKG5CEAvmVfPqaYXQHV70zNT8whAPUNY3qmTFEC+
4ugvcCsJQM90VZV7yRRAKjnT1g1iCUDnagpClREVQG//PYJAlwlA5VA/eEXC
EkDNqh9dGssJQJIBc+PdlRRA2pJMb6z9CUDtDrGqAMkTQEOMXYUGLwpAjwLI
v/BYEUAFBF1ON18KQDi/AJI/aRNASqAKdkyOCkAO405AEoQUQKsSHeE=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5396825396825397, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9BQvX3fREpQN64dwvy
SOQ/sz4wcjZgKkDfVqmFon3tP497kwpYBCpA/AmBZtBQ8j9GYVJJlfQpQIOR
BD6aO/U/hnNYpL3PKUCF+JAQAbP3P8WdU3njGCpAZ8hRwvLV+T+bIrrNfYEq
QFqa8FBjuPs/rKuTMGrnKUCrG0W78Wf9P9qsAxNxDSlAXkJExlXu/j8gZwLY
Gn8pQErxjfBdKQBAfkEeQoPWKEAwDFZVS80AQOCPJwMp5ydAaPTEOBFlAUDe
TOqGljcoQBxYWWJd8gFAxfnPW9j7J0BfwE5WinYCQGhFR6c0ZidAYf4DKbPy
AkDrzm42UoQmQLaVvjjCZwNAXuv8GWYOJ0CvqhQXfdYDQOJrFbEzGSZAURxh
nYk/BEDZGBNTfscmQMj9nsV1owRAM/SPWaDcJUDOEUy2uwIFQGLa5ECariVA
vDSKScVdBUBrRMPu7ZolQGmz5tPutAVAO3unuB9+JEAWQH4EiQgGQAdKCSCK
QiNAZgymBNxYBkBS1I4XQdMiQMht5d0mpgZAVJGDSBiSIkA6mcUHovAGQChL
frFdRyJAlSeDB4A4B0BuncUskPEiQE1Dkz7ufQdA4SciG5tyIkCQQGBSFcEH
QNzTnIAOsSBAiC1M0xoCCEBHIvwgT68gQC5hhhMgQQhAauIsxOVDHUBGqu6p
Q34IQCQZJmCz+BtA3EI/hKG5CEBjqFgWsN4XQHV70zNT8whAcaLqI4fNFkC+
4ugvcCsJQGhcRZNjyBZAKjnT1g1iCUC3/4Zcl7oWQG//PYJAlwlABKBZbZEo
FUDNqh9dGssJQIwNEWfQghRA2pJMb6z9CUC9Fnx5DMkRQEOMXYUGLwpAk5zr
YGlfFEAFBF1ON18KQOnUotHRXhVASqAKdkyOCkDeNcifeYgUQIBaHtA=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.5714285714285714, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT8qFznPRKArQN64dwvy
SOQ/KanfByN5KkDfVqmFon3tPyB9I0El4ypA/AmBZtBQ8j84yBHuHIwqQIOR
BD6aO/U/uCYBusxAKkCF+JAQAbP3P6COy0hZGSpAZ8hRwvLV+T8AHEDtnWkq
QFqa8FBjuPs/+LNichrrKUCrG0W78Wf9P2vgsynJ0ilAXkJExlXu/j+W7RgS
7JEpQErxjfBdKQBAIp15K0deKUAwDFZVS80AQCKkXKNK8ihAaPTEOBFlAUAY
ofvZ6l0oQBxYWWJd8gFAJw/PkXWRKEBfwE5WinYCQCiLIs1/GihAYf4DKbPy
AkCBL4MEUuMnQLaVvjjCZwNAyegJWBROJ0CvqhQXfdYDQJQj+/yx9yZAURxh
nYk/BEA8AqEibM0mQMj9nsV1owRAXGfD27RQJkDOEUy2uwIFQKYabND8PyZA
vDSKScVdBUBzaNEUzWAlQGmz5tPutAVAAHGo6jN6JUAWQH4EiQgGQHrBgKrr
5SRAZgymBNxYBkBrFtIK3TAkQMht5d0mpgZArUxS5CjnI0A6mcUHovAGQCU0
uPkWGSNAlSeDB4A4B0AdBakVLLgiQE1Dkz7ufQdA6hDxqK3uIkCQQGBSFcEH
QEN217xCXiJAiC1M0xoCCEC8oMRd60chQC5hhhMgQQhAcrSB3lEPH0BGqu6p
Q34IQHMe3BjtZx1A3EI/hKG5CED5T64rfeYbQHV70zNT8whAFIjqdmoxGkC+
4ugvcCsJQHbjOeRd0BlAKjnT1g1iCUAXW0ZNsJsXQG//PYJAlwlA+lVJHikj
F0DNqh9dGssJQNjPF9VE9hVA2pJMb6z9CUB75vP+F+4TQEOMXYUGLwpAeGDT
D/rIE0AFBF1ON18KQGASgMCT5BRASqAKdkyOCkBbOsie024UQDnoIJI=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6031746031746031, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+HzoBa+LcpQN64dwvy
SOQ/H7zjgYY6KkDfVqmFon3tP0V5baKtUypA/AmBZtBQ8j+FskbF0h4qQIOR
BD6aO/U/+kJFnE0QKkCF+JAQAbP3PyaNK46fXypAZ8hRwvLV+T/0zKU30QUq
QFqa8FBjuPs/sX8EDMT5KUCrG0W78Wf9PwQ9+oci7ClAXkJExlXu/j8EZwng
/9ApQErxjfBdKQBA91keb4ysKUAwDFZVS80AQM4b6hYz9yhAaPTEOBFlAUDd
10hvFuUoQBxYWWJd8gFAa/uuaaN1KEBfwE5WinYCQID0C6stiihAYf4DKbPy
AkCgiSml5gwoQLaVvjjCZwNAfrC0XHa1J0CvqhQXfdYDQNzW58JGqCdAURxh
nYk/BEDHMhN663cnQMj9nsV1owRACDcNb5s3J0DOEUy2uwIFQN02THqZ5iZA
vDSKScVdBUCQEFPdnbAmQGmz5tPutAVACk/AVPngJUAWQH4EiQgGQOHxXdRZ
zSVAZgymBNxYBkAYi/fB4IAlQMht5d0mpgZAeDOK626wJEA6mcUHovAGQFA5
54RBSSRAlSeDB4A4B0A/W0n8P8sjQE1Dkz7ufQdA46tujf//I0CQQGBSFcEH
QDNuaxxSpSNAiC1M0xoCCEByTVlbNPgiQC5hhhMgQQhANkHyzll1IUBGqu6p
Q34IQJV/WWOb/CBA3EI/hKG5CEC8Ax172S8gQHV70zNT8whAlQkuGGN0HkC+
4ugvcCsJQBxq6SgpTB1AKjnT1g1iCUB9djGErhwcQG//PYJAlwlAr1e1ZCrl
GUDNqh9dGssJQIRgDkVV/hlA2pJMb6z9CUD0J2POcRsYQEOMXYUGLwpAp89h
0iUKF0AFBF1ON18KQK//cXt1RhlASqAKdkyOCkCMbHAdYn4YQETyIpY=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6349206349206349, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT9i4h0unzEqQN64dwvy
SOQ/267Qlp97KkDfVqmFon3tPyXaNzUoQypA/AmBZtBQ8j/V4dAdavEpQIOR
BD6aO/U/gmt3cJGiKUCF+JAQAbP3P4UpAuJOiClAZ8hRwvLV+T/esBlv6Lgo
QFqa8FBjuPs/nz4qcQfvKUCrG0W78Wf9P17m5GPVSilAXkJExlXu/j+rOadR
JzopQErxjfBdKQBAnDCeeAANKUAwDFZVS80AQITJZTlFzChAaPTEOBFlAUCT
+vAtHh4pQBxYWWJd8gFAJR2/kwzQKEBfwE5WinYCQESWCJyqwShAYf4DKbPy
AkBDHKdFds0oQLaVvjjCZwNA1BDNuxR9KECvqhQXfdYDQLvlVQgptidAURxh
nYk/BEAEqimwGTcnQMj9nsV1owRAZFGJ+2NQJ0DOEUy2uwIFQJhd8Un27yZA
vDSKScVdBUAlLKO9ErkmQGmz5tPutAVAU2PJRNkDJkAWQH4EiQgGQAxU8nbK
8iVAZgymBNxYBkDjw6HX1GIlQMht5d0mpgZA69W2a8UtJUA6mcUHovAGQH6A
j/uEgyRAlSeDB4A4B0CJ8opDwyckQE1Dkz7ufQdATSh/sDy8JECQQGBSFcEH
QFqjQES3nCNAiC1M0xoCCEAnsTTX4QYjQC5hhhMgQQhAC+wwy64fIkBGqu6p
Q34IQJzArcEClyFA3EI/hKG5CEDF7HFTT4kgQHV70zNT8whAD4naHnclH0C+
4ugvcCsJQOuS/dYmxx1AKjnT1g1iCUCKEbqF0HEcQG//PYJAlwlAWJpB+ou1
G0DNqh9dGssJQHr8Gsl0RBpA2pJMb6z9CUBpnp445qIZQEOMXYUGLwpAdi3X
d5QqF0AFBF1ON18KQMbGPjl9bBhASqAKdkyOCkAfu9biu98XQPGbJDU=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
         {Hue[0.6666666666666666, 1, 1], PointSize[0.012833333333333334`], 
          AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBwQI+/SFib1JlAgAAACsAAAACAAAAv3O8Gn49zT+Wk7qy4dYoQN64dwvy
SOQ/YWZT5EE7KEDfVqmFon3tP/ZkExW0DylA/AmBZtBQ8j/MB73lM28pQIOR
BD6aO/U/75s0IhUzKUCF+JAQAbP3P12/LC2dLSlAZ8hRwvLV+T/sm62nSZ0o
QFqa8FBjuPs/cj1+wHTjKECrG0W78Wf9P7Zrp8SSGSlAXkJExlXu/j+8/AEr
FCopQErxjfBdKQBAG/n7JE7AKEAwDFZVS80AQK9ZTdXtoihAaPTEOBFlAUAp
L3mw9c8oQBxYWWJd8gFAkARuOo4NKUBfwE5WinYCQIg9o4yn9ChAYf4DKbPy
AkDZuCYLvYUoQLaVvjjCZwNAjKcKo04mKECvqhQXfdYDQIc7wUws1SdAURxh
nYk/BEDkQoWJXacnQMj9nsV1owRApFSBpqqtJ0DOEUy2uwIFQP51NLgIbCdA
vDSKScVdBUCE/RUfr+AmQGmz5tPutAVALb/esHpvJkAWQH4EiQgGQHql/qUx
PCZAZgymBNxYBkC9F7a8o6wlQMht5d0mpgZAu0p64wh9JUA6mcUHovAGQOeX
/X7XMSVAlSeDB4A4B0DTnqkX7+UkQE1Dkz7ufQdAFJ7e+Ba6JECQQGBSFcEH
QKreuCBXjyRAiC1M0xoCCEBgRiYyy70jQC5hhhMgQQhAYHf9N+JqIkBGqu6p
Q34IQEdYwBIfByJA3EI/hKG5CEC+oHu1cuEhQHV70zNT8whAoYJx3Wm5IEC+
4ugvcCsJQKqmvCV68R9AKjnT1g1iCUAhKSLmudQdQG//PYJAlwlADzzGuTW6
G0DNqh9dGssJQApCQj0f2xtA2pJMb6z9CUDoXr0KthMcQEOMXYUGLwpAkLTC
NDM2GkAFBF1ON18KQEkXFzQZ6xpASqAKdkyOCkD3RKDdTL8YQL0kI70=
           "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0.09920984278980781, -6.918818032593451},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Exp[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotLabel->FormBox["\"Energy: \[Chi]\"", TraditionalForm],
      PlotRange->All,
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledTicks[{Log, Exp}]}, {{{0.6931471805599453, 
           FormBox["2", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
           FormBox["5", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox["10", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {2.995732273553991, 
           FormBox["20", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {0.4054651081081644, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.791759469228055, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.70805020110221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {3.912023005428146, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.0943445622221, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.248495242049359, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.382026634673881, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.499809670330265, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.0106352940962555`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {5.298317366548036, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}, {{-9.210340371976182, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {0., 
           FormBox["1", TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {9.210340371976184, 
           FormBox[
            
            TemplateBox[{"10", "4"}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {2.302585092994046, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {4.605170185988092, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {6.907755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->500,
  PlotLabel->FormBox["\"Run 0\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.7174485209153194`*^9},ExpressionUUID->"743442cf-d7ee-4348-b541-\
62fdb59e084f"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 150, 3, 101, "Title", "ExpressionUUID" -> \
"647ae26a-0dfd-4da5-9dec-e031ea6f6415"],
Cell[720, 27, 312, 8, 49, "Text", "ExpressionUUID" -> \
"640a50f2-602b-4e60-918a-dc10b0712773"],
Cell[1035, 37, 190, 3, 30, "Text", "ExpressionUUID" -> \
"92a70921-2b96-45c9-ab5e-c2fd9df0fb0e"],
Cell[1228, 42, 206, 4, 30, "Input", "ExpressionUUID" -> \
"ff631b0f-5c88-4747-8849-2106354cba40"],
Cell[CellGroupData[{
Cell[1459, 50, 195, 5, 70, "Section", "ExpressionUUID" -> \
"f6388f7c-32e9-4027-a88a-9cb9ca3112da"],
Cell[1657, 57, 243, 5, 30, "Text", "ExpressionUUID" -> \
"a11f6c1f-d9df-4210-8ae3-482ec5295260"],
Cell[1903, 64, 189, 3, 30, "Text", "ExpressionUUID" -> \
"4a2226d2-1f00-403c-b1f2-07a8632f8e50"],
Cell[2095, 69, 320, 8, 30, "Input", "ExpressionUUID" -> \
"ce530a0c-cdd3-451e-9d9e-68661d11a4c3"],
Cell[2418, 79, 365, 9, 87, "Text", "ExpressionUUID" -> \
"9df98c66-da92-4bd4-a460-62d7067e867a"],
Cell[2786, 90, 1056, 29, 88, "Input", "ExpressionUUID" -> \
"455df81f-858a-46a4-970b-7d4dbc4742b3"],
Cell[3845, 121, 585, 8, 68, "Text", "ExpressionUUID" -> \
"b97756e8-b54c-4a9c-82fc-958cb0382575"],
Cell[4433, 131, 165, 4, 30, "Input", "ExpressionUUID" -> \
"11367dc8-0d41-4b1d-8d23-12e2c9d26249"],
Cell[4601, 137, 656, 11, 125, "Text", "ExpressionUUID" -> \
"d3f0a529-3981-4da3-8802-e2e886131cb8"],
Cell[5260, 150, 1637, 43, 107, "Input", "ExpressionUUID" -> \
"703ff8f5-efb2-4dfa-9b2c-0fb9c7ff4a5d"]
}, Closed]],
Cell[CellGroupData[{
Cell[6934, 198, 157, 3, 56, "Section", "ExpressionUUID" -> \
"d1ffe392-1495-4f30-b8ea-d93a51dd6529"],
Cell[7094, 203, 116, 0, 30, "Text", "ExpressionUUID" -> \
"c38a4233-03c0-4297-a19d-8d4e21baf914"],
Cell[CellGroupData[{
Cell[7235, 207, 1113, 30, 107, "Input", "ExpressionUUID" -> \
"20954f38-80a4-406e-a851-1e63061d85d3"],
Cell[8351, 239, 245, 3, 30, "Output", "ExpressionUUID" -> \
"cc223350-5cc4-402a-9490-30e6d172faa6"]
}, Open  ]],
Cell[8611, 245, 1108, 28, 107, "Input", "ExpressionUUID" -> \
"55dd7ff1-d5ce-47d8-bebb-0fe8084e65a7"],
Cell[9722, 275, 179, 3, 30, "Text", "ExpressionUUID" -> \
"242e76a5-d1f1-4660-8214-dd6a2188d0b6"],
Cell[9904, 280, 773, 21, 69, "Input", "ExpressionUUID" -> \
"4e83951c-fb68-44a2-888e-ab33bbdd6244"],
Cell[10680, 303, 150, 2, 30, "Text", "ExpressionUUID" -> \
"b07fa990-61c0-4fa0-bd42-a65e7ef5f768"],
Cell[10833, 307, 1371, 36, 107, "Input", "ExpressionUUID" -> \
"043a5482-e018-46ae-aa33-f0650c7f80bb"],
Cell[12207, 345, 303, 4, 30, "Text", "ExpressionUUID" -> \
"ef71382c-8d12-4330-92dc-079ec68a92a7"],
Cell[12513, 351, 1097, 31, 69, "Input", "ExpressionUUID" -> \
"5de2389b-5465-4b83-a9b2-12e1e8e210ed"],
Cell[13613, 384, 100, 0, 30, "Text", "ExpressionUUID" -> \
"5a16e1d9-f2f9-497a-9b5c-6ea379ab8d92"],
Cell[13716, 386, 16073, 390, 582, "Input", "ExpressionUUID" -> \
"ba40603a-7f5c-4686-8ce6-78cafde98795"]
}, Closed]],
Cell[CellGroupData[{
Cell[29826, 781, 180, 3, 56, "Section", "ExpressionUUID" -> \
"77e9d301-cd92-4d0a-8936-850c8d80f4d3"],
Cell[30009, 786, 180, 3, 30, "Text", "ExpressionUUID" -> \
"22bbbac7-b571-4557-bcf3-8eb86678bbe1"],
Cell[CellGroupData[{
Cell[30214, 793, 9318, 225, 411, "Input", "ExpressionUUID" -> \
"9e54e3bf-a0e4-4950-bbaf-3715e4184040"],
Cell[CellGroupData[{
Cell[39557, 1022, 8245, 197, 209, "Print", "ExpressionUUID" -> \
"efbc3cd5-2ff1-4f87-bceb-d5391efc5eda"],
Cell[47805, 1221, 7098, 169, 209, "Print", "ExpressionUUID" -> \
"3ff89116-6888-4b6e-ac8f-3690891e5236"],
Cell[54906, 1392, 8925, 211, 209, "Print", "ExpressionUUID" -> \
"e6ae89eb-23e6-4ee9-9679-2bcdf4c464ea"],
Cell[63834, 1605, 2351, 55, 209, "Print", "ExpressionUUID" -> \
"504797a6-84a8-40ac-80e9-9455d0ee1c5b"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[66246, 1667, 191, 3, 56, "Section", "ExpressionUUID" -> \
"0db4247c-1cc5-4632-b580-98086167c67e"],
Cell[66440, 1672, 320, 7, 30, "Text", "ExpressionUUID" -> \
"3a15c55b-8a0c-408e-87c1-4cba742064f7"],
Cell[CellGroupData[{
Cell[66785, 1683, 12493, 279, 720, "Input", "ExpressionUUID" -> \
"3af5fb35-91fb-49d1-9629-3f50ad376e83"],
Cell[CellGroupData[{
Cell[79303, 1966, 155, 3, 22, "Print", "ExpressionUUID" -> \
"d35c166d-08e6-47f8-a37b-0a842b4fa933"],
Cell[79461, 1971, 111741, 2597, 441, "Print", "ExpressionUUID" -> \
"e701f3e7-32ba-42e7-a9c2-5bb2805a16db"],
Cell[191205, 4570, 153, 3, 22, "Print", "ExpressionUUID" -> \
"dd4d8d79-a539-4a88-b625-fcd62e77ac1f"],
Cell[191361, 4575, 108407, 2514, 441, "Print", "ExpressionUUID" -> \
"cde033c3-587f-4ce5-a54f-be5e0e3b9fde"],
Cell[299771, 7091, 155, 3, 22, "Print", "ExpressionUUID" -> \
"af5d6983-63d3-406f-94bd-80eeff7a2746"],
Cell[299929, 7096, 100815, 2332, 441, "Print", "ExpressionUUID" -> \
"1467eded-c9bb-466c-82d4-00f0c859b32c"],
Cell[400747, 9430, 153, 3, 22, "Print", "ExpressionUUID" -> \
"ca6c7c17-c460-4f2c-9a31-c4574a10613c"],
Cell[400903, 9435, 106094, 2458, 441, "Print", "ExpressionUUID" -> \
"d0d518e5-1e76-4de9-b4b5-e3b8bb215fcd"],
Cell[507000, 11895, 153, 3, 22, "Print", "ExpressionUUID" -> \
"3def9cd5-69ce-4305-9ed5-68b063db6f85"],
Cell[507156, 11900, 103813, 2406, 441, "Print", "ExpressionUUID" -> \
"fe48b464-f719-4098-bd5e-dc1f79a02ba3"],
Cell[610972, 14308, 153, 3, 22, "Print", "ExpressionUUID" -> \
"79a9ff64-34fb-41bb-be65-d5ec2eaecbdf"],
Cell[611128, 14313, 108916, 2527, 441, "Print", "ExpressionUUID" -> \
"d582313f-e8e0-4654-8d0d-3dd8cde8c259"],
Cell[720047, 16842, 155, 3, 22, "Print", "ExpressionUUID" -> \
"2462c9e3-85db-4b76-be3c-b276b99a7d86"],
Cell[720205, 16847, 108772, 2529, 441, "Print", "ExpressionUUID" -> \
"87c85fa6-25c1-4ed9-978f-2bad0254ba9f"],
Cell[828980, 19378, 155, 3, 22, "Print", "ExpressionUUID" -> \
"53a172ee-57d2-4aef-9b10-0f39792636f6"],
Cell[829138, 19383, 108568, 2520, 441, "Print", "ExpressionUUID" -> \
"c3be1222-db0d-4471-b3d9-41c9ddee4996"],
Cell[937709, 21905, 153, 3, 22, "Print", "ExpressionUUID" -> \
"05aa7e69-417e-468d-9092-04d272a2dd0a"],
Cell[937865, 21910, 107360, 2493, 441, "Print", "ExpressionUUID" -> \
"3439620c-efd0-42e1-b857-81d206c8cd74"],
Cell[1045228, 24405, 156, 3, 22, "Print", "ExpressionUUID" -> \
"5328a584-daea-489a-b47c-2fb22aa265f4"],
Cell[1045387, 24410, 117033, 2723, 441, "Print", "ExpressionUUID" -> \
"a6c57d61-8648-4723-9b5f-74d9b51e2e4f"],
Cell[1162423, 27135, 154, 3, 22, "Print", "ExpressionUUID" -> \
"8233fbbf-0ad2-430a-93a2-62eb3dda633b"],
Cell[1162580, 27140, 124935, 2917, 441, "Print", "ExpressionUUID" -> \
"ce06005d-8378-4709-a6fc-66eea090639a"],
Cell[1287518, 30059, 154, 3, 22, "Print", "ExpressionUUID" -> \
"e025549d-ab49-4e83-b0b4-f7719577fc53"],
Cell[1287675, 30064, 77990, 1795, 441, "Print", "ExpressionUUID" -> \
"31263d13-3b44-40db-8e66-2204e75f05e8"],
Cell[1365668, 31861, 156, 3, 22, "Print", "ExpressionUUID" -> \
"52b99aa8-8a6e-4f10-9f22-069ad2ed92ed"],
Cell[1365827, 31866, 73763, 1691, 441, "Print", "ExpressionUUID" -> \
"40fd334f-4d9a-43a0-9257-a41ed98cbdb6"],
Cell[1439593, 33559, 156, 3, 22, "Print", "ExpressionUUID" -> \
"1fa36350-7ca8-41d2-8099-0060fc1e578c"],
Cell[1439752, 33564, 72661, 1666, 441, "Print", "ExpressionUUID" -> \
"d5bdd27d-4273-47bc-af2d-18d0074f4f16"],
Cell[1512416, 35232, 156, 3, 22, "Print", "ExpressionUUID" -> \
"f83c42a6-9a71-4c21-a957-ae42387db3f6"],
Cell[1512575, 35237, 94232, 2183, 441, "Print", "ExpressionUUID" -> \
"a1382b4d-1202-4e63-abca-166d4d5aa8eb"],
Cell[1606810, 37422, 154, 3, 22, "Print", "ExpressionUUID" -> \
"3027954f-3d3e-4224-b418-1edcd9687c60"],
Cell[1606967, 37427, 117683, 2747, 441, "Print", "ExpressionUUID" -> \
"58acf29a-10ab-4f5c-a62e-819791800261"],
Cell[1724653, 40176, 154, 3, 22, "Print", "ExpressionUUID" -> \
"28b69bc9-99aa-405b-a081-c34c026f5d37"],
Cell[1724810, 40181, 117687, 2747, 441, "Print", "ExpressionUUID" -> \
"736cfa48-a404-452f-ae84-f00f03dfb081"],
Cell[1842500, 42930, 156, 3, 22, "Print", "ExpressionUUID" -> \
"65a25a64-22e8-4040-ad00-fd38e96d1f3b"],
Cell[1842659, 42935, 117680, 2747, 441, "Print", "ExpressionUUID" -> \
"4f29b0be-560b-4db4-8f7a-07a05e021a3c"],
Cell[1960342, 45684, 154, 3, 22, "Print", "ExpressionUUID" -> \
"a5393048-4b67-4860-b49e-91fef1e74c76"],
Cell[1960499, 45689, 111797, 2604, 441, "Print", "ExpressionUUID" -> \
"524dd56d-232e-4e96-b9ee-eeef3325a3df"],
Cell[2072299, 48295, 156, 3, 22, "Print", "ExpressionUUID" -> \
"8bf9d0c6-8c8f-4b77-b033-74963eaec831"],
Cell[2072458, 48300, 113326, 2643, 441, "Print", "ExpressionUUID" -> \
"4d3d4c6e-9526-485d-b780-6a9f55620ae1"],
Cell[2185787, 50945, 154, 3, 22, "Print", "ExpressionUUID" -> \
"6ea29a49-d75f-4d43-8627-6c71043d48ba"],
Cell[2185944, 50950, 107219, 2496, 441, "Print", "ExpressionUUID" -> \
"ca318413-1d62-4ab1-9975-f2a3e0f55bf1"]
}, Open  ]]
}, Open  ]],
Cell[2293190, 53450, 116, 0, 30, "Text", "ExpressionUUID" -> \
"3e1e796f-4847-4949-8a32-e72c3c9d9f43"],
Cell[CellGroupData[{
Cell[2293331, 53454, 4395, 105, 202, "Input", "ExpressionUUID" -> \
"2b84c568-0e54-4a9e-b070-7101f193963f"],
Cell[2297729, 53561, 84929, 1651, 187, "Print", "ExpressionUUID" -> \
"59be8b09-6642-4738-b68f-f7c684f3c872"]
}, Open  ]],
Cell[2382673, 55215, 127, 0, 30, "Text", "ExpressionUUID" -> \
"e9b1c171-ede6-4e00-9373-7ab2d93f7ca4"],
Cell[CellGroupData[{
Cell[2382825, 55219, 3861, 92, 202, "Input", "ExpressionUUID" -> \
"2296c541-62e1-47cb-b2a0-13c40e5d42c0"],
Cell[2386689, 55313, 62751, 1148, 187, "Print", "ExpressionUUID" -> \
"e330b64e-7a23-4b50-bd18-903f18f070c6"]
}, Open  ]],
Cell[2449455, 56464, 125, 0, 30, "Text", "ExpressionUUID" -> \
"39fb4dda-a944-4dee-945e-463fb6bd931b"],
Cell[CellGroupData[{
Cell[2449605, 56468, 5210, 126, 221, "Input", "ExpressionUUID" -> \
"5b3e7c40-a66e-4c69-831c-c8ab136d8f44"],
Cell[2454818, 56596, 99986, 2010, 187, "Print", "ExpressionUUID" -> \
"e039d370-54a7-46a4-bd13-aea5984ade92"]
}, Open  ]],
Cell[2554819, 58609, 125, 0, 30, "Text", "ExpressionUUID" -> \
"b2713133-0de4-4882-8fac-2895652ca46f"],
Cell[CellGroupData[{
Cell[2554969, 58613, 4166, 101, 202, "Input", "ExpressionUUID" -> \
"d057cf37-128d-4091-9ea1-c4d45636ec61"],
Cell[2559138, 58716, 83418, 1617, 187, "Print", "ExpressionUUID" -> \
"743442cf-d7ee-4348-b541-62fdb59e084f"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

